# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/issue_id.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/core/yq/libs/config/protos/issue_id.proto\x12\x03NYq\"\x83\x02\n\nTIssuesIds\"\xf4\x01\n\nEIssueCode\x12\x11\n\rDEFAULT_ERROR\x10\x00\x12\x0e\n\nUNEXPECTED\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\x12\n\rACCESS_DENIED\x10\xe8\x07\x12\x13\n\x0eINTERNAL_ERROR\x10\xe9\x07\x12\x0c\n\x07TIMEOUT\x10\xea\x07\x12\x10\n\x0b\x42\x41\x44_REQUEST\x10\xeb\x07\x12\x0c\n\x07\x45XPIRED\x10\xec\x07\x12\x10\n\x0bUNSUPPORTED\x10\xed\x07\x12\x11\n\x0cUNAUTHORIZED\x10\xee\x07\x12\x0e\n\tNOT_READY\x10\xef\x07\x12\x13\n\x0eQUOTA_EXCEEDED\x10\xf0\x07\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.issue_id_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TISSUESIDS._serialized_start=55
  _TISSUESIDS._serialized_end=314
  _TISSUESIDS_EISSUECODE._serialized_start=70
  _TISSUESIDS_EISSUECODE._serialized_end=314
# @@protoc_insertion_point(module_scope)
