# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/msgbus_health.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ydb/core/protos/msgbus_health.proto\x12\rNKikimrClient\";\n\x0eTHealthRequest\x12\x19\n\x11\x44\x65\x61\x64lineInstantMs\x18\x01 \x01(\x04\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x04\"^\n\x0fTHealthResponse\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x16\n\rProtobufError\x18\x90\x03 \x01(\x0c\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x04\x12\x13\n\x0b\x45rrorReason\x18\x03 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.msgbus_health_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _THEALTHREQUEST._serialized_start=54
  _THEALTHREQUEST._serialized_end=113
  _THEALTHRESPONSE._serialized_start=115
  _THEALTHRESPONSE._serialized_end=209
# @@protoc_insertion_point(module_scope)
