# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/change_exchange.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/change_exchange.proto\x12\x15NKikimrChangeExchange\x1a\x1bgoogle/protobuf/empty.proto\"\xaa\x06\n\rTChangeRecord\x12\r\n\x05Order\x18\x01 \x01(\x04\x12\r\n\x05Group\x18\x02 \x01(\x04\x12\x0c\n\x04Step\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\x12\x13\n\x0bPathOwnerId\x18\x05 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x06 \x01(\x04\x12\x46\n\nAsyncIndex\x18\x07 \x01(\x0b\x32\x30.NKikimrChangeExchange.TChangeRecord.TDataChangeH\x00\x12I\n\rCdcDataChange\x18\x08 \x01(\x0b\x32\x30.NKikimrChangeExchange.TChangeRecord.TDataChangeH\x00\x1a\x99\x04\n\x0bTDataChange\x12N\n\x03Key\x18\x01 \x01(\x0b\x32\x41.NKikimrChangeExchange.TChangeRecord.TDataChange.TSerializedCells\x12S\n\x08OldImage\x18\x02 \x01(\x0b\x32\x41.NKikimrChangeExchange.TChangeRecord.TDataChange.TSerializedCells\x12S\n\x08NewImage\x18\x03 \x01(\x0b\x32\x41.NKikimrChangeExchange.TChangeRecord.TDataChange.TSerializedCells\x12S\n\x06Upsert\x18\x04 \x01(\x0b\x32\x41.NKikimrChangeExchange.TChangeRecord.TDataChange.TSerializedCellsH\x00\x12\'\n\x05\x45rase\x18\x05 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12R\n\x05Reset\x18\x06 \x01(\x0b\x32\x41.NKikimrChangeExchange.TChangeRecord.TDataChange.TSerializedCellsH\x00\x1a.\n\x10TSerializedCells\x12\x0c\n\x04Tags\x18\x01 \x03(\r\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x42\x0e\n\x0cRowOperationB\x06\n\x04Kind\"2\n\x0cTEvHandshake\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"l\n\x0fTEvApplyRecords\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x35\n\x07Records\x18\x03 \x03(\x0b\x32$.NKikimrChangeExchange.TChangeRecord\"\x95\x05\n\tTEvStatus\x12\x38\n\x06Status\x18\x01 \x01(\x0e\x32(.NKikimrChangeExchange.TEvStatus.EStatus\x12\x38\n\x06Reason\x18\x02 \x01(\x0e\x32(.NKikimrChangeExchange.TEvStatus.EReason\x12\x46\n\x0eRecordStatuses\x18\x03 \x03(\x0b\x32..NKikimrChangeExchange.TEvStatus.TRecordStatus\x12\x17\n\x0fLastRecordOrder\x18\x04 \x01(\x04\x1a\x92\x01\n\rTRecordStatus\x12\r\n\x05Order\x18\x01 \x01(\x04\x12\x38\n\x06Status\x18\x02 \x01(\x0e\x32(.NKikimrChangeExchange.TEvStatus.EStatus\x12\x38\n\x06Reason\x18\x03 \x01(\x0e\x32(.NKikimrChangeExchange.TEvStatus.EReason\"?\n\x07\x45Status\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\r\n\tSTATUS_OK\x10\x01\x12\x11\n\rSTATUS_REJECT\x10\x02\"\xdc\x01\n\x07\x45Reason\x12\x0f\n\x0bREASON_NONE\x10\x00\x12\x19\n\x15REASON_UNKNOWN_ORIGIN\x10\x01\x12\x17\n\x13REASON_STALE_ORIGIN\x10\x02\x12\x1a\n\x16REASON_ORDER_VIOLATION\x10\x03\x12\x1a\n\x16REASON_UNEXPECTED_KIND\x10\x04\x12#\n\x1fREASON_UNEXPECTED_ROW_OPERATION\x10\x05\x12\x17\n\x13REASON_SCHEME_ERROR\x10\x06\x12\x16\n\x12REASON_WRONG_STATE\x10\x07\"#\n\x11TEvActivateSender\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\"&\n\x14TEvActivateSenderAck\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.change_exchange_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TCHANGERECORD._serialized_start=94
  _TCHANGERECORD._serialized_end=904
  _TCHANGERECORD_TDATACHANGE._serialized_start=359
  _TCHANGERECORD_TDATACHANGE._serialized_end=896
  _TCHANGERECORD_TDATACHANGE_TSERIALIZEDCELLS._serialized_start=834
  _TCHANGERECORD_TDATACHANGE_TSERIALIZEDCELLS._serialized_end=880
  _TEVHANDSHAKE._serialized_start=906
  _TEVHANDSHAKE._serialized_end=956
  _TEVAPPLYRECORDS._serialized_start=958
  _TEVAPPLYRECORDS._serialized_end=1066
  _TEVSTATUS._serialized_start=1069
  _TEVSTATUS._serialized_end=1730
  _TEVSTATUS_TRECORDSTATUS._serialized_start=1296
  _TEVSTATUS_TRECORDSTATUS._serialized_end=1442
  _TEVSTATUS_ESTATUS._serialized_start=1444
  _TEVSTATUS_ESTATUS._serialized_end=1507
  _TEVSTATUS_EREASON._serialized_start=1510
  _TEVSTATUS_EREASON._serialized_end=1730
  _TEVACTIVATESENDER._serialized_start=1732
  _TEVACTIVATESENDER._serialized_end=1767
  _TEVACTIVATESENDERACK._serialized_start=1769
  _TEVACTIVATESENDERACK._serialized_end=1807
# @@protoc_insertion_point(module_scope)
