# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/ydb_persqueue_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_scheme_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__scheme__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos.annotations import validation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_annotations_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/public/api/protos/ydb_persqueue_v1.proto\x12\x10Ydb.PersQueue.V1\x1a)ydb/public/api/protos/ydb_operation.proto\x1a&ydb/public/api/protos/ydb_scheme.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a\x32ydb/public/api/protos/annotations/validation.proto\"p\n\tMetaValue\x12\x35\n\x05value\x18\x01 \x03(\x0b\x32&.Ydb.PersQueue.V1.MetaValue.ValueEntry\x1a,\n\nValueEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"8\n\x0cOffsetsRange\x12\x14\n\x0cstart_offset\x18\x01 \x01(\x03\x12\x12\n\nend_offset\x18\x02 \x01(\x03\"#\n\x12UpdateTokenRequest\x12\r\n\x05token\x18\x01 \x01(\t\"\x15\n\x13UpdateTokenResponse\"\xbd\x07\n\x1bStreamingWriteClientMessage\x12Q\n\x0cinit_request\x18\x01 \x01(\x0b\x32\x39.Ydb.PersQueue.V1.StreamingWriteClientMessage.InitRequestH\x00\x12S\n\rwrite_request\x18\x02 \x01(\x0b\x32:.Ydb.PersQueue.V1.StreamingWriteClientMessage.WriteRequestH\x00\x12\x44\n\x14update_token_request\x18\x03 \x01(\x0b\x32$.Ydb.PersQueue.V1.UpdateTokenRequestH\x00\x1a\x8c\x03\n\x0bInitRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x18\n\x10message_group_id\x18\x02 \x01(\t\x12`\n\x0csession_meta\x18\x03 \x03(\x0b\x32J.Ydb.PersQueue.V1.StreamingWriteClientMessage.InitRequest.SessionMetaEntry\x12\x1a\n\x12partition_group_id\x18\x04 \x01(\x03\x12$\n\x1cmax_supported_format_version\x18\x05 \x01(\x03\x12\x12\n\nsession_id\x18\x64 \x01(\t\x12\x1a\n\x12\x63onnection_attempt\x18\x65 \x01(\x03\x12\x17\n\x0f\x63onnection_meta\x18\x66 \x01(\x0c\x12\x19\n\x11preferred_cluster\x18g \x01(\t\x12\x18\n\x0fidle_timeout_ms\x18\xc8\x01 \x01(\x03\x1a\x32\n\x10SessionMetaEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x8e\x02\n\x0cWriteRequest\x12\x18\n\x10sequence_numbers\x18\x02 \x03(\x03\x12\x15\n\rcreated_at_ms\x18\x03 \x03(\x03\x12\x12\n\nsent_at_ms\x18\x04 \x03(\x03\x12\x15\n\rmessage_sizes\x18\x05 \x03(\x03\x12\x16\n\x0e\x62locks_offsets\x18\x06 \x03(\x03\x12\x1b\n\x13\x62locks_part_numbers\x18\x07 \x03(\x03\x12\x1d\n\x15\x62locks_message_counts\x18\x08 \x03(\x03\x12!\n\x19\x62locks_uncompressed_sizes\x18\t \x03(\x03\x12\x16\n\x0e\x62locks_headers\x18\n \x03(\x0c\x12\x13\n\x0b\x62locks_data\x18\x0b \x03(\x0c\x42\x10\n\x0e\x63lient_message\"\x94\x08\n\x1bStreamingWriteServerMessage\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12S\n\rinit_response\x18\x03 \x01(\x0b\x32:.Ydb.PersQueue.V1.StreamingWriteServerMessage.InitResponseH\x00\x12`\n\x14\x62\x61tch_write_response\x18\x04 \x01(\x0b\x32@.Ydb.PersQueue.V1.StreamingWriteServerMessage.BatchWriteResponseH\x00\x12\x46\n\x15update_token_response\x18\x05 \x01(\x0b\x32%.Ydb.PersQueue.V1.UpdateTokenResponseH\x00\x1a\x97\x02\n\x0cInitResponse\x12\x1c\n\x14last_sequence_number\x18\x01 \x01(\x03\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\t\x12\x0f\n\x07\x63luster\x18\x04 \x01(\t\x12\x14\n\x0cpartition_id\x18\x05 \x01(\x03\x12\x1c\n\x14\x62lock_format_version\x18\x06 \x01(\x03\x12\x31\n\x10supported_codecs\x18\n \x03(\x0e\x32\x17.Ydb.PersQueue.V1.Codec\x12\x1d\n\x15max_flush_window_size\x18\x07 \x01(\x03\x12\x16\n\x0emax_block_size\x18\x08 \x01(\x03\x12\x17\n\x0f\x63onnection_meta\x18\t \x01(\x0c\x1a\xc7\x01\n\x12\x42\x61tchWriteResponse\x12\x18\n\x10sequence_numbers\x18\x01 \x03(\x03\x12\x0f\n\x07offsets\x18\x02 \x03(\x03\x12\x17\n\x0f\x61lready_written\x18\x03 \x03(\x08\x12\x14\n\x0cpartition_id\x18\x04 \x01(\x03\x12W\n\x10write_statistics\x18\x05 \x01(\x0b\x32=.Ydb.PersQueue.V1.StreamingWriteServerMessage.WriteStatistics\x1a\xab\x01\n\x0fWriteStatistics\x12\x1b\n\x13persist_duration_ms\x18\x01 \x01(\x03\x12\'\n\x1fqueued_in_partition_duration_ms\x18\x02 \x01(\x03\x12*\n\"throttled_on_partition_duration_ms\x18\x03 \x01(\x03\x12&\n\x1ethrottled_on_topic_duration_ms\x18\x04 \x01(\x03\x42\x10\n\x0eserver_message\"\x14\n\x04Path\x12\x0c\n\x04path\x18\x01 \x01(\t\"&\n\x08KeyValue\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"D\n\nReadParams\x12\x1f\n\x17max_read_messages_count\x18\x01 \x01(\r\x12\x15\n\rmax_read_size\x18\x02 \x01(\r\";\n\x0c\x43ommitCookie\x12\x11\n\tassign_id\x18\x01 \x01(\x04\x12\x18\n\x10partition_cookie\x18\x02 \x01(\x04\"P\n\x11\x43ommitOffsetRange\x12\x11\n\tassign_id\x18\x01 \x01(\x04\x12\x14\n\x0cstart_offset\x18\x02 \x01(\x04\x12\x12\n\nend_offset\x18\x03 \x01(\x04\"\x9b\x01\n\x10PartitionSession\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x12\x1a\n\x12partition_group_id\x18\x04 \x01(\x03\x12\x1c\n\x14partition_session_id\x18\x06 \x01(\x03\x12\x17\n\x0f\x63onnection_meta\x18\x07 \x01(\x0c\"\xf6\x16\n\x1aStreamingReadClientMessage\x12P\n\x0cinit_request\x18\x01 \x01(\x0b\x32\x38.Ydb.PersQueue.V1.StreamingReadClientMessage.InitRequestH\x00\x12P\n\x0cread_request\x18\x02 \x01(\x0b\x32\x38.Ydb.PersQueue.V1.StreamingReadClientMessage.ReadRequestH\x00\x12v\n start_partition_session_response\x18\x03 \x01(\x0b\x32J.Ydb.PersQueue.V1.StreamingReadClientMessage.StartPartitionSessionResponseH\x00\x12T\n\x0e\x63ommit_request\x18\x04 \x01(\x0b\x32:.Ydb.PersQueue.V1.StreamingReadClientMessage.CommitRequestH\x00\x12t\n\x1fstop_partition_session_response\x18\x05 \x01(\x0b\x32I.Ydb.PersQueue.V1.StreamingReadClientMessage.StopPartitionSessionResponseH\x00\x12[\n\x12pause_read_request\x18\x06 \x01(\x0b\x32=.Ydb.PersQueue.V1.StreamingReadClientMessage.PauseReadRequestH\x00\x12]\n\x13resume_read_request\x18\x07 \x01(\x0b\x32>.Ydb.PersQueue.V1.StreamingReadClientMessage.ResumeReadRequestH\x00\x12v\n partition_session_status_request\x18\x08 \x01(\x0b\x32J.Ydb.PersQueue.V1.StreamingReadClientMessage.PartitionSessionStatusRequestH\x00\x12Y\n\x11\x61\x64\x64_topic_request\x18\t \x01(\x0b\x32<.Ydb.PersQueue.V1.StreamingReadClientMessage.AddTopicRequestH\x00\x12_\n\x14remove_topic_request\x18\n \x01(\x0b\x32?.Ydb.PersQueue.V1.StreamingReadClientMessage.RemoveTopicRequestH\x00\x12\x44\n\x14update_token_request\x18\x0b \x01(\x0b\x32$.Ydb.PersQueue.V1.UpdateTokenRequestH\x00\x1a\xa1\x07\n\x0bInitRequest\x12\\\n\x14topics_read_settings\x18\x01 \x03(\x0b\x32>.Ydb.PersQueue.V1.StreamingReadClientMessage.TopicReadSettings\x12\x1a\n\x12read_only_original\x18\x02 \x01(\x08\x12\x10\n\x08\x63onsumer\x18\x03 \x01(\t\x12\x1b\n\x13max_lag_duration_ms\x18\x04 \x01(\x03\x12 \n\x18start_from_written_at_ms\x18\x05 \x01(\x03\x12$\n\x1cmax_supported_format_version\x18\x06 \x01(\x03\x12\x1b\n\x13max_meta_cache_size\x18\n \x01(\x03\x12\x12\n\nsession_id\x18\x64 \x01(\t\x12\x1a\n\x12\x63onnection_attempt\x18\x65 \x01(\x03\x12M\n\x05state\x18\x66 \x01(\x0b\x32>.Ydb.PersQueue.V1.StreamingReadClientMessage.InitRequest.State\x12\x18\n\x0fidle_timeout_ms\x18\xc8\x01 \x01(\x03\x1a\xea\x03\n\x05State\x12w\n\x19partition_sessions_states\x18\x01 \x03(\x0b\x32T.Ydb.PersQueue.V1.StreamingReadClientMessage.InitRequest.State.PartitionSessionState\x1a\xe7\x02\n\x15PartitionSessionState\x12=\n\x11partition_session\x18\x01 \x01(\x0b\x32\".Ydb.PersQueue.V1.PartitionSession\x12\x13\n\x0bread_offset\x18\x02 \x01(\x03\x12\x36\n\x0eoffsets_ranges\x18\x03 \x03(\x0b\x32\x1e.Ydb.PersQueue.V1.OffsetsRange\x12k\n\x06status\x18\x04 \x01(\x0e\x32[.Ydb.PersQueue.V1.StreamingReadClientMessage.InitRequest.State.PartitionSessionState.Status\"U\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\x0c\n\x08STOPPING\x10\x02\x12\x0b\n\x07READING\x10\x03\x12\n\n\x06PAUSED\x10\x04\x1a\x30\n\x0bReadRequest\x12!\n\x19request_uncompressed_size\x18\x01 \x01(\x03\x1a\x85\x01\n\x1dStartPartitionSessionResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x13\n\x0bread_offset\x18\x02 \x01(\x03\x12\x15\n\rcommit_offset\x18\x03 \x01(\x03\x12\x1a\n\x12verify_read_offset\x18\x04 \x01(\x08\x1a<\n\x1cStopPartitionSessionResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x1a\x31\n\x10PauseReadRequest\x12\x1d\n\x15partition_session_ids\x18\x01 \x03(\x03\x1a`\n\x11ResumeReadRequest\x12\x1d\n\x15partition_session_ids\x18\x01 \x03(\x03\x12\x14\n\x0cread_offsets\x18\x02 \x03(\x03\x12\x16\n\x0eresume_cookies\x18\x03 \x03(\x03\x1a^\n\rCommitRequest\x12M\n\x07\x63ommits\x18\x01 \x03(\x0b\x32<.Ydb.PersQueue.V1.StreamingReadClientMessage.PartitionCommit\x1a=\n\x1dPartitionSessionStatusRequest\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x1an\n\x0f\x41\x64\x64TopicRequest\x12[\n\x13topic_read_settings\x18\x01 \x01(\x0b\x32>.Ydb.PersQueue.V1.StreamingReadClientMessage.TopicReadSettings\x1a#\n\x12RemoveTopicRequest\x12\r\n\x05topic\x18\x01 \x01(\t\x1a\x61\n\x11TopicReadSettings\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x1b\n\x13partition_group_ids\x18\x02 \x03(\x03\x12 \n\x18start_from_written_at_ms\x18\x03 \x01(\x03\x1a`\n\x0fPartitionCommit\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12/\n\x07offsets\x18\x02 \x03(\x0b\x32\x1e.Ydb.PersQueue.V1.OffsetsRangeB\x10\n\x0e\x63lient_message\"\xac\x16\n\x1aStreamingReadServerMessage\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12R\n\rinit_response\x18\x03 \x01(\x0b\x32\x39.Ydb.PersQueue.V1.StreamingReadServerMessage.InitResponseH\x00\x12R\n\rread_response\x18\x04 \x01(\x0b\x32\x39.Ydb.PersQueue.V1.StreamingReadServerMessage.ReadResponseH\x00\x12t\n\x1fstart_partition_session_request\x18\x06 \x01(\x0b\x32I.Ydb.PersQueue.V1.StreamingReadServerMessage.StartPartitionSessionRequestH\x00\x12r\n\x1estop_partition_session_request\x18\x07 \x01(\x0b\x32H.Ydb.PersQueue.V1.StreamingReadServerMessage.StopPartitionSessionRequestH\x00\x12V\n\x0f\x63ommit_response\x18\x08 \x01(\x0b\x32;.Ydb.PersQueue.V1.StreamingReadServerMessage.CommitResponseH\x00\x12x\n!partition_session_status_response\x18\t \x01(\x0b\x32K.Ydb.PersQueue.V1.StreamingReadServerMessage.PartitionSessionStatusResponseH\x00\x12]\n\x13pause_read_response\x18\n \x01(\x0b\x32>.Ydb.PersQueue.V1.StreamingReadServerMessage.PauseReadResponseH\x00\x12_\n\x14resume_read_response\x18\x0b \x01(\x0b\x32?.Ydb.PersQueue.V1.StreamingReadServerMessage.ResumeReadResponseH\x00\x12[\n\x12\x61\x64\x64_topic_response\x18\x0c \x01(\x0b\x32=.Ydb.PersQueue.V1.StreamingReadServerMessage.AddTopicResponseH\x00\x12\x61\n\x15remove_topic_response\x18\r \x01(\x0b\x32@.Ydb.PersQueue.V1.StreamingReadServerMessage.RemoveTopicResponseH\x00\x12\x46\n\x15update_token_response\x18\x0e \x01(\x0b\x32%.Ydb.PersQueue.V1.UpdateTokenResponseH\x00\x1a\x82\x02\n\x0cInitResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x7f\n\x1d\x62lock_format_version_by_topic\x18\x02 \x03(\x0b\x32X.Ydb.PersQueue.V1.StreamingReadServerMessage.InitResponse.BlockFormatVersionByTopicEntry\x12\x1b\n\x13max_meta_cache_size\x18\n \x01(\x03\x1a@\n\x1e\x42lockFormatVersionByTopicEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x8b\x01\n\x1cStartPartitionSessionRequest\x12=\n\x11partition_session\x18\x01 \x01(\x0b\x32\".Ydb.PersQueue.V1.PartitionSession\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x12\x12\n\nend_offset\x18\x03 \x01(\x03\x1ag\n\x1bStopPartitionSessionRequest\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x10\n\x08graceful\x18\x02 \x01(\x08\x12\x18\n\x10\x63ommitted_offset\x18\x03 \x01(\x03\x1a\xe0\x01\n\x0e\x43ommitResponse\x12z\n\x1cpartitions_committed_offsets\x18\x01 \x03(\x0b\x32T.Ydb.PersQueue.V1.StreamingReadServerMessage.CommitResponse.PartitionCommittedOffset\x1aR\n\x18PartitionCommittedOffset\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x1a\x98\x05\n\x0cReadResponse\x12_\n\x0epartition_data\x18\x01 \x03(\x0b\x32G.Ydb.PersQueue.V1.StreamingReadServerMessage.ReadResponse.PartitionData\x1a\xc9\x01\n\x0bMessageData\x12\x0e\n\x06offset\x18\x01 \x01(\x03\x12\x0e\n\x06seq_no\x18\x02 \x01(\x03\x12\x1b\n\x13\x63reate_timestamp_ms\x18\x03 \x01(\x03\x12&\n\x05\x63odec\x18\x04 \x01(\x0e\x32\x17.Ydb.PersQueue.V1.Codec\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12\x19\n\x11uncompressed_size\x18\x06 \x01(\x03\x12\x15\n\rpartition_key\x18\x07 \x01(\t\x12\x15\n\rexplicit_hash\x18\x08 \x01(\x0c\x1a\xd9\x01\n\x05\x42\x61tch\x12\x18\n\x10message_group_id\x18\x02 \x01(\x0c\x12\x31\n\x0csession_meta\x18\x03 \x01(\x0b\x32\x1b.Ydb.PersQueue.V1.MetaValue\x12\x1a\n\x12write_timestamp_ms\x18\x04 \x01(\x03\x12\n\n\x02ip\x18\x05 \x01(\t\x12[\n\x0cmessage_data\x18\x01 \x03(\x0b\x32\x45.Ydb.PersQueue.V1.StreamingReadServerMessage.ReadResponse.MessageData\x1a\x7f\n\rPartitionData\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12P\n\x07\x62\x61tches\x18\x02 \x03(\x0b\x32?.Ydb.PersQueue.V1.StreamingReadServerMessage.ReadResponse.Batch\x1a\x8d\x01\n\x1ePartitionSessionStatusResponse\x12\x1c\n\x14partition_session_id\x18\x01 \x01(\x03\x12\x18\n\x10\x63ommitted_offset\x18\x02 \x01(\x03\x12\x12\n\nend_offset\x18\x03 \x01(\x03\x12\x1f\n\x17written_at_watermark_ms\x18\x04 \x01(\x03\x1a\x13\n\x11PauseReadResponse\x1a\x14\n\x12ResumeReadResponse\x1a\x30\n\x10\x41\x64\x64TopicResponse\x12\x1c\n\x14\x62lock_format_version\x18\x01 \x01(\x03\x1a\x15\n\x13RemoveTopicResponseB\x10\n\x0eserver_message\"\x99\x01\n\x0fPartitionStream\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x14\n\x0cpartition_id\x18\x03 \x01(\x03\x12\x1a\n\x12partition_group_id\x18\x04 \x01(\x03\x12\x1b\n\x13partition_stream_id\x18\x06 \x01(\x03\x12\x17\n\x0f\x63onnection_meta\x18\x07 \x01(\x0c\"\xac\x11\n#MigrationStreamingReadClientMessage\x12Y\n\x0cinit_request\x18\x01 \x01(\x0b\x32\x41.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.InitRequestH\x00\x12J\n\x04read\x18\x02 \x01(\x0b\x32:.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.ReadH\x00\x12U\n\nstart_read\x18\x03 \x01(\x0b\x32?.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.StartReadH\x00\x12N\n\x06\x63ommit\x18\x04 \x01(\x0b\x32<.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.CommitH\x00\x12R\n\x08released\x18\x05 \x01(\x0b\x32>.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.ReleasedH\x00\x12N\n\x06status\x18\x06 \x01(\x0b\x32<.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.StatusH\x00\x12\r\n\x05token\x18\x14 \x01(\x0c\x1a\x61\n\x11TopicReadSettings\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x1b\n\x13partition_group_ids\x18\x02 \x03(\x03\x12 \n\x18start_from_written_at_ms\x18\x03 \x01(\x03\x1a\x90\x08\n\x0bInitRequest\x12\x65\n\x14topics_read_settings\x18\x01 \x03(\x0b\x32G.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.TopicReadSettings\x12\x1a\n\x12read_only_original\x18\x02 \x01(\x08\x12\x10\n\x08\x63onsumer\x18\x03 \x01(\t\x12\x1b\n\x13max_lag_duration_ms\x18\x04 \x01(\x03\x12 \n\x18start_from_written_at_ms\x18\x05 \x01(\x03\x12*\n\"max_supported_block_format_version\x18\x06 \x01(\x03\x12\x1b\n\x13max_meta_cache_size\x18\n \x01(\x03\x12\x12\n\nsession_id\x18\x64 \x01(\t\x12\x1a\n\x12\x63onnection_attempt\x18\x65 \x01(\x03\x12V\n\x05state\x18\x66 \x01(\x0b\x32G.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.InitRequest.State\x12\x18\n\x0fidle_timeout_ms\x18\xc8\x01 \x01(\x03\x12\x31\n\x0bread_params\x18* \x01(\x0b\x32\x1c.Ydb.PersQueue.V1.ReadParams\x12\x14\n\x0branges_mode\x18\xba\x03 \x01(\x08\x1a\xf8\x03\n\x05State\x12~\n\x18partition_streams_states\x18\x01 \x03(\x0b\x32\\.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.InitRequest.State.PartitionStreamState\x1a\xee\x02\n\x14PartitionStreamState\x12;\n\x10partition_stream\x18\x01 \x01(\x0b\x32!.Ydb.PersQueue.V1.PartitionStream\x12\x13\n\x0bread_offset\x18\x02 \x01(\x03\x12\x35\n\roffset_ranges\x18\x03 \x03(\x0b\x32\x1e.Ydb.PersQueue.V1.OffsetsRange\x12s\n\x06status\x18\x04 \x01(\x0e\x32\x63.Ydb.PersQueue.V1.MigrationStreamingReadClientMessage.InitRequest.State.PartitionStreamState.Status\"X\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0e\n\nDESTROYING\x10\x02\x12\x0b\n\x07READING\x10\x03\x12\x0b\n\x07STOPPED\x10\x04\x1a\x06\n\x04Read\x1a\xb1\x01\n\tStartRead\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.Ydb.PersQueue.V1.Path\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x11\n\tpartition\x18\x03 \x01(\x04\x12\x11\n\tassign_id\x18\x05 \x01(\x04\x12\x13\n\x0bread_offset\x18\x06 \x01(\x04\x12\x15\n\rcommit_offset\x18\x07 \x01(\x04\x12\x1a\n\x12verify_read_offset\x18\x08 \x01(\x08\x1ah\n\x08Released\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.Ydb.PersQueue.V1.Path\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x11\n\tpartition\x18\x03 \x01(\x04\x12\x11\n\tassign_id\x18\x05 \x01(\x04\x1au\n\x06\x43ommit\x12/\n\x07\x63ookies\x18\x01 \x03(\x0b\x32\x1e.Ydb.PersQueue.V1.CommitCookie\x12:\n\roffset_ranges\x18\x02 \x03(\x0b\x32#.Ydb.PersQueue.V1.CommitOffsetRange\x1a\x66\n\x06Status\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.Ydb.PersQueue.V1.Path\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x11\n\tpartition\x18\x03 \x01(\x04\x12\x11\n\tassign_id\x18\x05 \x01(\x04\x42\t\n\x07request\"\xa6\x12\n#MigrationStreamingReadServerMessage\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12[\n\rinit_response\x18\x03 \x01(\x0b\x32\x42.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.InitResponseH\x00\x12U\n\ndata_batch\x18\x04 \x01(\x0b\x32?.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.DataBatchH\x00\x12R\n\x08\x61ssigned\x18\x05 \x01(\x0b\x32>.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.AssignedH\x00\x12P\n\x07release\x18\x06 \x01(\x0b\x32=.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.ReleaseH\x00\x12T\n\tcommitted\x18\x07 \x01(\x0b\x32?.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.CommittedH\x00\x12\x61\n\x10partition_status\x18\x08 \x01(\x0b\x32\x45.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.PartitionStatusH\x00\x1a\x8c\x02\n\x0cInitResponse\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x88\x01\n\x1d\x62lock_format_version_by_topic\x18\x02 \x03(\x0b\x32\x61.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.InitResponse.BlockFormatVersionByTopicEntry\x12\x1b\n\x13max_meta_cache_size\x18\n \x01(\x03\x1a@\n\x1e\x42lockFormatVersionByTopicEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x03:\x02\x38\x01\x1a\x91\x01\n\x08\x41ssigned\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.Ydb.PersQueue.V1.Path\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x11\n\tpartition\x18\x03 \x01(\x04\x12\x11\n\tassign_id\x18\x05 \x01(\x04\x12\x13\n\x0bread_offset\x18\x06 \x01(\x04\x12\x12\n\nend_offset\x18\x07 \x01(\x04\x1a\x98\x01\n\x07Release\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.Ydb.PersQueue.V1.Path\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x11\n\tpartition\x18\x03 \x01(\x04\x12\x11\n\tassign_id\x18\x05 \x01(\x04\x12\x18\n\x10\x66orceful_release\x18\x06 \x01(\x08\x12\x15\n\rcommit_offset\x18\x07 \x01(\x04\x1ax\n\tCommitted\x12/\n\x07\x63ookies\x18\x01 \x03(\x0b\x32\x1e.Ydb.PersQueue.V1.CommitCookie\x12:\n\roffset_ranges\x18\x02 \x03(\x0b\x32#.Ydb.PersQueue.V1.CommitOffsetRange\x1a\x97\x06\n\tDataBatch\x12\x65\n\x0epartition_data\x18\x01 \x03(\x0b\x32M.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.DataBatch.PartitionData\x1a\xc9\x01\n\x0bMessageData\x12\x0e\n\x06offset\x18\x01 \x01(\x04\x12\x0e\n\x06seq_no\x18\x02 \x01(\x04\x12\x1b\n\x13\x63reate_timestamp_ms\x18\x03 \x01(\x04\x12&\n\x05\x63odec\x18\x04 \x01(\x0e\x32\x17.Ydb.PersQueue.V1.Codec\x12\x0c\n\x04\x64\x61ta\x18\x05 \x01(\x0c\x12\x19\n\x11uncompressed_size\x18\x06 \x01(\x04\x12\x15\n\rpartition_key\x18\x07 \x01(\t\x12\x15\n\rexplicit_hash\x18\x08 \x01(\x0c\x1a\xd7\x01\n\x05\x42\x61tch\x12\x11\n\tsource_id\x18\x02 \x01(\x0c\x12\x30\n\x0c\x65xtra_fields\x18\x03 \x03(\x0b\x32\x1a.Ydb.PersQueue.V1.KeyValue\x12\x1a\n\x12write_timestamp_ms\x18\x04 \x01(\x04\x12\n\n\x02ip\x18\x05 \x01(\t\x12\x61\n\x0cmessage_data\x18\x01 \x03(\x0b\x32K.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.DataBatch.MessageData\x1a\xfc\x01\n\rPartitionData\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.Ydb.PersQueue.V1.Path\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x11\n\tpartition\x18\x03 \x01(\x04\x12V\n\x07\x62\x61tches\x18\x04 \x03(\x0b\x32\x45.Ydb.PersQueue.V1.MigrationStreamingReadServerMessage.DataBatch.Batch\x12.\n\x06\x63ookie\x18\x05 \x01(\x0b\x32\x1e.Ydb.PersQueue.V1.CommitCookie\x12\x18\n\x10\x64\x65precated_topic\x18\n \x01(\t\x1a\xb9\x01\n\x0fPartitionStatus\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.Ydb.PersQueue.V1.Path\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x11\n\tpartition\x18\x03 \x01(\x04\x12\x11\n\tassign_id\x18\x05 \x01(\x04\x12\x18\n\x10\x63ommitted_offset\x18\x06 \x01(\x04\x12\x12\n\nend_offset\x18\x07 \x01(\x04\x12\x1a\n\x12write_watermark_ms\x18\x08 \x01(\x04\x42\n\n\x08response\"\xb9\x01\n\x0fReadInfoRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12&\n\x06topics\x18\x02 \x03(\x0b\x32\x16.Ydb.PersQueue.V1.Path\x12\x19\n\x11get_only_original\x18\x03 \x01(\x08\x12(\n\x08\x63onsumer\x18\x04 \x01(\x0b\x32\x16.Ydb.PersQueue.V1.Path\"@\n\x10ReadInfoResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xa1\x06\n\x0eReadInfoResult\x12:\n\x06topics\x18\x01 \x03(\x0b\x32*.Ydb.PersQueue.V1.ReadInfoResult.TopicInfo\x1a\xd2\x05\n\tTopicInfo\x12%\n\x05topic\x18\x01 \x01(\x0b\x32\x16.Ydb.PersQueue.V1.Path\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12)\n\x06status\x18\x03 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12L\n\npartitions\x18\x05 \x03(\x0b\x32\x38.Ydb.PersQueue.V1.ReadInfoResult.TopicInfo.PartitionInfo\x1a\xea\x03\n\rPartitionInfo\x12\x11\n\tpartition\x18\x01 \x01(\x04\x12)\n\x06status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x14\n\x0cstart_offset\x18\x04 \x01(\x04\x12\x12\n\nend_offset\x18\x05 \x01(\x04\x12\x15\n\rcommit_offset\x18\x06 \x01(\x04\x12\x1a\n\x12\x63ommit_time_lag_ms\x18\x07 \x01(\x04\x12\x13\n\x0bread_offset\x18\x08 \x01(\x04\x12\x18\n\x10read_time_lag_ms\x18\t \x01(\x04\x12\x12\n\nsession_id\x18\n \x01(\t\x12\x13\n\x0b\x63lient_node\x18\x0b \x01(\t\x12\x12\n\nproxy_node\x18\x0c \x01(\t\x12\x13\n\x0btablet_node\x18\r \x01(\t\x12\x11\n\tassign_id\x18\x0e \x01(\x04\x12\x1b\n\x13\x61ssign_timestamp_ms\x18\x0f \x01(\x04\x12\x18\n\x10last_read_cookie\x18\x10 \x01(\x04\x12\x1d\n\x15\x63ommitted_read_cookie\x18\x11 \x01(\x04\x12+\n#out_of_order_read_cookies_to_commit\x18\x12 \x03(\x04\"[\n\x10\x44ropTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"A\n\x11\x44ropTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x11\n\x0f\x44ropTopicResult\"\xb1\x01\n\x0b\x43redentials\x12\x15\n\x0boauth_token\x18\x01 \x01(\tH\x00\x12\x14\n\njwt_params\x18\x02 \x01(\tH\x00\x12\x30\n\x03iam\x18\x03 \x01(\x0b\x32!.Ydb.PersQueue.V1.Credentials.IamH\x00\x1a\x34\n\x03Iam\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x1b\n\x13service_account_key\x18\x02 \x01(\tB\r\n\x0b\x63redentials\"\xd5\n\n\rTopicSettings\x12!\n\x10partitions_count\x18\x01 \x01(\x05\x42\x07\xb2\xe6*\x03> 0\x12&\n\x13retention_period_ms\x18\x02 \x01(\x03\x42\x07\xb2\xe6*\x03> 0H\x00\x12+\n\x17retention_storage_bytes\x18\x0e \x01(\x03\x42\x08\xb2\xe6*\x04>= 0H\x00\x12\x39\n\'message_group_seqno_retention_period_ms\x18\x0c \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12;\n)max_partition_message_groups_seqno_stored\x18\r \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12@\n\x10supported_format\x18\x03 \x01(\x0e\x32&.Ydb.PersQueue.V1.TopicSettings.Format\x12\x39\n\x10supported_codecs\x18\x04 \x03(\x0e\x32\x17.Ydb.PersQueue.V1.CodecB\x06\x9a\xe6*\x02\x18\x64\x12,\n\x1amax_partition_storage_size\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12+\n\x19max_partition_write_speed\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12+\n\x19max_partition_write_burst\x18\x07 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1d\n\x15\x63lient_write_disabled\x18\x08 \x01(\x08\x12\x45\n\nread_rules\x18\t \x03(\x0b\x32(.Ydb.PersQueue.V1.TopicSettings.ReadRuleB\x07\x9a\xe6*\x03\x18\xb8\x17\x12\x43\n\nattributes\x18\n \x03(\x0b\x32/.Ydb.PersQueue.V1.TopicSettings.AttributesEntry\x12L\n\x12remote_mirror_rule\x18\x0b \x01(\x0b\x32\x30.Ydb.PersQueue.V1.TopicSettings.RemoteMirrorRule\x1a\x99\x02\n\x08ReadRule\x12\x1b\n\rconsumer_name\x18\x01 \x01(\tB\x04\x90\xe6*\x01\x12\x11\n\timportant\x18\x02 \x01(\x08\x12/\n\x1dstarting_message_timestamp_ms\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12@\n\x10supported_format\x18\x04 \x01(\x0e\x32&.Ydb.PersQueue.V1.TopicSettings.Format\x12\x39\n\x10supported_codecs\x18\x05 \x03(\x0e\x32\x17.Ydb.PersQueue.V1.CodecB\x06\x9a\xe6*\x02\x18\x64\x12\x19\n\x07version\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x14\n\x0cservice_type\x18\x07 \x01(\t\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\xc6\x01\n\x10RemoteMirrorRule\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x12\n\ntopic_path\x18\x02 \x01(\t\x12\x15\n\rconsumer_name\x18\x03 \x01(\t\x12\x32\n\x0b\x63redentials\x18\x04 \x01(\x0b\x32\x1d.Ydb.PersQueue.V1.Credentials\x12/\n\x1dstarting_message_timestamp_ms\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x10\n\x08\x64\x61tabase\x18\x06 \x01(\t\"1\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x46ORMAT_BASE\x10\x01\x42\x0b\n\tretention\"\x96\x01\n\x12\x43reateTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\x90\xe6*\x01\x12\x31\n\x08settings\x18\x04 \x01(\x0b\x32\x1f.Ydb.PersQueue.V1.TopicSettings\"C\n\x13\x43reateTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x43reateTopicResult\"\x95\x01\n\x11\x41lterTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\x90\xe6*\x01\x12\x31\n\x08settings\x18\x04 \x01(\x0b\x32\x1f.Ydb.PersQueue.V1.TopicSettings\"B\n\x12\x41lterTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10\x41lterTopicResult\"\xa0\x01\n\x12\x41\x64\x64ReadRuleRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\x90\xe6*\x01\x12;\n\tread_rule\x18\x03 \x01(\x0b\x32(.Ydb.PersQueue.V1.TopicSettings.ReadRule\"C\n\x13\x41\x64\x64ReadRuleResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x41\x64\x64ReadRuleResult\"}\n\x15RemoveReadRuleRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\x90\xe6*\x01\x12\x15\n\rconsumer_name\x18\x03 \x01(\t\"F\n\x16RemoveReadRuleResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x16\n\x14RemoveReadRuleResult\"e\n\x14\x44\x65scribeTopicRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\x04path\x18\x02 \x01(\tB\x04\x90\xe6*\x01\"E\n\x15\x44\x65scribeTopicResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"i\n\x13\x44\x65scribeTopicResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12\x31\n\x08settings\x18\x02 \x01(\x0b\x32\x1f.Ydb.PersQueue.V1.TopicSettings*]\n\x05\x43odec\x12\x15\n\x11\x43ODEC_UNSPECIFIED\x10\x00\x12\r\n\tCODEC_RAW\x10\x01\x12\x0e\n\nCODEC_GZIP\x10\x02\x12\x0e\n\nCODEC_LZOP\x10\x03\x12\x0e\n\nCODEC_ZSTD\x10\x04\x42\x1d\n\x18\x63om.yandex.ydb.persqueue\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.ydb_persqueue_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030com.yandex.ydb.persqueue\370\001\001'
  _METAVALUE_VALUEENTRY._options = None
  _METAVALUE_VALUEENTRY._serialized_options = b'8\001'
  _STREAMINGWRITECLIENTMESSAGE_INITREQUEST_SESSIONMETAENTRY._options = None
  _STREAMINGWRITECLIENTMESSAGE_INITREQUEST_SESSIONMETAENTRY._serialized_options = b'8\001'
  _STREAMINGREADSERVERMESSAGE_INITRESPONSE_BLOCKFORMATVERSIONBYTOPICENTRY._options = None
  _STREAMINGREADSERVERMESSAGE_INITRESPONSE_BLOCKFORMATVERSIONBYTOPICENTRY._serialized_options = b'8\001'
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_INITRESPONSE_BLOCKFORMATVERSIONBYTOPICENTRY._options = None
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_INITRESPONSE_BLOCKFORMATVERSIONBYTOPICENTRY._serialized_options = b'8\001'
  _TOPICSETTINGS_READRULE.fields_by_name['consumer_name']._options = None
  _TOPICSETTINGS_READRULE.fields_by_name['consumer_name']._serialized_options = b'\220\346*\001'
  _TOPICSETTINGS_READRULE.fields_by_name['starting_message_timestamp_ms']._options = None
  _TOPICSETTINGS_READRULE.fields_by_name['starting_message_timestamp_ms']._serialized_options = b'\262\346*\004>= 0'
  _TOPICSETTINGS_READRULE.fields_by_name['supported_codecs']._options = None
  _TOPICSETTINGS_READRULE.fields_by_name['supported_codecs']._serialized_options = b'\232\346*\002\030d'
  _TOPICSETTINGS_READRULE.fields_by_name['version']._options = None
  _TOPICSETTINGS_READRULE.fields_by_name['version']._serialized_options = b'\262\346*\004>= 0'
  _TOPICSETTINGS_ATTRIBUTESENTRY._options = None
  _TOPICSETTINGS_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _TOPICSETTINGS_REMOTEMIRRORRULE.fields_by_name['starting_message_timestamp_ms']._options = None
  _TOPICSETTINGS_REMOTEMIRRORRULE.fields_by_name['starting_message_timestamp_ms']._serialized_options = b'\262\346*\004>= 0'
  _TOPICSETTINGS.fields_by_name['partitions_count']._options = None
  _TOPICSETTINGS.fields_by_name['partitions_count']._serialized_options = b'\262\346*\003> 0'
  _TOPICSETTINGS.fields_by_name['retention_period_ms']._options = None
  _TOPICSETTINGS.fields_by_name['retention_period_ms']._serialized_options = b'\262\346*\003> 0'
  _TOPICSETTINGS.fields_by_name['retention_storage_bytes']._options = None
  _TOPICSETTINGS.fields_by_name['retention_storage_bytes']._serialized_options = b'\262\346*\004>= 0'
  _TOPICSETTINGS.fields_by_name['message_group_seqno_retention_period_ms']._options = None
  _TOPICSETTINGS.fields_by_name['message_group_seqno_retention_period_ms']._serialized_options = b'\262\346*\004>= 0'
  _TOPICSETTINGS.fields_by_name['max_partition_message_groups_seqno_stored']._options = None
  _TOPICSETTINGS.fields_by_name['max_partition_message_groups_seqno_stored']._serialized_options = b'\262\346*\004>= 0'
  _TOPICSETTINGS.fields_by_name['supported_codecs']._options = None
  _TOPICSETTINGS.fields_by_name['supported_codecs']._serialized_options = b'\232\346*\002\030d'
  _TOPICSETTINGS.fields_by_name['max_partition_storage_size']._options = None
  _TOPICSETTINGS.fields_by_name['max_partition_storage_size']._serialized_options = b'\262\346*\004>= 0'
  _TOPICSETTINGS.fields_by_name['max_partition_write_speed']._options = None
  _TOPICSETTINGS.fields_by_name['max_partition_write_speed']._serialized_options = b'\262\346*\004>= 0'
  _TOPICSETTINGS.fields_by_name['max_partition_write_burst']._options = None
  _TOPICSETTINGS.fields_by_name['max_partition_write_burst']._serialized_options = b'\262\346*\004>= 0'
  _TOPICSETTINGS.fields_by_name['read_rules']._options = None
  _TOPICSETTINGS.fields_by_name['read_rules']._serialized_options = b'\232\346*\003\030\270\027'
  _CREATETOPICREQUEST.fields_by_name['path']._options = None
  _CREATETOPICREQUEST.fields_by_name['path']._serialized_options = b'\220\346*\001'
  _ALTERTOPICREQUEST.fields_by_name['path']._options = None
  _ALTERTOPICREQUEST.fields_by_name['path']._serialized_options = b'\220\346*\001'
  _ADDREADRULEREQUEST.fields_by_name['path']._options = None
  _ADDREADRULEREQUEST.fields_by_name['path']._serialized_options = b'\220\346*\001'
  _REMOVEREADRULEREQUEST.fields_by_name['path']._options = None
  _REMOVEREADRULEREQUEST.fields_by_name['path']._serialized_options = b'\220\346*\001'
  _DESCRIBETOPICREQUEST.fields_by_name['path']._options = None
  _DESCRIBETOPICREQUEST.fields_by_name['path']._serialized_options = b'\220\346*\001'
  _CODEC._serialized_start=17515
  _CODEC._serialized_end=17608
  _METAVALUE._serialized_start=294
  _METAVALUE._serialized_end=406
  _METAVALUE_VALUEENTRY._serialized_start=362
  _METAVALUE_VALUEENTRY._serialized_end=406
  _OFFSETSRANGE._serialized_start=408
  _OFFSETSRANGE._serialized_end=464
  _UPDATETOKENREQUEST._serialized_start=466
  _UPDATETOKENREQUEST._serialized_end=501
  _UPDATETOKENRESPONSE._serialized_start=503
  _UPDATETOKENRESPONSE._serialized_end=524
  _STREAMINGWRITECLIENTMESSAGE._serialized_start=527
  _STREAMINGWRITECLIENTMESSAGE._serialized_end=1484
  _STREAMINGWRITECLIENTMESSAGE_INITREQUEST._serialized_start=797
  _STREAMINGWRITECLIENTMESSAGE_INITREQUEST._serialized_end=1193
  _STREAMINGWRITECLIENTMESSAGE_INITREQUEST_SESSIONMETAENTRY._serialized_start=1143
  _STREAMINGWRITECLIENTMESSAGE_INITREQUEST_SESSIONMETAENTRY._serialized_end=1193
  _STREAMINGWRITECLIENTMESSAGE_WRITEREQUEST._serialized_start=1196
  _STREAMINGWRITECLIENTMESSAGE_WRITEREQUEST._serialized_end=1466
  _STREAMINGWRITESERVERMESSAGE._serialized_start=1487
  _STREAMINGWRITESERVERMESSAGE._serialized_end=2531
  _STREAMINGWRITESERVERMESSAGE_INITRESPONSE._serialized_start=1858
  _STREAMINGWRITESERVERMESSAGE_INITRESPONSE._serialized_end=2137
  _STREAMINGWRITESERVERMESSAGE_BATCHWRITERESPONSE._serialized_start=2140
  _STREAMINGWRITESERVERMESSAGE_BATCHWRITERESPONSE._serialized_end=2339
  _STREAMINGWRITESERVERMESSAGE_WRITESTATISTICS._serialized_start=2342
  _STREAMINGWRITESERVERMESSAGE_WRITESTATISTICS._serialized_end=2513
  _PATH._serialized_start=2533
  _PATH._serialized_end=2553
  _KEYVALUE._serialized_start=2555
  _KEYVALUE._serialized_end=2593
  _READPARAMS._serialized_start=2595
  _READPARAMS._serialized_end=2663
  _COMMITCOOKIE._serialized_start=2665
  _COMMITCOOKIE._serialized_end=2724
  _COMMITOFFSETRANGE._serialized_start=2726
  _COMMITOFFSETRANGE._serialized_end=2806
  _PARTITIONSESSION._serialized_start=2809
  _PARTITIONSESSION._serialized_end=2964
  _STREAMINGREADCLIENTMESSAGE._serialized_start=2967
  _STREAMINGREADCLIENTMESSAGE._serialized_end=5901
  _STREAMINGREADCLIENTMESSAGE_INITREQUEST._serialized_start=4052
  _STREAMINGREADCLIENTMESSAGE_INITREQUEST._serialized_end=4981
  _STREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE._serialized_start=4491
  _STREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE._serialized_end=4981
  _STREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE_PARTITIONSESSIONSTATE._serialized_start=4622
  _STREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE_PARTITIONSESSIONSTATE._serialized_end=4981
  _STREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE_PARTITIONSESSIONSTATE_STATUS._serialized_start=4896
  _STREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE_PARTITIONSESSIONSTATE_STATUS._serialized_end=4981
  _STREAMINGREADCLIENTMESSAGE_READREQUEST._serialized_start=4983
  _STREAMINGREADCLIENTMESSAGE_READREQUEST._serialized_end=5031
  _STREAMINGREADCLIENTMESSAGE_STARTPARTITIONSESSIONRESPONSE._serialized_start=5034
  _STREAMINGREADCLIENTMESSAGE_STARTPARTITIONSESSIONRESPONSE._serialized_end=5167
  _STREAMINGREADCLIENTMESSAGE_STOPPARTITIONSESSIONRESPONSE._serialized_start=5169
  _STREAMINGREADCLIENTMESSAGE_STOPPARTITIONSESSIONRESPONSE._serialized_end=5229
  _STREAMINGREADCLIENTMESSAGE_PAUSEREADREQUEST._serialized_start=5231
  _STREAMINGREADCLIENTMESSAGE_PAUSEREADREQUEST._serialized_end=5280
  _STREAMINGREADCLIENTMESSAGE_RESUMEREADREQUEST._serialized_start=5282
  _STREAMINGREADCLIENTMESSAGE_RESUMEREADREQUEST._serialized_end=5378
  _STREAMINGREADCLIENTMESSAGE_COMMITREQUEST._serialized_start=5380
  _STREAMINGREADCLIENTMESSAGE_COMMITREQUEST._serialized_end=5474
  _STREAMINGREADCLIENTMESSAGE_PARTITIONSESSIONSTATUSREQUEST._serialized_start=5476
  _STREAMINGREADCLIENTMESSAGE_PARTITIONSESSIONSTATUSREQUEST._serialized_end=5537
  _STREAMINGREADCLIENTMESSAGE_ADDTOPICREQUEST._serialized_start=5539
  _STREAMINGREADCLIENTMESSAGE_ADDTOPICREQUEST._serialized_end=5649
  _STREAMINGREADCLIENTMESSAGE_REMOVETOPICREQUEST._serialized_start=5651
  _STREAMINGREADCLIENTMESSAGE_REMOVETOPICREQUEST._serialized_end=5686
  _STREAMINGREADCLIENTMESSAGE_TOPICREADSETTINGS._serialized_start=5688
  _STREAMINGREADCLIENTMESSAGE_TOPICREADSETTINGS._serialized_end=5785
  _STREAMINGREADCLIENTMESSAGE_PARTITIONCOMMIT._serialized_start=5787
  _STREAMINGREADCLIENTMESSAGE_PARTITIONCOMMIT._serialized_end=5883
  _STREAMINGREADSERVERMESSAGE._serialized_start=5904
  _STREAMINGREADSERVERMESSAGE._serialized_end=8764
  _STREAMINGREADSERVERMESSAGE_INITRESPONSE._serialized_start=7087
  _STREAMINGREADSERVERMESSAGE_INITRESPONSE._serialized_end=7345
  _STREAMINGREADSERVERMESSAGE_INITRESPONSE_BLOCKFORMATVERSIONBYTOPICENTRY._serialized_start=7281
  _STREAMINGREADSERVERMESSAGE_INITRESPONSE_BLOCKFORMATVERSIONBYTOPICENTRY._serialized_end=7345
  _STREAMINGREADSERVERMESSAGE_STARTPARTITIONSESSIONREQUEST._serialized_start=7348
  _STREAMINGREADSERVERMESSAGE_STARTPARTITIONSESSIONREQUEST._serialized_end=7487
  _STREAMINGREADSERVERMESSAGE_STOPPARTITIONSESSIONREQUEST._serialized_start=7489
  _STREAMINGREADSERVERMESSAGE_STOPPARTITIONSESSIONREQUEST._serialized_end=7592
  _STREAMINGREADSERVERMESSAGE_COMMITRESPONSE._serialized_start=7595
  _STREAMINGREADSERVERMESSAGE_COMMITRESPONSE._serialized_end=7819
  _STREAMINGREADSERVERMESSAGE_COMMITRESPONSE_PARTITIONCOMMITTEDOFFSET._serialized_start=7737
  _STREAMINGREADSERVERMESSAGE_COMMITRESPONSE_PARTITIONCOMMITTEDOFFSET._serialized_end=7819
  _STREAMINGREADSERVERMESSAGE_READRESPONSE._serialized_start=7822
  _STREAMINGREADSERVERMESSAGE_READRESPONSE._serialized_end=8486
  _STREAMINGREADSERVERMESSAGE_READRESPONSE_MESSAGEDATA._serialized_start=7936
  _STREAMINGREADSERVERMESSAGE_READRESPONSE_MESSAGEDATA._serialized_end=8137
  _STREAMINGREADSERVERMESSAGE_READRESPONSE_BATCH._serialized_start=8140
  _STREAMINGREADSERVERMESSAGE_READRESPONSE_BATCH._serialized_end=8357
  _STREAMINGREADSERVERMESSAGE_READRESPONSE_PARTITIONDATA._serialized_start=8359
  _STREAMINGREADSERVERMESSAGE_READRESPONSE_PARTITIONDATA._serialized_end=8486
  _STREAMINGREADSERVERMESSAGE_PARTITIONSESSIONSTATUSRESPONSE._serialized_start=8489
  _STREAMINGREADSERVERMESSAGE_PARTITIONSESSIONSTATUSRESPONSE._serialized_end=8630
  _STREAMINGREADSERVERMESSAGE_PAUSEREADRESPONSE._serialized_start=8632
  _STREAMINGREADSERVERMESSAGE_PAUSEREADRESPONSE._serialized_end=8651
  _STREAMINGREADSERVERMESSAGE_RESUMEREADRESPONSE._serialized_start=8653
  _STREAMINGREADSERVERMESSAGE_RESUMEREADRESPONSE._serialized_end=8673
  _STREAMINGREADSERVERMESSAGE_ADDTOPICRESPONSE._serialized_start=8675
  _STREAMINGREADSERVERMESSAGE_ADDTOPICRESPONSE._serialized_end=8723
  _STREAMINGREADSERVERMESSAGE_REMOVETOPICRESPONSE._serialized_start=8725
  _STREAMINGREADSERVERMESSAGE_REMOVETOPICRESPONSE._serialized_end=8746
  _PARTITIONSTREAM._serialized_start=8767
  _PARTITIONSTREAM._serialized_end=8920
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE._serialized_start=8923
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE._serialized_end=11143
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_TOPICREADSETTINGS._serialized_start=5688
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_TOPICREADSETTINGS._serialized_end=5785
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_INITREQUEST._serialized_start=9575
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_INITREQUEST._serialized_end=10615
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE._serialized_start=10111
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE._serialized_end=10615
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE_PARTITIONSTREAMSTATE._serialized_start=10249
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE_PARTITIONSTREAMSTATE._serialized_end=10615
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE_PARTITIONSTREAMSTATE_STATUS._serialized_start=10527
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_INITREQUEST_STATE_PARTITIONSTREAMSTATE_STATUS._serialized_end=10615
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_READ._serialized_start=10617
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_READ._serialized_end=10623
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_STARTREAD._serialized_start=10626
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_STARTREAD._serialized_end=10803
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_RELEASED._serialized_start=10805
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_RELEASED._serialized_end=10909
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_COMMIT._serialized_start=10911
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_COMMIT._serialized_end=11028
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_STATUS._serialized_start=11030
  _MIGRATIONSTREAMINGREADCLIENTMESSAGE_STATUS._serialized_end=11132
  _MIGRATIONSTREAMINGREADSERVERMESSAGE._serialized_start=11146
  _MIGRATIONSTREAMINGREADSERVERMESSAGE._serialized_end=13488
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_INITRESPONSE._serialized_start=11801
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_INITRESPONSE._serialized_end=12069
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_INITRESPONSE_BLOCKFORMATVERSIONBYTOPICENTRY._serialized_start=7281
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_INITRESPONSE_BLOCKFORMATVERSIONBYTOPICENTRY._serialized_end=7345
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_ASSIGNED._serialized_start=12072
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_ASSIGNED._serialized_end=12217
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_RELEASE._serialized_start=12220
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_RELEASE._serialized_end=12372
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_COMMITTED._serialized_start=12374
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_COMMITTED._serialized_end=12494
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_DATABATCH._serialized_start=12497
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_DATABATCH._serialized_end=13288
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_DATABATCH_MESSAGEDATA._serialized_start=12614
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_DATABATCH_MESSAGEDATA._serialized_end=12815
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_DATABATCH_BATCH._serialized_start=12818
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_DATABATCH_BATCH._serialized_end=13033
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_DATABATCH_PARTITIONDATA._serialized_start=13036
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_DATABATCH_PARTITIONDATA._serialized_end=13288
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_PARTITIONSTATUS._serialized_start=13291
  _MIGRATIONSTREAMINGREADSERVERMESSAGE_PARTITIONSTATUS._serialized_end=13476
  _READINFOREQUEST._serialized_start=13491
  _READINFOREQUEST._serialized_end=13676
  _READINFORESPONSE._serialized_start=13678
  _READINFORESPONSE._serialized_end=13742
  _READINFORESULT._serialized_start=13745
  _READINFORESULT._serialized_end=14546
  _READINFORESULT_TOPICINFO._serialized_start=13824
  _READINFORESULT_TOPICINFO._serialized_end=14546
  _READINFORESULT_TOPICINFO_PARTITIONINFO._serialized_start=14056
  _READINFORESULT_TOPICINFO_PARTITIONINFO._serialized_end=14546
  _DROPTOPICREQUEST._serialized_start=14548
  _DROPTOPICREQUEST._serialized_end=14639
  _DROPTOPICRESPONSE._serialized_start=14641
  _DROPTOPICRESPONSE._serialized_end=14706
  _DROPTOPICRESULT._serialized_start=14708
  _DROPTOPICRESULT._serialized_end=14725
  _CREDENTIALS._serialized_start=14728
  _CREDENTIALS._serialized_end=14905
  _CREDENTIALS_IAM._serialized_start=14838
  _CREDENTIALS_IAM._serialized_end=14890
  _TOPICSETTINGS._serialized_start=14908
  _TOPICSETTINGS._serialized_end=16273
  _TOPICSETTINGS_READRULE._serialized_start=15676
  _TOPICSETTINGS_READRULE._serialized_end=15957
  _TOPICSETTINGS_ATTRIBUTESENTRY._serialized_start=15959
  _TOPICSETTINGS_ATTRIBUTESENTRY._serialized_end=16008
  _TOPICSETTINGS_REMOTEMIRRORRULE._serialized_start=16011
  _TOPICSETTINGS_REMOTEMIRRORRULE._serialized_end=16209
  _TOPICSETTINGS_FORMAT._serialized_start=16211
  _TOPICSETTINGS_FORMAT._serialized_end=16260
  _CREATETOPICREQUEST._serialized_start=16276
  _CREATETOPICREQUEST._serialized_end=16426
  _CREATETOPICRESPONSE._serialized_start=16428
  _CREATETOPICRESPONSE._serialized_end=16495
  _CREATETOPICRESULT._serialized_start=16497
  _CREATETOPICRESULT._serialized_end=16516
  _ALTERTOPICREQUEST._serialized_start=16519
  _ALTERTOPICREQUEST._serialized_end=16668
  _ALTERTOPICRESPONSE._serialized_start=16670
  _ALTERTOPICRESPONSE._serialized_end=16736
  _ALTERTOPICRESULT._serialized_start=16738
  _ALTERTOPICRESULT._serialized_end=16756
  _ADDREADRULEREQUEST._serialized_start=16759
  _ADDREADRULEREQUEST._serialized_end=16919
  _ADDREADRULERESPONSE._serialized_start=16921
  _ADDREADRULERESPONSE._serialized_end=16988
  _ADDREADRULERESULT._serialized_start=16990
  _ADDREADRULERESULT._serialized_end=17009
  _REMOVEREADRULEREQUEST._serialized_start=17011
  _REMOVEREADRULEREQUEST._serialized_end=17136
  _REMOVEREADRULERESPONSE._serialized_start=17138
  _REMOVEREADRULERESPONSE._serialized_end=17208
  _REMOVEREADRULERESULT._serialized_start=17210
  _REMOVEREADRULERESULT._serialized_end=17232
  _DESCRIBETOPICREQUEST._serialized_start=17234
  _DESCRIBETOPICREQUEST._serialized_end=17335
  _DESCRIBETOPICRESPONSE._serialized_start=17337
  _DESCRIBETOPICRESPONSE._serialized_end=17406
  _DESCRIBETOPICRESULT._serialized_start=17408
  _DESCRIBETOPICRESULT._serialized_end=17513
# @@protoc_insertion_point(module_scope)
