# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/filestore_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/core/protos/filestore_config.proto\x12\x10NKikimrFileStore\"\x97\x01\n\x0fTChannelProfile\x12\x10\n\x08PoolKind\x18\x01 \x01(\t\x12\x0c\n\x04Size\x18\x02 \x01(\x04\x12\x10\n\x08ReadIops\x18\x03 \x01(\x01\x12\x15\n\rReadBandwidth\x18\x04 \x01(\x01\x12\x11\n\tWriteIops\x18\x05 \x01(\x01\x12\x16\n\x0eWriteBandwidth\x18\x06 \x01(\x01\x12\x10\n\x08\x44\x61taKind\x18\x07 \x01(\r\"\xcc\x07\n\x07TConfig\x12\x0f\n\x07Version\x18\x01 \x01(\r\x12\x14\n\x0c\x46ileSystemId\x18\n \x01(\t\x12\x11\n\tProjectId\x18\x0b \x01(\t\x12\x10\n\x08\x46olderId\x18\x0c \x01(\t\x12\x0f\n\x07\x43loudId\x18\r \x01(\t\x12\x11\n\tBlockSize\x18\x0e \x01(\r\x12\x13\n\x0b\x42locksCount\x18\x0f \x01(\x04\x12\x12\n\nCreationTs\x18\x10 \x01(\x04\x12\x0f\n\x07\x41lterTs\x18\x11 \x01(\x04\x12\x19\n\x11RangeIdHasherType\x18\x12 \x01(\r\x12\x42\n\x17\x45xplicitChannelProfiles\x18\x1e \x03(\x0b\x32!.NKikimrFileStore.TChannelProfile\x12\x1d\n\x15PoolKindChangeAllowed\x18\x1f \x01(\x08\x12\x18\n\x10StorageMediaKind\x18  \x01(\r\x12*\n\"PerformanceProfileMaxReadBandwidth\x18! \x01(\r\x12%\n\x1dPerformanceProfileMaxReadIops\x18\" \x01(\r\x12+\n#PerformanceProfileMaxWriteBandwidth\x18# \x01(\r\x12&\n\x1ePerformanceProfileMaxWriteIops\x18$ \x01(\r\x12#\n\x1bPerformanceProfileBoostTime\x18% \x01(\r\x12)\n!PerformanceProfileBoostRefillTime\x18& \x01(\r\x12)\n!PerformanceProfileBoostPercentage\x18\' \x01(\r\x12\x12\n\nNodesCount\x18( \x01(\r\x12+\n#PerformanceProfileThrottlingEnabled\x18) \x01(\x08\x12)\n!PerformanceProfileBurstPercentage\x18* \x01(\r\x12\x37\n/PerformanceProfileDefaultPostponedRequestWeight\x18+ \x01(\r\x12,\n$PerformanceProfileMaxPostponedWeight\x18, \x01(\r\x12\x30\n(PerformanceProfileMaxWriteCostMultiplier\x18- \x01(\r\x12*\n\"PerformanceProfileMaxPostponedTime\x18. \x01(\r\x12+\n#PerformanceProfileMaxPostponedCount\x18/ \x01(\r\"H\n\rTUpdateConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12)\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x19.NKikimrFileStore.TConfig\"`\n\x15TUpdateConfigResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12)\n\x06Status\x18\x03 \x01(\x0e\x32\x19.NKikimrFileStore.EStatus*Q\n\x07\x45Status\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x15\n\x11\x45RROR_BAD_VERSION\x10\x02\x12\x1c\n\x18\x45RROR_UPDATE_IN_PROGRESS\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.filestore_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ESTATUS._serialized_start=1361
  _ESTATUS._serialized_end=1442
  _TCHANNELPROFILE._serialized_start=61
  _TCHANNELPROFILE._serialized_end=212
  _TCONFIG._serialized_start=215
  _TCONFIG._serialized_end=1187
  _TUPDATECONFIG._serialized_start=1189
  _TUPDATECONFIG._serialized_end=1261
  _TUPDATECONFIGRESPONSE._serialized_start=1263
  _TUPDATECONFIGRESPONSE._serialized_end=1359
# @@protoc_insertion_point(module_scope)
