# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/minikql_engine.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/minikql_engine.proto\x12\x14NKikimrMiniKQLEngine*\xe1\x01\n\x07\x45Result\x12\x0b\n\x07Unknown\x10\x00\x12\x06\n\x02Ok\x10\x01\x12\x11\n\rSchemeChanged\x10\x02\x12\x0e\n\nIsReadonly\x10\x03\x12\x0c\n\x08KeyError\x10\x04\x12\x10\n\x0cProgramError\x10\x05\x12\x11\n\rTooManyShards\x10\x06\x12\x0f\n\x0bTooManyData\x10\x07\x12\x14\n\x10SnapshotNotExist\x10\x08\x12\x14\n\x10SnapshotNotReady\x10\t\x12\r\n\tTooManyRS\x10\n\x12\x10\n\x0cResultTooBig\x10\x0b\x12\r\n\tCancelled\x10\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.minikql_engine_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ERESULT._serialized_start=63
  _ERESULT._serialized_end=288
# @@protoc_insertion_point(module_scope)
