# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/sys_view.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import labeled_counters_pb2 as ydb_dot_core_dot_protos_dot_labeled__counters__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/sys_view.proto\x12\x0eNKikimrSysView\x1a&ydb/core/protos/labeled_counters.proto\x1a\x1cydb/core/protos/tablet.proto\"F\n\x12TPartitionStatsKey\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0f\n\x07PartIdx\x18\x03 \x01(\x04\"S\n\tTTtlStats\x12\x13\n\x0bLastRunTime\x18\x01 \x01(\x04\x12\x19\n\x11LastRowsProcessed\x18\x02 \x01(\x04\x12\x16\n\x0eLastRowsErased\x18\x03 \x01(\x04\"\xd5\x03\n\x0fTPartitionStats\x12\x10\n\x08\x44\x61taSize\x18\x01 \x01(\x04\x12\x10\n\x08RowCount\x18\x02 \x01(\x04\x12\x11\n\tIndexSize\x18\x03 \x01(\x04\x12\x10\n\x08\x43PUCores\x18\x04 \x01(\x01\x12\x10\n\x08TabletId\x18\x05 \x01(\x06\x12\x0e\n\x06NodeId\x18\x06 \x01(\r\x12\x11\n\tStartTime\x18\x07 \x01(\x04\x12\x12\n\nAccessTime\x18\x08 \x01(\x04\x12\x12\n\nUpdateTime\x18\t \x01(\x04\x12\x17\n\x0fInFlightTxCount\x18\n \x01(\x04\x12\x12\n\nRowUpdates\x18\x0b \x01(\x04\x12\x12\n\nRowDeletes\x18\x0c \x01(\x04\x12\x10\n\x08RowReads\x18\r \x01(\x04\x12\x12\n\nRangeReads\x18\x0e \x01(\x04\x12\x15\n\rRangeReadRows\x18\x0f \x01(\x04\x12\x1c\n\x14ImmediateTxCompleted\x18\x10 \x01(\x04\x12\x1a\n\x12PlannedTxCompleted\x18\x11 \x01(\x04\x12\x1c\n\x14TxRejectedByOverload\x18\x12 \x01(\x04\x12\x19\n\x11TxRejectedBySpace\x18\x13 \x01(\x04\x12+\n\x08TtlStats\x18\x14 \x01(\x0b\x32\x19.NKikimrSysView.TTtlStats\"\x86\x01\n\x15TPartitionStatsResult\x12/\n\x03Key\x18\x01 \x01(\x0b\x32\".NKikimrSysView.TPartitionStatsKey\x12.\n\x05Stats\x18\x02 \x01(\x0b\x32\x1f.NKikimrSysView.TPartitionStats\x12\x0c\n\x04Path\x18\x03 \x01(\t\"\xf2\x01\n\x14TEvGetPartitionStats\x12\x18\n\x10\x44omainKeyOwnerId\x18\x01 \x01(\x04\x12\x17\n\x0f\x44omainKeyPathId\x18\x02 \x01(\x04\x12\x30\n\x04\x46rom\x18\x03 \x01(\x0b\x32\".NKikimrSysView.TPartitionStatsKey\x12\x15\n\rFromInclusive\x18\x04 \x01(\x08\x12.\n\x02To\x18\x05 \x01(\x0b\x32\".NKikimrSysView.TPartitionStatsKey\x12\x13\n\x0bToInclusive\x18\x06 \x01(\x08\x12\x19\n\x11IncludePathColumn\x18\x07 \x01(\x08\"\xab\x01\n\x1aTEvGetPartitionStatsResult\x12\x34\n\x05Stats\x18\x01 \x03(\x0b\x32%.NKikimrSysView.TPartitionStatsResult\x12\x30\n\x04Next\x18\x02 \x01(\x0b\x32\".NKikimrSysView.TPartitionStatsKey\x12\x11\n\tLastBatch\x18\x03 \x01(\x08\x12\x12\n\nOverloaded\x18\x04 \x01(\x08\"\xa0\x01\n\x0fTQueryDataStats\x12\x10\n\x08ReadRows\x18\x01 \x01(\x04\x12\x11\n\tReadBytes\x18\x02 \x01(\x04\x12\x12\n\nUpdateRows\x18\x03 \x01(\x04\x12\x13\n\x0bUpdateBytes\x18\x04 \x01(\x04\x12\x12\n\nDeleteRows\x18\x05 \x01(\x04\x12\x13\n\x0b\x44\x65leteBytes\x18\x06 \x01(\x04\x12\x16\n\x0ePartitionCount\x18\x07 \x01(\x04\"@\n\nTStatsAggr\x12\x0b\n\x03Min\x18\x01 \x01(\x04\x12\x0b\n\x03Max\x18\x02 \x01(\x04\x12\x0b\n\x03Sum\x18\x03 \x01(\x04\x12\x0b\n\x03\x43nt\x18\x04 \x01(\x04\"\xd5\x03\n\x0bTQueryStats\x12\x11\n\tQueryText\x18\x01 \x01(\t\x12\x15\n\rQueryTextHash\x18\x02 \x01(\x04\x12\x12\n\nDurationMs\x18\x03 \x01(\x04\x12\x11\n\tEndTimeMs\x18\x04 \x01(\x04\x12.\n\x05Stats\x18\x05 \x01(\x0b\x32\x1f.NKikimrSysView.TQueryDataStats\x12\x0f\n\x07UserSID\x18\x06 \x01(\t\x12\x16\n\x0eParametersSize\x18\x07 \x01(\x04\x12\x19\n\x11\x43ompileDurationMs\x18\x08 \x01(\x04\x12\x16\n\x0e\x46romQueryCache\x18\t \x01(\x08\x12\x0e\n\x06NodeId\x18\n \x01(\r\x12\x33\n\x0fShardsCpuTimeUs\x18\x0b \x01(\x0b\x32\x1a.NKikimrSysView.TStatsAggr\x12\x34\n\x10\x43omputeCpuTimeUs\x18\x0c \x01(\x0b\x32\x1a.NKikimrSysView.TStatsAggr\x12\x18\n\x10\x43ompileCpuTimeUs\x18\r \x01(\x04\x12\x18\n\x10ProcessCpuTimeUs\x18\x0e \x01(\x04\x12\x16\n\x0eTotalCpuTimeUs\x18\x0f \x01(\x04\x12\x0c\n\x04Type\x18\x10 \x01(\t\x12\x14\n\x0cRequestUnits\x18\x11 \x01(\x04\"<\n\x0eTTopQueryStats\x12*\n\x05Stats\x18\x01 \x03(\x0b\x32\x1b.NKikimrSysView.TQueryStats\"j\n\x10TEvGetQueryStats\x12-\n\tStatsType\x18\x01 \x01(\x0e\x32\x1a.NKikimrSysView.EStatsType\x12\x13\n\x0bStartBucket\x18\x02 \x01(\x04\x12\x12\n\nTenantName\x18\x03 \x01(\t\".\n\x10THashedQueryText\x12\x0c\n\x04Hash\x18\x01 \x01(\x04\x12\x0c\n\x04Text\x18\x02 \x01(\t\"\xa9\x01\n\x16TEvGetQueryStatsResult\x12/\n\x07\x42uckets\x18\x01 \x03(\x0b\x32\x1e.NKikimrSysView.TTopQueryStats\x12\x12\n\nLastBucket\x18\x02 \x01(\x04\x12\x14\n\x0c\x42ucketSizeMs\x18\x03 \x01(\x04\x12\x34\n\nQueryTexts\x18\x04 \x03(\x0b\x32 .NKikimrSysView.THashedQueryText\",\n\tTPDiskKey\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\"\xe3\x02\n\nTPDiskInfo\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12\x0c\n\x04Kind\x18\x02 \x01(\x04\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12\x0c\n\x04Guid\x18\x04 \x01(\x04\x12\r\n\x05\x42oxId\x18\x05 \x01(\x04\x12\x14\n\x0cSharedWithOs\x18\x06 \x01(\x08\x12\x13\n\x0bReadCentric\x18\x07 \x01(\x08\x12\x15\n\rAvailableSize\x18\x08 \x01(\x04\x12\x11\n\tTotalSize\x18\t \x01(\x04\x12\x10\n\x08StatusV2\x18\x0c \x01(\t\x12\x1d\n\x15StatusChangeTimestamp\x18\r \x01(\x04\x12\x1f\n\x17\x45nforcedDynamicSlotSize\x18\x0e \x01(\x04\x12\x19\n\x11\x45xpectedSlotCount\x18\x0f \x01(\r\x12\x16\n\x0eNumActiveSlots\x18\x10 \x01(\r\x12\x10\n\x08\x43\x61tegory\x18\x11 \x01(\x04\x12\x16\n\x0e\x44\x65\x63ommitStatus\x18\x12 \x01(\tJ\x04\x08\n\x10\x0bJ\x04\x08\x0b\x10\x0c\"_\n\x0bTPDiskEntry\x12&\n\x03Key\x18\x01 \x01(\x0b\x32\x19.NKikimrSysView.TPDiskKey\x12(\n\x04Info\x18\x02 \x01(\x0b\x32\x1a.NKikimrSysView.TPDiskInfo\"\x91\x01\n\x13TEvGetPDisksRequest\x12\'\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x19.NKikimrSysView.TPDiskKey\x12\x15\n\rInclusiveFrom\x18\x02 \x01(\x08\x12%\n\x02To\x18\x03 \x01(\x0b\x32\x19.NKikimrSysView.TPDiskKey\x12\x13\n\x0bInclusiveTo\x18\x04 \x01(\x08\"D\n\x14TEvGetPDisksResponse\x12,\n\x07\x45ntries\x18\x01 \x03(\x0b\x32\x1b.NKikimrSysView.TPDiskEntry\"=\n\tTVSlotKey\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x0f\n\x07VSlotId\x18\x03 \x01(\r\"\xe4\x01\n\nTVSlotInfo\x12\x0f\n\x07GroupId\x18\x02 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x03 \x01(\r\x12\x11\n\tFailRealm\x18\x04 \x01(\r\x12\x12\n\nFailDomain\x18\x05 \x01(\r\x12\r\n\x05VDisk\x18\x06 \x01(\r\x12\x15\n\rAllocatedSize\x18\x07 \x01(\x04\x12\x15\n\rAvailableSize\x18\x08 \x01(\x04\x12\x10\n\x08StatusV2\x18\x0c \x01(\t\x12\x0c\n\x04Kind\x18\r \x01(\t\x12\x16\n\x0eIsBeingDeleted\x18\x0e \x01(\x08J\x04\x08\x01\x10\x02J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"_\n\x0bTVSlotEntry\x12&\n\x03Key\x18\x01 \x01(\x0b\x32\x19.NKikimrSysView.TVSlotKey\x12(\n\x04Info\x18\x02 \x01(\x0b\x32\x1a.NKikimrSysView.TVSlotInfo\"\x91\x01\n\x13TEvGetVSlotsRequest\x12\'\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x19.NKikimrSysView.TVSlotKey\x12\x15\n\rInclusiveFrom\x18\x02 \x01(\x08\x12%\n\x02To\x18\x03 \x01(\x0b\x32\x19.NKikimrSysView.TVSlotKey\x12\x13\n\x0bInclusiveTo\x18\x04 \x01(\x08\"D\n\x14TEvGetVSlotsResponse\x12,\n\x07\x45ntries\x18\x01 \x03(\x0b\x32\x1b.NKikimrSysView.TVSlotEntry\"\x1c\n\tTGroupKey\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\"\xba\x02\n\nTGroupInfo\x12\x12\n\nGeneration\x18\x01 \x01(\r\x12\r\n\x05\x42oxId\x18\x03 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x04 \x01(\x04\x12\x16\n\x0e\x45ncryptionMode\x18\x05 \x01(\r\x12\x16\n\x0eLifeCyclePhase\x18\x06 \x01(\r\x12\x15\n\rAllocatedSize\x18\x07 \x01(\x04\x12\x15\n\rAvailableSize\x18\x08 \x01(\x04\x12\x17\n\x0fSeenOperational\x18\x0b \x01(\x08\x12\x18\n\x10\x45rasureSpeciesV2\x18\x0c \x01(\t\x12\x1b\n\x13PutTabletLogLatency\x18\r \x01(\x04\x12\x1a\n\x12PutUserDataLatency\x18\x0e \x01(\x04\x12\x16\n\x0eGetFastLatency\x18\x0f \x01(\x04J\x04\x08\x02\x10\x03J\x04\x08\t\x10\nJ\x04\x08\n\x10\x0b\"_\n\x0bTGroupEntry\x12&\n\x03Key\x18\x01 \x01(\x0b\x32\x19.NKikimrSysView.TGroupKey\x12(\n\x04Info\x18\x02 \x01(\x0b\x32\x1a.NKikimrSysView.TGroupInfo\"\x91\x01\n\x13TEvGetGroupsRequest\x12\'\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x19.NKikimrSysView.TGroupKey\x12\x15\n\rInclusiveFrom\x18\x02 \x01(\x08\x12%\n\x02To\x18\x03 \x01(\x0b\x32\x19.NKikimrSysView.TGroupKey\x12\x13\n\x0bInclusiveTo\x18\x04 \x01(\x08\"D\n\x14TEvGetGroupsResponse\x12,\n\x07\x45ntries\x18\x01 \x03(\x0b\x32\x1b.NKikimrSysView.TGroupEntry\"7\n\x0fTStoragePoolKey\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x02 \x01(\x04\"\xfd\x01\n\x10TStoragePoolInfo\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x0c\n\x04Kind\x18\x05 \x01(\t\x12\x11\n\tNumGroups\x18\x06 \x01(\r\x12\x16\n\x0e\x45ncryptionMode\x18\x07 \x01(\r\x12\x15\n\rSchemeshardId\x18\x08 \x01(\x04\x12\x0e\n\x06PathId\x18\t \x01(\x04\x12\x18\n\x10\x45rasureSpeciesV2\x18\n \x01(\t\x12\x13\n\x0bVDiskKindV2\x18\x0c \x01(\t\x12\x13\n\x0bPDiskFilter\x18\r \x01(\t\x12\x17\n\x0fPDiskFilterData\x18\x0e \x01(\x0cJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"q\n\x11TStoragePoolEntry\x12,\n\x03Key\x18\x01 \x01(\x0b\x32\x1f.NKikimrSysView.TStoragePoolKey\x12.\n\x04Info\x18\x02 \x01(\x0b\x32 .NKikimrSysView.TStoragePoolInfo\"\xa3\x01\n\x19TEvGetStoragePoolsRequest\x12-\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x1f.NKikimrSysView.TStoragePoolKey\x12\x15\n\rInclusiveFrom\x18\x02 \x01(\x08\x12+\n\x02To\x18\x03 \x01(\x0b\x32\x1f.NKikimrSysView.TStoragePoolKey\x12\x13\n\x0bInclusiveTo\x18\x04 \x01(\x08\"P\n\x1aTEvGetStoragePoolsResponse\x12\x32\n\x07\x45ntries\x18\x01 \x03(\x0b\x32!.NKikimrSysView.TStoragePoolEntry\"\xfa\x01\n\x12TStorageStatsEntry\x12\x13\n\x0bPDiskFilter\x18\x02 \x01(\t\x12\x16\n\x0e\x45rasureSpecies\x18\x03 \x01(\t\x12\x1c\n\x14\x43urrentGroupsCreated\x18\x04 \x01(\r\x12\x1c\n\x14\x43urrentAllocatedSize\x18\x05 \x01(\x04\x12\x1c\n\x14\x43urrentAvailableSize\x18\x06 \x01(\x04\x12\x1f\n\x17\x41vailableGroupsToCreate\x18\x07 \x01(\r\x12\x1d\n\x15\x41vailableSizeToCreate\x18\x08 \x01(\x04\x12\x17\n\x0fPDiskFilterData\x18\t \x01(\x0cJ\x04\x08\x01\x10\x02\"\x1b\n\x19TEvGetStorageStatsRequest\"Q\n\x1aTEvGetStorageStatsResponse\x12\x33\n\x07\x45ntries\x18\x01 \x03(\x0b\x32\".NKikimrSysView.TStorageStatsEntry\"\xcd\x01\n\x0cTTabletEntry\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nFollowerId\x18\x02 \x01(\r\x12\x0c\n\x04Type\x18\x03 \x01(\t\x12\r\n\x05State\x18\x04 \x01(\t\x12\x15\n\rVolatileState\x18\x05 \x01(\t\x12\x11\n\tBootState\x18\x06 \x01(\t\x12\x12\n\nGeneration\x18\x07 \x01(\r\x12\x0e\n\x06NodeId\x18\x08 \x01(\r\x12\x0b\n\x03\x43PU\x18\t \x01(\x04\x12\x0e\n\x06Memory\x18\n \x01(\x04\x12\x0f\n\x07Network\x18\x0b \x01(\x04\"2\n\x16TEvGetTabletIdsRequest\x12\x0c\n\x04\x46rom\x18\x01 \x01(\x06\x12\n\n\x02To\x18\x02 \x01(\x06\",\n\x17TEvGetTabletIdsResponse\x12\x11\n\tTabletIds\x18\x01 \x03(\x06\"A\n\x14TEvGetTabletsRequest\x12\x11\n\tTabletIds\x18\x01 \x03(\x06\x12\x16\n\x0e\x42\x61tchSizeLimit\x18\x02 \x01(\r\"\\\n\x15TEvGetTabletsResponse\x12-\n\x07\x45ntries\x18\x01 \x03(\x0b\x32\x1c.NKikimrSysView.TTabletEntry\x12\x14\n\x0cNextTabletId\x18\x02 \x01(\x06\"\xc7\x04\n\rTQueryMetrics\x12\x15\n\rQueryTextHash\x18\x01 \x01(\x06\x12\r\n\x05\x43ount\x18\x02 \x01(\x04\x12\x39\n\tCpuTimeUs\x18\x03 \x01(\x0b\x32&.NKikimrSysView.TQueryMetrics.TMetrics\x12:\n\nDurationUs\x18\x04 \x01(\x0b\x32&.NKikimrSysView.TQueryMetrics.TMetrics\x12\x38\n\x08ReadRows\x18\x05 \x01(\x0b\x32&.NKikimrSysView.TQueryMetrics.TMetrics\x12\x39\n\tReadBytes\x18\x06 \x01(\x0b\x32&.NKikimrSysView.TQueryMetrics.TMetrics\x12:\n\nUpdateRows\x18\x07 \x01(\x0b\x32&.NKikimrSysView.TQueryMetrics.TMetrics\x12;\n\x0bUpdateBytes\x18\x08 \x01(\x0b\x32&.NKikimrSysView.TQueryMetrics.TMetrics\x12:\n\nDeleteRows\x18\t \x01(\x0b\x32&.NKikimrSysView.TQueryMetrics.TMetrics\x12<\n\x0cRequestUnits\x18\n \x01(\x0b\x32&.NKikimrSysView.TQueryMetrics.TMetrics\x1a\x31\n\x08TMetrics\x12\x0b\n\x03Sum\x18\x01 \x01(\x04\x12\x0b\n\x03Min\x18\x02 \x01(\x04\x12\x0b\n\x03Max\x18\x03 \x01(\x04\"\xef\x03\n\x17TEvIntervalQuerySummary\x12\x10\n\x08\x44\x61tabase\x18\x01 \x01(\t\x12\x15\n\rIntervalEndUs\x18\x02 \x01(\x04\x12\x0e\n\x06NodeId\x18\x03 \x01(\r\x12\x42\n\x07Metrics\x18\x04 \x01(\x0b\x32\x31.NKikimrSysView.TEvIntervalQuerySummary.TQuerySet\x12H\n\rTopByDuration\x18\x05 \x01(\x0b\x32\x31.NKikimrSysView.TEvIntervalQuerySummary.TQuerySet\x12I\n\x0eTopByReadBytes\x18\x06 \x01(\x0b\x32\x31.NKikimrSysView.TEvIntervalQuerySummary.TQuerySet\x12G\n\x0cTopByCpuTime\x18\x07 \x01(\x0b\x32\x31.NKikimrSysView.TEvIntervalQuerySummary.TQuerySet\x12L\n\x11TopByRequestUnits\x18\x08 \x01(\x0b\x32\x31.NKikimrSysView.TEvIntervalQuerySummary.TQuerySet\x1a+\n\tTQuerySet\x12\x0e\n\x06Hashes\x18\x01 \x03(\x06\x12\x0e\n\x06Values\x18\x02 \x03(\x04\"\xd1\x01\n\x1cTEvGetIntervalMetricsRequest\x12\x10\n\x08\x44\x61tabase\x18\x01 \x01(\t\x12\x15\n\rIntervalEndUs\x18\x02 \x01(\x04\x12\x0f\n\x07Metrics\x18\x03 \x03(\x06\x12\x17\n\x0fQueryTextsToGet\x18\x04 \x03(\x06\x12\x15\n\rTopByDuration\x18\x05 \x03(\x06\x12\x16\n\x0eTopByReadBytes\x18\x06 \x03(\x06\x12\x14\n\x0cTopByCpuTime\x18\x07 \x03(\x06\x12\x19\n\x11TopByRequestUnits\x18\x08 \x03(\x06\"\xb2\x03\n\x1dTEvGetIntervalMetricsResponse\x12\x15\n\rIntervalEndUs\x18\x01 \x01(\x04\x12.\n\x07Metrics\x18\x02 \x03(\x0b\x32\x1d.NKikimrSysView.TQueryMetrics\x12L\n\nQueryTexts\x18\x03 \x03(\x0b\x32\x38.NKikimrSysView.TEvGetIntervalMetricsResponse.TQueryText\x12\x32\n\rTopByDuration\x18\x04 \x03(\x0b\x32\x1b.NKikimrSysView.TQueryStats\x12\x33\n\x0eTopByReadBytes\x18\x05 \x03(\x0b\x32\x1b.NKikimrSysView.TQueryStats\x12\x31\n\x0cTopByCpuTime\x18\x06 \x03(\x0b\x32\x1b.NKikimrSysView.TQueryStats\x12\x36\n\x11TopByRequestUnits\x18\x07 \x03(\x0b\x32\x1b.NKikimrSysView.TQueryStats\x1a(\n\nTQueryText\x12\x0c\n\x04Hash\x18\x01 \x01(\x06\x12\x0c\n\x04Text\x18\x02 \x01(\t\")\n\x15TEvConfigureProcessor\x12\x10\n\x08\x44\x61tabase\x18\x01 \x01(\t\"7\n\x10TQueryMetricsKey\x12\x15\n\rIntervalEndUs\x18\x01 \x01(\x04\x12\x0c\n\x04Rank\x18\x02 \x01(\r\"\x86\x01\n\x12TQueryMetricsEntry\x12-\n\x03Key\x18\x01 \x01(\x0b\x32 .NKikimrSysView.TQueryMetricsKey\x12.\n\x07Metrics\x18\x02 \x01(\x0b\x32\x1d.NKikimrSysView.TQueryMetrics\x12\x11\n\tQueryText\x18\x03 \x01(\t\"m\n\x10TQueryStatsEntry\x12-\n\x03Key\x18\x01 \x01(\x0b\x32 .NKikimrSysView.TQueryMetricsKey\x12*\n\x05Stats\x18\x02 \x01(\x0b\x32\x1b.NKikimrSysView.TQueryStats\"\xcf\x01\n\x19TEvGetQueryMetricsRequest\x12.\n\x04\x46rom\x18\x01 \x01(\x0b\x32 .NKikimrSysView.TQueryMetricsKey\x12\x15\n\rInclusiveFrom\x18\x02 \x01(\x08\x12,\n\x02To\x18\x03 \x01(\x0b\x32 .NKikimrSysView.TQueryMetricsKey\x12\x13\n\x0bInclusiveTo\x18\x04 \x01(\x08\x12(\n\x04Type\x18\x05 \x01(\x0e\x32\x1a.NKikimrSysView.EStatsType\"\xa8\x01\n\x1aTEvGetQueryMetricsResponse\x12\x33\n\x07\x45ntries\x18\x01 \x03(\x0b\x32\".NKikimrSysView.TQueryMetricsEntry\x12.\n\x04Next\x18\x02 \x01(\x0b\x32 .NKikimrSysView.TQueryMetricsKey\x12\x11\n\tLastBatch\x18\x03 \x01(\x08\x12\x12\n\nOverloaded\x18\x04 \x01(\x08\"\xa4\x01\n\x18TEvGetQueryStatsResponse\x12\x31\n\x07\x45ntries\x18\x01 \x03(\x0b\x32 .NKikimrSysView.TQueryStatsEntry\x12.\n\x04Next\x18\x02 \x01(\x0b\x32 .NKikimrSysView.TQueryMetricsKey\x12\x11\n\tLastBatch\x18\x03 \x01(\x08\x12\x12\n\nOverloaded\x18\x04 \x01(\x08\"\xba\x01\n\x0bTDbCounters\x12\x0e\n\x06Simple\x18\x01 \x03(\x04\x12\x12\n\nCumulative\x18\x02 \x03(\x04\x12\x17\n\x0f\x43umulativeCount\x18\x03 \x01(\x04\x12\x39\n\tHistogram\x18\x04 \x03(\x0b\x32&.NKikimrSysView.TDbCounters.THistogram\x1a\x33\n\nTHistogram\x12\x0f\n\x07\x42uckets\x18\x01 \x03(\x04\x12\x14\n\x0c\x42ucketsCount\x18\x02 \x01(\x04\"\xa0\x02\n\x11TDbTabletCounters\x12\x33\n\x04Type\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x35\n\x10\x45xecutorCounters\x18\x02 \x01(\x0b\x32\x1b.NKikimrSysView.TDbCounters\x12\x30\n\x0b\x41ppCounters\x18\x03 \x01(\x0b\x32\x1b.NKikimrSysView.TDbCounters\x12\x38\n\x13MaxExecutorCounters\x18\x04 \x01(\x0b\x32\x1b.NKikimrSysView.TDbCounters\x12\x33\n\x0eMaxAppCounters\x18\x05 \x01(\x0b\x32\x1b.NKikimrSysView.TDbCounters\"q\n\x0fTDbGRpcCounters\x12\x13\n\x0bGRpcService\x18\x01 \x01(\t\x12\x13\n\x0bGRpcRequest\x18\x02 \x01(\t\x12\x34\n\x0fRequestCounters\x18\x03 \x01(\x0b\x32\x1b.NKikimrSysView.TDbCounters\"L\n\x14TDbGRpcProxyCounters\x12\x34\n\x0fRequestCounters\x18\x01 \x01(\x0b\x32\x1b.NKikimrSysView.TDbCounters\"b\n\x12TDbLabeledCounters\x12L\n\x14\x41ggregatedPerTablets\x18\x01 \x01(\x0b\x32..NKikimrLabeledCounters.TTabletLabeledCounters\"\xaf\x02\n\x12TDbServiceCounters\x12)\n\x04Main\x18\x01 \x01(\x0b\x32\x1b.NKikimrSysView.TDbCounters\x12\x39\n\x0eTabletCounters\x18\x02 \x03(\x0b\x32!.NKikimrSysView.TDbTabletCounters\x12\x35\n\x0cGRpcCounters\x18\x03 \x03(\x0b\x32\x1f.NKikimrSysView.TDbGRpcCounters\x12?\n\x11GRpcProxyCounters\x18\x04 \x01(\x0b\x32$.NKikimrSysView.TDbGRpcProxyCounters\x12;\n\x0fLabeledCounters\x18\x05 \x03(\x0b\x32\".NKikimrSysView.TDbLabeledCounters\"\x91\x02\n\x18TEvSendDbCountersRequest\x12R\n\x0fServiceCounters\x18\x01 \x03(\x0b\x32\x39.NKikimrSysView.TEvSendDbCountersRequest.TServiceCounters\x12\x0e\n\x06NodeId\x18\x02 \x01(\x04\x12\x12\n\nGeneration\x18\x03 \x01(\x04\x1a}\n\x10TServiceCounters\x12\x33\n\x07Service\x18\x01 \x01(\x0e\x32\".NKikimrSysView.EDbCountersService\x12\x34\n\x08\x43ounters\x18\x02 \x01(\x0b\x32\".NKikimrSysView.TDbServiceCounters\"A\n\x19TEvSendDbCountersResponse\x12\x10\n\x08\x44\x61tabase\x18\x01 \x01(\t\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"\x9f\x02\n\x1fTEvSendDbLabeledCountersRequest\x12Y\n\x0fServiceCounters\x18\x01 \x03(\x0b\x32@.NKikimrSysView.TEvSendDbLabeledCountersRequest.TServiceCounters\x12\x0e\n\x06NodeId\x18\x02 \x01(\x04\x12\x12\n\nGeneration\x18\x03 \x01(\x04\x1a}\n\x10TServiceCounters\x12\x33\n\x07Service\x18\x01 \x01(\x0e\x32\".NKikimrSysView.EDbCountersService\x12\x34\n\x08\x43ounters\x18\x02 \x01(\x0b\x32\".NKikimrSysView.TDbServiceCounters\"H\n TEvSendDbLabeledCountersResponse\x12\x10\n\x08\x44\x61tabase\x18\x01 \x01(\t\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"8\n\x11TTopPartitionsKey\x12\x15\n\rIntervalEndUs\x18\x01 \x01(\x04\x12\x0c\n\x04Rank\x18\x02 \x01(\x04\"\xba\x01\n\x12TTopPartitionsInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x12\n\nPeakTimeUs\x18\x03 \x01(\x04\x12\x10\n\x08\x43PUCores\x18\x04 \x01(\x01\x12\x0e\n\x06NodeId\x18\x05 \x01(\r\x12\x10\n\x08\x44\x61taSize\x18\x06 \x01(\x04\x12\x10\n\x08RowCount\x18\x07 \x01(\x04\x12\x11\n\tIndexSize\x18\x08 \x01(\x04\x12\x17\n\x0fInFlightTxCount\x18\t \x01(\r\"w\n\x13TTopPartitionsEntry\x12.\n\x03Key\x18\x01 \x01(\x0b\x32!.NKikimrSysView.TTopPartitionsKey\x12\x30\n\x04Info\x18\x02 \x01(\x0b\x32\".NKikimrSysView.TTopPartitionsInfo\"\xd2\x01\n\x1aTEvGetTopPartitionsRequest\x12/\n\x04\x46rom\x18\x01 \x01(\x0b\x32!.NKikimrSysView.TTopPartitionsKey\x12\x15\n\rInclusiveFrom\x18\x02 \x01(\x08\x12-\n\x02To\x18\x03 \x01(\x0b\x32!.NKikimrSysView.TTopPartitionsKey\x12\x13\n\x0bInclusiveTo\x18\x04 \x01(\x08\x12(\n\x04Type\x18\x05 \x01(\x0e\x32\x1a.NKikimrSysView.EStatsType\"\xab\x01\n\x1bTEvGetTopPartitionsResponse\x12\x34\n\x07\x45ntries\x18\x01 \x03(\x0b\x32#.NKikimrSysView.TTopPartitionsEntry\x12/\n\x04Next\x18\x02 \x01(\x0b\x32!.NKikimrSysView.TTopPartitionsKey\x12\x11\n\tLastBatch\x18\x03 \x01(\x08\x12\x12\n\nOverloaded\x18\x04 \x01(\x08\"^\n\x14TEvSendTopPartitions\x12\x36\n\nPartitions\x18\x01 \x03(\x0b\x32\".NKikimrSysView.TTopPartitionsInfo\x12\x0e\n\x06TimeUs\x18\x02 \x01(\x04*\xe4\x02\n\nEStatsType\x12\x1b\n\x17TOP_DURATION_ONE_MINUTE\x10\x01\x12\x19\n\x15TOP_DURATION_ONE_HOUR\x10\x02\x12\x1d\n\x19TOP_READ_BYTES_ONE_MINUTE\x10\x03\x12\x1b\n\x17TOP_READ_BYTES_ONE_HOUR\x10\x04\x12\x1b\n\x17TOP_CPU_TIME_ONE_MINUTE\x10\x05\x12\x19\n\x15TOP_CPU_TIME_ONE_HOUR\x10\x06\x12\x16\n\x12METRICS_ONE_MINUTE\x10\x07\x12\x14\n\x10METRICS_ONE_HOUR\x10\x08\x12 \n\x1cTOP_REQUEST_UNITS_ONE_MINUTE\x10\t\x12\x1e\n\x1aTOP_REQUEST_UNITS_ONE_HOUR\x10\n\x12\x1d\n\x19TOP_PARTITIONS_ONE_MINUTE\x10\x0b\x12\x1b\n\x17TOP_PARTITIONS_ONE_HOUR\x10\x0c*q\n\x12\x45\x44\x62\x43ountersService\x12\x07\n\x03KQP\x10\x01\x12\x0b\n\x07TABLETS\x10\x02\x12\x08\n\x04GRPC\x10\x03\x12\x0e\n\nGRPC_PROXY\x10\x04\x12\x0b\n\x07LABELED\x10\x05\x12\x0e\n\nRESERVED_3\x10\x06\x12\x0e\n\nRESERVED_4\x10\x07\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.sys_view_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ESTATSTYPE._serialized_start=11161
  _ESTATSTYPE._serialized_end=11517
  _EDBCOUNTERSSERVICE._serialized_start=11519
  _EDBCOUNTERSSERVICE._serialized_end=11632
  _TPARTITIONSTATSKEY._serialized_start=120
  _TPARTITIONSTATSKEY._serialized_end=190
  _TTTLSTATS._serialized_start=192
  _TTTLSTATS._serialized_end=275
  _TPARTITIONSTATS._serialized_start=278
  _TPARTITIONSTATS._serialized_end=747
  _TPARTITIONSTATSRESULT._serialized_start=750
  _TPARTITIONSTATSRESULT._serialized_end=884
  _TEVGETPARTITIONSTATS._serialized_start=887
  _TEVGETPARTITIONSTATS._serialized_end=1129
  _TEVGETPARTITIONSTATSRESULT._serialized_start=1132
  _TEVGETPARTITIONSTATSRESULT._serialized_end=1303
  _TQUERYDATASTATS._serialized_start=1306
  _TQUERYDATASTATS._serialized_end=1466
  _TSTATSAGGR._serialized_start=1468
  _TSTATSAGGR._serialized_end=1532
  _TQUERYSTATS._serialized_start=1535
  _TQUERYSTATS._serialized_end=2004
  _TTOPQUERYSTATS._serialized_start=2006
  _TTOPQUERYSTATS._serialized_end=2066
  _TEVGETQUERYSTATS._serialized_start=2068
  _TEVGETQUERYSTATS._serialized_end=2174
  _THASHEDQUERYTEXT._serialized_start=2176
  _THASHEDQUERYTEXT._serialized_end=2222
  _TEVGETQUERYSTATSRESULT._serialized_start=2225
  _TEVGETQUERYSTATSRESULT._serialized_end=2394
  _TPDISKKEY._serialized_start=2396
  _TPDISKKEY._serialized_end=2440
  _TPDISKINFO._serialized_start=2443
  _TPDISKINFO._serialized_end=2798
  _TPDISKENTRY._serialized_start=2800
  _TPDISKENTRY._serialized_end=2895
  _TEVGETPDISKSREQUEST._serialized_start=2898
  _TEVGETPDISKSREQUEST._serialized_end=3043
  _TEVGETPDISKSRESPONSE._serialized_start=3045
  _TEVGETPDISKSRESPONSE._serialized_end=3113
  _TVSLOTKEY._serialized_start=3115
  _TVSLOTKEY._serialized_end=3176
  _TVSLOTINFO._serialized_start=3179
  _TVSLOTINFO._serialized_end=3407
  _TVSLOTENTRY._serialized_start=3409
  _TVSLOTENTRY._serialized_end=3504
  _TEVGETVSLOTSREQUEST._serialized_start=3507
  _TEVGETVSLOTSREQUEST._serialized_end=3652
  _TEVGETVSLOTSRESPONSE._serialized_start=3654
  _TEVGETVSLOTSRESPONSE._serialized_end=3722
  _TGROUPKEY._serialized_start=3724
  _TGROUPKEY._serialized_end=3752
  _TGROUPINFO._serialized_start=3755
  _TGROUPINFO._serialized_end=4069
  _TGROUPENTRY._serialized_start=4071
  _TGROUPENTRY._serialized_end=4166
  _TEVGETGROUPSREQUEST._serialized_start=4169
  _TEVGETGROUPSREQUEST._serialized_end=4314
  _TEVGETGROUPSRESPONSE._serialized_start=4316
  _TEVGETGROUPSRESPONSE._serialized_end=4384
  _TSTORAGEPOOLKEY._serialized_start=4386
  _TSTORAGEPOOLKEY._serialized_end=4441
  _TSTORAGEPOOLINFO._serialized_start=4444
  _TSTORAGEPOOLINFO._serialized_end=4697
  _TSTORAGEPOOLENTRY._serialized_start=4699
  _TSTORAGEPOOLENTRY._serialized_end=4812
  _TEVGETSTORAGEPOOLSREQUEST._serialized_start=4815
  _TEVGETSTORAGEPOOLSREQUEST._serialized_end=4978
  _TEVGETSTORAGEPOOLSRESPONSE._serialized_start=4980
  _TEVGETSTORAGEPOOLSRESPONSE._serialized_end=5060
  _TSTORAGESTATSENTRY._serialized_start=5063
  _TSTORAGESTATSENTRY._serialized_end=5313
  _TEVGETSTORAGESTATSREQUEST._serialized_start=5315
  _TEVGETSTORAGESTATSREQUEST._serialized_end=5342
  _TEVGETSTORAGESTATSRESPONSE._serialized_start=5344
  _TEVGETSTORAGESTATSRESPONSE._serialized_end=5425
  _TTABLETENTRY._serialized_start=5428
  _TTABLETENTRY._serialized_end=5633
  _TEVGETTABLETIDSREQUEST._serialized_start=5635
  _TEVGETTABLETIDSREQUEST._serialized_end=5685
  _TEVGETTABLETIDSRESPONSE._serialized_start=5687
  _TEVGETTABLETIDSRESPONSE._serialized_end=5731
  _TEVGETTABLETSREQUEST._serialized_start=5733
  _TEVGETTABLETSREQUEST._serialized_end=5798
  _TEVGETTABLETSRESPONSE._serialized_start=5800
  _TEVGETTABLETSRESPONSE._serialized_end=5892
  _TQUERYMETRICS._serialized_start=5895
  _TQUERYMETRICS._serialized_end=6478
  _TQUERYMETRICS_TMETRICS._serialized_start=6429
  _TQUERYMETRICS_TMETRICS._serialized_end=6478
  _TEVINTERVALQUERYSUMMARY._serialized_start=6481
  _TEVINTERVALQUERYSUMMARY._serialized_end=6976
  _TEVINTERVALQUERYSUMMARY_TQUERYSET._serialized_start=6933
  _TEVINTERVALQUERYSUMMARY_TQUERYSET._serialized_end=6976
  _TEVGETINTERVALMETRICSREQUEST._serialized_start=6979
  _TEVGETINTERVALMETRICSREQUEST._serialized_end=7188
  _TEVGETINTERVALMETRICSRESPONSE._serialized_start=7191
  _TEVGETINTERVALMETRICSRESPONSE._serialized_end=7625
  _TEVGETINTERVALMETRICSRESPONSE_TQUERYTEXT._serialized_start=7585
  _TEVGETINTERVALMETRICSRESPONSE_TQUERYTEXT._serialized_end=7625
  _TEVCONFIGUREPROCESSOR._serialized_start=7627
  _TEVCONFIGUREPROCESSOR._serialized_end=7668
  _TQUERYMETRICSKEY._serialized_start=7670
  _TQUERYMETRICSKEY._serialized_end=7725
  _TQUERYMETRICSENTRY._serialized_start=7728
  _TQUERYMETRICSENTRY._serialized_end=7862
  _TQUERYSTATSENTRY._serialized_start=7864
  _TQUERYSTATSENTRY._serialized_end=7973
  _TEVGETQUERYMETRICSREQUEST._serialized_start=7976
  _TEVGETQUERYMETRICSREQUEST._serialized_end=8183
  _TEVGETQUERYMETRICSRESPONSE._serialized_start=8186
  _TEVGETQUERYMETRICSRESPONSE._serialized_end=8354
  _TEVGETQUERYSTATSRESPONSE._serialized_start=8357
  _TEVGETQUERYSTATSRESPONSE._serialized_end=8521
  _TDBCOUNTERS._serialized_start=8524
  _TDBCOUNTERS._serialized_end=8710
  _TDBCOUNTERS_THISTOGRAM._serialized_start=8659
  _TDBCOUNTERS_THISTOGRAM._serialized_end=8710
  _TDBTABLETCOUNTERS._serialized_start=8713
  _TDBTABLETCOUNTERS._serialized_end=9001
  _TDBGRPCCOUNTERS._serialized_start=9003
  _TDBGRPCCOUNTERS._serialized_end=9116
  _TDBGRPCPROXYCOUNTERS._serialized_start=9118
  _TDBGRPCPROXYCOUNTERS._serialized_end=9194
  _TDBLABELEDCOUNTERS._serialized_start=9196
  _TDBLABELEDCOUNTERS._serialized_end=9294
  _TDBSERVICECOUNTERS._serialized_start=9297
  _TDBSERVICECOUNTERS._serialized_end=9600
  _TEVSENDDBCOUNTERSREQUEST._serialized_start=9603
  _TEVSENDDBCOUNTERSREQUEST._serialized_end=9876
  _TEVSENDDBCOUNTERSREQUEST_TSERVICECOUNTERS._serialized_start=9751
  _TEVSENDDBCOUNTERSREQUEST_TSERVICECOUNTERS._serialized_end=9876
  _TEVSENDDBCOUNTERSRESPONSE._serialized_start=9878
  _TEVSENDDBCOUNTERSRESPONSE._serialized_end=9943
  _TEVSENDDBLABELEDCOUNTERSREQUEST._serialized_start=9946
  _TEVSENDDBLABELEDCOUNTERSREQUEST._serialized_end=10233
  _TEVSENDDBLABELEDCOUNTERSREQUEST_TSERVICECOUNTERS._serialized_start=9751
  _TEVSENDDBLABELEDCOUNTERSREQUEST_TSERVICECOUNTERS._serialized_end=9876
  _TEVSENDDBLABELEDCOUNTERSRESPONSE._serialized_start=10235
  _TEVSENDDBLABELEDCOUNTERSRESPONSE._serialized_end=10307
  _TTOPPARTITIONSKEY._serialized_start=10309
  _TTOPPARTITIONSKEY._serialized_end=10365
  _TTOPPARTITIONSINFO._serialized_start=10368
  _TTOPPARTITIONSINFO._serialized_end=10554
  _TTOPPARTITIONSENTRY._serialized_start=10556
  _TTOPPARTITIONSENTRY._serialized_end=10675
  _TEVGETTOPPARTITIONSREQUEST._serialized_start=10678
  _TEVGETTOPPARTITIONSREQUEST._serialized_end=10888
  _TEVGETTOPPARTITIONSRESPONSE._serialized_start=10891
  _TEVGETTOPPARTITIONSRESPONSE._serialized_end=11062
  _TEVSENDTOPPARTITIONS._serialized_start=11064
  _TEVSENDTOPPARTITIONS._serialized_end=11158
# @@protoc_insertion_point(module_scope)
