# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/node_whiteboard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import blobstorage_disk_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from ydb.core.protos import tracing_pb2 as ydb_dot_core_dot_protos_dot_tracing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/node_whiteboard.proto\x12\x11NKikimrWhiteboard\x1a,library/cpp/actors/protos/interconnect.proto\x1a\x1cydb/core/protos/tablet.proto\x1a ydb/core/protos/subdomains.proto\x1a&ydb/core/protos/blobstorage_disk.proto\x1a google/protobuf/descriptor.proto\x1a\x1dydb/core/protos/tracing.proto\"4\n\x16TCustomTabletAttribute\x12\x0b\n\x03Key\x18\x01 \x01(\r\x12\r\n\x05Value\x18\x02 \x01(\t\"\x99\x06\n\x10TTabletStateInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nCreateTime\x18\x02 \x01(\x04\x12\x12\n\nChangeTime\x18\x03 \x01(\x04\x12?\n\x05State\x18\x04 \x01(\x0e\x32\x30.NKikimrWhiteboard.TTabletStateInfo.ETabletState\x12\x11\n\tUserState\x18\x05 \x01(\r\x12\x12\n\nGeneration\x18\x06 \x01(\r\x12\x33\n\x04Type\x18\x07 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x0c\n\x04Host\x18\x08 \x01(\t\x12\x17\n\x0f\x43hannelGroupIDs\x18\t \x03(\r\x12=\n\nAttributes\x18\n \x03(\x0b\x32).NKikimrWhiteboard.TCustomTabletAttribute\x12\x0e\n\x06NodeId\x18\x0b \x01(\r\x12\x0e\n\x06Leader\x18\x0c \x01(\x08\x12\r\n\x05\x43ount\x18\r \x01(\r\x12\x12\n\nFollowerId\x18\x0e \x01(\r\x12)\n\x07Overall\x18\x0f \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12/\n\x08TenantId\x18\x10 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x0e\n\x06HiveId\x18\x11 \x01(\x06\"\x98\x02\n\x0c\x45TabletState\x12\x0b\n\x07\x43reated\x10\x00\x12\x17\n\x13ResolveStateStorage\x10\x01\x12\r\n\tCandidate\x10\x02\x12\x14\n\x10\x42lockBlobStorage\x10\x03\x12\x10\n\x0cRebuildGraph\x10\x04\x12\x12\n\x0eWriteZeroEntry\x10\x05\x12\x0c\n\x08Restored\x10\x06\x12\x0c\n\x08\x44iscover\x10\x07\x12\x08\n\x04Lock\x10\x08\x12\x08\n\x04\x44\x65\x61\x64\x10\t\x12\n\n\x06\x41\x63tive\x10\n\x12\x11\n\rResolveLeader\x10\x0b\x12\x0b\n\x07\x44\x65leted\x10\x0c\x12\x0b\n\x07Stopped\x10\r\x12\x0e\n\nReserved14\x10\x0e\x12\x0e\n\nReserved15\x10\x0f\x12\x0e\n\nReserved16\x10\x10\"f\n\x15TEvTabletStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\x12\x0e\n\x06\x46ormat\x18\x05 \x01(\t\x12\x0f\n\x07GroupBy\x18\x14 \x01(\t\x12\x16\n\x0e\x46ilterTabletId\x18\x16 \x03(\x06\"\xb0\x01\n\x16TEvTabletStateResponse\x12<\n\x0fTabletStateInfo\x18\x01 \x03(\x0b\x32#.NKikimrWhiteboard.TTabletStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\x04\x12\x17\n\x0fProcessDuration\x18\x04 \x01(\x04\x12\x0f\n\x07Packed5\x18\x05 \x01(\x0c\"\xba\x01\n\x0eTNodeStateInfo\x12\x10\n\x08PeerName\x18\x01 \x01(\t\x12\x11\n\tConnected\x18\x02 \x01(\x08\x12\x0e\n\x06NodeId\x18\x03 \x01(\r\x12\x12\n\nChangeTime\x18\x04 \x01(\x04\x12\x1f\n\x0fOutputQueueSize\x18\x05 \x01(\rB\x06\xc8\xb9\"\x80\x80@\x12/\n\rConnectStatus\x18\x06 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\r\n\x05\x43ount\x18\r \x01(\r\"+\n\x13TEvNodeStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x80\x01\n\x14TEvNodeStateResponse\x12\x38\n\rNodeStateInfo\x18\x01 \x03(\x0b\x32!.NKikimrWhiteboard.TNodeStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\xc0\x03\n\x0fTPDiskStateInfo\x12\x0f\n\x07PDiskId\x18\x01 \x01(\r\x12\x12\n\nCreateTime\x18\x02 \x01(\x04\x12\x12\n\nChangeTime\x18\x03 \x01(\x04\x12\x0c\n\x04Path\x18\x04 \x01(\t\x12\x0c\n\x04Guid\x18\x05 \x01(\x04\x12\x10\n\x08\x43\x61tegory\x18\x06 \x01(\x04\x12\x1e\n\rAvailableSize\x18\x07 \x01(\x04\x42\x07\xc8\xb9\"\x80\x80\x80\x32\x12\x11\n\tTotalSize\x18\x08 \x01(\x04\x12\x30\n\x05State\x18\t \x01(\x0e\x32!.NKikimrBlobStorage.TPDiskState.E\x12\x0e\n\x06NodeId\x18\n \x01(\r\x12\r\n\x05\x43ount\x18\r \x01(\r\x12(\n\x06\x44\x65vice\x18\x0e \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12*\n\x08Realtime\x18\x0f \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12+\n\tStateFlag\x18\x10 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12)\n\x07Overall\x18\x11 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x14\n\x0cSerialNumber\x18\x12 \x01(\t\",\n\x14TEvPDiskStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x83\x01\n\x15TEvPDiskStateResponse\x12:\n\x0ePDiskStateInfo\x18\x01 \x03(\x0b\x32\".NKikimrWhiteboard.TPDiskStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\xec\x01\n\x16TVDiskSatisfactionRank\x12\x42\n\tFreshRank\x18\x01 \x01(\x0b\x32/.NKikimrWhiteboard.TVDiskSatisfactionRank.TRank\x12\x42\n\tLevelRank\x18\x02 \x01(\x0b\x32/.NKikimrWhiteboard.TVDiskSatisfactionRank.TRank\x1aJ\n\x05TRank\x12\x19\n\x0bRankPercent\x18\x01 \x01(\rB\x04\xc8\xb9\"\x03\x12&\n\x04\x46lag\x18\x02 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\"\x9f\x07\n\x0fTVDiskStateInfo\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x12\n\nCreateTime\x18\x02 \x01(\x04\x12\x12\n\nChangeTime\x18\x03 \x01(\x04\x12\x0f\n\x07PDiskId\x18\x04 \x01(\r\x12\x13\n\x0bVDiskSlotId\x18\x05 \x01(\r\x12\x0c\n\x04Guid\x18\x06 \x01(\x04\x12\x0c\n\x04Kind\x18\x07 \x01(\x04\x12\x0e\n\x06NodeId\x18\t \x01(\r\x12\r\n\x05\x43ount\x18\x11 \x01(\r\x12)\n\x07Overall\x18\n \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x32\n\nVDiskState\x18\x0b \x01(\x0e\x32\x1e.NKikimrWhiteboard.EVDiskState\x12+\n\tDiskSpace\x18\x0c \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x43\n\x10SatisfactionRank\x18\r \x01(\x0b\x32).NKikimrWhiteboard.TVDiskSatisfactionRank\x12\x12\n\nReplicated\x18\x0e \x01(\x08\x12#\n\x14UnreplicatedPhantoms\x18\x14 \x01(\x08:\x05\x66\x61lse\x12&\n\x17UnreplicatedNonPhantoms\x18\x15 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x13ReplicationProgress\x18\x1e \x01(\x02\x12#\n\x1bReplicationSecondsRemaining\x18\x1f \x01(\r\x12\x19\n\x0eUnsyncedVDisks\x18\x0f \x01(\x04:\x01\x30\x12\x1f\n\rAllocatedSize\x18\x10 \x01(\x04\x42\x08\xc8\xb9\"\x80\x80\x80\x80\x02\x12\x1f\n\rAvailableSize\x18\x1c \x01(\x04\x42\x08\xc8\xb9\"\x80\x80\x80\x80\x02\x12\x1a\n\x12HasUnreadableBlobs\x18\x18 \x01(\x08\x12\x17\n\x0fIncarnationGuid\x18\x19 \x01(\x06\x12\x11\n\tDonorMode\x18\x1a \x01(\x08\x12\x14\n\x0cInstanceGuid\x18\x1b \x01(\x06\x12,\n\x06\x44onors\x18\x1d \x03(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12-\n\x0b\x46rontQueues\x18\x12 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x17\n\x0fStoragePoolName\x18\x13 \x01(\t\x12\x16\n\x0eReadThroughput\x18\x16 \x01(\x04\x12\x17\n\x0fWriteThroughput\x18\x17 \x01(\x04\",\n\x14TEvVDiskStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x83\x01\n\x15TEvVDiskStateResponse\x12:\n\x0eVDiskStateInfo\x18\x01 \x03(\x0b\x32\".NKikimrWhiteboard.TVDiskStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\xc2\x03\n\x11TBSGroupStateInfo\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x16\n\x0e\x45rasureSpecies\x18\x02 \x01(\t\x12.\n\x08VDiskIds\x18\x03 \x03(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x12\n\nChangeTime\x18\x04 \x01(\x04\x12\x0e\n\x06NodeId\x18\x05 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x06 \x01(\r\x12)\n\x07Overall\x18\x07 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12)\n\x07Latency\x18\x08 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\r\n\x05\x43ount\x18\r \x01(\r\x12\x17\n\x0fStoragePoolName\x18\x0e \x01(\t\x12\x1e\n\rAllocatedSize\x18\x0f \x01(\x04\x42\x07\xc8\xb9\"\x80\xc2\xd7/\x12\x1e\n\rAvailableSize\x18\x10 \x01(\x04\x42\x07\xc8\xb9\"\x80\xc2\xd7/\x12\x16\n\x0eReadThroughput\x18\x11 \x01(\x04\x12\x17\n\x0fWriteThroughput\x18\x12 \x01(\x04\x12\x12\n\nEncryption\x18\x13 \x01(\x08\x12\x14\n\x0cVDiskNodeIds\x18\x14 \x03(\r\".\n\x16TEvBSGroupStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x89\x01\n\x17TEvBSGroupStateResponse\x12>\n\x10\x42SGroupStateInfo\x18\x01 \x03(\x0b\x32$.NKikimrWhiteboard.TBSGroupStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\xb8\x08\n\x10TSystemStateInfo\x12\x11\n\tStartTime\x18\x01 \x01(\x04\x12\x12\n\nChangeTime\x18\x02 \x01(\x04\x12O\n\x0eSystemLocation\x18\x03 \x01(\x0b\x32\x37.NKikimrWhiteboard.TSystemStateInfo.TLegacyNodeLocation\x12\x13\n\x0bLoadAverage\x18\x04 \x03(\x01\x12\x14\n\x0cNumberOfCpus\x18\x05 \x01(\r\x12-\n\x0bSystemState\x18\x06 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x31\n\x0fMessageBusState\x18\x07 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12+\n\tGRpcState\x18\x08 \x01(\x0e\x32\x18.NKikimrWhiteboard.EFlag\x12\x0e\n\x06NodeId\x18\t \x01(\r\x12\r\n\x05\x43ount\x18\r \x01(\r\x12\x14\n\x0c\x44\x61taCenterId\x18\x0e \x01(\r\x12\x1d\n\x15\x44\x61taCenterDescription\x18\x0f \x01(\t\x12\x12\n\nDataCenter\x18\x10 \x01(\t\x12\x0e\n\x06RackId\x18\x11 \x01(\r\x12\x0c\n\x04Rack\x18\x12 \x01(\t\x12\x0c\n\x04Host\x18\x13 \x01(\t\x12\x0f\n\x07Version\x18\x14 \x01(\t\x12\x41\n\tPoolStats\x18\x15 \x03(\x0b\x32..NKikimrWhiteboard.TSystemStateInfo.TPoolStats\x12@\n\tEndpoints\x18\x16 \x03(\x0b\x32-.NKikimrWhiteboard.TSystemStateInfo.TEndpoint\x12\r\n\x05Roles\x18\x17 \x03(\t\x12\x0f\n\x07Tenants\x18\x18 \x03(\t\x12\x13\n\x0b\x43lusterName\x18\x19 \x01(\t\x12\x12\n\nMemoryUsed\x18\x1a \x01(\x04\x12\x13\n\x0bMemoryLimit\x18\x1b \x01(\x04\x12@\n\x0b\x43onfigState\x18\x1c \x01(\x0e\x32\x1f.NKikimrWhiteboard.EConfigState:\nConsistent\x12\x19\n\x11MemoryUsedInAlloc\x18\x1d \x01(\x04\x12\x14\n\x0cMaxDiskUsage\x18\x1e \x01(\x01\x12\x34\n\x08Location\x18\x1f \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x1a@\n\nTPoolStats\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x13\n\x05Usage\x18\x02 \x01(\x01\x42\x04\xd0\xb9\"\x1e\x12\x0f\n\x07Threads\x18\x03 \x01(\r\x1a*\n\tTEndpoint\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x1aS\n\x13TLegacyNodeLocation\x12\x12\n\nDataCenter\x18\x01 \x01(\r\x12\x0c\n\x04Room\x18\x02 \x01(\r\x12\x0c\n\x04Rack\x18\x03 \x01(\r\x12\x0c\n\x04\x42ody\x18\x04 \x01(\r\"-\n\x15TEvSystemStateRequest\x12\x14\n\x0c\x43hangedSince\x18\x01 \x01(\x04\"\x86\x01\n\x16TEvSystemStateResponse\x12<\n\x0fSystemStateInfo\x18\x01 \x03(\x0b\x32#.NKikimrWhiteboard.TSystemStateInfo\x12\x14\n\x0cResponseTime\x18\x02 \x01(\x04\x12\x18\n\x10ResponseDuration\x18\x03 \x01(\r\"\x18\n\x16TEvTabletLookupRequest\",\n\x17TEvTabletLookupResponse\x12\x11\n\tTabletIDs\x18\x01 \x03(\x04\")\n\x15TEvTraceLookupRequest\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\"D\n\x16TEvTraceLookupResponse\x12*\n\x08TraceIDs\x18\x01 \x03(\x0b\x32\x18.NKikimrTracing.TTraceID\"o\n\x0fTEvTraceRequest\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12)\n\x07TraceID\x18\x02 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12\x0c\n\x04Mode\x18\x03 \x01(\r\x12\x11\n\tPrecision\x18\x04 \x01(\r\"!\n\x10TEvTraceResponse\x12\r\n\x05Trace\x18\x01 \x01(\t\"\x86\x01\n\x14TEvSignalBodyRequest\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12)\n\x07TraceID\x18\x02 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12\x0c\n\x04Mode\x18\x03 \x01(\r\x12\x11\n\tPrecision\x18\x04 \x01(\r\x12\x10\n\x08SignalID\x18\x05 \x01(\t\"+\n\x15TEvSignalBodyResponse\x12\x12\n\nSignalBody\x18\x01 \x01(\t*=\n\x05\x45\x46lag\x12\x08\n\x04Grey\x10\x00\x12\t\n\x05Green\x10\x01\x12\n\n\x06Yellow\x10\x02\x12\n\n\x06Orange\x10\x03\x12\x07\n\x03Red\x10\x04*{\n\x0b\x45VDiskState\x12\x0b\n\x07Initial\x10\x01\x12\x16\n\x12LocalRecoveryError\x10\x02\x12\x14\n\x10SyncGuidRecovery\x10\x03\x12\x19\n\x15SyncGuidRecoveryError\x10\x04\x12\x06\n\x02OK\x10\x05\x12\x0e\n\nPDiskError\x10\x06*,\n\x0c\x45\x43onfigState\x12\x0e\n\nConsistent\x10\x00\x12\x0c\n\x08Outdated\x10\x01:B\n\x19InsignificantChangeAmount\x12\x1d.google.protobuf.FieldOptions\x18\x99\xa7\x04 \x01(\x04:C\n\x1aInsignificantChangePercent\x12\x1d.google.protobuf.FieldOptions\x18\x9a\xa7\x04 \x01(\rB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.node_whiteboard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(InsignificantChangeAmount)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(InsignificantChangePercent)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TNODESTATEINFO.fields_by_name['OutputQueueSize']._options = None
  _TNODESTATEINFO.fields_by_name['OutputQueueSize']._serialized_options = b'\310\271\"\200\200@'
  _TPDISKSTATEINFO.fields_by_name['AvailableSize']._options = None
  _TPDISKSTATEINFO.fields_by_name['AvailableSize']._serialized_options = b'\310\271\"\200\200\2002'
  _TVDISKSATISFACTIONRANK_TRANK.fields_by_name['RankPercent']._options = None
  _TVDISKSATISFACTIONRANK_TRANK.fields_by_name['RankPercent']._serialized_options = b'\310\271\"\003'
  _TVDISKSTATEINFO.fields_by_name['AllocatedSize']._options = None
  _TVDISKSTATEINFO.fields_by_name['AllocatedSize']._serialized_options = b'\310\271\"\200\200\200\200\002'
  _TVDISKSTATEINFO.fields_by_name['AvailableSize']._options = None
  _TVDISKSTATEINFO.fields_by_name['AvailableSize']._serialized_options = b'\310\271\"\200\200\200\200\002'
  _TBSGROUPSTATEINFO.fields_by_name['AllocatedSize']._options = None
  _TBSGROUPSTATEINFO.fields_by_name['AllocatedSize']._serialized_options = b'\310\271\"\200\302\327/'
  _TBSGROUPSTATEINFO.fields_by_name['AvailableSize']._options = None
  _TBSGROUPSTATEINFO.fields_by_name['AvailableSize']._serialized_options = b'\310\271\"\200\302\327/'
  _TSYSTEMSTATEINFO_TPOOLSTATS.fields_by_name['Usage']._options = None
  _TSYSTEMSTATEINFO_TPOOLSTATS.fields_by_name['Usage']._serialized_options = b'\320\271\"\036'
  _EFLAG._serialized_start=6176
  _EFLAG._serialized_end=6237
  _EVDISKSTATE._serialized_start=6239
  _EVDISKSTATE._serialized_end=6362
  _ECONFIGSTATE._serialized_start=6364
  _ECONFIGSTATE._serialized_end=6408
  _TCUSTOMTABLETATTRIBUTE._serialized_start=275
  _TCUSTOMTABLETATTRIBUTE._serialized_end=327
  _TTABLETSTATEINFO._serialized_start=330
  _TTABLETSTATEINFO._serialized_end=1123
  _TTABLETSTATEINFO_ETABLETSTATE._serialized_start=843
  _TTABLETSTATEINFO_ETABLETSTATE._serialized_end=1123
  _TEVTABLETSTATEREQUEST._serialized_start=1125
  _TEVTABLETSTATEREQUEST._serialized_end=1227
  _TEVTABLETSTATERESPONSE._serialized_start=1230
  _TEVTABLETSTATERESPONSE._serialized_end=1406
  _TNODESTATEINFO._serialized_start=1409
  _TNODESTATEINFO._serialized_end=1595
  _TEVNODESTATEREQUEST._serialized_start=1597
  _TEVNODESTATEREQUEST._serialized_end=1640
  _TEVNODESTATERESPONSE._serialized_start=1643
  _TEVNODESTATERESPONSE._serialized_end=1771
  _TPDISKSTATEINFO._serialized_start=1774
  _TPDISKSTATEINFO._serialized_end=2222
  _TEVPDISKSTATEREQUEST._serialized_start=2224
  _TEVPDISKSTATEREQUEST._serialized_end=2268
  _TEVPDISKSTATERESPONSE._serialized_start=2271
  _TEVPDISKSTATERESPONSE._serialized_end=2402
  _TVDISKSATISFACTIONRANK._serialized_start=2405
  _TVDISKSATISFACTIONRANK._serialized_end=2641
  _TVDISKSATISFACTIONRANK_TRANK._serialized_start=2567
  _TVDISKSATISFACTIONRANK_TRANK._serialized_end=2641
  _TVDISKSTATEINFO._serialized_start=2644
  _TVDISKSTATEINFO._serialized_end=3571
  _TEVVDISKSTATEREQUEST._serialized_start=3573
  _TEVVDISKSTATEREQUEST._serialized_end=3617
  _TEVVDISKSTATERESPONSE._serialized_start=3620
  _TEVVDISKSTATERESPONSE._serialized_end=3751
  _TBSGROUPSTATEINFO._serialized_start=3754
  _TBSGROUPSTATEINFO._serialized_end=4204
  _TEVBSGROUPSTATEREQUEST._serialized_start=4206
  _TEVBSGROUPSTATEREQUEST._serialized_end=4252
  _TEVBSGROUPSTATERESPONSE._serialized_start=4255
  _TEVBSGROUPSTATERESPONSE._serialized_end=4392
  _TSYSTEMSTATEINFO._serialized_start=4395
  _TSYSTEMSTATEINFO._serialized_end=5475
  _TSYSTEMSTATEINFO_TPOOLSTATS._serialized_start=5282
  _TSYSTEMSTATEINFO_TPOOLSTATS._serialized_end=5346
  _TSYSTEMSTATEINFO_TENDPOINT._serialized_start=5348
  _TSYSTEMSTATEINFO_TENDPOINT._serialized_end=5390
  _TSYSTEMSTATEINFO_TLEGACYNODELOCATION._serialized_start=5392
  _TSYSTEMSTATEINFO_TLEGACYNODELOCATION._serialized_end=5475
  _TEVSYSTEMSTATEREQUEST._serialized_start=5477
  _TEVSYSTEMSTATEREQUEST._serialized_end=5522
  _TEVSYSTEMSTATERESPONSE._serialized_start=5525
  _TEVSYSTEMSTATERESPONSE._serialized_end=5659
  _TEVTABLETLOOKUPREQUEST._serialized_start=5661
  _TEVTABLETLOOKUPREQUEST._serialized_end=5685
  _TEVTABLETLOOKUPRESPONSE._serialized_start=5687
  _TEVTABLETLOOKUPRESPONSE._serialized_end=5731
  _TEVTRACELOOKUPREQUEST._serialized_start=5733
  _TEVTRACELOOKUPREQUEST._serialized_end=5774
  _TEVTRACELOOKUPRESPONSE._serialized_start=5776
  _TEVTRACELOOKUPRESPONSE._serialized_end=5844
  _TEVTRACEREQUEST._serialized_start=5846
  _TEVTRACEREQUEST._serialized_end=5957
  _TEVTRACERESPONSE._serialized_start=5959
  _TEVTRACERESPONSE._serialized_end=5992
  _TEVSIGNALBODYREQUEST._serialized_start=5995
  _TEVSIGNALBODYREQUEST._serialized_end=6129
  _TEVSIGNALBODYRESPONSE._serialized_start=6131
  _TEVSIGNALBODYRESPONSE._serialized_end=6174
# @@protoc_insertion_point(module_scope)
