# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/core/yq/libs/config/protos/common.proto\x12\x0bNYq.NConfig\"`\n\x10TYdbDriverConfig\x12\x19\n\x11NetworkThreadsNum\x18\x01 \x01(\x04\x12\x18\n\x10\x43lientThreadsNum\x18\x02 \x01(\x04\x12\x17\n\x0fGrpcMemoryQuota\x18\x03 \x01(\x04\"\xea\x02\n\rTCommonConfig\x12\x36\n\x0fYdbDriverConfig\x18\x01 \x01(\x0b\x32\x1d.NYq.NConfig.TYdbDriverConfig\x12\x1b\n\x13YdbMvpCloudEndpoint\x18\x02 \x01(\t\x12\x12\n\nMdbGateway\x18\x03 \x01(\t\x12\x17\n\x0fUseBearerForYdb\x18\x04 \x01(\x08\x12\x18\n\x10MdbTransformHost\x18\x05 \x01(\x08\x12\x1d\n\x15ObjectStorageEndpoint\x18\x06 \x01(\t\x12\x11\n\tIdsPrefix\x18\x07 \x01(\t\x12\x1c\n\x14MaxTasksPerOperation\x18\x08 \x01(\x04\x12\'\n\x1fQueryArtifactsCompressionMethod\x18\t \x01(\t\x12(\n QueryArtifactsCompressionMinSize\x18\n \x01(\x04\x12\x1a\n\x12MonitoringEndpoint\x18\x0b \x01(\tB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TYDBDRIVERCONFIG._serialized_start=60
  _TYDBDRIVERCONFIG._serialized_end=156
  _TCOMMONCONFIG._serialized_start=159
  _TCOMMONCONFIG._serialized_end=521
# @@protoc_insertion_point(module_scope)
