# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/replication.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/replication.proto\x12\x12NKikimrReplication\x1a\x1aydb/core/protos/base.proto\"4\n\x12TStaticCredentials\x12\x0c\n\x04User\x18\x01 \x01(\t\x12\x10\n\x08Password\x18\x02 \x01(\t\"\x87\x04\n\x12TReplicationConfig\x12\x13\n\x0bSrcEndpoint\x18\x01 \x01(\t\x12\x13\n\x0bSrcDatabase\x18\x02 \x01(\t\x12\x43\n\x11StaticCredentials\x18\x03 \x01(\x0b\x32&.NKikimrReplication.TStaticCredentialsH\x00\x12N\n\nEverything\x18\x04 \x01(\x0b\x32\x38.NKikimrReplication.TReplicationConfig.TTargetEverythingH\x01\x12J\n\x08Specific\x18\x05 \x01(\x0b\x32\x36.NKikimrReplication.TReplicationConfig.TTargetSpecificH\x01\x12\x13\n\x0bInitialSync\x18\x06 \x01(\x08\x1a&\n\x11TTargetEverything\x12\x11\n\tDstPrefix\x18\x01 \x01(\t\x1a\x8f\x01\n\x0fTTargetSpecific\x12O\n\x07Targets\x18\x01 \x03(\x0b\x32>.NKikimrReplication.TReplicationConfig.TTargetSpecific.TTarget\x1a+\n\x07TTarget\x12\x0f\n\x07SrcPath\x18\x01 \x01(\t\x12\x0f\n\x07\x44stPath\x18\x02 \x01(\tB\r\n\x0b\x43redentialsB\x08\n\x06Target\",\n\x0cTOperationId\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06PartId\x18\x02 \x01(\r\"\xac\x01\n\x14TEvCreateReplication\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x35\n\x0bOperationId\x18\x02 \x01(\x0b\x32 .NKikimrReplication.TOperationId\x12\x36\n\x06\x43onfig\x18\x03 \x01(\x0b\x32&.NKikimrReplication.TReplicationConfig\"\xe4\x01\n\x1aTEvCreateReplicationResult\x12\x35\n\x0bOperationId\x18\x01 \x01(\x0b\x32 .NKikimrReplication.TOperationId\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x46\n\x06Status\x18\x03 \x01(\x0e\x32\x36.NKikimrReplication.TEvCreateReplicationResult.EStatus\"7\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0e\x41LREADY_EXISTS\x10\x02\"r\n\x12TEvDropReplication\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x35\n\x0bOperationId\x18\x02 \x01(\x0b\x32 .NKikimrReplication.TOperationId\"\xdb\x01\n\x18TEvDropReplicationResult\x12\x35\n\x0bOperationId\x18\x01 \x01(\x0b\x32 .NKikimrReplication.TOperationId\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x44\n\x06Status\x18\x03 \x01(\x0e\x32\x34.NKikimrReplication.TEvDropReplicationResult.EStatus\"2\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\r\n\tNOT_FOUND\x10\x02\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.replication_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSTATICCREDENTIALS._serialized_start=85
  _TSTATICCREDENTIALS._serialized_end=137
  _TREPLICATIONCONFIG._serialized_start=140
  _TREPLICATIONCONFIG._serialized_end=659
  _TREPLICATIONCONFIG_TTARGETEVERYTHING._serialized_start=450
  _TREPLICATIONCONFIG_TTARGETEVERYTHING._serialized_end=488
  _TREPLICATIONCONFIG_TTARGETSPECIFIC._serialized_start=491
  _TREPLICATIONCONFIG_TTARGETSPECIFIC._serialized_end=634
  _TREPLICATIONCONFIG_TTARGETSPECIFIC_TTARGET._serialized_start=591
  _TREPLICATIONCONFIG_TTARGETSPECIFIC_TTARGET._serialized_end=634
  _TOPERATIONID._serialized_start=661
  _TOPERATIONID._serialized_end=705
  _TEVCREATEREPLICATION._serialized_start=708
  _TEVCREATEREPLICATION._serialized_end=880
  _TEVCREATEREPLICATIONRESULT._serialized_start=883
  _TEVCREATEREPLICATIONRESULT._serialized_end=1111
  _TEVCREATEREPLICATIONRESULT_ESTATUS._serialized_start=1056
  _TEVCREATEREPLICATIONRESULT_ESTATUS._serialized_end=1111
  _TEVDROPREPLICATION._serialized_start=1113
  _TEVDROPREPLICATION._serialized_end=1227
  _TEVDROPREPLICATIONRESULT._serialized_start=1230
  _TEVDROPREPLICATIONRESULT._serialized_end=1449
  _TEVDROPREPLICATIONRESULT_ESTATUS._serialized_start=1399
  _TEVDROPREPLICATIONRESULT_ESTATUS._serialized_end=1449
# @@protoc_insertion_point(module_scope)
