# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/issue_id.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.public.issue.protos import issue_severity_pb2 as ydb_dot_library_dot_yql_dot_public_dot_issue_dot_protos_dot_issue__severity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/issue_id.proto\x12\rNKikimrIssues\x1a\x38ydb/library/yql/public/issue/protos/issue_severity.proto\"\xd0\x07\n\nTIssuesIds\x12/\n\x03ids\x18\x01 \x03(\x0b\x32\".NKikimrIssues.TIssuesIds.TIssueId\x1a\x80\x01\n\x08TIssueId\x12\x32\n\x04\x63ode\x18\x02 \x01(\x0e\x32$.NKikimrIssues.TIssuesIds.EIssueCode\x12\x30\n\x08severity\x18\x01 \x01(\x0e\x32\x1e.NYql.TSeverityIds.ESeverityId\x12\x0e\n\x06\x66ormat\x18\x03 \x01(\t\"\x8d\x06\n\nEIssueCode\x12\x11\n\rDEFAULT_ERROR\x10\x00\x12\x0e\n\nUNEXPECTED\x10\x01\x12\x08\n\x04INFO\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\x0b\n\x07SUCCESS\x10\x04\x12\x13\n\rACCESS_DENIED\x10\xc0\x9a\x0c\x12\x14\n\x0ePATH_NOT_EXIST\x10\x88\x9c\x0c\x12\x18\n\x12\x44\x41TABASE_NOT_EXIST\x10\x8a\x9c\x0c\x12\x1d\n\x17GENERIC_DATASHARD_ERROR\x10\xec\x9c\x0c\x12\x1b\n\x15GENERIC_RESOLVE_ERROR\x10\xd0\x9d\x0c\x12\x1a\n\x14RESOLVE_LOOKUP_ERROR\x10\xd1\x9d\x0c\x12\x1b\n\x15GENERIC_TXPROXY_ERROR\x10\xb4\x9e\x0c\x12\x15\n\x0fKEY_PARSE_ERROR\x10\xb5\x9e\x0c\x12\x14\n\x0e\x45MPTY_OP_RANGE\x10\xb6\x9e\x0c\x12\x12\n\x0c\x45NGINE_ERROR\x10\xb7\x9e\x0c\x12\x1b\n\x15\x44OMAIN_LOCALITY_ERROR\x10\xb8\x9e\x0c\x12\x19\n\x13SHARD_NOT_AVAILABLE\x10\xb9\x9e\x0c\x12\x16\n\x10TX_STATE_UNKNOWN\x10\xba\x9e\x0c\x12 \n\x1aTX_DECLINED_BY_COORDINATOR\x10\xbb\x9e\x0c\x12&\n TX_DECLINED_IMPLICIT_COORDINATOR\x10\xbc\x9e\x0c\x12!\n\x1bSHARD_PROGRAM_SIZE_EXCEEDED\x10\xbd\x9e\x0c\x12\x14\n\x0eSCOPE_REQPROXY\x10\x98\x9f\x0c\x12\x1d\n\x17SCOPE_TXPROXY_INTERPRET\x10\xfc\x9f\x0c\x12\x1b\n\x15SCOPE_TXPROXY_RESOLVE\x10\xfd\x9f\x0c\x12\x1b\n\x15SCOPE_TXPROXY_PREPARE\x10\xfe\x9f\x0c\x12\x1b\n\x15SCOPE_TXPROXY_EXECUTE\x10\xff\x9f\x0c\x12\x1e\n\x18YDB_API_VALIDATION_ERROR\x10\xe0\xa0\x0c\x12\x1a\n\x14YDB_AUTH_UNAVAILABLE\x10\xe1\xa0\x0c\x12\x16\n\x10YDB_DB_NOT_READY\x10\xe2\xa0\x0c\x12 \n\x1aYDB_RESOURCE_USAGE_LIMITED\x10\xe3\xa0\x0c\"\x81\x03\n\nTStatusIds\"\xf2\x02\n\x0b\x45StatusCode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\r\n\tTRANSIENT\x10\x02\x12\n\n\x05\x45RROR\x10\x80\x01\x12\x0f\n\nINPROGRESS\x10\x81\x01\x12\x0c\n\x07TIMEOUT\x10\x82\x01\x12\r\n\x08NOTREADY\x10\x83\x01\x12\x13\n\x0eINTERNAL_ERROR\x10\x85\x01\x12\r\n\x08REJECTED\x10\x86\x01\x12\x11\n\x0cNOTSUPPORTED\x10\x87\x01\x12\x0f\n\nOVERLOADED\x10\x88\x01\x12\x13\n\x0ePATH_NOT_EXIST\x10\x89\x01\x12\x12\n\rACCESS_DENIED\x10\x8a\x01\x12\x10\n\x0b\x42\x41\x44_REQUEST\x10\x96\x01\x12\x10\n\x0bQUERY_ERROR\x10\x97\x01\x12\x12\n\rPROCESS_ERROR\x10\x98\x01\x12\x10\n\x0b\x42\x41\x44_SESSION\x10\x99\x01\x12\x16\n\x11LOCKS_INVALIDATED\x10\xaa\x01\x12\x1a\n\x15LOCKS_ACQUIRE_FAILURE\x10\xab\x01\x12\x11\n\x0cSCHEME_ERROR\x10\xac\x01\x42\x18\n\x16ru.yandex.kikimr.protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.issue_id_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TISSUESIDS._serialized_start=108
  _TISSUESIDS._serialized_end=1084
  _TISSUESIDS_TISSUEID._serialized_start=172
  _TISSUESIDS_TISSUEID._serialized_end=300
  _TISSUESIDS_EISSUECODE._serialized_start=303
  _TISSUESIDS_EISSUECODE._serialized_end=1084
  _TSTATUSIDS._serialized_start=1087
  _TSTATUSIDS._serialized_end=1472
  _TSTATUSIDS_ESTATUSCODE._serialized_start=1102
  _TSTATUSIDS_ESTATUSCODE._serialized_end=1472
# @@protoc_insertion_point(module_scope)
