# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/config_units.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/config_units.proto\x12\x12NKikimrConfigUnits\"H\n\tTDuration\x12\x0f\n\x07Seconds\x18\x01 \x01(\x04\x12\x14\n\x0cMilliseconds\x18\x02 \x01(\x04\x12\x14\n\x0cMicroseconds\x18\x03 \x01(\x04')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.config_units_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TDURATION._serialized_start=58
  _TDURATION._serialized_end=130
# @@protoc_insertion_point(module_scope)
