# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_pipe.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/tablet_pipe.proto\x12\x11NKikimrTabletPipe\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\"Z\n\nTEvConnect\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12(\n\x08\x43lientId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x10\n\x08\x46\x65\x61tures\x18\x03 \x01(\r\"\xd9\x01\n\x10TEvConnectResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12(\n\x08\x43lientId\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x08ServerId\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x14\n\x06Leader\x18\x05 \x01(\x08:\x04true\x12\x1d\n\x15SupportsDataInPayload\x18\x06 \x01(\x08\"\x98\x01\n\x07TEvPush\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12&\n\x06Sender\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x06\x42uffer\x18\x04 \x01(\x0c\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x16\n\x0e\x45xtendedFormat\x18\x06 \x01(\x08\x12\r\n\x05SeqNo\x18\x07 \x01(\x04\"u\n\rTEvPeerClosed\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12(\n\x08\x43lientId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x08ServerId\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\"\x92\x01\n\x0fTEvPeerShutdown\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12(\n\x08\x43lientId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x08ServerId\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x19\n\x11MaxForwardedSeqNo\x18\x04 \x01(\x04*)\n\x08\x45\x46\x65\x61ture\x12\x1d\n\x19\x46\x45\x41TURE_GRACEFUL_SHUTDOWN\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_pipe_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EFEATURE._serialized_start=859
  _EFEATURE._serialized_end=900
  _TEVCONNECT._serialized_start=124
  _TEVCONNECT._serialized_end=214
  _TEVCONNECTRESULT._serialized_start=217
  _TEVCONNECTRESULT._serialized_end=434
  _TEVPUSH._serialized_start=437
  _TEVPUSH._serialized_end=589
  _TEVPEERCLOSED._serialized_start=591
  _TEVPEERCLOSED._serialized_end=708
  _TEVPEERSHUTDOWN._serialized_start=711
  _TEVPEERSHUTDOWN._serialized_end=857
# @@protoc_insertion_point(module_scope)
