# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_blob_depot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ydb/core/protos/counters_blob_depot.proto\x12\x10NKikimrBlobDepot\x1a\x1eydb/core/protos/counters.proto*\x82\x02\n\x0f\x45SimpleCounters\x12=\n\x1e\x43OUNTER_TOTAL_STORED_DATA_SIZE\x10\x00\x1a\x19\x82\xd6\x1b\x15\n\x13TotalStoredDataSize\x12?\n\x1f\x43OUNTER_TOTAL_STORED_TRASH_SIZE\x10\x01\x1a\x1a\x82\xd6\x1b\x16\n\x14TotalStoredTrashSize\x12\x39\n\x1c\x43OUNTER_IN_FLIGHT_TRASH_SIZE\x10\x02\x1a\x17\x82\xd6\x1b\x13\n\x11InFlightTrashSize\x12\x34\n\x19\x43OUNTER_BYTES_TO_DECOMMIT\x10\x03\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42ytesToDecommit*\x8a\x02\n\x13\x45\x43umulativeCounters\x12.\n\x15\x43OUNTER_PUTS_INCOMING\x10\x00\x1a\x13\x82\xd6\x1b\x0f\n\rPuts/Incoming\x12\"\n\x0f\x43OUNTER_PUTS_OK\x10\x01\x1a\r\x82\xd6\x1b\t\n\x07Puts/Ok\x12(\n\x12\x43OUNTER_PUTS_ERROR\x10\x02\x1a\x10\x82\xd6\x1b\x0c\n\nPuts/Error\x12\x37\n\x1a\x43OUNTER_DECOMMIT_GET_BYTES\x10\x03\x1a\x17\x82\xd6\x1b\x13\n\x11\x44\x65\x63ommit/GetBytes\x12<\n\x1d\x43OUNTER_DECOMMIT_PUT_OK_BYTES\x10\x04\x1a\x19\x82\xd6\x1b\x15\n\x13\x44\x65\x63ommit/PutOkBytes*\xad\x03\n\x13\x45PercentileCounters\x12\x38\n COUNTER_PERCENTILE_SELECT_GROUPS\x10\x00\x1a\x12\x82\xd6\x1b\x0e\n\x0cSelectGroups\x1a\xdb\x02\x92\xd6\x1b\xd6\x02\x12\x11\x08\xf4\x03\x12\x0c(1) < 500 us\x12\x11\x08\xe8\x07\x12\x0c(2) 0.5-1 ms\x12\x0f\x08\xd0\x0f\x12\n(3) 1-2 ms\x12\x0f\x08\xa0\x1f\x12\n(4) 2-4 ms\x12\x0f\x08\xc0>\x12\n(5) 4-8 ms\x12\x10\x08\x80}\x12\x0b(6) 8-16 ms\x12\x12\x08\x80\xfa\x01\x12\x0c(7) 16-32 ms\x12\x12\x08\x80\xf4\x03\x12\x0c(8) 32-64 ms\x12\x13\x08\x80\xe8\x07\x12\r(9) 64-128 ms\x12\x15\x08\x80\xd0\x0f\x12\x0f(10) 128-256 ms\x12\x15\x08\x80\xa0\x1f\x12\x0f(11) 256-512 ms\x12\x16\x08\x80\xc0>\x12\x10(12) 512-1024 ms\x12\x17\x08\x80\x89z\x12\x11(13) 1024-2000 ms\x12\x11\x08\x80\x92\xf4\x01\x12\n(14) 2-4 s\x12\x11\x08\x80\xa4\xe8\x03\x12\n(15) 4-8 s\x12\x12\x08\x80\xc8\xd0\x07\x12\x0b(16) 8-16 s\x12\x13\x08\x80\x90\xa1\x0f\x12\x0c(17) 16-32 s*\x94\x06\n\x08\x45TxTypes\x12<\n\x1bTXTYPE_PUT_ASSIMILATED_DATA\x10\x00\x1a\x1b\x8a\xd6\x1b\x17\n\x15TTxPutAssimilatedData\x12\x42\n\x1eTXTYPE_COMMIT_ASSIMILATED_BLOB\x10\x01\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxCommitAssimilatedBlob\x12\x31\n\x15TXTYPE_FINISH_COPYING\x10\x02\x1a\x16\x8a\xd6\x1b\x12\n\x10TTxFinishCopying\x12;\n\x1aTXTYPE_FINISH_DECOMMISSION\x10\x03\x1a\x1b\x8a\xd6\x1b\x17\n\x15TTxFinishDecommission\x12%\n\x0fTXTYPE_MON_DATA\x10\x04\x1a\x10\x8a\xd6\x1b\x0c\n\nTTxMonData\x12+\n\x12TXTYPE_INIT_SCHEMA\x10\x05\x1a\x13\x8a\xd6\x1b\x0f\n\rTTxInitSchema\x12-\n\x13TXTYPE_APPLY_CONFIG\x10\x06\x1a\x14\x8a\xd6\x1b\x10\n\x0eTTxApplyConfig\x12\x1e\n\x0bTXTYPE_LOAD\x10\x07\x1a\r\x8a\xd6\x1b\t\n\x07TTxLoad\x12%\n\x0fTXTYPE_ISSUE_GC\x10\x08\x1a\x10\x8a\xd6\x1b\x0c\n\nTTxIssueGC\x12)\n\x11TXTYPE_CONFIRM_GC\x10\t\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTTxConfirmGC\x12:\n\x1aTXTYPE_COMMIT_CERTAIN_KEYS\x10\n\x1a\x1a\x8a\xd6\x1b\x16\n\x14TTxCommitCertainKeys\x12$\n\x0eTXTYPE_RESOLVE\x10\x0b\x1a\x10\x8a\xd6\x1b\x0c\n\nTTxResolve\x12\'\n\x10TXTYPE_DATA_LOAD\x10\x0c\x1a\x11\x8a\xd6\x1b\r\n\x0bTTxDataLoad\x12\x33\n\x16TXTYPE_COLLECT_GARBAGE\x10\r\x1a\x17\x8a\xd6\x1b\x13\n\x11TTxCollectGarbage\x12\x32\n\x16TXTYPE_COMMIT_BLOB_SEQ\x10\x0e\x1a\x16\x8a\xd6\x1b\x12\n\x10TTxCommitBlobSeq\x12-\n\x13TXTYPE_UPDATE_BLOCK\x10\x0f\x1a\x14\x8a\xd6\x1b\x10\n\x0eTTxUpdateBlockB\r\x9a\xd6\x1b\tBlobDepot')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_blob_depot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\232\326\033\tBlobDepot'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TOTAL_STORED_DATA_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TOTAL_STORED_DATA_SIZE"]._serialized_options = b'\202\326\033\025\n\023TotalStoredDataSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TOTAL_STORED_TRASH_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TOTAL_STORED_TRASH_SIZE"]._serialized_options = b'\202\326\033\026\n\024TotalStoredTrashSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_TRASH_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_IN_FLIGHT_TRASH_SIZE"]._serialized_options = b'\202\326\033\023\n\021InFlightTrashSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_TO_DECOMMIT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_TO_DECOMMIT"]._serialized_options = b'\202\326\033\021\n\017BytesToDecommit'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_INCOMING"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_INCOMING"]._serialized_options = b'\202\326\033\017\n\rPuts/Incoming'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_OK"]._serialized_options = b'\202\326\033\t\n\007Puts/Ok'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PUTS_ERROR"]._serialized_options = b'\202\326\033\014\n\nPuts/Error'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DECOMMIT_GET_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DECOMMIT_GET_BYTES"]._serialized_options = b'\202\326\033\023\n\021Decommit/GetBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DECOMMIT_PUT_OK_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DECOMMIT_PUT_OK_BYTES"]._serialized_options = b'\202\326\033\025\n\023Decommit/PutOkBytes'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\326\002\022\021\010\364\003\022\014(1) < 500 us\022\021\010\350\007\022\014(2) 0.5-1 ms\022\017\010\320\017\022\n(3) 1-2 ms\022\017\010\240\037\022\n(4) 2-4 ms\022\017\010\300>\022\n(5) 4-8 ms\022\020\010\200}\022\013(6) 8-16 ms\022\022\010\200\372\001\022\014(7) 16-32 ms\022\022\010\200\364\003\022\014(8) 32-64 ms\022\023\010\200\350\007\022\r(9) 64-128 ms\022\025\010\200\320\017\022\017(10) 128-256 ms\022\025\010\200\240\037\022\017(11) 256-512 ms\022\026\010\200\300>\022\020(12) 512-1024 ms\022\027\010\200\211z\022\021(13) 1024-2000 ms\022\021\010\200\222\364\001\022\n(14) 2-4 s\022\021\010\200\244\350\003\022\n(15) 4-8 s\022\022\010\200\310\320\007\022\013(16) 8-16 s\022\023\010\200\220\241\017\022\014(17) 16-32 s'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PERCENTILE_SELECT_GROUPS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PERCENTILE_SELECT_GROUPS"]._serialized_options = b'\202\326\033\016\n\014SelectGroups'
  _ETXTYPES.values_by_name["TXTYPE_PUT_ASSIMILATED_DATA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PUT_ASSIMILATED_DATA"]._serialized_options = b'\212\326\033\027\n\025TTxPutAssimilatedData'
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_ASSIMILATED_BLOB"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_ASSIMILATED_BLOB"]._serialized_options = b'\212\326\033\032\n\030TTxCommitAssimilatedBlob'
  _ETXTYPES.values_by_name["TXTYPE_FINISH_COPYING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FINISH_COPYING"]._serialized_options = b'\212\326\033\022\n\020TTxFinishCopying'
  _ETXTYPES.values_by_name["TXTYPE_FINISH_DECOMMISSION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FINISH_DECOMMISSION"]._serialized_options = b'\212\326\033\027\n\025TTxFinishDecommission'
  _ETXTYPES.values_by_name["TXTYPE_MON_DATA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_DATA"]._serialized_options = b'\212\326\033\014\n\nTTxMonData'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\017\n\rTTxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_APPLY_CONFIG"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_APPLY_CONFIG"]._serialized_options = b'\212\326\033\020\n\016TTxApplyConfig'
  _ETXTYPES.values_by_name["TXTYPE_LOAD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOAD"]._serialized_options = b'\212\326\033\t\n\007TTxLoad'
  _ETXTYPES.values_by_name["TXTYPE_ISSUE_GC"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ISSUE_GC"]._serialized_options = b'\212\326\033\014\n\nTTxIssueGC'
  _ETXTYPES.values_by_name["TXTYPE_CONFIRM_GC"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIRM_GC"]._serialized_options = b'\212\326\033\016\n\014TTxConfirmGC'
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_CERTAIN_KEYS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_CERTAIN_KEYS"]._serialized_options = b'\212\326\033\026\n\024TTxCommitCertainKeys'
  _ETXTYPES.values_by_name["TXTYPE_RESOLVE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESOLVE"]._serialized_options = b'\212\326\033\014\n\nTTxResolve'
  _ETXTYPES.values_by_name["TXTYPE_DATA_LOAD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DATA_LOAD"]._serialized_options = b'\212\326\033\r\n\013TTxDataLoad'
  _ETXTYPES.values_by_name["TXTYPE_COLLECT_GARBAGE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COLLECT_GARBAGE"]._serialized_options = b'\212\326\033\023\n\021TTxCollectGarbage'
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_BLOB_SEQ"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COMMIT_BLOB_SEQ"]._serialized_options = b'\212\326\033\022\n\020TTxCommitBlobSeq'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_BLOCK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_BLOCK"]._serialized_options = b'\212\326\033\020\n\016TTxUpdateBlock'
  _ESIMPLECOUNTERS._serialized_start=96
  _ESIMPLECOUNTERS._serialized_end=354
  _ECUMULATIVECOUNTERS._serialized_start=357
  _ECUMULATIVECOUNTERS._serialized_end=623
  _EPERCENTILECOUNTERS._serialized_start=626
  _EPERCENTILECOUNTERS._serialized_end=1055
  _ETXTYPES._serialized_start=1058
  _ETXTYPES._serialized_end=1846
# @@protoc_insertion_point(module_scope)
