# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/netclassifier.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ydb/core/protos/netclassifier.proto\x12\x14NKikimrNetClassifier\"\xff\x01\n\x1bTNetClassifierUpdaterConfig\x12\x18\n\x10NetDataSourceUrl\x18\x01 \x01(\t\x12\x1c\n\x14RetryIntervalSeconds\x18\x02 \x01(\r\x12$\n\x1cNetDataUpdateIntervalSeconds\x18\x03 \x01(\r\x12N\n\x06\x46ormat\x18\x04 \x01(\x0e\x32\x39.NKikimrNetClassifier.TNetClassifierUpdaterConfig.EFormat:\x03TSV\x12\x12\n\nNetBoxTags\x18\x05 \x03(\t\"\x1e\n\x07\x45\x46ormat\x12\x07\n\x03TSV\x10\x00\x12\n\n\x06NETBOX\x10\x01\"&\n\x07TSubnet\x12\x0c\n\x04Mask\x18\x01 \x01(\t\x12\r\n\x05Label\x18\x02 \x01(\t\":\n\x08TNetData\x12.\n\x07Subnets\x18\x01 \x03(\x0b\x32\x1d.NKikimrNetClassifier.TSubnet\"\xce\x01\n\x14TNetClassifierConfig\x12H\n\rUpdaterConfig\x18\x01 \x01(\x0b\x32\x31.NKikimrNetClassifier.TNetClassifierUpdaterConfig\x12\x17\n\x0fNetDataFilePath\x18\x02 \x01(\t\x12#\n\x17\x43msConfigTimeoutSeconds\x18\x03 \x01(\r:\x02\x33\x30\x12.\n\"TimedCountersUpdateIntervalSeconds\x18\x04 \x01(\r:\x02\x31\x35\"v\n!TNetClassifierDistributableConfig\x12\x1d\n\x15LastUpdateDatetimeUTC\x18\x01 \x01(\t\x12\x1b\n\x13LastUpdateTimestamp\x18\x02 \x01(\x04\x12\x15\n\rPackedNetData\x18\x03 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.netclassifier_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TNETCLASSIFIERUPDATERCONFIG._serialized_start=62
  _TNETCLASSIFIERUPDATERCONFIG._serialized_end=317
  _TNETCLASSIFIERUPDATERCONFIG_EFORMAT._serialized_start=287
  _TNETCLASSIFIERUPDATERCONFIG_EFORMAT._serialized_end=317
  _TSUBNET._serialized_start=319
  _TSUBNET._serialized_end=357
  _TNETDATA._serialized_start=359
  _TNETDATA._serialized_end=417
  _TNETCLASSIFIERCONFIG._serialized_start=420
  _TNETCLASSIFIERCONFIG._serialized_end=626
  _TNETCLASSIFIERDISTRIBUTABLECONFIG._serialized_start=628
  _TNETCLASSIFIERDISTRIBUTABLECONFIG._serialized_end=746
# @@protoc_insertion_point(module_scope)
