# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/kqp_physical.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.mkql_proto.protos import minikql_pb2 as ydb_dot_library_dot_mkql__proto_dot_protos_dot_minikql__pb2
from ydb.library.yql.dq.proto import dq_tasks_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__tasks__pb2
from ydb.public.api.protos import ydb_value_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/kqp_physical.proto\x12\tNKqpProto\x1a+ydb/library/mkql_proto/protos/minikql.proto\x1a\'ydb/library/yql/dq/proto/dq_tasks.proto\x1a%ydb/public/api/protos/ydb_value.proto\"\x18\n\x16TKqpPhyExternalBinding\"\x92\x02\n\x16TKqpPhyInternalBinding\x12\x35\n\x04Type\x18\x01 \x01(\x0e\x32\'.NKqpProto.TKqpPhyInternalBinding.EType\"\xc0\x01\n\x05\x45Type\x12\x15\n\x11PARAM_UNSPECIFIED\x10\x00\x12\r\n\tPARAM_NOW\x10\x01\x12\x16\n\x12PARAM_CURRENT_DATE\x10\x02\x12\x1a\n\x16PARAM_CURRENT_DATETIME\x10\x03\x12\x1b\n\x17PARAM_CURRENT_TIMESTAMP\x10\x04\x12\x17\n\x13PARAM_RANDOM_NUMBER\x10\x05\x12\x10\n\x0cPARAM_RANDOM\x10\x06\x12\x15\n\x11PARAM_RANDOM_UUID\x10\x07\">\n\x16TKqpPhyTxResultBinding\x12\x0f\n\x07TxIndex\x18\x01 \x01(\r\x12\x13\n\x0bResultIndex\x18\x02 \x01(\r\"\xe5\x01\n\x13TKqpPhyParamBinding\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12<\n\x0f\x45xternalBinding\x18\x02 \x01(\x0b\x32!.NKqpProto.TKqpPhyExternalBindingH\x00\x12<\n\x0fTxResultBinding\x18\x03 \x01(\x0b\x32!.NKqpProto.TKqpPhyTxResultBindingH\x00\x12<\n\x0fInternalBinding\x18\x04 \x01(\x0b\x32!.NKqpProto.TKqpPhyInternalBindingH\x00\x42\x06\n\x04Type\"\\\n\x14TKqpPhyResultBinding\x12<\n\x0fTxResultBinding\x18\x01 \x01(\x0b\x32!.NKqpProto.TKqpPhyTxResultBindingH\x00\x42\x06\n\x04Type\")\n\rTKqpPhyColumn\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\"`\n\x0cTKqpPhyTable\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0f\n\x07OwnerId\x18\x02 \x01(\x04\x12\x0f\n\x07TableId\x18\x03 \x01(\x04\x12\x0f\n\x07SysView\x18\x04 \x01(\t\x12\x0f\n\x07Version\x18\x05 \x01(\x04\"&\n\x11TKqpPhyParamValue\x12\x11\n\tParamName\x18\x01 \x01(\t\"C\n\x18TKqpPhyParamElementValue\x12\x11\n\tParamName\x18\x01 \x01(\t\x12\x14\n\x0c\x45lementIndex\x18\x02 \x01(\r\"a\n\x13TKqpPhyLiteralValue\x12#\n\x04Type\x18\x01 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\x12%\n\x05Value\x18\x02 \x01(\x0b\x32\x16.NKikimrMiniKQL.TValue\"\xd9\x02\n\x0fTKqpPhyRowsList\x12-\n\x04Rows\x18\x01 \x03(\x0b\x32\x1f.NKqpProto.TKqpPhyRowsList.TRow\x1a|\n\x06TValue\x12\x32\n\nParamValue\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValueH\x00\x12\x36\n\x0cLiteralValue\x18\x02 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyLiteralValueH\x00\x42\x06\n\x04Kind\x1a\x98\x01\n\x04TRow\x12=\n\x07\x43olumns\x18\x01 \x03(\x0b\x32,.NKqpProto.TKqpPhyRowsList.TRow.ColumnsEntry\x1aQ\n\x0c\x43olumnsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.NKqpProto.TKqpPhyRowsList.TValue:\x02\x38\x01\"\xf4\x01\n\x0cTKqpPhyValue\x12\x32\n\nParamValue\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValueH\x00\x12@\n\x11ParamElementValue\x18\x02 \x01(\x0b\x32#.NKqpProto.TKqpPhyParamElementValueH\x00\x12.\n\x08RowsList\x18\x03 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyRowsListH\x00\x12\x36\n\x0cLiteralValue\x18\x04 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyLiteralValueH\x00\x42\x06\n\x04Kind\"O\n\x0fTKqpPhyKeyBound\x12\'\n\x06Values\x18\x01 \x03(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x13\n\x0bIsInclusive\x18\x02 \x01(\x08\"c\n\x0fTKqpPhyKeyRange\x12(\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyKeyBound\x12&\n\x02To\x18\x02 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyKeyBound\"\x96\x01\n\x12TKqpPhyOpReadRange\x12,\n\x08KeyRange\x18\x01 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyKeyRange\x12+\n\nItemsLimit\x18\x02 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x0f\n\x07Reverse\x18\x03 \x01(\x08\x12\x14\n\x0cSkipNullKeys\x18\x04 \x03(\x08\"A\n\x13TKqpPhyOpUpsertRows\x12*\n\tRowsValue\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\"A\n\x13TKqpPhyOpDeleteRows\x12*\n\tRowsValue\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\"=\n\x0fTKqpPhyOpLookup\x12*\n\tKeysValue\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\"\xef\x01\n\x17TKqpPhyOpReadOlapRanges\x12/\n\tKeyRanges\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValue\x12+\n\nItemsLimit\x18\x02 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x0f\n\x07Reverse\x18\x03 \x01(\x08\x12\x13\n\x0bOlapProgram\x18\x04 \x01(\x0c\x12!\n\x19OlapProgramParameterNames\x18\x05 \x03(\t\x12\x0e\n\x06Sorted\x18\x06 \x01(\x08\x12\x1d\n\nResultType\x18\x07 \x01(\x0b\x32\t.Ydb.Type\"\x84\x01\n\x13TKqpPhyOpReadRanges\x12/\n\tKeyRanges\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValue\x12+\n\nItemsLimit\x18\x02 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x0f\n\x07Reverse\x18\x03 \x01(\x08\"\xb3\x03\n\x15TKqpPhyTableOperation\x12&\n\x05Table\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyTable\x12)\n\x07\x43olumns\x18\x02 \x03(\x0b\x32\x18.NKqpProto.TKqpPhyColumn\x12\x32\n\tReadRange\x18\x03 \x01(\x0b\x32\x1d.NKqpProto.TKqpPhyOpReadRangeH\x00\x12\x34\n\nUpsertRows\x18\x04 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyOpUpsertRowsH\x00\x12\x34\n\nDeleteRows\x18\x05 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyOpDeleteRowsH\x00\x12,\n\x06Lookup\x18\x06 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyOpLookupH\x00\x12;\n\rReadOlapRange\x18\x07 \x01(\x0b\x32\".NKqpProto.TKqpPhyOpReadOlapRangesH\x00\x12\x34\n\nReadRanges\x18\x08 \x01(\x0b\x32\x1e.NKqpProto.TKqpPhyOpReadRangesH\x00\x42\x06\n\x04Type\"\x13\n\x11TKqpPhyCnUnionAll\"\x0e\n\x0cTKqpPhyCnMap\"*\n\x14TKqpPhyCnHashShuffle\x12\x12\n\nKeyColumns\x18\x01 \x03(\t\"\x14\n\x12TKqpPhyCnBroadcast\"\x13\n\x11TKqpPhyCnMapShard\"\x17\n\x15TKqpPhyCnShuffleShard\"\x11\n\x0fTKqpPhyCnResult\"\x10\n\x0eTKqpPhyCnValue\"6\n\x11TKqpPhySortColumn\x12\x0e\n\x06\x43olumn\x18\x01 \x01(\t\x12\x11\n\tAscending\x18\x02 \x01(\x08\"C\n\x0eTKqpPhyCnMerge\x12\x31\n\x0bSortColumns\x18\x01 \x03(\x0b\x32\x1c.NKqpProto.TKqpPhySortColumn\"\x90\x01\n\x15TKqpPhyCnStreamLookup\x12&\n\x05Table\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyTable\x12\x12\n\nKeyColumns\x18\x02 \x03(\t\x12\x0f\n\x07\x43olumns\x18\x03 \x03(\t\x12\x16\n\x0eLookupKeysType\x18\x04 \x01(\x0c\x12\x12\n\nResultType\x18\x05 \x01(\x0c\"\xca\x04\n\x11TKqpPhyConnection\x12\x12\n\nStageIndex\x18\x01 \x01(\r\x12\x13\n\x0bOutputIndex\x18\x02 \x01(\r\x12\x12\n\nInputIndex\x18\r \x01(\r\x12\x30\n\x08UnionAll\x18\x03 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyCnUnionAllH\x00\x12&\n\x03Map\x18\x04 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyCnMapH\x00\x12\x36\n\x0bHashShuffle\x18\x05 \x01(\x0b\x32\x1f.NKqpProto.TKqpPhyCnHashShuffleH\x00\x12\x32\n\tBroadcast\x18\x06 \x01(\x0b\x32\x1d.NKqpProto.TKqpPhyCnBroadcastH\x00\x12\x30\n\x08MapShard\x18\x07 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyCnMapShardH\x00\x12\x38\n\x0cShuffleShard\x18\x08 \x01(\x0b\x32 .NKqpProto.TKqpPhyCnShuffleShardH\x00\x12,\n\x06Result\x18\t \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyCnResultH\x00\x12*\n\x05Value\x18\n \x01(\x0b\x32\x19.NKqpProto.TKqpPhyCnValueH\x00\x12*\n\x05Merge\x18\x0b \x01(\x0b\x32\x19.NKqpProto.TKqpPhyCnMergeH\x00\x12\x38\n\x0cStreamLookup\x18\x0c \x01(\x0b\x32 .NKqpProto.TKqpPhyCnStreamLookupH\x00\x42\x06\n\x04Type\"\xbb\x02\n\x14TKqpReadRangesSource\x12&\n\x05Table\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyTable\x12)\n\x07\x43olumns\x18\x02 \x03(\x0b\x32\x18.NKqpProto.TKqpPhyColumn\x12+\n\nItemsLimit\x18\x03 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyValue\x12\x0f\n\x07Reverse\x18\x04 \x01(\x08\x12\x0e\n\x06Sorted\x18\x05 \x01(\x08\x12.\n\x06Ranges\x18\x06 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyParamValueH\x00\x12.\n\x08KeyRange\x18\x07 \x01(\x0b\x32\x1a.NKqpProto.TKqpPhyKeyRangeH\x00\x12\x14\n\x0cSkipNullKeys\x18\x08 \x03(\tB\x0c\n\nRangesExpr\"e\n\nTKqpSource\x12\x12\n\nInputIndex\x18\x01 \x01(\r\x12;\n\x10ReadRangesSource\x18\x03 \x01(\x0b\x32\x1f.NKqpProto.TKqpReadRangesSourceH\x00\x42\x06\n\x04Type\"\xb2\x02\n\x0cTKqpPhyStage\x12(\n\x07Program\x18\x01 \x01(\x0b\x32\x17.NYql.NDqProto.TProgram\x12\x19\n\x11ProgramParameters\x18\x02 \x03(\t\x12\x12\n\nProgramAst\x18\x03 \x01(\t\x12,\n\x06Inputs\x18\x04 \x03(\x0b\x32\x1c.NKqpProto.TKqpPhyConnection\x12\x14\n\x0cOutputsCount\x18\x05 \x01(\r\x12\x32\n\x08TableOps\x18\x06 \x03(\x0b\x32 .NKqpProto.TKqpPhyTableOperation\x12\x16\n\x0eIsEffectsStage\x18\x07 \x01(\x08\x12\x11\n\tStageGuid\x18\x08 \x01(\t\x12&\n\x07Sources\x18\t \x03(\x0b\x32\x15.NKqpProto.TKqpSource\"\x91\x01\n\rTKqpPhyResult\x12\x30\n\nConnection\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpPhyConnection\x12\'\n\x08ItemType\x18\x02 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\x12\x10\n\x08IsStream\x18\x03 \x01(\x08\x12\x13\n\x0b\x43olumnHints\x18\x04 \x03(\t\"\xc3\x02\n\tTKqpPhyTx\x12(\n\x04Type\x18\x01 \x01(\x0e\x32\x1a.NKqpProto.TKqpPhyTx.EType\x12\'\n\x06Stages\x18\x02 \x03(\x0b\x32\x17.NKqpProto.TKqpPhyStage\x12)\n\x07Results\x18\x03 \x03(\x0b\x32\x18.NKqpProto.TKqpPhyResult\x12\x35\n\rParamBindings\x18\x04 \x03(\x0b\x32\x1e.NKqpProto.TKqpPhyParamBinding\x12\x0c\n\x04Plan\x18\x05 \x01(\t\x12\x12\n\nHasEffects\x18\x06 \x01(\x08\"_\n\x05\x45Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cTYPE_COMPUTE\x10\x01\x12\r\n\tTYPE_DATA\x10\x02\x12\r\n\tTYPE_SCAN\x10\x03\x12\x10\n\x0cTYPE_GENERIC\x10\x04\"\xa9\x01\n\rTKqpTableInfo\x12-\n\x07TableId\x18\x01 \x01(\x0b\x32\x1c.NKqpProto.TKqpTableInfo.TId\x12\x11\n\tTableName\x18\x02 \x01(\t\x12\x15\n\rSchemaVersion\x18\x03 \x01(\x04\x12\x16\n\x0eHasIndexTables\x18\x04 \x01(\x08\x1a\'\n\x03TId\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\"\x8d\x01\n\x0bTKqpTableOp\x12\x32\n\x08Position\x18\x01 \x01(\x0b\x32 .NKqpProto.TKqpTableOp.TPosition\x12\r\n\x05Table\x18\x02 \x01(\t\x12\x11\n\tOperation\x18\x03 \x01(\r\x1a(\n\tTPosition\x12\x0b\n\x03Row\x18\x01 \x01(\r\x12\x0e\n\x06\x43olumn\x18\x02 \x01(\r\"\x93\x03\n\x0cTKqpPhyQuery\x12+\n\x04Type\x18\x01 \x01(\x0e\x32\x1d.NKqpProto.TKqpPhyQuery.EType\x12*\n\x0cTransactions\x18\x02 \x03(\x0b\x32\x14.NKqpProto.TKqpPhyTx\x12\x37\n\x0eResultBindings\x18\x04 \x03(\x0b\x32\x1f.NKqpProto.TKqpPhyResultBinding\x12\x11\n\tQueryPlan\x18\x05 \x01(\t\x12\x10\n\x08QueryAst\x18\x06 \x01(\t\x12(\n\x08TableOps\x18\x07 \x03(\x0b\x32\x16.NKqpProto.TKqpTableOp\x12,\n\nTableInfos\x18\x08 \x03(\x0b\x32\x18.NKqpProto.TKqpTableInfo\x12!\n\x19HasUncommittedChangesRead\x18\t \x01(\x08\"K\n\x05\x45Type\x12\x14\n\x10TYPE_UNSPECIFIED\x10\x00\x12\r\n\tTYPE_DATA\x10\x01\x12\r\n\tTYPE_SCAN\x10\x02\x12\x0e\n\nTYPE_QUERY\x10\x03J\x04\x08\x03\x10\x04\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.kqp_physical_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TKQPPHYROWSLIST_TROW_COLUMNSENTRY._options = None
  _TKQPPHYROWSLIST_TROW_COLUMNSENTRY._serialized_options = b'8\001'
  _TKQPPHYEXTERNALBINDING._serialized_start=174
  _TKQPPHYEXTERNALBINDING._serialized_end=198
  _TKQPPHYINTERNALBINDING._serialized_start=201
  _TKQPPHYINTERNALBINDING._serialized_end=475
  _TKQPPHYINTERNALBINDING_ETYPE._serialized_start=283
  _TKQPPHYINTERNALBINDING_ETYPE._serialized_end=475
  _TKQPPHYTXRESULTBINDING._serialized_start=477
  _TKQPPHYTXRESULTBINDING._serialized_end=539
  _TKQPPHYPARAMBINDING._serialized_start=542
  _TKQPPHYPARAMBINDING._serialized_end=771
  _TKQPPHYRESULTBINDING._serialized_start=773
  _TKQPPHYRESULTBINDING._serialized_end=865
  _TKQPPHYCOLUMN._serialized_start=867
  _TKQPPHYCOLUMN._serialized_end=908
  _TKQPPHYTABLE._serialized_start=910
  _TKQPPHYTABLE._serialized_end=1006
  _TKQPPHYPARAMVALUE._serialized_start=1008
  _TKQPPHYPARAMVALUE._serialized_end=1046
  _TKQPPHYPARAMELEMENTVALUE._serialized_start=1048
  _TKQPPHYPARAMELEMENTVALUE._serialized_end=1115
  _TKQPPHYLITERALVALUE._serialized_start=1117
  _TKQPPHYLITERALVALUE._serialized_end=1214
  _TKQPPHYROWSLIST._serialized_start=1217
  _TKQPPHYROWSLIST._serialized_end=1562
  _TKQPPHYROWSLIST_TVALUE._serialized_start=1283
  _TKQPPHYROWSLIST_TVALUE._serialized_end=1407
  _TKQPPHYROWSLIST_TROW._serialized_start=1410
  _TKQPPHYROWSLIST_TROW._serialized_end=1562
  _TKQPPHYROWSLIST_TROW_COLUMNSENTRY._serialized_start=1481
  _TKQPPHYROWSLIST_TROW_COLUMNSENTRY._serialized_end=1562
  _TKQPPHYVALUE._serialized_start=1565
  _TKQPPHYVALUE._serialized_end=1809
  _TKQPPHYKEYBOUND._serialized_start=1811
  _TKQPPHYKEYBOUND._serialized_end=1890
  _TKQPPHYKEYRANGE._serialized_start=1892
  _TKQPPHYKEYRANGE._serialized_end=1991
  _TKQPPHYOPREADRANGE._serialized_start=1994
  _TKQPPHYOPREADRANGE._serialized_end=2144
  _TKQPPHYOPUPSERTROWS._serialized_start=2146
  _TKQPPHYOPUPSERTROWS._serialized_end=2211
  _TKQPPHYOPDELETEROWS._serialized_start=2213
  _TKQPPHYOPDELETEROWS._serialized_end=2278
  _TKQPPHYOPLOOKUP._serialized_start=2280
  _TKQPPHYOPLOOKUP._serialized_end=2341
  _TKQPPHYOPREADOLAPRANGES._serialized_start=2344
  _TKQPPHYOPREADOLAPRANGES._serialized_end=2583
  _TKQPPHYOPREADRANGES._serialized_start=2586
  _TKQPPHYOPREADRANGES._serialized_end=2718
  _TKQPPHYTABLEOPERATION._serialized_start=2721
  _TKQPPHYTABLEOPERATION._serialized_end=3156
  _TKQPPHYCNUNIONALL._serialized_start=3158
  _TKQPPHYCNUNIONALL._serialized_end=3177
  _TKQPPHYCNMAP._serialized_start=3179
  _TKQPPHYCNMAP._serialized_end=3193
  _TKQPPHYCNHASHSHUFFLE._serialized_start=3195
  _TKQPPHYCNHASHSHUFFLE._serialized_end=3237
  _TKQPPHYCNBROADCAST._serialized_start=3239
  _TKQPPHYCNBROADCAST._serialized_end=3259
  _TKQPPHYCNMAPSHARD._serialized_start=3261
  _TKQPPHYCNMAPSHARD._serialized_end=3280
  _TKQPPHYCNSHUFFLESHARD._serialized_start=3282
  _TKQPPHYCNSHUFFLESHARD._serialized_end=3305
  _TKQPPHYCNRESULT._serialized_start=3307
  _TKQPPHYCNRESULT._serialized_end=3324
  _TKQPPHYCNVALUE._serialized_start=3326
  _TKQPPHYCNVALUE._serialized_end=3342
  _TKQPPHYSORTCOLUMN._serialized_start=3344
  _TKQPPHYSORTCOLUMN._serialized_end=3398
  _TKQPPHYCNMERGE._serialized_start=3400
  _TKQPPHYCNMERGE._serialized_end=3467
  _TKQPPHYCNSTREAMLOOKUP._serialized_start=3470
  _TKQPPHYCNSTREAMLOOKUP._serialized_end=3614
  _TKQPPHYCONNECTION._serialized_start=3617
  _TKQPPHYCONNECTION._serialized_end=4203
  _TKQPREADRANGESSOURCE._serialized_start=4206
  _TKQPREADRANGESSOURCE._serialized_end=4521
  _TKQPSOURCE._serialized_start=4523
  _TKQPSOURCE._serialized_end=4624
  _TKQPPHYSTAGE._serialized_start=4627
  _TKQPPHYSTAGE._serialized_end=4933
  _TKQPPHYRESULT._serialized_start=4936
  _TKQPPHYRESULT._serialized_end=5081
  _TKQPPHYTX._serialized_start=5084
  _TKQPPHYTX._serialized_end=5407
  _TKQPPHYTX_ETYPE._serialized_start=5312
  _TKQPPHYTX_ETYPE._serialized_end=5407
  _TKQPTABLEINFO._serialized_start=5410
  _TKQPTABLEINFO._serialized_end=5579
  _TKQPTABLEINFO_TID._serialized_start=5540
  _TKQPTABLEINFO_TID._serialized_end=5579
  _TKQPTABLEOP._serialized_start=5582
  _TKQPTABLEOP._serialized_end=5723
  _TKQPTABLEOP_TPOSITION._serialized_start=5683
  _TKQPTABLEOP_TPOSITION._serialized_end=5723
  _TKQPPHYQUERY._serialized_start=5726
  _TKQPPHYQUERY._serialized_end=6129
  _TKQPPHYQUERY_ETYPE._serialized_start=6048
  _TKQPPHYQUERY_ETYPE._serialized_end=6123
# @@protoc_insertion_point(module_scope)
