# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/kesus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.public.api.protos import ydb_coordination_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__coordination__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bydb/core/protos/kesus.proto\x12\x0cNKikimrKesus\x1a&library/cpp/actors/protos/actors.proto\x1a,ydb/public/api/protos/ydb_coordination.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\"a\n\x0bTKesusError\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"*\n\x0fTEvDummyRequest\x12\x17\n\x0fUseTransactions\x18\x01 \x01(\x08\"\x12\n\x10TEvDummyResponse\"e\n\x0cTEvSetConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12(\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x0f\n\x07Version\x18\x03 \x01(\x04\x12\x0c\n\x04Path\x18\x04 \x01(\t\"^\n\x12TEvSetConfigResult\x12(\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\"\x0e\n\x0cTEvGetConfig\"]\n\x12TEvGetConfigResult\x12(\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x18.Ydb.Coordination.Config\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x12\x0c\n\x04Path\x18\x03 \x01(\t\"\'\n\x12TEvDescribeProxies\x12\x11\n\tKesusPath\x18\x01 \x01(\t\"\xd1\x01\n\x18TEvDescribeProxiesResult\x12I\n\x07Proxies\x18\x01 \x03(\x0b\x32\x38.NKikimrKesus.TEvDescribeProxiesResult.TProxyDescription\x1aj\n\x11TProxyDescription\x12\'\n\x07\x41\x63torID\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x18\n\x10\x41ttachedSessions\x18\x03 \x03(\x04\"(\n\x13TEvDescribeSessions\x12\x11\n\tKesusPath\x18\x01 \x01(\t\"\xed\x01\n\x19TEvDescribeSessionsResult\x12M\n\x08Sessions\x18\x01 \x03(\x0b\x32;.NKikimrKesus.TEvDescribeSessionsResult.TSessionDescription\x1a\x80\x01\n\x13TSessionDescription\x12\x11\n\tSessionId\x18\x01 \x01(\x04\x12\x15\n\rTimeoutMillis\x18\x02 \x01(\x04\x12\x13\n\x0b\x44\x65scription\x18\x03 \x01(\t\x12*\n\nOwnerProxy\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\"\xba\x01\n\x14TEvDescribeSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\x15\n\rIncludeOwners\x18\x05 \x01(\x08\x12\x16\n\x0eIncludeWaiters\x18\x06 \x01(\x08\x12\x11\n\tWatchData\x18\x07 \x01(\x08\x12\x13\n\x0bWatchOwners\x18\x08 \x01(\x08\"\xb9\x01\n\x1aTEvDescribeSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x44\n\x14SemaphoreDescription\x18\x03 \x01(\x0b\x32&.Ydb.Coordination.SemaphoreDescription\x12\x12\n\nWatchAdded\x18\x04 \x01(\x08\"b\n\x1bTEvDescribeSemaphoreChanged\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12\x13\n\x0b\x44\x61taChanged\x18\x02 \x01(\x08\x12\x15\n\rOwnersChanged\x18\x03 \x01(\x08\"~\n\x12TEvCreateSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\r\n\x05Limit\x18\x05 \x01(\x04\x12\x0c\n\x04\x44\x61ta\x18\x06 \x01(\x0c\"]\n\x18TEvCreateSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"o\n\x12TEvUpdateSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x05 \x01(\x0c\"]\n\x18TEvUpdateSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"p\n\x12TEvDeleteSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\r\n\x05\x46orce\x18\x05 \x01(\x08\"]\n\x18TEvDeleteSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\">\n\x10TEvRegisterProxy\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\"[\n\x16TEvRegisterProxyResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"@\n\x12TEvUnregisterProxy\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\"]\n\x18TEvUnregisterProxyResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"\xa3\x01\n\x10TEvAttachSession\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x15\n\rTimeoutMillis\x18\x04 \x01(\x04\x12\x13\n\x0b\x44\x65scription\x18\x05 \x01(\t\x12\r\n\x05SeqNo\x18\x06 \x01(\x04\x12\x15\n\rProtectionKey\x18\x07 \x01(\x0c\"n\n\x16TEvAttachSessionResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x11\n\tSessionId\x18\x03 \x01(\x04\"Q\n\x10TEvDetachSession\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\"[\n\x16TEvDetachSessionResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"R\n\x11TEvDestroySession\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\"\\\n\x17TEvDestroySessionResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"\xa9\x01\n\x13TEvAcquireSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\x15\n\rTimeoutMillis\x18\x05 \x01(\x04\x12\r\n\x05\x43ount\x18\x06 \x01(\x04\x12\x0c\n\x04\x44\x61ta\x18\x07 \x01(\x0c\x12\x11\n\tEphemeral\x18\x08 \x01(\x08\"5\n\x1aTEvAcquireSemaphorePending\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\"p\n\x19TEvAcquireSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x10\n\x08\x41\x63quired\x18\x03 \x01(\x08\"b\n\x13TEvReleaseSemaphore\x12\x11\n\tKesusPath\x18\x01 \x01(\t\x12\x17\n\x0fProxyGeneration\x18\x02 \x01(\x04\x12\x11\n\tSessionId\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\"p\n\x19TEvReleaseSemaphoreResult\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12\x10\n\x08Released\x18\x03 \x01(\x08\"*\n\x0fTEvProxyExpired\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\"&\n\x11TEvSessionExpired\x12\x11\n\tSessionId\x18\x01 \x01(\x04\">\n\x10TEvSessionStolen\x12\x17\n\x0fProxyGeneration\x18\x01 \x01(\x04\x12\x11\n\tSessionId\x18\x02 \x01(\x04\"\x94\x05\n\x11TAccountingConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x16\n\x0eReportPeriodMs\x18\x02 \x01(\x04\x12\x17\n\x0f\x41\x63\x63ountPeriodMs\x18\x03 \x01(\x04\x12\x18\n\x10\x43ollectPeriodSec\x18\x04 \x01(\x04\x12!\n\x19ProvisionedUnitsPerSecond\x18\x05 \x01(\x01\x12\x1e\n\x16ProvisionedCoefficient\x18\x06 \x01(\x01\x12\x1c\n\x14OvershootCoefficient\x18\x07 \x01(\x01\x12<\n\x0bProvisioned\x18\x08 \x01(\x0b\x32\'.NKikimrKesus.TAccountingConfig.TMetric\x12\x39\n\x08OnDemand\x18\t \x01(\x0b\x32\'.NKikimrKesus.TAccountingConfig.TMetric\x12:\n\tOvershoot\x18\n \x01(\x0b\x32\'.NKikimrKesus.TAccountingConfig.TMetric\x1a\x8c\x02\n\x07TMetric\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x18\n\x10\x42illingPeriodSec\x18\x02 \x01(\x04\x12\x0f\n\x07Version\x18\x03 \x01(\t\x12\x0e\n\x06Schema\x18\x05 \x01(\t\x12\x0f\n\x07\x43loudId\x18\x06 \x01(\t\x12\x10\n\x08\x46olderId\x18\x07 \x01(\t\x12\x12\n\nResourceId\x18\x08 \x01(\t\x12\x10\n\x08SourceId\x18\t \x01(\t\x12?\n\x04Tags\x18\n \x03(\x0b\x32\x31.NKikimrKesus.TAccountingConfig.TMetric.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x02\n\x1eTHierarchicalDRRResourceConfig\x12\x19\n\x11MaxUnitsPerSecond\x18\x03 \x01(\x01\x12\x1f\n\x17MaxBurstSizeCoefficient\x18\x04 \x01(\x01\x12\x0e\n\x06Weight\x18\x05 \x01(\r\x12\x1b\n\x13PrefetchCoefficient\x18\x06 \x01(\x01\x12\x19\n\x11PrefetchWatermark\x18\x07 \x01(\x01\x12R\n\rSpeedSettings\x18\x01 \x01(\x0b\x32;.NKikimrKesus.THierarchicalDRRResourceConfig.TSpeedSettings\x1a+\n\x0eTSpeedSettings\x12\x19\n\x11MaxUnitsPerSecond\x18\x01 \x01(\x01\"\xf0\x01\n\x18TStreamingQuoterResource\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x14\n\x0cResourcePath\x18\x02 \x01(\t\x12T\n\x1cHierarhicalDRRResourceConfig\x18\x03 \x01(\x0b\x32,.NKikimrKesus.THierarchicalDRRResourceConfigH\x00\x12\x39\n\x10\x41\x63\x63ountingConfig\x18\x04 \x01(\x0b\x32\x1f.NKikimrKesus.TAccountingConfigB\x19\n\x17\x41lgorithmSpecificConfig\"[\n\x1aTEvDescribeQuoterResources\x12\x13\n\x0bResourceIds\x18\x01 \x03(\x04\x12\x15\n\rResourcePaths\x18\x02 \x03(\t\x12\x11\n\tRecursive\x18\x03 \x01(\x08\"\x87\x01\n TEvDescribeQuoterResourcesResult\x12\x39\n\tResources\x18\x02 \x03(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\x12(\n\x05\x45rror\x18\x03 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"P\n\x14TEvAddQuoterResource\x12\x38\n\x08Resource\x18\x03 \x01(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\"Z\n\x1aTEvAddQuoterResourceResult\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"S\n\x17TEvUpdateQuoterResource\x12\x38\n\x08Resource\x18\x03 \x01(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\"]\n\x1dTEvUpdateQuoterResourceResult\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"C\n\x17TEvDeleteQuoterResource\x12\x12\n\nResourceId\x18\x03 \x01(\x04\x12\x14\n\x0cResourcePath\x18\x04 \x01(\t\"I\n\x1dTEvDeleteQuoterResourceResult\x12(\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"\xf2\x01\n\x17TEvSubscribeOnResources\x12O\n\tResources\x18\x01 \x03(\x0b\x32<.NKikimrKesus.TEvSubscribeOnResources.TResourceSubscribeInfo\x12\'\n\x07\x41\x63torID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1a]\n\x16TResourceSubscribeInfo\x12\x14\n\x0cResourcePath\x18\x01 \x01(\t\x12\x16\n\x0eStartConsuming\x18\x02 \x01(\x08\x12\x15\n\rInitialAmount\x18\x03 \x01(\x01\"\x91\x02\n\x1dTEvSubscribeOnResourcesResult\x12U\n\x07Results\x18\x01 \x03(\x0b\x32\x44.NKikimrKesus.TEvSubscribeOnResourcesResult.TResourceSubscribeResult\x1a\x98\x01\n\x18TResourceSubscribeResult\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12(\n\x05\x45rror\x18\x02 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\x12>\n\x0e\x45\x66\x66\x65\x63tiveProps\x18\x03 \x01(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\"\xe0\x01\n\x19TEvUpdateConsumptionState\x12L\n\rResourcesInfo\x18\x01 \x03(\x0b\x32\x35.NKikimrKesus.TEvUpdateConsumptionState.TResourceInfo\x12\'\n\x07\x41\x63torID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1aL\n\rTResourceInfo\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x17\n\x0f\x43onsumeResource\x18\x02 \x01(\x08\x12\x0e\n\x06\x41mount\x18\x03 \x01(\x01\"\x1e\n\x1cTEvUpdateConsumptionStateAck\"\x8d\x02\n\x15TEvResourcesAllocated\x12H\n\rResourcesInfo\x18\x01 \x03(\x0b\x32\x31.NKikimrKesus.TEvResourcesAllocated.TResourceInfo\x1a\xa9\x01\n\rTResourceInfo\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x0e\n\x06\x41mount\x18\x02 \x01(\x01\x12>\n\x0e\x45\x66\x66\x65\x63tiveProps\x18\x03 \x01(\x0b\x32&.NKikimrKesus.TStreamingQuoterResource\x12\x34\n\x11StateNotification\x18\x04 \x01(\x0b\x32\x19.NKikimrKesus.TKesusError\"\x1a\n\x18TEvResourcesAllocatedAck\"\x1e\n\x1cTEvGetQuoterResourceCounters\"\xc0\x01\n\"TEvGetQuoterResourceCountersResult\x12\\\n\x10ResourceCounters\x18\x01 \x03(\x0b\x32\x42.NKikimrKesus.TEvGetQuoterResourceCountersResult.TResourceCounters\x1a<\n\x11TResourceCounters\x12\x14\n\x0cResourcePath\x18\x01 \x01(\t\x12\x11\n\tAllocated\x18\x02 \x01(\x04\"\xe0\x01\n\x13TEvAccountResources\x12\x46\n\rResourcesInfo\x18\x01 \x03(\x0b\x32/.NKikimrKesus.TEvAccountResources.TResourceInfo\x12\'\n\x07\x41\x63torID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1aX\n\rTResourceInfo\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x0f\n\x07StartUs\x18\x02 \x01(\x04\x12\x12\n\nIntervalUs\x18\x03 \x01(\x04\x12\x0e\n\x06\x41mount\x18\x04 \x03(\x01\"\xd2\x01\n\x16TEvAccountResourcesAck\x12I\n\rResourcesInfo\x18\x01 \x03(\x0b\x32\x32.NKikimrKesus.TEvAccountResourcesAck.TResourceInfo\x1am\n\rTResourceInfo\x12\x12\n\nResourceId\x18\x01 \x01(\x04\x12\x12\n\nAcceptedUs\x18\x02 \x01(\x04\x12\x34\n\x11StateNotification\x18\x04 \x01(\x0b\x32\x19.NKikimrKesus.TKesusErrorB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.kesus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TACCOUNTINGCONFIG_TMETRIC_TAGSENTRY._options = None
  _TACCOUNTINGCONFIG_TMETRIC_TAGSENTRY._serialized_options = b'8\001'
  _TKESUSERROR._serialized_start=224
  _TKESUSERROR._serialized_end=321
  _TEVDUMMYREQUEST._serialized_start=323
  _TEVDUMMYREQUEST._serialized_end=365
  _TEVDUMMYRESPONSE._serialized_start=367
  _TEVDUMMYRESPONSE._serialized_end=385
  _TEVSETCONFIG._serialized_start=387
  _TEVSETCONFIG._serialized_end=488
  _TEVSETCONFIGRESULT._serialized_start=490
  _TEVSETCONFIGRESULT._serialized_end=584
  _TEVGETCONFIG._serialized_start=586
  _TEVGETCONFIG._serialized_end=600
  _TEVGETCONFIGRESULT._serialized_start=602
  _TEVGETCONFIGRESULT._serialized_end=695
  _TEVDESCRIBEPROXIES._serialized_start=697
  _TEVDESCRIBEPROXIES._serialized_end=736
  _TEVDESCRIBEPROXIESRESULT._serialized_start=739
  _TEVDESCRIBEPROXIESRESULT._serialized_end=948
  _TEVDESCRIBEPROXIESRESULT_TPROXYDESCRIPTION._serialized_start=842
  _TEVDESCRIBEPROXIESRESULT_TPROXYDESCRIPTION._serialized_end=948
  _TEVDESCRIBESESSIONS._serialized_start=950
  _TEVDESCRIBESESSIONS._serialized_end=990
  _TEVDESCRIBESESSIONSRESULT._serialized_start=993
  _TEVDESCRIBESESSIONSRESULT._serialized_end=1230
  _TEVDESCRIBESESSIONSRESULT_TSESSIONDESCRIPTION._serialized_start=1102
  _TEVDESCRIBESESSIONSRESULT_TSESSIONDESCRIPTION._serialized_end=1230
  _TEVDESCRIBESEMAPHORE._serialized_start=1233
  _TEVDESCRIBESEMAPHORE._serialized_end=1419
  _TEVDESCRIBESEMAPHORERESULT._serialized_start=1422
  _TEVDESCRIBESEMAPHORERESULT._serialized_end=1607
  _TEVDESCRIBESEMAPHORECHANGED._serialized_start=1609
  _TEVDESCRIBESEMAPHORECHANGED._serialized_end=1707
  _TEVCREATESEMAPHORE._serialized_start=1709
  _TEVCREATESEMAPHORE._serialized_end=1835
  _TEVCREATESEMAPHORERESULT._serialized_start=1837
  _TEVCREATESEMAPHORERESULT._serialized_end=1930
  _TEVUPDATESEMAPHORE._serialized_start=1932
  _TEVUPDATESEMAPHORE._serialized_end=2043
  _TEVUPDATESEMAPHORERESULT._serialized_start=2045
  _TEVUPDATESEMAPHORERESULT._serialized_end=2138
  _TEVDELETESEMAPHORE._serialized_start=2140
  _TEVDELETESEMAPHORE._serialized_end=2252
  _TEVDELETESEMAPHORERESULT._serialized_start=2254
  _TEVDELETESEMAPHORERESULT._serialized_end=2347
  _TEVREGISTERPROXY._serialized_start=2349
  _TEVREGISTERPROXY._serialized_end=2411
  _TEVREGISTERPROXYRESULT._serialized_start=2413
  _TEVREGISTERPROXYRESULT._serialized_end=2504
  _TEVUNREGISTERPROXY._serialized_start=2506
  _TEVUNREGISTERPROXY._serialized_end=2570
  _TEVUNREGISTERPROXYRESULT._serialized_start=2572
  _TEVUNREGISTERPROXYRESULT._serialized_end=2665
  _TEVATTACHSESSION._serialized_start=2668
  _TEVATTACHSESSION._serialized_end=2831
  _TEVATTACHSESSIONRESULT._serialized_start=2833
  _TEVATTACHSESSIONRESULT._serialized_end=2943
  _TEVDETACHSESSION._serialized_start=2945
  _TEVDETACHSESSION._serialized_end=3026
  _TEVDETACHSESSIONRESULT._serialized_start=3028
  _TEVDETACHSESSIONRESULT._serialized_end=3119
  _TEVDESTROYSESSION._serialized_start=3121
  _TEVDESTROYSESSION._serialized_end=3203
  _TEVDESTROYSESSIONRESULT._serialized_start=3205
  _TEVDESTROYSESSIONRESULT._serialized_end=3297
  _TEVACQUIRESEMAPHORE._serialized_start=3300
  _TEVACQUIRESEMAPHORE._serialized_end=3469
  _TEVACQUIRESEMAPHOREPENDING._serialized_start=3471
  _TEVACQUIRESEMAPHOREPENDING._serialized_end=3524
  _TEVACQUIRESEMAPHORERESULT._serialized_start=3526
  _TEVACQUIRESEMAPHORERESULT._serialized_end=3638
  _TEVRELEASESEMAPHORE._serialized_start=3640
  _TEVRELEASESEMAPHORE._serialized_end=3738
  _TEVRELEASESEMAPHORERESULT._serialized_start=3740
  _TEVRELEASESEMAPHORERESULT._serialized_end=3852
  _TEVPROXYEXPIRED._serialized_start=3854
  _TEVPROXYEXPIRED._serialized_end=3896
  _TEVSESSIONEXPIRED._serialized_start=3898
  _TEVSESSIONEXPIRED._serialized_end=3936
  _TEVSESSIONSTOLEN._serialized_start=3938
  _TEVSESSIONSTOLEN._serialized_end=4000
  _TACCOUNTINGCONFIG._serialized_start=4003
  _TACCOUNTINGCONFIG._serialized_end=4663
  _TACCOUNTINGCONFIG_TMETRIC._serialized_start=4395
  _TACCOUNTINGCONFIG_TMETRIC._serialized_end=4663
  _TACCOUNTINGCONFIG_TMETRIC_TAGSENTRY._serialized_start=4620
  _TACCOUNTINGCONFIG_TMETRIC_TAGSENTRY._serialized_end=4663
  _THIERARCHICALDRRRESOURCECONFIG._serialized_start=4666
  _THIERARCHICALDRRRESOURCECONFIG._serialized_end=4959
  _THIERARCHICALDRRRESOURCECONFIG_TSPEEDSETTINGS._serialized_start=4916
  _THIERARCHICALDRRRESOURCECONFIG_TSPEEDSETTINGS._serialized_end=4959
  _TSTREAMINGQUOTERRESOURCE._serialized_start=4962
  _TSTREAMINGQUOTERRESOURCE._serialized_end=5202
  _TEVDESCRIBEQUOTERRESOURCES._serialized_start=5204
  _TEVDESCRIBEQUOTERRESOURCES._serialized_end=5295
  _TEVDESCRIBEQUOTERRESOURCESRESULT._serialized_start=5298
  _TEVDESCRIBEQUOTERRESOURCESRESULT._serialized_end=5433
  _TEVADDQUOTERRESOURCE._serialized_start=5435
  _TEVADDQUOTERRESOURCE._serialized_end=5515
  _TEVADDQUOTERRESOURCERESULT._serialized_start=5517
  _TEVADDQUOTERRESOURCERESULT._serialized_end=5607
  _TEVUPDATEQUOTERRESOURCE._serialized_start=5609
  _TEVUPDATEQUOTERRESOURCE._serialized_end=5692
  _TEVUPDATEQUOTERRESOURCERESULT._serialized_start=5694
  _TEVUPDATEQUOTERRESOURCERESULT._serialized_end=5787
  _TEVDELETEQUOTERRESOURCE._serialized_start=5789
  _TEVDELETEQUOTERRESOURCE._serialized_end=5856
  _TEVDELETEQUOTERRESOURCERESULT._serialized_start=5858
  _TEVDELETEQUOTERRESOURCERESULT._serialized_end=5931
  _TEVSUBSCRIBEONRESOURCES._serialized_start=5934
  _TEVSUBSCRIBEONRESOURCES._serialized_end=6176
  _TEVSUBSCRIBEONRESOURCES_TRESOURCESUBSCRIBEINFO._serialized_start=6083
  _TEVSUBSCRIBEONRESOURCES_TRESOURCESUBSCRIBEINFO._serialized_end=6176
  _TEVSUBSCRIBEONRESOURCESRESULT._serialized_start=6179
  _TEVSUBSCRIBEONRESOURCESRESULT._serialized_end=6452
  _TEVSUBSCRIBEONRESOURCESRESULT_TRESOURCESUBSCRIBERESULT._serialized_start=6300
  _TEVSUBSCRIBEONRESOURCESRESULT_TRESOURCESUBSCRIBERESULT._serialized_end=6452
  _TEVUPDATECONSUMPTIONSTATE._serialized_start=6455
  _TEVUPDATECONSUMPTIONSTATE._serialized_end=6679
  _TEVUPDATECONSUMPTIONSTATE_TRESOURCEINFO._serialized_start=6603
  _TEVUPDATECONSUMPTIONSTATE_TRESOURCEINFO._serialized_end=6679
  _TEVUPDATECONSUMPTIONSTATEACK._serialized_start=6681
  _TEVUPDATECONSUMPTIONSTATEACK._serialized_end=6711
  _TEVRESOURCESALLOCATED._serialized_start=6714
  _TEVRESOURCESALLOCATED._serialized_end=6983
  _TEVRESOURCESALLOCATED_TRESOURCEINFO._serialized_start=6814
  _TEVRESOURCESALLOCATED_TRESOURCEINFO._serialized_end=6983
  _TEVRESOURCESALLOCATEDACK._serialized_start=6985
  _TEVRESOURCESALLOCATEDACK._serialized_end=7011
  _TEVGETQUOTERRESOURCECOUNTERS._serialized_start=7013
  _TEVGETQUOTERRESOURCECOUNTERS._serialized_end=7043
  _TEVGETQUOTERRESOURCECOUNTERSRESULT._serialized_start=7046
  _TEVGETQUOTERRESOURCECOUNTERSRESULT._serialized_end=7238
  _TEVGETQUOTERRESOURCECOUNTERSRESULT_TRESOURCECOUNTERS._serialized_start=7178
  _TEVGETQUOTERRESOURCECOUNTERSRESULT_TRESOURCECOUNTERS._serialized_end=7238
  _TEVACCOUNTRESOURCES._serialized_start=7241
  _TEVACCOUNTRESOURCES._serialized_end=7465
  _TEVACCOUNTRESOURCES_TRESOURCEINFO._serialized_start=7377
  _TEVACCOUNTRESOURCES_TRESOURCEINFO._serialized_end=7465
  _TEVACCOUNTRESOURCESACK._serialized_start=7468
  _TEVACCOUNTRESOURCESACK._serialized_end=7678
  _TEVACCOUNTRESOURCESACK_TRESOURCEINFO._serialized_start=7569
  _TEVACCOUNTRESOURCESACK_TRESOURCEINFO._serialized_end=7678
# @@protoc_insertion_point(module_scope)
