# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/proto/dq_checkpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/library/yql/dq/proto/dq_checkpoint.proto\x12\rNYql.NDqProto\"\xcd\x01\n\nTStateData\x12\x38\n\x07StateId\x18\x01 \x01(\x0b\x32%.NYql.NDqProto.TStateData.TExtStateIdH\x00\x12\x34\n\tStateData\x18\x02 \x01(\x0b\x32\x1f.NYql.NDqProto.TStateData.TDataH\x00\x1a\x1e\n\x0bTExtStateId\x12\x0f\n\x07StateId\x18\x01 \x01(\r\x1a&\n\x05TData\x12\x0c\n\x04\x42lob\x18\x01 \x01(\x0c\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x42\x07\n\x05State\"K\n\x0cTSourceState\x12\'\n\x04\x44\x61ta\x18\x01 \x03(\x0b\x32\x19.NYql.NDqProto.TStateData\x12\x12\n\nInputIndex\x18\x02 \x01(\x04\"J\n\nTSinkState\x12\'\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x19.NYql.NDqProto.TStateData\x12\x13\n\x0bOutputIndex\x18\x02 \x01(\x04\"W\n\x14TMiniKqlProgramState\x12\'\n\x04\x44\x61ta\x18\x01 \x01(\x0b\x32\x19.NYql.NDqProto.TStateData\x12\x16\n\x0eRuntimeVersion\x18\x02 \x01(\x04\"\xa9\x01\n\x12TComputeActorState\x12;\n\x0eMiniKqlProgram\x18\x01 \x01(\x0b\x32#.NYql.NDqProto.TMiniKqlProgramState\x12,\n\x07Sources\x18\x02 \x03(\x0b\x32\x1b.NYql.NDqProto.TSourceState\x12(\n\x05Sinks\x18\x03 \x03(\x0b\x32\x19.NYql.NDqProto.TSinkStateB\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.proto.dq_checkpoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TSTATEDATA._serialized_start=64
  _TSTATEDATA._serialized_end=269
  _TSTATEDATA_TEXTSTATEID._serialized_start=190
  _TSTATEDATA_TEXTSTATEID._serialized_end=220
  _TSTATEDATA_TDATA._serialized_start=222
  _TSTATEDATA_TDATA._serialized_end=260
  _TSOURCESTATE._serialized_start=271
  _TSOURCESTATE._serialized_end=346
  _TSINKSTATE._serialized_start=348
  _TSINKSTATE._serialized_end=422
  _TMINIKQLPROGRAMSTATE._serialized_start=424
  _TMINIKQLPROGRAMSTATE._serialized_end=511
  _TCOMPUTEACTORSTATE._serialized_start=514
  _TCOMPUTEACTORSTATE._serialized_end=683
# @@protoc_insertion_point(module_scope)
