# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/alloc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bydb/core/protos/alloc.proto\x12\rNKikimrConfig\"{\n\x10TAllocatorConfig\x12\x39\n\x05Param\x18\x01 \x03(\x0b\x32*.NKikimrConfig.TAllocatorConfig.ParamEntry\x1a,\n\nParamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x18\n\x16ru.yandex.kikimr.protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.alloc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TALLOCATORCONFIG_PARAMENTRY._options = None
  _TALLOCATORCONFIG_PARAMENTRY._serialized_options = b'8\001'
  _TALLOCATORCONFIG._serialized_start=46
  _TALLOCATORCONFIG._serialized_end=169
  _TALLOCATORCONFIG_PARAMENTRY._serialized_start=125
  _TALLOCATORCONFIG_PARAMENTRY._serialized_end=169
# @@protoc_insertion_point(module_scope)
