# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import tablet_counters_pb2 as ydb_dot_core_dot_protos_dot_tablet__counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/tablet.proto\x12\x11NKikimrTabletBase\x1a\x1aydb/core/protos/base.proto\x1a%ydb/core/protos/tablet_counters.proto\"\x8d\x06\n\x0cTTabletTypes\"\xfc\x05\n\x05\x45Type\x12\x0b\n\x07Unknown\x10\x00\x12\x12\n\x0eOldSchemeShard\x10\x01\x12\x10\n\x0cOldDataShard\x10\x02\x12\x0b\n\x07OldHive\x10\x03\x12\x12\n\x0eOldCoordinator\x10\x04\x12\x0c\n\x08Mediator\x10\x05\x12\x0e\n\nOldTxProxy\x10\x06\x12\x13\n\x0fOldBSController\x10\x07\x12\t\n\x05\x44ummy\x10\x08\x12\x11\n\rRTMRPartition\x10\n\x12\x0f\n\x0bOldKeyValue\x10\x0b\x12\x0c\n\x08KeyValue\x10\x0c\x12\x0f\n\x0b\x43oordinator\x10\r\x12\x08\n\x04Hive\x10\x0e\x12\x10\n\x0c\x42SController\x10\x0f\x12\x0f\n\x0bSchemeShard\x10\x10\x12\x0b\n\x07TxProxy\x10\x11\x12\r\n\tDataShard\x10\x12\x12\r\n\tPersQueue\x10\x14\x12\x07\n\x03\x43ms\x10\x15\x12\x0e\n\nNodeBroker\x10\x16\x12\x0f\n\x0bTxAllocator\x10\x17\x12\x19\n\x15PersQueueReadBalancer\x10\x18\x12\x14\n\x10\x42lockStoreVolume\x10\x19\x12\x17\n\x13\x42lockStorePartition\x10\x1a\x12\x14\n\x10TenantSlotBroker\x10\x1b\x12\x0b\n\x07\x43onsole\x10\x1c\x12\t\n\x05Kesus\x10\x1d\x12\x18\n\x14\x42lockStorePartition2\x10\x1e\x12\x1a\n\x16\x42lockStoreDiskRegistry\x10\x1f\x12\x14\n\x10SysViewProcessor\x10 \x12\r\n\tFileStore\x10!\x12\x0f\n\x0b\x43olumnShard\x10#\x12\r\n\tTestShard\x10$\x12\x11\n\rSequenceShard\x10%\x12\x19\n\x15ReplicationController\x10&\x12\r\n\tBlobDepot\x10\'\x12\x0e\n\nReserved40\x10(\x12\x0e\n\nReserved41\x10)\x12\x0e\n\nReserved42\x10*\x12\x0e\n\nReserved43\x10+\x12\x12\n\rUserTypeStart\x10\xff\x01\x12\x18\n\x0bTypeInvalid\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\"/\n\x12TTabletLogMetadata\x12\x0b\n\x03Key\x18\x01 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\"\x9f\x03\n\x0fTTabletLogEntry\x12\x11\n\tDependsOn\x18\x01 \x03(\r\x12-\n\nReferences\x18\x02 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x10\n\x08Snapshot\x18\x03 \x01(\x06\x12\x11\n\tConfirmed\x18\x04 \x01(\r\x12\x12\n\nIsSnapshot\x18\x05 \x01(\x08\x12/\n\x0cGcDiscovered\x18\x06 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12)\n\x06GcLeft\x18\x07 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x17\n\x0fIsTotalSnapshot\x18\x08 \x01(\x08\x12\x15\n\rZeroConfirmed\x18\n \x01(\x06\x12\x12\n\nZeroTailSz\x18\x0b \x01(\r\x12\x17\n\x0fZeroTailBitmask\x18\x0c \x03(\x06\x12\x17\n\x0f\x45mbeddedLogBody\x18\r \x01(\x0c\x12?\n\x10\x45mbeddedMetadata\x18\x0e \x03(\x0b\x32%.NKikimrTabletBase.TTabletLogMetadata\"\xeb\x01\n\x12TTabletChannelInfo\x12\x0f\n\x07\x43hannel\x18\x01 \x01(\r\x12\x13\n\x0b\x43hannelType\x18\x02 \x01(\r\x12\x44\n\x07History\x18\x03 \x03(\x0b\x32\x33.NKikimrTabletBase.TTabletChannelInfo.THistoryEntry\x12\x1a\n\x12\x43hannelErasureName\x18\x04 \x01(\t\x12\x13\n\x0bStoragePool\x18\x05 \x01(\t\x1a\x38\n\rTHistoryEntry\x12\x16\n\x0e\x46romGeneration\x18\x01 \x01(\r\x12\x0f\n\x07GroupID\x18\x02 \x01(\r\"\xdb\x01\n\x12TTabletStorageInfo\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x37\n\x08\x43hannels\x18\x02 \x03(\x0b\x32%.NKikimrTabletBase.TTabletChannelInfo\x12\x39\n\nTabletType\x18\x03 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x0f\n\x07Version\x18\x04 \x01(\r\x12\x15\n\rTenantIdOwner\x18\x05 \x01(\x04\x12\x17\n\x0fTenantIdLocalId\x18\x06 \x01(\x04\"*\n\x07TEvPing\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\r\n\x05\x46lags\x18\x02 \x01(\x04\"*\n\x07TEvPong\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\r\n\x05\x46lags\x18\x02 \x01(\x04\"7\n\x10TEvReadLocalBase\x12\x0f\n\x07RootKey\x18\x01 \x01(\x0c\x12\x12\n\nSaveScheme\x18\x02 \x01(\x08\"m\n\x16TEvReadLocalBaseResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x0f\n\x07RootKey\x18\x02 \x01(\x0c\x12\x0f\n\x07IsError\x18\x03 \x01(\x08\x12\x11\n\tDocBuffer\x18\x04 \x01(\x0c\x12\x0e\n\x06Scheme\x18\x05 \x01(\x0c\">\n\x11TEvFollowerAttach\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x17\n\x0f\x46ollowerAttempt\x18\x02 \x01(\r\"\xa9\x03\n\x11TEvFollowerUpdate\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x17\n\x0f\x46ollowerAttempt\x18\x02 \x01(\r\x12\x15\n\rStreamCounter\x18\x03 \x01(\x04\x12\x12\n\nGeneration\x18\n \x01(\r\x12\x0c\n\x04Step\x18\x0b \x01(\r\x12\x30\n\rReferencesIds\x18\x0c \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x12\n\nReferences\x18\r \x03(\x0c\x12\x12\n\nIsSnapshot\x18\x0e \x01(\x08\x12\x0c\n\x04\x42ody\x18\x0f \x01(\x0c\x12\x12\n\nAuxPayload\x18\x10 \x01(\x0c\x12@\n\x11TabletStorageInfo\x18\x11 \x01(\x0b\x32%.NKikimrTabletBase.TTabletStorageInfo\x12/\n\x0cGcDiscovered\x18\x14 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12)\n\x06GcLeft\x18\x15 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x16\n\x0eNeedGCApplyAck\x18\x16 \x01(\x08\"_\n\x10TEvFollowerGcAck\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x17\n\x0f\x46ollowerAttempt\x18\x02 \x01(\r\x12\x12\n\nGeneration\x18\x03 \x01(\r\x12\x0c\n\x04Step\x18\x04 \x01(\r\"l\n\x14TEvFollowerAuxUpdate\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x17\n\x0f\x46ollowerAttempt\x18\x02 \x01(\r\x12\x15\n\rStreamCounter\x18\x03 \x01(\x04\x12\x12\n\nAuxPayload\x18\n \x01(\x0c\">\n\x11TEvFollowerDetach\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x17\n\x0f\x46ollowerAttempt\x18\x02 \x01(\r\"R\n\x15TEvFollowerDisconnect\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x17\n\x0f\x46ollowerAttempt\x18\x02 \x01(\r\x12\x0e\n\x06Reason\x18\x03 \x01(\r\"S\n\x12TEvFollowerRefresh\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x17\n\x0fOfflineProtocol\x18\x03 \x01(\x08\"\x10\n\x0eTEvGetCounters\"T\n\x16TEvGetCountersResponse\x12:\n\x0eTabletCounters\x18\x01 \x01(\x0b\x32\".NKikimrTabletBase.TTabletCounters\"a\n\x13TEvCutTabletHistory\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\x12\x0f\n\x07GroupID\x18\x03 \x01(\r\x12\x16\n\x0e\x46romGeneration\x18\x04 \x01(\r\"I\n\x11TThroughputRecord\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\x12\x12\n\nThroughput\x18\x03 \x01(\x04\"=\n\x0bTIopsRecord\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\x12\x0c\n\x04Iops\x18\x03 \x01(\x04\"\xa6\x03\n\x08TMetrics\x12\x0b\n\x03\x43PU\x18\x01 \x01(\x04\x12\x0e\n\x06Memory\x18\x02 \x01(\x04\x12\x0f\n\x07Network\x18\x03 \x01(\x04\x12\x0f\n\x07\x43ounter\x18\x04 \x01(\x04\x12\x0f\n\x07Storage\x18\x05 \x01(\x04\x12\x41\n\x13GroupReadThroughput\x18\x06 \x03(\x0b\x32$.NKikimrTabletBase.TThroughputRecord\x12\x42\n\x14GroupWriteThroughput\x18\x07 \x03(\x0b\x32$.NKikimrTabletBase.TThroughputRecord\x12\x16\n\x0eReadThroughput\x18\x08 \x01(\x04\x12\x17\n\x0fWriteThroughput\x18\t \x01(\x04\x12\x35\n\rGroupReadIops\x18\n \x03(\x0b\x32\x1e.NKikimrTabletBase.TIopsRecord\x12\x36\n\x0eGroupWriteIops\x18\x0b \x03(\x0b\x32\x1e.NKikimrTabletBase.TIopsRecord\x12\x10\n\x08ReadIops\x18\x0c \x01(\x04\x12\x11\n\tWriteIops\x18\r \x01(\x04\"\xe5\x01\n\rTEvTabletStop\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x38\n\x06Reason\x18\x02 \x01(\x0e\x32(.NKikimrTabletBase.TEvTabletStop.EReason\"\x87\x01\n\x07\x45Reason\x12\x11\n\rReasonUnknown\x10\x00\x12\x0e\n\nReasonStop\x10\x01\x12\x11\n\rReasonDemoted\x10\x02\x12\x12\n\x0eReasonIsolated\x10\x03\x12\x18\n\x14ReasonStorageBlocked\x10\x04\x12\x18\n\x14ReasonStorageFailure\x10\x05\" \n\x0cTEvDropLease\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\"#\n\x0fTEvLeaseDropped\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TTABLETTYPES._serialized_start=119
  _TTABLETTYPES._serialized_end=900
  _TTABLETTYPES_ETYPE._serialized_start=136
  _TTABLETTYPES_ETYPE._serialized_end=900
  _TTABLETLOGMETADATA._serialized_start=902
  _TTABLETLOGMETADATA._serialized_end=949
  _TTABLETLOGENTRY._serialized_start=952
  _TTABLETLOGENTRY._serialized_end=1367
  _TTABLETCHANNELINFO._serialized_start=1370
  _TTABLETCHANNELINFO._serialized_end=1605
  _TTABLETCHANNELINFO_THISTORYENTRY._serialized_start=1549
  _TTABLETCHANNELINFO_THISTORYENTRY._serialized_end=1605
  _TTABLETSTORAGEINFO._serialized_start=1608
  _TTABLETSTORAGEINFO._serialized_end=1827
  _TEVPING._serialized_start=1829
  _TEVPING._serialized_end=1871
  _TEVPONG._serialized_start=1873
  _TEVPONG._serialized_end=1915
  _TEVREADLOCALBASE._serialized_start=1917
  _TEVREADLOCALBASE._serialized_end=1972
  _TEVREADLOCALBASERESULT._serialized_start=1974
  _TEVREADLOCALBASERESULT._serialized_end=2083
  _TEVFOLLOWERATTACH._serialized_start=2085
  _TEVFOLLOWERATTACH._serialized_end=2147
  _TEVFOLLOWERUPDATE._serialized_start=2150
  _TEVFOLLOWERUPDATE._serialized_end=2575
  _TEVFOLLOWERGCACK._serialized_start=2577
  _TEVFOLLOWERGCACK._serialized_end=2672
  _TEVFOLLOWERAUXUPDATE._serialized_start=2674
  _TEVFOLLOWERAUXUPDATE._serialized_end=2782
  _TEVFOLLOWERDETACH._serialized_start=2784
  _TEVFOLLOWERDETACH._serialized_end=2846
  _TEVFOLLOWERDISCONNECT._serialized_start=2848
  _TEVFOLLOWERDISCONNECT._serialized_end=2930
  _TEVFOLLOWERREFRESH._serialized_start=2932
  _TEVFOLLOWERREFRESH._serialized_end=3015
  _TEVGETCOUNTERS._serialized_start=3017
  _TEVGETCOUNTERS._serialized_end=3033
  _TEVGETCOUNTERSRESPONSE._serialized_start=3035
  _TEVGETCOUNTERSRESPONSE._serialized_end=3119
  _TEVCUTTABLETHISTORY._serialized_start=3121
  _TEVCUTTABLETHISTORY._serialized_end=3218
  _TTHROUGHPUTRECORD._serialized_start=3220
  _TTHROUGHPUTRECORD._serialized_end=3293
  _TIOPSRECORD._serialized_start=3295
  _TIOPSRECORD._serialized_end=3356
  _TMETRICS._serialized_start=3359
  _TMETRICS._serialized_end=3781
  _TEVTABLETSTOP._serialized_start=3784
  _TEVTABLETSTOP._serialized_end=4013
  _TEVTABLETSTOP_EREASON._serialized_start=3878
  _TEVTABLETSTOP_EREASON._serialized_end=4013
  _TEVDROPLEASE._serialized_start=4015
  _TEVDROPLEASE._serialized_end=4047
  _TEVLEASEDROPPED._serialized_start=4049
  _TEVLEASEDROPPED._serialized_end=4084
# @@protoc_insertion_point(module_scope)
