# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/protos/common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ydb/library/yql/protos/common.proto\x12\x0bNYql.NProto\"\xab\x01\n\x05TTime\x12\r\n\x05Value\x18\x01 \x01(\x04\x12&\n\x04Unit\x18\x02 \x01(\x0e\x32\x18.NYql.NProto.TTime.TUnit\"k\n\x05TUnit\x12\x0f\n\x0bNANOSECONDS\x10\x01\x12\x10\n\x0cMICROSECONDS\x10\x02\x12\x10\n\x0cMILLISECONDS\x10\x03\x12\x0b\n\x07SECONDS\x10\x04\x12\x0b\n\x07MINUTES\x10\x05\x12\t\n\x05HOURS\x10\x06\x12\x08\n\x04\x44\x41YS\x10\x07\x42\x15\n\x13ru.yandex.yql.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.protos.common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023ru.yandex.yql.proto'
  _TTIME._serialized_start=53
  _TTIME._serialized_end=224
  _TTIME_TUNIT._serialized_start=117
  _TTIME_TUNIT._serialized_end=224
# @@protoc_insertion_point(module_scope)
