# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/actors/protos/dq_stats.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ydb/library/yql/dq/actors/protos/dq_stats.proto\x12\rNYql.NDqProto\x1a\x19google/protobuf/any.proto\"\xd6\x01\n\x18TDqAsyncInputBufferStats\x12\x12\n\nInputIndex\x18\x01 \x01(\x04\x12\x0e\n\x06\x43hunks\x18\x02 \x01(\x04\x12\r\n\x05\x42ytes\x18\x03 \x01(\x04\x12\x0e\n\x06RowsIn\x18\x04 \x01(\x04\x12\x0f\n\x07RowsOut\x18\x05 \x01(\x04\x12\x16\n\x0eMaxMemoryUsage\x18\x06 \x01(\x04\x12\x13\n\x0b\x45rrorsCount\x18\x07 \x01(\r\x12\x14\n\x0cIngressBytes\x18\x08 \x01(\x04\x12#\n\x05\x45xtra\x18\x64 \x01(\x0b\x32\x14.google.protobuf.Any\"\x87\x02\n\x14TDqInputChannelStats\x12\x11\n\tChannelId\x18\x01 \x01(\x04\x12\x0e\n\x06\x43hunks\x18\x02 \x01(\x04\x12\r\n\x05\x42ytes\x18\x03 \x01(\x04\x12\x0e\n\x06RowsIn\x18\x04 \x01(\x04\x12\x0f\n\x07RowsOut\x18\x05 \x01(\x04\x12\x1d\n\x15\x44\x65serializationTimeUs\x18\x06 \x01(\x04\x12\x16\n\x0eMaxMemoryUsage\x18\x07 \x01(\x04\x12\x14\n\x0cPollRequests\x18\x08 \x01(\r\x12\x16\n\x0eResentMessages\x18\t \x01(\r\x12\x12\n\nWaitTimeUs\x18\n \x01(\x04\x12#\n\x05\x45xtra\x18\x64 \x01(\x0b\x32\x14.google.protobuf.Any\"\xd7\x01\n\x19TDqAsyncOutputBufferStats\x12\x13\n\x0bOutputIndex\x18\x01 \x01(\x04\x12\x0e\n\x06\x43hunks\x18\x02 \x01(\x04\x12\r\n\x05\x42ytes\x18\x03 \x01(\x04\x12\x0e\n\x06RowsIn\x18\x04 \x01(\x04\x12\x0f\n\x07RowsOut\x18\x05 \x01(\x04\x12\x16\n\x0eMaxMemoryUsage\x18\x06 \x01(\x04\x12\x13\n\x0b\x45rrorsCount\x18\x07 \x01(\r\x12\x13\n\x0b\x45gressBytes\x18\x08 \x01(\x04\x12#\n\x05\x45xtra\x18\x64 \x01(\x0b\x32\x14.google.protobuf.Any\"\xe7\x02\n\x15TDqOutputChannelStats\x12\x11\n\tChannelId\x18\x01 \x01(\x04\x12\x0e\n\x06\x43hunks\x18\x02 \x01(\x04\x12\r\n\x05\x42ytes\x18\x03 \x01(\x04\x12\x0e\n\x06RowsIn\x18\x04 \x01(\x04\x12\x0f\n\x07RowsOut\x18\x05 \x01(\x04\x12\x1b\n\x13SerializationTimeUs\x18\x06 \x01(\x04\x12\x19\n\x11\x42lockedByCapacity\x18\x07 \x01(\r\x12\x16\n\x0eResentMessages\x18\x08 \x01(\r\x12\x14\n\x0cNoDstActorId\x18\t \x01(\r\x12\x17\n\x0fMaxRowsInMemory\x18\n \x01(\r\x12\x16\n\x0eMaxMemoryUsage\x18\x0b \x01(\x04\x12\x14\n\x0cSpilledBytes\x18\x0c \x01(\x04\x12\x13\n\x0bSpilledRows\x18\r \x01(\x04\x12\x14\n\x0cSpilledBlobs\x18\x0e \x01(\x04\x12#\n\x05\x45xtra\x18\x64 \x01(\x0b\x32\x14.google.protobuf.Any\"\xd6\x01\n\rTDqTableStats\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12\x10\n\x08ReadRows\x18\x02 \x01(\x04\x12\x11\n\tReadBytes\x18\x03 \x01(\x04\x12\x11\n\tWriteRows\x18\x04 \x01(\x04\x12\x12\n\nWriteBytes\x18\x05 \x01(\x04\x12\x11\n\tEraseRows\x18\x06 \x01(\x04\x12\x12\n\nEraseBytes\x18\x07 \x01(\x04\x12\x1a\n\x12\x41\x66\x66\x65\x63tedPartitions\x18\x08 \x01(\r\x12#\n\x05\x45xtra\x18\x64 \x01(\x0b\x32\x14.google.protobuf.Any\"9\n\x0bTDqMkqlStat\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x03\x12\r\n\x05\x44\x65riv\x18\x03 \x01(\x08\"3\n\x14TDqDataProviderStats\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05\x42ytes\x18\x02 \x01(\x04\"\x8c\x08\n\x0cTDqTaskStats\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12\x0f\n\x07StageId\x18\x02 \x01(\r\x12\x11\n\tCpuTimeUs\x18\x03 \x01(\x04\x12\x16\n\x0e\x46irstRowTimeMs\x18\x04 \x01(\x04\x12\x14\n\x0c\x46inishTimeMs\x18\x05 \x01(\x04\x12\x11\n\tInputRows\x18\x06 \x01(\x04\x12\x12\n\nInputBytes\x18\x07 \x01(\x04\x12\x12\n\nOutputRows\x18\x08 \x01(\x04\x12\x13\n\x0bOutputBytes\x18\t \x01(\x04\x12,\n\x06Tables\x18\n \x03(\x0b\x32\x1c.NYql.NDqProto.TDqTableStats\x12\x34\n\x07Ingress\x18\r \x03(\x0b\x32#.NYql.NDqProto.TDqDataProviderStats\x12\x33\n\x06\x45gress\x18\x0e \x03(\x0b\x32#.NYql.NDqProto.TDqDataProviderStats\x12\x16\n\x0e\x42uildCpuTimeUs\x18g \x01(\x04\x12\x12\n\nWaitTimeUs\x18h \x01(\x04\x12\x18\n\x10WaitOutputTimeUs\x18i \x01(\x04\x12\x18\n\x10\x43omputeCpuTimeUs\x18\x66 \x01(\x04\x12\x1a\n\x12PendingInputTimeUs\x18k \x01(\x04\x12\x1b\n\x13PendingOutputTimeUs\x18l \x01(\x04\x12\x14\n\x0c\x46inishTimeUs\x18m \x01(\x04\x12-\n\tMkqlStats\x18n \x03(\x0b\x32\x1a.NYql.NDqProto.TDqMkqlStat\x12\x44\n\x13\x43omputeCpuTimeByRun\x18j \x03(\x0b\x32\'.NYql.NDqProto.TDqTaskStats.THistBucket\x12\x39\n\x07Sources\x18\x96\x01 \x03(\x0b\x32\'.NYql.NDqProto.TDqAsyncInputBufferStats\x12;\n\rInputChannels\x18\x97\x01 \x03(\x0b\x32#.NYql.NDqProto.TDqInputChannelStats\x12\x38\n\x05Sinks\x18\x98\x01 \x03(\x0b\x32(.NYql.NDqProto.TDqAsyncOutputBufferStats\x12=\n\x0eOutputChannels\x18\x99\x01 \x03(\x0b\x32$.NYql.NDqProto.TDqOutputChannelStats\x12\x41\n\x0fInputTransforms\x18\x9b\x01 \x03(\x0b\x32\'.NYql.NDqProto.TDqAsyncInputBufferStats\x12$\n\x05\x45xtra\x18\xc8\x01 \x01(\x0b\x32\x14.google.protobuf.Any\x1a+\n\x0bTHistBucket\x12\r\n\x05\x42ound\x18\x01 \x01(\x01\x12\r\n\x05Value\x18\x02 \x01(\x04J\x06\x08\x9a\x01\x10\x9b\x01\"\xea\x01\n\x14TDqComputeActorStats\x12\x11\n\tCpuTimeUs\x18\x01 \x01(\x04\x12\x12\n\nDurationUs\x18\x02 \x01(\x04\x12*\n\x05Tasks\x18\x03 \x03(\x0b\x32\x1b.NYql.NDqProto.TDqTaskStats\x12\x1a\n\x12MkqlMaxMemoryUsage\x18\x66 \x01(\x04\x12\x1c\n\x14MkqlExtraMemoryBytes\x18g \x01(\x04\x12\x1f\n\x17MkqlExtraMemoryRequests\x18h \x01(\r\x12$\n\x05\x45xtra\x18\xc8\x01 \x01(\x0b\x32\x14.google.protobuf.Any\"B\n\x0cTDqStatsAggr\x12\x0b\n\x03Min\x18\x01 \x01(\x04\x12\x0b\n\x03Max\x18\x02 \x01(\x04\x12\x0b\n\x03Sum\x18\x03 \x01(\x04\x12\x0b\n\x03\x43nt\x18\x04 \x01(\x04\"\x8e\x01\n\x0bTExtraStats\x12\x34\n\x05Stats\x18\x01 \x03(\x0b\x32%.NYql.NDqProto.TExtraStats.StatsEntry\x1aI\n\nStatsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr:\x02\x38\x01\"*\n\x0eTDqStatsMinMax\x12\x0b\n\x03Min\x18\x01 \x01(\x04\x12\x0b\n\x03Max\x18\x02 \x01(\x04\"\x88\x03\n\x11TDqTableAggrStats\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12-\n\x08ReadRows\x18\x02 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12.\n\tReadBytes\x18\x03 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12.\n\tWriteRows\x18\x04 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12/\n\nWriteBytes\x18\x05 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12.\n\tEraseRows\x18\x06 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12/\n\nEraseBytes\x18\x07 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12\x1a\n\x12\x41\x66\x66\x65\x63tedPartitions\x18\x08 \x01(\r\x12#\n\x05\x45xtra\x18\x64 \x01(\x0b\x32\x14.google.protobuf.Any\"\xfe\x04\n\rTDqStageStats\x12\x0f\n\x07StageId\x18\x01 \x01(\r\x12\x11\n\tStageGuid\x18\x02 \x01(\t\x12\x0f\n\x07Program\x18\x03 \x01(\t\x12\x17\n\x0fTotalTasksCount\x18\x05 \x01(\r\x12\x18\n\x10\x46\x61iledTasksCount\x18\x06 \x01(\r\x12.\n\tCpuTimeUs\x18\x08 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12.\n\tInputRows\x18\t \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12/\n\nInputBytes\x18\n \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12/\n\nOutputRows\x18\x0b \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12\x30\n\x0bOutputBytes\x18\x0c \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12\x35\n\x0e\x46irstRowTimeMs\x18\r \x01(\x0b\x32\x1d.NYql.NDqProto.TDqStatsMinMax\x12\x33\n\x0c\x46inishTimeMs\x18\x0e \x01(\x0b\x32\x1d.NYql.NDqProto.TDqStatsMinMax\x12\x12\n\nDurationUs\x18\x0f \x01(\x04\x12\x30\n\x06Tables\x18\x10 \x03(\x0b\x32 .NYql.NDqProto.TDqTableAggrStats\x12:\n\rComputeActors\x18\x11 \x03(\x0b\x32#.NYql.NDqProto.TDqComputeActorStats\x12#\n\x05\x45xtra\x18\x64 \x01(\x0b\x32\x14.google.protobuf.Any\"\xdc\x02\n\x11TDqExecutionStats\x12\x11\n\tCpuTimeUs\x18\x01 \x01(\x04\x12\x12\n\nDurationUs\x18\x02 \x01(\x04\x12\x12\n\nResultRows\x18\x03 \x01(\x04\x12\x13\n\x0bResultBytes\x18\x04 \x01(\x04\x12,\n\x06Tables\x18\x06 \x03(\x0b\x32\x1c.NYql.NDqProto.TDqTableStats\x12\x19\n\x11\x45xecuterCpuTimeUs\x18\n \x01(\x04\x12\x13\n\x0bStartTimeMs\x18\x0b \x01(\x04\x12\x14\n\x0c\x46inishTimeMs\x18\x0c \x01(\x04\x12\x16\n\x0e\x46irstRowTimeMs\x18\r \x01(\x04\x12,\n\x06Stages\x18\x0e \x03(\x0b\x32\x1c.NYql.NDqProto.TDqStageStats\x12\x18\n\x10TxPlansWithStats\x18\x0f \x03(\t\x12#\n\x05\x45xtra\x18\x64 \x01(\x0b\x32\x14.google.protobuf.Any*y\n\x0c\x45\x44qStatsMode\x12\x1d\n\x19\x44Q_STATS_MODE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x44Q_STATS_MODE_NONE\x10\n\x12\x17\n\x13\x44Q_STATS_MODE_BASIC\x10\x14\x12\x19\n\x15\x44Q_STATS_MODE_PROFILE\x10\x1e\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.actors.protos.dq_stats_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TEXTRASTATS_STATSENTRY._options = None
  _TEXTRASTATS_STATSENTRY._serialized_options = b'8\001'
  _EDQSTATSMODE._serialized_start=4405
  _EDQSTATSMODE._serialized_end=4526
  _TDQASYNCINPUTBUFFERSTATS._serialized_start=94
  _TDQASYNCINPUTBUFFERSTATS._serialized_end=308
  _TDQINPUTCHANNELSTATS._serialized_start=311
  _TDQINPUTCHANNELSTATS._serialized_end=574
  _TDQASYNCOUTPUTBUFFERSTATS._serialized_start=577
  _TDQASYNCOUTPUTBUFFERSTATS._serialized_end=792
  _TDQOUTPUTCHANNELSTATS._serialized_start=795
  _TDQOUTPUTCHANNELSTATS._serialized_end=1154
  _TDQTABLESTATS._serialized_start=1157
  _TDQTABLESTATS._serialized_end=1371
  _TDQMKQLSTAT._serialized_start=1373
  _TDQMKQLSTAT._serialized_end=1430
  _TDQDATAPROVIDERSTATS._serialized_start=1432
  _TDQDATAPROVIDERSTATS._serialized_end=1483
  _TDQTASKSTATS._serialized_start=1486
  _TDQTASKSTATS._serialized_end=2522
  _TDQTASKSTATS_THISTBUCKET._serialized_start=2471
  _TDQTASKSTATS_THISTBUCKET._serialized_end=2514
  _TDQCOMPUTEACTORSTATS._serialized_start=2525
  _TDQCOMPUTEACTORSTATS._serialized_end=2759
  _TDQSTATSAGGR._serialized_start=2761
  _TDQSTATSAGGR._serialized_end=2827
  _TEXTRASTATS._serialized_start=2830
  _TEXTRASTATS._serialized_end=2972
  _TEXTRASTATS_STATSENTRY._serialized_start=2899
  _TEXTRASTATS_STATSENTRY._serialized_end=2972
  _TDQSTATSMINMAX._serialized_start=2974
  _TDQSTATSMINMAX._serialized_end=3016
  _TDQTABLEAGGRSTATS._serialized_start=3019
  _TDQTABLEAGGRSTATS._serialized_end=3411
  _TDQSTAGESTATS._serialized_start=3414
  _TDQSTAGESTATS._serialized_end=4052
  _TDQEXECUTIONSTATS._serialized_start=4055
  _TDQEXECUTIONSTATS._serialized_end=4403
# @@protoc_insertion_point(module_scope)
