# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_cms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/counters_cms.proto\x12\x0cNKikimr.NCms\x1a\x1eydb/core/protos/counters.proto*t\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00\x12\x46\n\x19\x43OUNTER_BOOTSTRAP_DIFFERS\x10\x01\x1a\'\x82\xd6\x1b#\n!BootstrapConfigDiffersFromConsole*4\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\xc0\x06\n\x08\x45TxTypes\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x00\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12\x1d\n\x0bTXTYPE_INIT\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12+\n\x13TXTYPE_GET_LOG_TAIL\x10\x02\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxGetLogTail\x12(\n\x11TXTYPE_LOAD_STATE\x10\x03\x1a\x11\x8a\xd6\x1b\r\n\x0bTxLoadState\x12+\n\x13TXTYPE_LOG_AND_SEND\x10\x04\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxLogAndSend\x12*\n\x12TXTYPE_LOG_CLEANUP\x10\x05\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxLogCleanup\x12<\n\x1bTXTYPE_PROCESS_NOTIFICATION\x10\x06\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxProcessNotification\x12:\n\x1aTXTYPE_REJECT_NOTIFICATION\x10\x07\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxRejectNotification\x12I\n\"TXTYPE_REMOVE_EXPIRED_NOTIFICATION\x10\x08\x1a!\x8a\xd6\x1b\x1d\n\x1bTxRemoveExpiredNotification\x12\x36\n\x18TXTYPE_STORE_PERMISSIONS\x10\t\x1a\x18\x8a\xd6\x1b\x14\n\x12TxStorePermissions\x12\x38\n\x19TXTYPE_REMOVE_PERMISSIONS\x10\n\x1a\x19\x8a\xd6\x1b\x15\n\x13TxRemovePermissions\x12\x30\n\x15TXTYPE_REMOVE_REQUEST\x10\x0b\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxRemoveRequest\x12\x35\n\x18TXTYPE_REMOVE_WALLE_TASK\x10\x0c\x1a\x17\x8a\xd6\x1b\x13\n\x11TxRemoveWalleTask\x12\x33\n\x17TXTYPE_STORE_WALLE_TASK\x10\r\x1a\x16\x8a\xd6\x1b\x12\n\x10TxStoreWalleTask\x12.\n\x14TXTYPE_UPDATE_CONFIG\x10\x0e\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxUpdateConfig\x12\x34\n\x17TXTYPE_UPDATE_DOWNTIMES\x10\x0f\x1a\x17\x8a\xd6\x1b\x13\n\x11TxUpdateDowntimesB\x1f\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x03\x43ms')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_cms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\003Cms'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BOOTSTRAP_DIFFERS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BOOTSTRAP_DIFFERS"]._serialized_options = b'\202\326\033#\n!BootstrapConfigDiffersFromConsole'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_GET_LOG_TAIL"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_LOG_TAIL"]._serialized_options = b'\212\326\033\016\n\014TxGetLogTail'
  _ETXTYPES.values_by_name["TXTYPE_LOAD_STATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOAD_STATE"]._serialized_options = b'\212\326\033\r\n\013TxLoadState'
  _ETXTYPES.values_by_name["TXTYPE_LOG_AND_SEND"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOG_AND_SEND"]._serialized_options = b'\212\326\033\016\n\014TxLogAndSend'
  _ETXTYPES.values_by_name["TXTYPE_LOG_CLEANUP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOG_CLEANUP"]._serialized_options = b'\212\326\033\016\n\014TxLogCleanup'
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_NOTIFICATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_NOTIFICATION"]._serialized_options = b'\212\326\033\027\n\025TxProcessNotification'
  _ETXTYPES.values_by_name["TXTYPE_REJECT_NOTIFICATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REJECT_NOTIFICATION"]._serialized_options = b'\212\326\033\026\n\024TxRejectNotification'
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_EXPIRED_NOTIFICATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_EXPIRED_NOTIFICATION"]._serialized_options = b'\212\326\033\035\n\033TxRemoveExpiredNotification'
  _ETXTYPES.values_by_name["TXTYPE_STORE_PERMISSIONS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STORE_PERMISSIONS"]._serialized_options = b'\212\326\033\024\n\022TxStorePermissions'
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_PERMISSIONS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_PERMISSIONS"]._serialized_options = b'\212\326\033\025\n\023TxRemovePermissions'
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_REQUEST"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_REQUEST"]._serialized_options = b'\212\326\033\021\n\017TxRemoveRequest'
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_WALLE_TASK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REMOVE_WALLE_TASK"]._serialized_options = b'\212\326\033\023\n\021TxRemoveWalleTask'
  _ETXTYPES.values_by_name["TXTYPE_STORE_WALLE_TASK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STORE_WALLE_TASK"]._serialized_options = b'\212\326\033\022\n\020TxStoreWalleTask'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_CONFIG"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_CONFIG"]._serialized_options = b'\212\326\033\020\n\016TxUpdateConfig'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DOWNTIMES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DOWNTIMES"]._serialized_options = b'\212\326\033\023\n\021TxUpdateDowntimes'
  _ESIMPLECOUNTERS._serialized_start=84
  _ESIMPLECOUNTERS._serialized_end=200
  _ECUMULATIVECOUNTERS._serialized_start=202
  _ECUMULATIVECOUNTERS._serialized_end=254
  _EPERCENTILECOUNTERS._serialized_start=256
  _EPERCENTILECOUNTERS._serialized_end=334
  _ETXTYPES._serialized_start=337
  _ETXTYPES._serialized_end=1169
# @@protoc_insertion_point(module_scope)
