# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/ydb_result_set_old.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from ydb.library.yql.public.types import yql_types_pb2 as ydb_dot_library_dot_yql_dot_public_dot_types_dot_yql__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ydb/core/protos/ydb_result_set_old.proto\x12\x06YdbOld\x1a\x1cgoogle/protobuf/struct.proto\x1a,ydb/library/yql/public/types/yql_types.proto\",\n\x08\x44\x61taType\x12 \n\x02id\x18\x01 \x01(\x0e\x32\x14.NYql.NProto.TypeIds\"*\n\x0cOptionalType\x12\x1a\n\x04item\x18\x01 \x01(\x0b\x32\x0c.YdbOld.Type\"&\n\x08ListType\x12\x1a\n\x04item\x18\x01 \x01(\x0b\x32\x0c.YdbOld.Type\"%\n\x07Variant\x12\x1a\n\x04item\x18\x01 \x01(\x0b\x32\x0c.YdbOld.Type\"+\n\tTupleType\x12\x1e\n\x08\x65lements\x18\x01 \x03(\x0b\x32\x0c.YdbOld.Type\"2\n\x06Member\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\x04type\x18\x02 \x01(\x0b\x32\x0c.YdbOld.Type\"-\n\nStructType\x12\x1f\n\x07members\x18\x01 \x03(\x0b\x32\x0e.YdbOld.Member\"D\n\x08\x44ictType\x12\x19\n\x03key\x18\x01 \x01(\x0b\x32\x0c.YdbOld.Type\x12\x1d\n\x07payload\x18\x02 \x01(\x0b\x32\x0c.YdbOld.Type\"\xe5\x02\n\x04Type\x12%\n\tdata_type\x18\x01 \x01(\x0b\x32\x10.YdbOld.DataTypeH\x00\x12-\n\roptional_type\x18\x02 \x01(\x0b\x32\x14.YdbOld.OptionalTypeH\x00\x12%\n\tlist_type\x18\x03 \x01(\x0b\x32\x10.YdbOld.ListTypeH\x00\x12\'\n\ntuple_type\x18\x04 \x01(\x0b\x32\x11.YdbOld.TupleTypeH\x00\x12)\n\x0bstruct_type\x18\x05 \x01(\x0b\x32\x12.YdbOld.StructTypeH\x00\x12%\n\tdict_type\x18\x06 \x01(\x0b\x32\x10.YdbOld.DictTypeH\x00\x12\'\n\x0cvariant_type\x18\x07 \x01(\x0b\x32\x0f.YdbOld.VariantH\x00\x12/\n\tvoid_type\x18\x08 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x42\x0b\n\ttype_type\"G\n\tValuePair\x12\x1a\n\x03key\x18\x01 \x01(\x0b\x32\r.YdbOld.Value\x12\x1e\n\x07payload\x18\x02 \x01(\x0b\x32\r.YdbOld.Value\"\xc0\x03\n\x05Value\x12\x14\n\nbool_value\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bint32_value\x18\x02 \x01(\x0fH\x00\x12\x16\n\x0cuint32_value\x18\x03 \x01(\x07H\x00\x12\x15\n\x0bint64_value\x18\x04 \x01(\x10H\x00\x12\x16\n\x0cuint64_value\x18\x05 \x01(\x06H\x00\x12\x15\n\x0b\x66loat_value\x18\x06 \x01(\x02H\x00\x12\x16\n\x0c\x64ouble_value\x18\x07 \x01(\x01H\x00\x12\x15\n\x0b\x62ytes_value\x18\x08 \x01(\x0cH\x00\x12\x14\n\ntext_value\x18\t \x01(\tH\x00\x12\x35\n\x0fnull_flag_value\x18\n \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12%\n\x0cnested_value\x18\x0b \x01(\x0b\x32\r.YdbOld.ValueH\x00\x12\x11\n\x07low_128\x18\x0f \x01(\x06H\x00\x12\x1c\n\x05items\x18\x0c \x03(\x0b\x32\r.YdbOld.Value\x12 \n\x05pairs\x18\r \x03(\x0b\x32\x11.YdbOld.ValuePair\x12\x15\n\rvariant_index\x18\x0e \x01(\r\x12\x10\n\x08high_128\x18\x10 \x01(\x06\x42\r\n\x0bvalue_value\"6\n\nColumnMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x1a\n\x04type\x18\x02 \x01(\x0b\x32\x0c.YdbOld.Type\"d\n\tResultSet\x12\'\n\x0b\x63olumn_meta\x18\x01 \x03(\x0b\x32\x12.YdbOld.ColumnMeta\x12\x1b\n\x04rows\x18\x02 \x03(\x0b\x32\r.YdbOld.Value\x12\x11\n\ttruncated\x18\x03 \x01(\x08\x42#\n\x11ru.yandex.ydb.oldB\x0bValueProtos\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.ydb_result_set_old_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\021ru.yandex.ydb.oldB\013ValueProtos\370\001\001'
  _DATATYPE._serialized_start=128
  _DATATYPE._serialized_end=172
  _OPTIONALTYPE._serialized_start=174
  _OPTIONALTYPE._serialized_end=216
  _LISTTYPE._serialized_start=218
  _LISTTYPE._serialized_end=256
  _VARIANT._serialized_start=258
  _VARIANT._serialized_end=295
  _TUPLETYPE._serialized_start=297
  _TUPLETYPE._serialized_end=340
  _MEMBER._serialized_start=342
  _MEMBER._serialized_end=392
  _STRUCTTYPE._serialized_start=394
  _STRUCTTYPE._serialized_end=439
  _DICTTYPE._serialized_start=441
  _DICTTYPE._serialized_end=509
  _TYPE._serialized_start=512
  _TYPE._serialized_end=869
  _VALUEPAIR._serialized_start=871
  _VALUEPAIR._serialized_end=942
  _VALUE._serialized_start=945
  _VALUE._serialized_end=1393
  _COLUMNMETA._serialized_start=1395
  _COLUMNMETA._serialized_end=1449
  _RESULTSET._serialized_start=1451
  _RESULTSET._serialized_end=1551
# @@protoc_insertion_point(module_scope)
