# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_pq.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/counters_pq.proto\x12\x0bNKikimr.NPQ\x1a\x1eydb/core/protos/counters.proto*\xb2\x11\n\x13\x45\x43umulativeCounters\x12,\n\x16\x43OUNTER_PQ_BAD_REQUEST\x10\x00\x1a\x10\x82\xd6\x1b\x0c\n\nBadRequest\x12/\n\x17\x43OUNTER_PQ_INITIALIZING\x10\x01\x1a\x12\x82\xd6\x1b\x0e\n\x0cInitializing\x12\x37\n\x1c\x43OUNTER_PQ_CREATE_SESSION_OK\x10\x02\x1a\x15\x82\xd6\x1b\x11\n\x0f\x43reateSessionOk\x12=\n\x1f\x43OUNTER_PQ_CREATE_SESSION_ERROR\x10\x03\x1a\x18\x82\xd6\x1b\x14\n\x12\x43reateSessionError\x12\x37\n\x1c\x43OUNTER_PQ_DELETE_SESSION_OK\x10\x04\x1a\x15\x82\xd6\x1b\x11\n\x0f\x44\x65leteSessionOk\x12=\n\x1f\x43OUNTER_PQ_DELETE_SESSION_ERROR\x10\x05\x1a\x18\x82\xd6\x1b\x14\n\x12\x44\x65leteSessionError\x12<\n\x1f\x43OUNTER_PQ_SET_CLIENT_OFFSET_OK\x10\x06\x1a\x17\x82\xd6\x1b\x13\n\x11SetClientOffsetOk\x12\x42\n\"COUNTER_PQ_SET_CLIENT_OFFSET_ERROR\x10\x07\x1a\x1a\x82\xd6\x1b\x16\n\x14SetClientOffsetError\x12<\n\x1f\x43OUNTER_PQ_GET_CLIENT_OFFSET_OK\x10\x08\x1a\x17\x82\xd6\x1b\x13\n\x11GetClientOffsetOk\x12\x42\n\"COUNTER_PQ_GET_CLIENT_OFFSET_ERROR\x10\t\x1a\x1a\x82\xd6\x1b\x16\n\x14GetClientOffsetError\x12$\n\x12\x43OUNTER_PQ_READ_OK\x10\n\x1a\x0c\x82\xd6\x1b\x08\n\x06ReadOk\x12*\n\x15\x43OUNTER_PQ_READ_ERROR\x10\x0b\x1a\x0f\x82\xd6\x1b\x0b\n\tReadError\x12>\n COUNTER_PQ_READ_ERROR_NO_SESSION\x10\x0c\x1a\x18\x82\xd6\x1b\x14\n\x12ReadErrorNoSession\x12\x42\n\"COUNTER_PQ_READ_ERROR_SMALL_OFFSET\x10\r\x1a\x1a\x82\xd6\x1b\x16\n\x14ReadErrorSmallOffset\x12>\n COUNTER_PQ_READ_ERROR_BIG_OFFSET\x10\x0e\x1a\x18\x82\xd6\x1b\x14\n\x12ReadErrorBigOffset\x12@\n!COUNTER_PQ_READ_ERROR_IN_PROGRESS\x10\x0f\x1a\x19\x82\xd6\x1b\x15\n\x13ReadErrorInProgress\x12\x36\n\x1c\x43OUNTER_PQ_READ_HEAD_ONLY_OK\x10\x10\x1a\x14\x82\xd6\x1b\x10\n\x0eReadHeadOnlyOk\x12=\n\x1f\x43OUNTER_PQ_READ_SUBSCRIPTION_OK\x10\x11\x1a\x18\x82\xd6\x1b\x14\n\x12ReadSubscriptionOk\x12\x43\n\"COUNTER_PQ_READ_SUBSCRIPTION_ERROR\x10\x12\x1a\x1b\x82\xd6\x1b\x17\n\x15ReadSubscriptionError\x12G\n$COUNTER_PQ_READ_SUBSCRIPTION_TIMEOUT\x10\x13\x1a\x1d\x82\xd6\x1b\x19\n\x17ReadSubscriptionTimeout\x12*\n\x15\x43OUNTER_PQ_READ_BYTES\x10\x14\x1a\x0f\x82\xd6\x1b\x0b\n\tBytesRead\x12\x31\n\x19\x43OUNTER_PQ_WRITE_BYTES_OK\x10\x15\x1a\x12\x82\xd6\x1b\x0e\n\x0c\x42ytesWriteOk\x12;\n\x1e\x43OUNTER_PQ_WRITE_BYTES_ALREADY\x10\x16\x1a\x17\x82\xd6\x1b\x13\n\x11\x42ytesWriteAlready\x12\x37\n\x1c\x43OUNTER_PQ_WRITE_BYTES_ERROR\x10\x17\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42ytesWriteError\x12&\n\x13\x43OUNTER_PQ_WRITE_OK\x10\x18\x1a\r\x82\xd6\x1b\t\n\x07WriteOk\x12\x30\n\x18\x43OUNTER_PQ_WRITE_ALREADY\x10\x19\x1a\x12\x82\xd6\x1b\x0e\n\x0cWriteAlready\x12,\n\x16\x43OUNTER_PQ_WRITE_ERROR\x10\x1a\x1a\x10\x82\xd6\x1b\x0c\n\nWriteError\x12\x42\n\"COUNTER_PQ_WRITE_CYCLE_BYTES_TOTAL\x10\x1b\x1a\x1a\x82\xd6\x1b\x16\n\x14\x42ytesWriteCycleTotal\x12\x46\n$COUNTER_PQ_WRITE_TIMESTAMP_CACHE_HIT\x10\x1c\x1a\x1c\x82\xd6\x1b\x18\n\x16TimestampWriteCacheHit\x12H\n%COUNTER_PQ_WRITE_TIMESTAMP_CACHE_MISS\x10\x1d\x1a\x1d\x82\xd6\x1b\x19\n\x17TimestampWriteCacheMiss\x12\x43\n COUNTER_PQ_WRITE_TIMESTAMP_ERROR\x10\x1e\x1a\x1d\x82\xd6\x1b\x19\n\x17TimestampWriteReadError\x12O\n)COUNTER_PQ_WRITE_TIMESTAMP_OFFSET_IS_LOST\x10\x1f\x1a \x82\xd6\x1b\x1c\n\x1aTimestampWriteOffsetIsLost\x12\x31\n\x16\x43OUNTER_PQ_SID_CREATED\x10 \x1a\x15\x82\xd6\x1b\x11\n\x0fSourceIdCreated\x12\x44\n#COUNTER_PQ_WRITE_BYTES_SMALL_OFFSET\x10!\x1a\x1b\x82\xd6\x1b\x17\n\x15\x42ytesWriteSmallOffset\x12\x39\n\x1d\x43OUNTER_PQ_WRITE_SMALL_OFFSET\x10\"\x1a\x16\x82\xd6\x1b\x12\n\x10WriteSmallOffset\x12/\n\x1b\x43OUNTER_PQ_TABLET_CPU_USAGE\x10#\x1a\x0e\x82\xd6\x1b\n\n\x08\x43PUUsage\x12=\n%COUNTER_PQ_TABLET_NETWORK_BYTES_USAGE\x10$\x1a\x12\x82\xd6\x1b\x0e\n\x0cNetworkUsage*\xc3\x03\n\x0f\x45SimpleCounters\x12<\n\x1c\x43OUNTER_PQ_TABLET_CACHE_SIZE\x10\x00\x1a\x1a\x82\xd6\x1b\x16\n\x14TabletCacheSizeBytes\x12=\n\x1d\x43OUNTER_PQ_TABLET_CACHE_COUNT\x10\x01\x1a\x1a\x82\xd6\x1b\x16\n\x14TabletCacheSizeBlobs\x12>\n COUNTER_PQ_TABLET_CACHED_ON_READ\x10\x02\x1a\x18\x82\xd6\x1b\x14\n\x12TabletCachedOnRead\x12@\n!COUNTER_PQ_TABLET_CACHED_ON_WRATE\x10\x03\x1a\x19\x82\xd6\x1b\x15\n\x13TabletCachedOnWrite\x12\x42\n%COUNTER_PQ_TABLET_RESERVED_BYTES_SIZE\x10\x04\x1a\x17\x82\xd6\x1b\x13\n\x11ReservedBytesSize\x12\x35\n\x1e\x43OUNTER_PQ_TABLET_OPENED_PIPES\x10\x05\x1a\x11\x82\xd6\x1b\r\n\x0bOpenedPipes\x12\x36\n\x1a\x43OUNTER_PQ_TABLET_INFLIGHT\x10\x06\x1a\x16\x82\xd6\x1b\x12\n\x10RequestsInflight*\xd7\r\n\x13\x45PercentileCounters\x12?\n!COUNTER_LATENCY_PQ_GET_MAX_SEQ_NO\x10\x00\x1a\x18\x82\xd6\x1b\x14\n\x12LatencyGetMaxSeqNo\x12\x41\n!COUNTER_LATENCY_PQ_DELETE_SESSION\x10\x01\x1a\x1a\x82\xd6\x1b\x16\n\x14LatencyDeleteSession\x12\x41\n!COUNTER_LATENCY_PQ_CREATE_SESSION\x10\x02\x1a\x1a\x82\xd6\x1b\x16\n\x14LatencyCreateSession\x12\x39\n\x1d\x43OUNTER_LATENCY_PQ_SET_OFFSET\x10\x03\x1a\x16\x82\xd6\x1b\x12\n\x10LatencySetOffset\x12\x39\n\x1d\x43OUNTER_LATENCY_PQ_GET_OFFSET\x10\x04\x1a\x16\x82\xd6\x1b\x12\n\x10LatencyGetOffset\x12\x30\n\x18\x43OUNTER_LATENCY_PQ_WRITE\x10\x05\x1a\x12\x82\xd6\x1b\x0e\n\x0cLatencyWrite\x12.\n\x17\x43OUNTER_LATENCY_PQ_READ\x10\x06\x1a\x11\x82\xd6\x1b\r\n\x0bLatencyRead\x12\x33\n\x1a\x43OUNTER_LATENCY_PQ_READ_OK\x10\x07\x1a\x13\x82\xd6\x1b\x0f\n\rLatencyReadOk\x12\x39\n\x1d\x43OUNTER_LATENCY_PQ_READ_ERROR\x10\x08\x1a\x16\x82\xd6\x1b\x12\n\x10LatencyReadError\x12@\n!COUNTER_LATENCY_PQ_READ_HEAD_ONLY\x10\t\x1a\x19\x82\xd6\x1b\x15\n\x13LatencyReadHeadOnly\x12?\n COUNTER_LATENCY_PQ_GET_OWNERSHIP\x10\n\x1a\x19\x82\xd6\x1b\x15\n\x13LatencyGetOwnership\x12;\n\x1e\x43OUNTER_LATENCY_PQ_WRITE_CYCLE\x10\x0b\x1a\x17\x82\xd6\x1b\x13\n\x11LatencyWriteCycle\x12.\n\x17\x43OUNTER_LATENCY_PQ_INIT\x10\x0c\x1a\x11\x82\xd6\x1b\r\n\x0bLatencyInit\x12\xad\x01\n\x1c\x43OUNTER_PQ_WRITE_CYCLE_BYTES\x10\r\x1a\x8a\x01\x82\xd6\x1b\x85\x01\n\x0fWriteCycleBytes\x12\x08\x08\x00\x12\x04\x30 Kb\x12\x0c\x08\x80\xa0\x06\x12\x06\x31\x30\x30 Kb\x12\x0c\x08\x80\xc0\x0c\x12\x06\x32\x30\x30 Kb\x12\x0c\x08\x80\x80 \x12\x06\x35\x31\x32 Kb\x12\n\x08\x80\x80@\x12\x04\x31 Mb\x12\x0b\x08\x80\x80\x80\x01\x12\x04\x32 Mb\x12\x0b\x08\x80\x80\x80\x02\x12\x04\x34 Mb\x12\x0b\x08\x80\x80\x80\x03\x12\x04\x36 Mb\x12\x0b\x08\x80\x80\x80\x04\x12\x04\x38 Mb\x12\xa9\x01\n\x1a\x43OUNTER_PQ_WRITE_NEW_BYTES\x10\x0e\x1a\x88\x01\x82\xd6\x1b\x83\x01\n\rWriteNewBytes\x12\x08\x08\x00\x12\x04\x30 Kb\x12\x0c\x08\x80\xa0\x06\x12\x06\x31\x30\x30 Kb\x12\x0c\x08\x80\xc0\x0c\x12\x06\x32\x30\x30 Kb\x12\x0c\x08\x80\x80 \x12\x06\x35\x31\x32 Kb\x12\n\x08\x80\x80@\x12\x04\x31 Mb\x12\x0b\x08\x80\x80\x80\x01\x12\x04\x32 Mb\x12\x0b\x08\x80\x80\x80\x02\x12\x04\x34 Mb\x12\x0b\x08\x80\x80\x80\x03\x12\x04\x36 Mb\x12\x0b\x08\x80\x80\x80\x04\x12\x04\x38 Mb\x12>\n COUNTER_LATENCY_PQ_RECEIVE_QUEUE\x10\x0f\x1a\x18\x82\xd6\x1b\x14\n\x12LatencyReciveQueue\x12?\n COUNTER_LATENCY_PQ_RESERVE_BYTES\x10\x10\x1a\x19\x82\xd6\x1b\x15\n\x13LatencyReserveBytes\x12P\n)COUNTER_LATENCY_PQ_REGISTER_MESSAGE_GROUP\x10\x11\x1a!\x82\xd6\x1b\x1d\n\x1bLatencyRegisterMessageGroup\x12T\n+COUNTER_LATENCY_PQ_DEREGISTER_MESSAGE_GROUP\x10\x12\x1a#\x82\xd6\x1b\x1f\n\x1dLatencyDeregisterMessageGroup\x12J\n&COUNTER_LATENCY_PQ_SPLIT_MESSAGE_GROUP\x10\x13\x1a\x1e\x82\xd6\x1b\x1a\n\x18LatencySplitMessageGroup\x1a\xef\x01\x92\xd6\x1b\xea\x01\x12\x08\x08\x00\x12\x04\x30 ms\x12\t\x08\x32\x12\x05\x35\x30 ms\x12\n\x08\x64\x12\x06\x31\x30\x30 ms\x12\x0b\x08\xc8\x01\x12\x06\x32\x30\x30 ms\x12\x0b\x08\xac\x02\x12\x06\x33\x30\x30 ms\x12\x0b\x08\x90\x03\x12\x06\x34\x30\x30 ms\x12\x0b\x08\xf4\x03\x12\x06\x35\x30\x30 ms\x12\x0b\x08\xee\x05\x12\x06\x37\x35\x30 ms\x12\x0c\x08\xe8\x07\x12\x07\x31\x30\x30\x30 ms\x12\x0c\x08\xdc\x0b\x12\x07\x31\x35\x30\x30 ms\x12\x0c\x08\xd0\x0f\x12\x07\x32\x30\x30\x30 ms\x12\x0c\x08\x88\'\x12\x07\x35\x30\x30\x30 ms\x12\r\x08\x90N\x12\x08\x31\x30\x30\x30\x30 ms\x12\x0e\x08\xa0\x9c\x01\x12\x08\x32\x30\x30\x30\x30 ms\x12\x0e\x08\xb0\xea\x01\x12\x08\x33\x30\x30\x30\x30 ms\x12\x0e\x08\xe0\xd4\x03\x12\x08\x36\x30\x30\x30\x30 ms\x12\x0f\x08\xc0\xa9\x07\x12\t120000 ms*\xf0\x10\n\x16\x45\x43lientLabeledCounters\x12v\n\x18METRIC_COMMIT_WRITE_TIME\x10\x00\x1aX\xa2\xd6\x1bT\n\x19WriteTimeLagMsByCommitted\x10\x02\x18\x02\"3topic.partition.committed_read_lag_milliseconds_max\x12~\n\x19METRIC_COMMIT_CREATE_TIME\x10\x01\x1a_\xa2\xd6\x1b[\n\x1a\x43reateTimeLagMsByCommitted\x10\x02\x18\x02\"9topic.partition.committed_end_to_end_lag_milliseconds_max\x12h\n\x19METRIC_COMMIT_MESSAGE_LAG\x10\x02\x1aI\xa2\xd6\x1b\x45\n\x15MessageLagByCommitted\x10\x01\"*topic.partition.committed_lag_messages_max\x12\x38\n\x16METRIC_COMMIT_SIZE_LAG\x10\x03\x1a\x1c\xa2\xd6\x1b\x18\n\x12SizeLagByCommitted\x10\x01\"\x00\x12\x43\n\x16METRIC_READ_WRITE_TIME\x10\x04\x1a\'\xa2\xd6\x1b#\n\x1bWriteTimeLagMsByLastReadOld\x10\x02\x18\x02\"\x00\x12m\n\x16METRIC_READ_TOTAL_TIME\x10\x05\x1aQ\xa2\xd6\x1bM\n\x18TotalTimeLagMsByLastRead\x10\x01\"/topic.partition.end_to_end_lag_milliseconds_max\x12`\n\x17METRIC_READ_MESSAGE_LAG\x10\x06\x1a\x43\xa2\xd6\x1b?\n\x14MessageLagByLastRead\x10\x01\"%topic.partition.read.lag_messages_max\x12\x35\n\x14METRIC_READ_SIZE_LAG\x10\x07\x1a\x1b\xa2\xd6\x1b\x17\n\x11SizeLagByLastRead\x10\x01\"\x00\x12W\n\x16METRIC_USER_PARTITIONS\x10\x08\x1a;\xa2\xd6\x1b\x37\n\x16UserPartitionsAnswered\x10\x03\"\x1btopic.partition.alive_count\x12]\n\x1dMETRIC_READ_TOTAL_MESSAGE_LAG\x10\t\x1a:\xa2\xd6\x1b\x36\n\x19TotalMessageLagByLastRead\x10\x03\"\x17topic.read.lag_messages\x12@\n\x1aMETRIC_READ_TOTAL_SIZE_LAG\x10\n\x1a \xa2\xd6\x1b\x1c\n\x16TotalSizeLagByLastRead\x10\x03\"\x00\x12I\n%METRIC_MIN_READ_QUOTA_BYTES_AVAIL_SEC\x10\x0b\x1a\x1e\xa2\xd6\x1b\x1a\n\x14ReadBytesAvailAvgSec\x10\x02\"\x00\x12I\n%METRIC_MIN_READ_QUOTA_BYTES_AVAIL_MIN\x10\x0c\x1a\x1e\xa2\xd6\x1b\x1a\n\x14ReadBytesAvailAvgMin\x10\x02\"\x00\x12\x42\n\x1dMETRIC_READ_OFFSET_REWIND_SUM\x10\r\x1a\x1f\xa2\xd6\x1b\x1b\n\x13ReadOffsetRewindSum\x10\x03\x18\x03\"\x00\x12\x38\n\x19METRIC_TOTAL_READ_SPEED_1\x10\x0e\x1a\x19\xa2\xd6\x1b\x15\n\x0fReadBytesPerSec\x10\x03\"\x00\x12\x39\n\x17METRIC_MAX_READ_SPEED_1\x10\x0f\x1a\x1c\xa2\xd6\x1b\x18\n\x12ReadBytesMaxPerSec\x10\x01\"\x00\x12\x38\n\x19METRIC_TOTAL_READ_SPEED_2\x10\x10\x1a\x19\xa2\xd6\x1b\x15\n\x0fReadBytesPerMin\x10\x03\"\x00\x12\x39\n\x17METRIC_MAX_READ_SPEED_2\x10\x11\x1a\x1c\xa2\xd6\x1b\x18\n\x12ReadBytesMaxPerMin\x10\x01\"\x00\x12\x39\n\x19METRIC_TOTAL_READ_SPEED_3\x10\x12\x1a\x1a\xa2\xd6\x1b\x16\n\x10ReadBytesPerHour\x10\x03\"\x00\x12:\n\x17METRIC_MAX_READ_SPEED_3\x10\x13\x1a\x1d\xa2\xd6\x1b\x19\n\x13ReadBytesMaxPerHour\x10\x01\"\x00\x12\x38\n\x19METRIC_TOTAL_READ_SPEED_4\x10\x14\x1a\x19\xa2\xd6\x1b\x15\n\x0fReadBytesPerDay\x10\x03\"\x00\x12\x39\n\x17METRIC_MAX_READ_SPEED_4\x10\x15\x1a\x1c\xa2\xd6\x1b\x18\n\x12ReadBytesMaxPerDay\x10\x01\"\x00\x12\x35\n\x17METRIC_READ_QUOTA_BYTES\x10\x16\x1a\x18\xa2\xd6\x1b\x14\n\x0eReadBytesQuota\x10\x02\"\x00\x12Z\n\x14METRIC_READ_TIME_LAG\x10\x17\x1a@\xa2\xd6\x1b<\n\rReadTimeLagMs\x10\x01\")topic.partition.read.lag_milliseconds_max\x12g\n\x15METRIC_WRITE_TIME_LAG\x10\x18\x1aL\xa2\xd6\x1bH\n\x18WriteTimeLagMsByLastRead\x10\x01\"*topic.partition.write.lag_milliseconds_max\x12\x64\n\x15METRIC_LAST_READ_TIME\x10\x19\x1aI\xa2\xd6\x1b\x45\n\x13TimeSinceLastReadMs\x10\x02\x18\x02\"*topic.partition.read.idle_milliseconds_max\x12\x41\n\x17METRIC_READ_QUOTA_USAGE\x10\x1a\x1a$\xa2\xd6\x1b \n\x1aPartitionMaxReadQuotaUsage\x10\x01\"\x00\x1a\x1e\xaa\xd6\x1b\x1a\n\x06\x63lient\n\timportant\n\x05topic*\xcd\x14\n\x19\x45PartitionLabeledCounters\x12\\\n\x10METRIC_LIFE_TIME\x10\x00\x1a\x46\xa2\xd6\x1b\x42\n\x13PartitionLifeTimeMs\x10\x01\x18\x02\"\'topic.partition.uptime_milliseconds_min\x12\x61\n\x10METRIC_INIT_TIME\x10\x01\x1aK\xa2\xd6\x1bG\n\x13PartitionInitTimeMs\x10\x01\".topic.partition.init_duration_milliseconds_max\x12N\n\x11METRIC_PARTITIONS\x10\x02\x1a\x37\xa2\xd6\x1b\x33\n\x12PartitionsAnswered\x10\x03\"\x1btopic.partition.alive_count\x12\x41\n\x0fMETRIC_NUM_SIDS\x10\x03\x1a,\xa2\xd6\x1b(\n\rSourceIdCount\x10\x03\"\x15topic.producers_count\x12V\n\x13METRIC_MAX_NUM_SIDS\x10\x04\x1a=\xa2\xd6\x1b\x39\n\x10SourceIdMaxCount\x10\x01\"#topic.partition.producers_count_max\x12*\n\x11METRIC_GAPS_COUNT\x10\x05\x1a\x13\xa2\xd6\x1b\x0f\n\tGapsCount\x10\x03\"\x00\x12\x31\n\x15METRIC_MAX_GAPS_COUNT\x10\x06\x1a\x16\xa2\xd6\x1b\x12\n\x0cGapsMaxCount\x10\x01\"\x00\x12(\n\x10METRIC_GAPS_SIZE\x10\x07\x1a\x12\xa2\xd6\x1b\x0e\n\x08GapsSize\x10\x03\"\x00\x12/\n\x14METRIC_MAX_GAPS_SIZE\x10\x08\x1a\x15\xa2\xd6\x1b\x11\n\x0bGapsMaxSize\x10\x01\"\x00\x12K\n&METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_SEC\x10\t\x1a\x1f\xa2\xd6\x1b\x1b\n\x15WriteBytesAvailAvgSec\x10\x02\"\x00\x12K\n&METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_MIN\x10\n\x1a\x1f\xa2\xd6\x1b\x1b\n\x15WriteBytesAvailAvgMin\x10\x02\"\x00\x12:\n\x1aMETRIC_TOTAL_WRITE_SPEED_1\x10\x0b\x1a\x1a\xa2\xd6\x1b\x16\n\x10WriteBytesPerSec\x10\x03\"\x00\x12;\n\x18METRIC_MAX_WRITE_SPEED_1\x10\x0c\x1a\x1d\xa2\xd6\x1b\x19\n\x13WriteBytesMaxPerSec\x10\x01\"\x00\x12:\n\x1aMETRIC_TOTAL_WRITE_SPEED_2\x10\r\x1a\x1a\xa2\xd6\x1b\x16\n\x10WriteBytesPerMin\x10\x03\"\x00\x12;\n\x18METRIC_MAX_WRITE_SPEED_2\x10\x0e\x1a\x1d\xa2\xd6\x1b\x19\n\x13WriteBytesMaxPerMin\x10\x01\"\x00\x12;\n\x1aMETRIC_TOTAL_WRITE_SPEED_3\x10\x0f\x1a\x1b\xa2\xd6\x1b\x17\n\x11WriteBytesPerHour\x10\x03\"\x00\x12<\n\x18METRIC_MAX_WRITE_SPEED_3\x10\x10\x1a\x1e\xa2\xd6\x1b\x1a\n\x14WriteBytesMaxPerHour\x10\x01\"\x00\x12:\n\x1aMETRIC_TOTAL_WRITE_SPEED_4\x10\x11\x1a\x1a\xa2\xd6\x1b\x16\n\x10WriteBytesPerDay\x10\x03\"\x00\x12;\n\x18METRIC_MAX_WRITE_SPEED_4\x10\x12\x1a\x1d\xa2\xd6\x1b\x19\n\x13WriteBytesMaxPerDay\x10\x01\"\x00\x12\x46\n\x16METRIC_TOTAL_PART_SIZE\x10\x13\x1a*\xa2\xd6\x1b&\n\rTotalPartSize\x10\x03\"\x13topic.storage_bytes\x12P\n\x14METRIC_MAX_PART_SIZE\x10\x14\x1a\x36\xa2\xd6\x1b\x32\n\x0bMaxPartSize\x10\x01\"!topic.partition.storage_bytes_max\x12i\n\x18METRIC_WRITE_QUOTA_BYTES\x10\x15\x1aK\xa2\xd6\x1bG\n\x0fWriteBytesQuota\x10\x02\"2topic.partition.write.speed_limit_bytes_per_second\x12k\n\x18METRIC_WRITE_TIME_LAG_MS\x10\x16\x1aM\xa2\xd6\x1bI\n\x19WriteTimeLagMsByLastWrite\x10\x01\"*topic.partition.write.lag_milliseconds_max\x12g\n\x16METRIC_LAST_WRITE_TIME\x10\x17\x1aK\xa2\xd6\x1bG\n\x14TimeSinceLastWriteMs\x10\x02\x18\x02\"+topic.partition.write.idle_milliseconds_max\x12:\n\x1aMETRIC_TOTAL_QUOTA_SPEED_1\x10\x18\x1a\x1a\xa2\xd6\x1b\x16\n\x10QuotaBytesPerSec\x10\x03\"\x00\x12;\n\x18METRIC_MAX_QUOTA_SPEED_1\x10\x19\x1a\x1d\xa2\xd6\x1b\x19\n\x13QuotaBytesMaxPerSec\x10\x01\"\x00\x12:\n\x1aMETRIC_TOTAL_QUOTA_SPEED_2\x10\x1a\x1a\x1a\xa2\xd6\x1b\x16\n\x10QuotaBytesPerMin\x10\x03\"\x00\x12\x65\n\x18METRIC_MAX_QUOTA_SPEED_2\x10\x1b\x1aG\xa2\xd6\x1b\x43\n\x13QuotaBytesMaxPerMin\x10\x01\"*topic.partition.write.bytes_per_minute_max\x12;\n\x1aMETRIC_TOTAL_QUOTA_SPEED_3\x10\x1c\x1a\x1b\xa2\xd6\x1b\x17\n\x11QuotaBytesPerHour\x10\x03\"\x00\x12\x64\n\x18METRIC_MAX_QUOTA_SPEED_3\x10\x1d\x1a\x46\xa2\xd6\x1b\x42\n\x14QuotaBytesMaxPerHour\x10\x01\"(topic.partition.write.bytes_per_hour_max\x12:\n\x1aMETRIC_TOTAL_QUOTA_SPEED_4\x10\x1e\x1a\x1a\xa2\xd6\x1b\x16\n\x10QuotaBytesPerDay\x10\x03\"\x00\x12\x62\n\x18METRIC_MAX_QUOTA_SPEED_4\x10\x1f\x1a\x44\xa2\xd6\x1b@\n\x13QuotaBytesMaxPerDay\x10\x01\"\'topic.partition.write.bytes_per_day_max\x12r\n\x18METRIC_WRITE_QUOTA_USAGE\x10 \x1aT\xa2\xd6\x1bP\n\x1bPartitionMaxWriteQuotaUsage\x10\x01\"/topic.partition.write.throttled_nanoseconds_max\x12<\n\x17METRIC_MIN_SID_LIFETIME\x10!\x1a\x1f\xa2\xd6\x1b\x1b\n\x15SourceIdMinLifetimeMs\x10\x02\"\x00\x12Q\n\x17METRIC_PARTITIONS_TOTAL\x10\"\x1a\x34\xa2\xd6\x1b\x30\n\x0fPartitionsTotal\x10\x01\"\x1btopic.partition.total_count\x1a\x0b\xaa\xd6\x1b\x07\n\x05topicB\x1e\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x02PQ')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_pq_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\002PQ'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_BAD_REQUEST"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_BAD_REQUEST"]._serialized_options = b'\202\326\033\014\n\nBadRequest'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_INITIALIZING"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_INITIALIZING"]._serialized_options = b'\202\326\033\016\n\014Initializing'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_CREATE_SESSION_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_CREATE_SESSION_OK"]._serialized_options = b'\202\326\033\021\n\017CreateSessionOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_CREATE_SESSION_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_CREATE_SESSION_ERROR"]._serialized_options = b'\202\326\033\024\n\022CreateSessionError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_DELETE_SESSION_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_DELETE_SESSION_OK"]._serialized_options = b'\202\326\033\021\n\017DeleteSessionOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_DELETE_SESSION_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_DELETE_SESSION_ERROR"]._serialized_options = b'\202\326\033\024\n\022DeleteSessionError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SET_CLIENT_OFFSET_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SET_CLIENT_OFFSET_OK"]._serialized_options = b'\202\326\033\023\n\021SetClientOffsetOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SET_CLIENT_OFFSET_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SET_CLIENT_OFFSET_ERROR"]._serialized_options = b'\202\326\033\026\n\024SetClientOffsetError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_GET_CLIENT_OFFSET_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_GET_CLIENT_OFFSET_OK"]._serialized_options = b'\202\326\033\023\n\021GetClientOffsetOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_GET_CLIENT_OFFSET_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_GET_CLIENT_OFFSET_ERROR"]._serialized_options = b'\202\326\033\026\n\024GetClientOffsetError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_OK"]._serialized_options = b'\202\326\033\010\n\006ReadOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR"]._serialized_options = b'\202\326\033\013\n\tReadError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_NO_SESSION"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_NO_SESSION"]._serialized_options = b'\202\326\033\024\n\022ReadErrorNoSession'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_SMALL_OFFSET"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_SMALL_OFFSET"]._serialized_options = b'\202\326\033\026\n\024ReadErrorSmallOffset'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_BIG_OFFSET"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_BIG_OFFSET"]._serialized_options = b'\202\326\033\024\n\022ReadErrorBigOffset'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_IN_PROGRESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_ERROR_IN_PROGRESS"]._serialized_options = b'\202\326\033\025\n\023ReadErrorInProgress'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_HEAD_ONLY_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_HEAD_ONLY_OK"]._serialized_options = b'\202\326\033\020\n\016ReadHeadOnlyOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_OK"]._serialized_options = b'\202\326\033\024\n\022ReadSubscriptionOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_ERROR"]._serialized_options = b'\202\326\033\027\n\025ReadSubscriptionError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_SUBSCRIPTION_TIMEOUT"]._serialized_options = b'\202\326\033\031\n\027ReadSubscriptionTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_READ_BYTES"]._serialized_options = b'\202\326\033\013\n\tBytesRead'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_OK"]._serialized_options = b'\202\326\033\016\n\014BytesWriteOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_ALREADY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_ALREADY"]._serialized_options = b'\202\326\033\023\n\021BytesWriteAlready'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_ERROR"]._serialized_options = b'\202\326\033\021\n\017BytesWriteError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_OK"]._serialized_options = b'\202\326\033\t\n\007WriteOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_ALREADY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_ALREADY"]._serialized_options = b'\202\326\033\016\n\014WriteAlready'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_ERROR"]._serialized_options = b'\202\326\033\014\n\nWriteError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_CYCLE_BYTES_TOTAL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_CYCLE_BYTES_TOTAL"]._serialized_options = b'\202\326\033\026\n\024BytesWriteCycleTotal'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_CACHE_HIT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_CACHE_HIT"]._serialized_options = b'\202\326\033\030\n\026TimestampWriteCacheHit'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_CACHE_MISS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_CACHE_MISS"]._serialized_options = b'\202\326\033\031\n\027TimestampWriteCacheMiss'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_ERROR"]._serialized_options = b'\202\326\033\031\n\027TimestampWriteReadError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_OFFSET_IS_LOST"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_TIMESTAMP_OFFSET_IS_LOST"]._serialized_options = b'\202\326\033\034\n\032TimestampWriteOffsetIsLost'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SID_CREATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_SID_CREATED"]._serialized_options = b'\202\326\033\021\n\017SourceIdCreated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_SMALL_OFFSET"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_BYTES_SMALL_OFFSET"]._serialized_options = b'\202\326\033\027\n\025BytesWriteSmallOffset'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_SMALL_OFFSET"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_WRITE_SMALL_OFFSET"]._serialized_options = b'\202\326\033\022\n\020WriteSmallOffset'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CPU_USAGE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CPU_USAGE"]._serialized_options = b'\202\326\033\n\n\010CPUUsage'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_TABLET_NETWORK_BYTES_USAGE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PQ_TABLET_NETWORK_BYTES_USAGE"]._serialized_options = b'\202\326\033\016\n\014NetworkUsage'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHE_SIZE"]._serialized_options = b'\202\326\033\026\n\024TabletCacheSizeBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHE_COUNT"]._serialized_options = b'\202\326\033\026\n\024TabletCacheSizeBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHED_ON_READ"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHED_ON_READ"]._serialized_options = b'\202\326\033\024\n\022TabletCachedOnRead'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHED_ON_WRATE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_CACHED_ON_WRATE"]._serialized_options = b'\202\326\033\025\n\023TabletCachedOnWrite'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_RESERVED_BYTES_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_RESERVED_BYTES_SIZE"]._serialized_options = b'\202\326\033\023\n\021ReservedBytesSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_OPENED_PIPES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_OPENED_PIPES"]._serialized_options = b'\202\326\033\r\n\013OpenedPipes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_INFLIGHT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PQ_TABLET_INFLIGHT"]._serialized_options = b'\202\326\033\022\n\020RequestsInflight'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\352\001\022\010\010\000\022\0040 ms\022\t\0102\022\00550 ms\022\n\010d\022\006100 ms\022\013\010\310\001\022\006200 ms\022\013\010\254\002\022\006300 ms\022\013\010\220\003\022\006400 ms\022\013\010\364\003\022\006500 ms\022\013\010\356\005\022\006750 ms\022\014\010\350\007\022\0071000 ms\022\014\010\334\013\022\0071500 ms\022\014\010\320\017\022\0072000 ms\022\014\010\210\'\022\0075000 ms\022\r\010\220N\022\01010000 ms\022\016\010\240\234\001\022\01020000 ms\022\016\010\260\352\001\022\01030000 ms\022\016\010\340\324\003\022\01060000 ms\022\017\010\300\251\007\022\t120000 ms'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_MAX_SEQ_NO"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_MAX_SEQ_NO"]._serialized_options = b'\202\326\033\024\n\022LatencyGetMaxSeqNo'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_DELETE_SESSION"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_DELETE_SESSION"]._serialized_options = b'\202\326\033\026\n\024LatencyDeleteSession'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_CREATE_SESSION"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_CREATE_SESSION"]._serialized_options = b'\202\326\033\026\n\024LatencyCreateSession'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_SET_OFFSET"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_SET_OFFSET"]._serialized_options = b'\202\326\033\022\n\020LatencySetOffset'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_OFFSET"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_OFFSET"]._serialized_options = b'\202\326\033\022\n\020LatencyGetOffset'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_WRITE"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_WRITE"]._serialized_options = b'\202\326\033\016\n\014LatencyWrite'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ"]._serialized_options = b'\202\326\033\r\n\013LatencyRead'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_OK"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_OK"]._serialized_options = b'\202\326\033\017\n\rLatencyReadOk'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_ERROR"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_ERROR"]._serialized_options = b'\202\326\033\022\n\020LatencyReadError'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_HEAD_ONLY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_READ_HEAD_ONLY"]._serialized_options = b'\202\326\033\025\n\023LatencyReadHeadOnly'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_OWNERSHIP"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_GET_OWNERSHIP"]._serialized_options = b'\202\326\033\025\n\023LatencyGetOwnership'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_WRITE_CYCLE"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_WRITE_CYCLE"]._serialized_options = b'\202\326\033\023\n\021LatencyWriteCycle'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_INIT"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_INIT"]._serialized_options = b'\202\326\033\r\n\013LatencyInit'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PQ_WRITE_CYCLE_BYTES"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PQ_WRITE_CYCLE_BYTES"]._serialized_options = b'\202\326\033\205\001\n\017WriteCycleBytes\022\010\010\000\022\0040 Kb\022\014\010\200\240\006\022\006100 Kb\022\014\010\200\300\014\022\006200 Kb\022\014\010\200\200 \022\006512 Kb\022\n\010\200\200@\022\0041 Mb\022\013\010\200\200\200\001\022\0042 Mb\022\013\010\200\200\200\002\022\0044 Mb\022\013\010\200\200\200\003\022\0046 Mb\022\013\010\200\200\200\004\022\0048 Mb'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PQ_WRITE_NEW_BYTES"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PQ_WRITE_NEW_BYTES"]._serialized_options = b'\202\326\033\203\001\n\rWriteNewBytes\022\010\010\000\022\0040 Kb\022\014\010\200\240\006\022\006100 Kb\022\014\010\200\300\014\022\006200 Kb\022\014\010\200\200 \022\006512 Kb\022\n\010\200\200@\022\0041 Mb\022\013\010\200\200\200\001\022\0042 Mb\022\013\010\200\200\200\002\022\0044 Mb\022\013\010\200\200\200\003\022\0046 Mb\022\013\010\200\200\200\004\022\0048 Mb'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_RECEIVE_QUEUE"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_RECEIVE_QUEUE"]._serialized_options = b'\202\326\033\024\n\022LatencyReciveQueue'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_RESERVE_BYTES"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_RESERVE_BYTES"]._serialized_options = b'\202\326\033\025\n\023LatencyReserveBytes'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_REGISTER_MESSAGE_GROUP"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_REGISTER_MESSAGE_GROUP"]._serialized_options = b'\202\326\033\035\n\033LatencyRegisterMessageGroup'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_DEREGISTER_MESSAGE_GROUP"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_DEREGISTER_MESSAGE_GROUP"]._serialized_options = b'\202\326\033\037\n\035LatencyDeregisterMessageGroup'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_SPLIT_MESSAGE_GROUP"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_LATENCY_PQ_SPLIT_MESSAGE_GROUP"]._serialized_options = b'\202\326\033\032\n\030LatencySplitMessageGroup'
  _ECLIENTLABELEDCOUNTERS._options = None
  _ECLIENTLABELEDCOUNTERS._serialized_options = b'\252\326\033\032\n\006client\n\timportant\n\005topic'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_WRITE_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_WRITE_TIME"]._serialized_options = b'\242\326\033T\n\031WriteTimeLagMsByCommitted\020\002\030\002\"3topic.partition.committed_read_lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_CREATE_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_CREATE_TIME"]._serialized_options = b'\242\326\033[\n\032CreateTimeLagMsByCommitted\020\002\030\002\"9topic.partition.committed_end_to_end_lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_MESSAGE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_MESSAGE_LAG"]._serialized_options = b'\242\326\033E\n\025MessageLagByCommitted\020\001\"*topic.partition.committed_lag_messages_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_SIZE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_COMMIT_SIZE_LAG"]._serialized_options = b'\242\326\033\030\n\022SizeLagByCommitted\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_WRITE_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_WRITE_TIME"]._serialized_options = b'\242\326\033#\n\033WriteTimeLagMsByLastReadOld\020\002\030\002\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_TIME"]._serialized_options = b'\242\326\033M\n\030TotalTimeLagMsByLastRead\020\001\"/topic.partition.end_to_end_lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_MESSAGE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_MESSAGE_LAG"]._serialized_options = b'\242\326\033?\n\024MessageLagByLastRead\020\001\"%topic.partition.read.lag_messages_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_SIZE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_SIZE_LAG"]._serialized_options = b'\242\326\033\027\n\021SizeLagByLastRead\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_USER_PARTITIONS"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_USER_PARTITIONS"]._serialized_options = b'\242\326\0337\n\026UserPartitionsAnswered\020\003\"\033topic.partition.alive_count'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_MESSAGE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_MESSAGE_LAG"]._serialized_options = b'\242\326\0336\n\031TotalMessageLagByLastRead\020\003\"\027topic.read.lag_messages'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_SIZE_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TOTAL_SIZE_LAG"]._serialized_options = b'\242\326\033\034\n\026TotalSizeLagByLastRead\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MIN_READ_QUOTA_BYTES_AVAIL_SEC"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MIN_READ_QUOTA_BYTES_AVAIL_SEC"]._serialized_options = b'\242\326\033\032\n\024ReadBytesAvailAvgSec\020\002\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MIN_READ_QUOTA_BYTES_AVAIL_MIN"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MIN_READ_QUOTA_BYTES_AVAIL_MIN"]._serialized_options = b'\242\326\033\032\n\024ReadBytesAvailAvgMin\020\002\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_OFFSET_REWIND_SUM"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_OFFSET_REWIND_SUM"]._serialized_options = b'\242\326\033\033\n\023ReadOffsetRewindSum\020\003\030\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_1"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_1"]._serialized_options = b'\242\326\033\025\n\017ReadBytesPerSec\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_1"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_1"]._serialized_options = b'\242\326\033\030\n\022ReadBytesMaxPerSec\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_2"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_2"]._serialized_options = b'\242\326\033\025\n\017ReadBytesPerMin\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_2"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_2"]._serialized_options = b'\242\326\033\030\n\022ReadBytesMaxPerMin\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_3"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_3"]._serialized_options = b'\242\326\033\026\n\020ReadBytesPerHour\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_3"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_3"]._serialized_options = b'\242\326\033\031\n\023ReadBytesMaxPerHour\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_4"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_READ_SPEED_4"]._serialized_options = b'\242\326\033\025\n\017ReadBytesPerDay\020\003\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_4"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_MAX_READ_SPEED_4"]._serialized_options = b'\242\326\033\030\n\022ReadBytesMaxPerDay\020\001\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_QUOTA_BYTES"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_QUOTA_BYTES"]._serialized_options = b'\242\326\033\024\n\016ReadBytesQuota\020\002\"\000'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TIME_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_TIME_LAG"]._serialized_options = b'\242\326\033<\n\rReadTimeLagMs\020\001\")topic.partition.read.lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_WRITE_TIME_LAG"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_WRITE_TIME_LAG"]._serialized_options = b'\242\326\033H\n\030WriteTimeLagMsByLastRead\020\001\"*topic.partition.write.lag_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_LAST_READ_TIME"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_LAST_READ_TIME"]._serialized_options = b'\242\326\033E\n\023TimeSinceLastReadMs\020\002\030\002\"*topic.partition.read.idle_milliseconds_max'
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_QUOTA_USAGE"]._options = None
  _ECLIENTLABELEDCOUNTERS.values_by_name["METRIC_READ_QUOTA_USAGE"]._serialized_options = b'\242\326\033 \n\032PartitionMaxReadQuotaUsage\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS._options = None
  _EPARTITIONLABELEDCOUNTERS._serialized_options = b'\252\326\033\007\n\005topic'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_LIFE_TIME"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_LIFE_TIME"]._serialized_options = b'\242\326\033B\n\023PartitionLifeTimeMs\020\001\030\002\"\'topic.partition.uptime_milliseconds_min'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_INIT_TIME"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_INIT_TIME"]._serialized_options = b'\242\326\033G\n\023PartitionInitTimeMs\020\001\".topic.partition.init_duration_milliseconds_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_PARTITIONS"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_PARTITIONS"]._serialized_options = b'\242\326\0333\n\022PartitionsAnswered\020\003\"\033topic.partition.alive_count'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_NUM_SIDS"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_NUM_SIDS"]._serialized_options = b'\242\326\033(\n\rSourceIdCount\020\003\"\025topic.producers_count'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_NUM_SIDS"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_NUM_SIDS"]._serialized_options = b'\242\326\0339\n\020SourceIdMaxCount\020\001\"#topic.partition.producers_count_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_GAPS_COUNT"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_GAPS_COUNT"]._serialized_options = b'\242\326\033\017\n\tGapsCount\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_GAPS_COUNT"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_GAPS_COUNT"]._serialized_options = b'\242\326\033\022\n\014GapsMaxCount\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_GAPS_SIZE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_GAPS_SIZE"]._serialized_options = b'\242\326\033\016\n\010GapsSize\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_GAPS_SIZE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_GAPS_SIZE"]._serialized_options = b'\242\326\033\021\n\013GapsMaxSize\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_SEC"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_SEC"]._serialized_options = b'\242\326\033\033\n\025WriteBytesAvailAvgSec\020\002\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_MIN"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_WRITE_QUOTA_BYTES_AVAIL_MIN"]._serialized_options = b'\242\326\033\033\n\025WriteBytesAvailAvgMin\020\002\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_1"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_1"]._serialized_options = b'\242\326\033\026\n\020WriteBytesPerSec\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_1"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_1"]._serialized_options = b'\242\326\033\031\n\023WriteBytesMaxPerSec\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_2"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_2"]._serialized_options = b'\242\326\033\026\n\020WriteBytesPerMin\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_2"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_2"]._serialized_options = b'\242\326\033\031\n\023WriteBytesMaxPerMin\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_3"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_3"]._serialized_options = b'\242\326\033\027\n\021WriteBytesPerHour\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_3"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_3"]._serialized_options = b'\242\326\033\032\n\024WriteBytesMaxPerHour\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_4"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_WRITE_SPEED_4"]._serialized_options = b'\242\326\033\026\n\020WriteBytesPerDay\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_4"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_WRITE_SPEED_4"]._serialized_options = b'\242\326\033\031\n\023WriteBytesMaxPerDay\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_PART_SIZE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_PART_SIZE"]._serialized_options = b'\242\326\033&\n\rTotalPartSize\020\003\"\023topic.storage_bytes'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_PART_SIZE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_PART_SIZE"]._serialized_options = b'\242\326\0332\n\013MaxPartSize\020\001\"!topic.partition.storage_bytes_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_QUOTA_BYTES"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_QUOTA_BYTES"]._serialized_options = b'\242\326\033G\n\017WriteBytesQuota\020\002\"2topic.partition.write.speed_limit_bytes_per_second'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_TIME_LAG_MS"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_TIME_LAG_MS"]._serialized_options = b'\242\326\033I\n\031WriteTimeLagMsByLastWrite\020\001\"*topic.partition.write.lag_milliseconds_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_LAST_WRITE_TIME"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_LAST_WRITE_TIME"]._serialized_options = b'\242\326\033G\n\024TimeSinceLastWriteMs\020\002\030\002\"+topic.partition.write.idle_milliseconds_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_1"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_1"]._serialized_options = b'\242\326\033\026\n\020QuotaBytesPerSec\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_1"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_1"]._serialized_options = b'\242\326\033\031\n\023QuotaBytesMaxPerSec\020\001\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_2"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_2"]._serialized_options = b'\242\326\033\026\n\020QuotaBytesPerMin\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_2"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_2"]._serialized_options = b'\242\326\033C\n\023QuotaBytesMaxPerMin\020\001\"*topic.partition.write.bytes_per_minute_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_3"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_3"]._serialized_options = b'\242\326\033\027\n\021QuotaBytesPerHour\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_3"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_3"]._serialized_options = b'\242\326\033B\n\024QuotaBytesMaxPerHour\020\001\"(topic.partition.write.bytes_per_hour_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_4"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_TOTAL_QUOTA_SPEED_4"]._serialized_options = b'\242\326\033\026\n\020QuotaBytesPerDay\020\003\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_4"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MAX_QUOTA_SPEED_4"]._serialized_options = b'\242\326\033@\n\023QuotaBytesMaxPerDay\020\001\"\'topic.partition.write.bytes_per_day_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_QUOTA_USAGE"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_WRITE_QUOTA_USAGE"]._serialized_options = b'\242\326\033P\n\033PartitionMaxWriteQuotaUsage\020\001\"/topic.partition.write.throttled_nanoseconds_max'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_SID_LIFETIME"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_MIN_SID_LIFETIME"]._serialized_options = b'\242\326\033\033\n\025SourceIdMinLifetimeMs\020\002\"\000'
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_PARTITIONS_TOTAL"]._options = None
  _EPARTITIONLABELEDCOUNTERS.values_by_name["METRIC_PARTITIONS_TOTAL"]._serialized_options = b'\242\326\0330\n\017PartitionsTotal\020\001\"\033topic.partition.total_count'
  _ECUMULATIVECOUNTERS._serialized_start=83
  _ECUMULATIVECOUNTERS._serialized_end=2309
  _ESIMPLECOUNTERS._serialized_start=2312
  _ESIMPLECOUNTERS._serialized_end=2763
  _EPERCENTILECOUNTERS._serialized_start=2766
  _EPERCENTILECOUNTERS._serialized_end=4517
  _ECLIENTLABELEDCOUNTERS._serialized_start=4520
  _ECLIENTLABELEDCOUNTERS._serialized_end=6680
  _EPARTITIONLABELEDCOUNTERS._serialized_start=6683
  _EPARTITIONLABELEDCOUNTERS._serialized_end=9320
# @@protoc_insertion_point(module_scope)
