# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_vdisk_internal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import blobstorage_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__pb2
from ydb.core.protos import blobstorage_disk_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ydb/core/protos/blobstorage_vdisk_internal.proto\x12\x10NKikimrVDiskData\x1a\x1aydb/core/protos/base.proto\x1a!ydb/core/protos/blobstorage.proto\x1a&ydb/core/protos/blobstorage_disk.proto\";\n\tTDiskPart\x12\x10\n\x08\x43hunkIdx\x18\x01 \x01(\r\x12\x0e\n\x06Offset\x18\x02 \x01(\r\x12\x0c\n\x04Size\x18\x03 \x01(\r\">\n\x0cTDiskPartVec\x12.\n\tDiskParts\x18\x01 \x03(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\"A\n\x11TPhantomLogoBlobs\x12,\n\tLogoBlobs\x18\x01 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"\xa3\x01\n\x12TBulkFormedSstInfo\x12\x14\n\x0c\x46irstBlobLsn\x18\x01 \x01(\x04\x12\x13\n\x0bLastBlobLsn\x18\x02 \x01(\x04\x12/\n\nEntryPoint\x18\x03 \x01(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\x12\x10\n\x08\x43hunkIds\x18\x04 \x03(\r\x12\x1f\n\x10RemovedFromIndex\x18\x05 \x01(\x08:\x05\x66\x61lse\"O\n\x15TBulkFormedSstInfoSet\x12\x36\n\x08Segments\x18\x01 \x03(\x0b\x32$.NKikimrVDiskData.TBulkFormedSstInfo\"4\n\x07TLevel0\x12)\n\x04Ssts\x18\x01 \x03(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\"K\n\x07TLevelX\x12)\n\x04Ssts\x18\x01 \x03(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\x12\x15\n\rLastCompacted\x18\x02 \x01(\x0c\"\xef\x01\n\x0bTLevelIndex\x12)\n\x06Level0\x18\x01 \x01(\x0b\x32\x19.NKikimrVDiskData.TLevel0\x12.\n\x0bOtherLevels\x18\x02 \x03(\x0b\x32\x19.NKikimrVDiskData.TLevelX\x12\x15\n\rDeletedChunks\x18\x03 \x03(\r\x12\x45\n\x14\x42ulkFormedSstInfoSet\x18\x04 \x01(\x0b\x32\'.NKikimrVDiskData.TBulkFormedSstInfoSet\x12\x11\n\tNextSstId\x18\x0b \x01(\x04\x12\x14\n\x0c\x43ompactedLsn\x18\x0c \x01(\x04\"\xd2\x02\n\x11THullDbEntryPoint\x12\x31\n\nLevelIndex\x18\x01 \x01(\x0b\x32\x1d.NKikimrVDiskData.TLevelIndex\x12\x38\n\x10RemovedHugeBlobs\x18\x02 \x01(\x0b\x32\x1e.NKikimrVDiskData.TDiskPartVec\x12\x64\n\x1bUncommittedRemovedHugeBlobs\x18\x03 \x03(\x0b\x32?.NKikimrVDiskData.THullDbEntryPoint.TUncommittedRemovedHugeBlob\x1aj\n\x1bTUncommittedRemovedHugeBlob\x12\x11\n\tRecordLsn\x18\x01 \x01(\x04\x12\x38\n\x10RemovedHugeBlobs\x18\x02 \x01(\x0b\x32\x1e.NKikimrVDiskData.TDiskPartVec\"\x8a\x04\n\x11TSyncerVDiskEntry\x12-\n\x07VDiskID\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x37\n\x0cSyncGuidInfo\x18\x05 \x01(\x0b\x32!.NKikimrBlobStorage.TSyncGuidInfo\x12G\n\x0eLastSyncStatus\x18\x0b \x01(\x0e\x32/.NKikimrVDiskData.TSyncerVDiskEntry.ESyncStatus\x12\x31\n\tSyncState\x18\x0c \x01(\x0b\x32\x1e.NKikimrBlobStorage.TSyncState\x12\x0f\n\x07SchTime\x18\r \x01(\x04\x12\x0f\n\x07LastTry\x18\x0e \x01(\x04\x12\x10\n\x08LastGood\x18\x0f \x01(\x04\"\xdc\x01\n\x0b\x45SyncStatus\x12\x0b\n\x07Running\x10\x00\x12\x11\n\rProtocolError\x10\x01\x12\x08\n\x04Race\x10\x02\x12\t\n\x05\x45rror\x10\x03\x12\x0f\n\x0b\x46ullRecover\x10\x04\x12\x0f\n\x0b\x44isksSynced\x10\x05\x12\x0c\n\x08NotReady\x10\x06\x12\n\n\x06Locked\x10\x07\x12\x0c\n\x08SyncDone\x10\x08\x12\x0b\n\x07Timeout\x10\t\x12\r\n\tRedirLoop\x10\n\x12\x0b\n\x07Unknown\x10\x0b\x12\x15\n\x11\x44roppedConnection\x10\x0c\x12\x0e\n\nOutOfSpace\x10\r\"\x84\x01\n\x11TSyncerEntryPoint\x12\x39\n\rLocalGuidInfo\x18\x05 \x01(\x0b\x32\".NKikimrBlobStorage.TLocalGuidInfo\x12\x34\n\x07\x45ntries\x18\n \x03(\x0b\x32#.NKikimrVDiskData.TSyncerVDiskEntry\"\x9e\x02\n\x0fTIncrHugeChunks\x12<\n\x06\x43hunks\x18\x01 \x03(\x0b\x32,.NKikimrVDiskData.TIncrHugeChunks.TChunkInfo\x12\x15\n\rDeletedChunks\x18\x02 \x03(\r\x12\x15\n\rCurrentSerNum\x18\x03 \x01(\x04\x1aq\n\nTChunkInfo\x12\x10\n\x08\x43hunkIdx\x18\x01 \x01(\r\x12\x13\n\x0b\x43hunkSerNum\x18\x02 \x01(\x04\x12<\n\x05State\x18\x03 \x01(\x0e\x32-.NKikimrVDiskData.TIncrHugeChunks.EChunkState\",\n\x0b\x45\x43hunkState\x12\x0c\n\x08\x43omplete\x10\x01\x12\x0f\n\x0bWriteIntent\x10\x02\"\x85\x04\n\x0fTIncrHugeDelete\x12<\n\x06\x43hunks\x18\x01 \x03(\x0b\x32,.NKikimrVDiskData.TIncrHugeDelete.TChunkInfo\x12<\n\x06Owners\x18\x02 \x03(\x0b\x32,.NKikimrVDiskData.TIncrHugeDelete.TOwnerInfo\x1a\xc9\x02\n\nTChunkInfo\x12\x13\n\x0b\x43hunkSerNum\x18\x01 \x01(\x04\x12R\n\x0c\x44\x65letedItems\x18\x02 \x01(\x0b\x32:.NKikimrVDiskData.TIncrHugeDelete.TChunkInfo.TDeletedItemsH\x00\x12\x0e\n\x04\x42its\x18\x03 \x01(\x0cH\x00\x1a*\n\nTItemRange\x12\r\n\x05\x46irst\x18\x01 \x01(\r\x12\r\n\x05\x43ount\x18\x02 \x01(\r\x1ai\n\rTDeletedItems\x12\x0f\n\x07Indexes\x18\x01 \x03(\r\x12G\n\x06Ranges\x18\x02 \x03(\x0b\x32\x37.NKikimrVDiskData.TIncrHugeDelete.TChunkInfo.TItemRange\x1a\x1c\n\x0cTDeletedBits\x12\x0c\n\x04\x42its\x18\x01 \x01(\x0c\x42\r\n\x0b\x44\x65letedData\x1a*\n\nTOwnerInfo\x12\r\n\x05Owner\x18\x01 \x01(\r\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\"O\n\x1eTAnubisOsirisPutRecoveryLogRec\x12-\n\nLogoBlobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"\xec\x02\n\x19TAddBulkSstRecoveryLogRec\x12V\n\x12LogoBlobsAdditions\x18\x01 \x03(\x0b\x32:.NKikimrVDiskData.TAddBulkSstRecoveryLogRec.TSstAndRecsNum\x12S\n\x0f\x42locksAdditions\x18\x02 \x03(\x0b\x32:.NKikimrVDiskData.TAddBulkSstRecoveryLogRec.TSstAndRecsNum\x12U\n\x11\x42\x61rriersAdditions\x18\x03 \x03(\x0b\x32:.NKikimrVDiskData.TAddBulkSstRecoveryLogRec.TSstAndRecsNum\x1aK\n\x0eTSstAndRecsNum\x12(\n\x03Sst\x18\x01 \x01(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart\x12\x0f\n\x07RecsNum\x18\x02 \x01(\r\"\xe7\x01\n\x12TSyncLogEntryPoint\x12\x11\n\tPDiskGuid\x18\x01 \x01(\x06\x12\x1c\n\x14VDiskIncarnationGuid\x18\x02 \x01(\x06\x12-\n\x07VDiskID\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x13\n\x0bLogStartLsn\x18\n \x01(\x04\x12\x1f\n\x17RecoveryLogConfirmedLsn\x18\x0b \x01(\x04\x12\x1d\n\x15\x43hunksToDeleteDelayed\x18\x14 \x03(\r\x12\x1c\n\x14\x44iskRecLogSerialized\x18\x15 \x01(\x0c\"|\n\x0bTScrubState\x12\x18\n\x10NextSstIdToScrub\x18\x01 \x01(\x04\x12)\n\x06\x42lobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x0f\n\x07Success\x18\x03 \x01(\x08\x12\x17\n\x0fIncarnationGuid\x18\x04 \x01(\x06\"\xa8\x02\n\x10TScrubEntrypoint\x12P\n\x0fUnreadableBlobs\x18\x01 \x03(\x0b\x32\x37.NKikimrVDiskData.TScrubEntrypoint.TUnreadableBlobState\x12\x31\n\nScrubState\x18\x02 \x01(\x0b\x32\x1d.NKikimrVDiskData.TScrubState\x1a\x8e\x01\n\x14TUnreadableBlobState\x12)\n\x06\x42lobId\x18\x01 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x17\n\x0fUnreadableParts\x18\x02 \x01(\r\x12\x32\n\rCorruptedPart\x18\x03 \x01(\x0b\x32\x1b.NKikimrVDiskData.TDiskPart')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_vdisk_internal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TDISKPART._serialized_start=173
  _TDISKPART._serialized_end=232
  _TDISKPARTVEC._serialized_start=234
  _TDISKPARTVEC._serialized_end=296
  _TPHANTOMLOGOBLOBS._serialized_start=298
  _TPHANTOMLOGOBLOBS._serialized_end=363
  _TBULKFORMEDSSTINFO._serialized_start=366
  _TBULKFORMEDSSTINFO._serialized_end=529
  _TBULKFORMEDSSTINFOSET._serialized_start=531
  _TBULKFORMEDSSTINFOSET._serialized_end=610
  _TLEVEL0._serialized_start=612
  _TLEVEL0._serialized_end=664
  _TLEVELX._serialized_start=666
  _TLEVELX._serialized_end=741
  _TLEVELINDEX._serialized_start=744
  _TLEVELINDEX._serialized_end=983
  _THULLDBENTRYPOINT._serialized_start=986
  _THULLDBENTRYPOINT._serialized_end=1324
  _THULLDBENTRYPOINT_TUNCOMMITTEDREMOVEDHUGEBLOB._serialized_start=1218
  _THULLDBENTRYPOINT_TUNCOMMITTEDREMOVEDHUGEBLOB._serialized_end=1324
  _TSYNCERVDISKENTRY._serialized_start=1327
  _TSYNCERVDISKENTRY._serialized_end=1849
  _TSYNCERVDISKENTRY_ESYNCSTATUS._serialized_start=1629
  _TSYNCERVDISKENTRY_ESYNCSTATUS._serialized_end=1849
  _TSYNCERENTRYPOINT._serialized_start=1852
  _TSYNCERENTRYPOINT._serialized_end=1984
  _TINCRHUGECHUNKS._serialized_start=1987
  _TINCRHUGECHUNKS._serialized_end=2273
  _TINCRHUGECHUNKS_TCHUNKINFO._serialized_start=2114
  _TINCRHUGECHUNKS_TCHUNKINFO._serialized_end=2227
  _TINCRHUGECHUNKS_ECHUNKSTATE._serialized_start=2229
  _TINCRHUGECHUNKS_ECHUNKSTATE._serialized_end=2273
  _TINCRHUGEDELETE._serialized_start=2276
  _TINCRHUGEDELETE._serialized_end=2793
  _TINCRHUGEDELETE_TCHUNKINFO._serialized_start=2420
  _TINCRHUGEDELETE_TCHUNKINFO._serialized_end=2749
  _TINCRHUGEDELETE_TCHUNKINFO_TITEMRANGE._serialized_start=2555
  _TINCRHUGEDELETE_TCHUNKINFO_TITEMRANGE._serialized_end=2597
  _TINCRHUGEDELETE_TCHUNKINFO_TDELETEDITEMS._serialized_start=2599
  _TINCRHUGEDELETE_TCHUNKINFO_TDELETEDITEMS._serialized_end=2704
  _TINCRHUGEDELETE_TCHUNKINFO_TDELETEDBITS._serialized_start=2706
  _TINCRHUGEDELETE_TCHUNKINFO_TDELETEDBITS._serialized_end=2734
  _TINCRHUGEDELETE_TOWNERINFO._serialized_start=2751
  _TINCRHUGEDELETE_TOWNERINFO._serialized_end=2793
  _TANUBISOSIRISPUTRECOVERYLOGREC._serialized_start=2795
  _TANUBISOSIRISPUTRECOVERYLOGREC._serialized_end=2874
  _TADDBULKSSTRECOVERYLOGREC._serialized_start=2877
  _TADDBULKSSTRECOVERYLOGREC._serialized_end=3241
  _TADDBULKSSTRECOVERYLOGREC_TSSTANDRECSNUM._serialized_start=3166
  _TADDBULKSSTRECOVERYLOGREC_TSSTANDRECSNUM._serialized_end=3241
  _TSYNCLOGENTRYPOINT._serialized_start=3244
  _TSYNCLOGENTRYPOINT._serialized_end=3475
  _TSCRUBSTATE._serialized_start=3477
  _TSCRUBSTATE._serialized_end=3601
  _TSCRUBENTRYPOINT._serialized_start=3604
  _TSCRUBENTRYPOINT._serialized_end=3900
  _TSCRUBENTRYPOINT_TUNREADABLEBLOBSTATE._serialized_start=3758
  _TSCRUBENTRYPOINT_TUNREADABLEBLOBSTATE._serialized_end=3900
# @@protoc_insertion_point(module_scope)
