# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/actors/protos/dq_events.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.library.yql.dq.actors.protos import dq_stats_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__stats__pb2
from ydb.library.yql.dq.actors.protos import dq_status_codes_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__status__codes__pb2
from ydb.library.yql.dq.proto import dq_state_load_plan_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__state__load__plan__pb2
from ydb.library.yql.dq.proto import dq_tasks_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__tasks__pb2
from ydb.library.yql.dq.proto import dq_transport_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__transport__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ydb/library/yql/dq/actors/protos/dq_events.proto\x12\rNYql.NDqProto\x1a&library/cpp/actors/protos/actors.proto\x1a/ydb/library/yql/dq/actors/protos/dq_stats.proto\x1a\x36ydb/library/yql/dq/actors/protos/dq_status_codes.proto\x1a\x31ydb/library/yql/dq/proto/dq_state_load_plan.proto\x1a\'ydb/library/yql/dq/proto/dq_tasks.proto\x1a+ydb/library/yql/dq/proto/dq_transport.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\"-\n\x0bTCheckpoint\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"!\n\nTWatermark\x12\x13\n\x0bTimestampUs\x18\x01 \x01(\x04\"\xb5\x01\n\x0cTChannelData\x12\x11\n\tChannelId\x18\x01 \x01(\x04\x12\"\n\x04\x44\x61ta\x18\x02 \x01(\x0b\x32\x14.NYql.NDqProto.TData\x12\x10\n\x08\x46inished\x18\x03 \x01(\x08\x12.\n\nCheckpoint\x18\x04 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12,\n\tWatermark\x18\x05 \x01(\x0b\x32\x19.NYql.NDqProto.TWatermark\"E\n\x06TEvRun\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\":\n\x0fTEvChannelsInfo\x12\'\n\x06Update\x18\x01 \x03(\x0b\x32\x17.NYql.NDqProto.TChannel\"C\n\x12TComputeActorStats\x12\'\n\x07\x41\x63torId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorIdJ\x04\x08\x02\x10\x03\"\xb5\x02\n\x14TEvComputeActorState\x12\r\n\x05State\x18\x01 \x01(\r\x12\x36\n\x0bLegacyStats\x18\x02 \x01(\x0b\x32!.NYql.NDqProto.TComputeActorStats\x12\x30\n\rYdbStatusCode\x18\x03 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x0e\n\x06TaskId\x18\x05 \x01(\x04\x12\x32\n\x05Stats\x18\x06 \x01(\x0b\x32#.NYql.NDqProto.TDqComputeActorStats\x12\x37\n\nStatusCode\x18\x07 \x01(\x0e\x32#.NYql.NDqProto.StatusIds.StatusCode\"\x18\n\x16TEvComputeStateRequest\"y\n\x15TEvComputeChannelData\x12\x30\n\x0b\x43hannelData\x18\x01 \x01(\x0b\x32\x1b.NYql.NDqProto.TChannelData\x12\x10\n\x08SendTime\x18\x02 \x01(\x04\x12\r\n\x05SeqNo\x18\x03 \x01(\x04\x12\r\n\x05NoAck\x18\x04 \x01(\x08\"_\n\x18TEvComputeChannelDataAck\x12\x11\n\tChannelId\x18\x01 \x01(\x04\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\x12\x11\n\tFreeSpace\x18\x03 \x01(\x03\x12\x0e\n\x06\x46inish\x18\x04 \x01(\x08\"\xbe\x01\n\x11TEvAbortExecution\x12\x30\n\rYdbStatusCode\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x15\n\rLegacyMessage\x18\x02 \x01(\t\x12\x37\n\nStatusCode\x18\x03 \x01(\x0e\x32#.NYql.NDqProto.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"Z\n\x07TRlPath\x12\x18\n\x10\x43oordinationNode\x18\x01 \x01(\t\x12\x14\n\x0cResourcePath\x18\x02 \x01(\t\x12\x10\n\x08\x44\x61tabase\x18\x03 \x01(\t\x12\r\n\x05Token\x18\x04 \x01(\t\"\xc0\x02\n\x17TComputeRuntimeSettings\x12\x11\n\tTimeoutMs\x18\x01 \x01(\r\x12\x42\n\x08\x45xecType\x18\x02 \x01(\x0e\x32\x30.NYql.NDqProto.TComputeRuntimeSettings.EExecType\x12.\n\tStatsMode\x18\x08 \x01(\x0e\x32\x1b.NYql.NDqProto.EDqStatsMode\x12\x0f\n\x07UseLLVM\x18\x04 \x01(\x08\x12\x13\n\x0bUseSpilling\x18\x06 \x01(\x08\x12\x18\n\x10TasksOnNodeCount\x18\x05 \x01(\r\x12&\n\x06RlPath\x18\x07 \x01(\x0b\x32\x16.NYql.NDqProto.TRlPath\"0\n\tEExecType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x08\n\x04SCAN\x10\x01\x12\x08\n\x04\x44\x41TA\x10\x02J\x04\x08\x03\x10\x04\"\x7f\n\x1bTEvNewCheckpointCoordinator\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\x0f\n\x07GraphId\x18\x02 \x01(\t\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"]\n\x1eTEvNewCheckpointCoordinatorAck\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\x96\x01\n\x13TEvInjectCheckpoint\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\xca\x02\n\x16TEvSaveTaskStateResult\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x0e\n\x06TaskId\x18\x02 \x01(\x04\x12=\n\x06Status\x18\x03 \x01(\x0e\x32-.NYql.NDqProto.TEvSaveTaskStateResult.EStatus\x12\x16\n\x0eStateSizeBytes\x18\x04 \x01(\x04\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\\\n\x07\x45Status\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x11\n\rSTORAGE_ERROR\x10\x02\x12\x12\n\x0eINTERNAL_ERROR\x10\x03\x12\x11\n\rSTATE_TOO_BIG\x10\x04\"\x91\x01\n\x0eTEvCommitState\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\x90\x01\n\x11TEvStateCommitted\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x0e\n\x06TaskId\x18\x02 \x01(\x04\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\xdd\x01\n\x18TEvRestoreFromCheckpoint\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12@\n\rStateLoadPlan\x18\x03 \x01(\x0b\x32).NYql.NDqProto.NDqStateLoadPlan.TTaskPlan\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"\xbd\x02\n\x1eTEvRestoreFromCheckpointResult\x12.\n\nCheckpoint\x18\x01 \x01(\x0b\x32\x1a.NYql.NDqProto.TCheckpoint\x12\x0e\n\x06TaskId\x18\x02 \x01(\x04\x12L\n\x06Status\x18\x03 \x01(\x0e\x32<.NYql.NDqProto.TEvRestoreFromCheckpointResult.ERestoreStatus\x12;\n\rTransportMeta\x18\x64 \x01(\x0b\x32$.NYql.NDqProto.TMessageTransportMeta\"P\n\x0e\x45RestoreStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x06\n\x02OK\x10\x01\x12\x11\n\rSTORAGE_ERROR\x10\x02\x12\x12\n\x0eINTERNAL_ERROR\x10\x03\">\n\x15TMessageTransportMeta\x12\r\n\x05SeqNo\x18\x01 \x01(\x04\x12\x16\n\x0e\x43onfirmedSeqNo\x18\x02 \x01(\x04*~\n\rEComputeState\x12\x19\n\x15\x43OMPUTE_STATE_UNKNOWN\x10\x00\x12\x19\n\x15\x43OMPUTE_STATE_FAILURE\x10\x01\x12\x1b\n\x17\x43OMPUTE_STATE_EXECUTING\x10\x02\x12\x1a\n\x16\x43OMPUTE_STATE_FINISHED\x10\x03\x42\x03\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.actors.protos.dq_events_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _ECOMPUTESTATE._serialized_start=3687
  _ECOMPUTESTATE._serialized_end=3813
  _TCHECKPOINT._serialized_start=442
  _TCHECKPOINT._serialized_end=487
  _TWATERMARK._serialized_start=489
  _TWATERMARK._serialized_end=522
  _TCHANNELDATA._serialized_start=525
  _TCHANNELDATA._serialized_end=706
  _TEVRUN._serialized_start=708
  _TEVRUN._serialized_end=777
  _TEVCHANNELSINFO._serialized_start=779
  _TEVCHANNELSINFO._serialized_end=837
  _TCOMPUTEACTORSTATS._serialized_start=839
  _TCOMPUTEACTORSTATS._serialized_end=906
  _TEVCOMPUTEACTORSTATE._serialized_start=909
  _TEVCOMPUTEACTORSTATE._serialized_end=1218
  _TEVCOMPUTESTATEREQUEST._serialized_start=1220
  _TEVCOMPUTESTATEREQUEST._serialized_end=1244
  _TEVCOMPUTECHANNELDATA._serialized_start=1246
  _TEVCOMPUTECHANNELDATA._serialized_end=1367
  _TEVCOMPUTECHANNELDATAACK._serialized_start=1369
  _TEVCOMPUTECHANNELDATAACK._serialized_end=1464
  _TEVABORTEXECUTION._serialized_start=1467
  _TEVABORTEXECUTION._serialized_end=1657
  _TRLPATH._serialized_start=1659
  _TRLPATH._serialized_end=1749
  _TCOMPUTERUNTIMESETTINGS._serialized_start=1752
  _TCOMPUTERUNTIMESETTINGS._serialized_end=2072
  _TCOMPUTERUNTIMESETTINGS_EEXECTYPE._serialized_start=2018
  _TCOMPUTERUNTIMESETTINGS_EEXECTYPE._serialized_end=2066
  _TEVNEWCHECKPOINTCOORDINATOR._serialized_start=2074
  _TEVNEWCHECKPOINTCOORDINATOR._serialized_end=2201
  _TEVNEWCHECKPOINTCOORDINATORACK._serialized_start=2203
  _TEVNEWCHECKPOINTCOORDINATORACK._serialized_end=2296
  _TEVINJECTCHECKPOINT._serialized_start=2299
  _TEVINJECTCHECKPOINT._serialized_end=2449
  _TEVSAVETASKSTATERESULT._serialized_start=2452
  _TEVSAVETASKSTATERESULT._serialized_end=2782
  _TEVSAVETASKSTATERESULT_ESTATUS._serialized_start=2690
  _TEVSAVETASKSTATERESULT_ESTATUS._serialized_end=2782
  _TEVCOMMITSTATE._serialized_start=2785
  _TEVCOMMITSTATE._serialized_end=2930
  _TEVSTATECOMMITTED._serialized_start=2933
  _TEVSTATECOMMITTED._serialized_end=3077
  _TEVRESTOREFROMCHECKPOINT._serialized_start=3080
  _TEVRESTOREFROMCHECKPOINT._serialized_end=3301
  _TEVRESTOREFROMCHECKPOINTRESULT._serialized_start=3304
  _TEVRESTOREFROMCHECKPOINTRESULT._serialized_end=3621
  _TEVRESTOREFROMCHECKPOINTRESULT_ERESTORESTATUS._serialized_start=3541
  _TEVRESTOREFROMCHECKPOINTRESULT_ERESTORESTATUS._serialized_end=3621
  _TMESSAGETRANSPORTMETA._serialized_start=3623
  _TMESSAGETRANSPORTMETA._serialized_end=3685
# @@protoc_insertion_point(module_scope)
