# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blobstorage_disk_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__pb2
from ydb.core.protos import blobstorage_disk_color_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__color__pb2
from ydb.core.protos import blobstorage_pdisk_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__pdisk__config__pb2
from ydb.core.protos import blob_depot_config_pb2 as ydb_dot_core_dot_protos_dot_blob__depot__config__pb2
from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ydb/core/protos/blobstorage_config.proto\x12\x12NKikimrBlobStorage\x1a&ydb/core/protos/blobstorage_disk.proto\x1a,ydb/core/protos/blobstorage_disk_color.proto\x1a.ydb/core/protos/blobstorage_pdisk_config.proto\x1a\'ydb/core/protos/blob_depot_config.proto\x1a,library/cpp/actors/protos/interconnect.proto\"\xbe\x01\n\x10THostConfigDrive\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12,\n\x04Type\x18\x02 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskType\x12\x14\n\x0cSharedWithOs\x18\x03 \x01(\x08\x12\x13\n\x0bReadCentric\x18\x04 \x01(\x08\x12\x0c\n\x04Kind\x18\x05 \x01(\x04\x12\x35\n\x0bPDiskConfig\x18\x06 \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\"\xcc\x01\n\x11TDefineHostConfig\x12\x14\n\x0cHostConfigId\x18\x01 \x01(\x04\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x33\n\x05\x44rive\x18\x03 \x03(\x0b\x32$.NKikimrBlobStorage.THostConfigDrive\x12@\n\x16\x44\x65\x66\x61ultHostPDiskConfig\x18\x04 \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"\'\n\x0fTReadHostConfig\x12\x14\n\x0cHostConfigId\x18\x01 \x03(\x04\"G\n\x11TDeleteHostConfig\x12\x14\n\x0cHostConfigId\x18\x01 \x01(\x04\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"8\n\x08THostKey\x12\x0c\n\x04\x46qdn\x18\x01 \x01(\t\x12\x0e\n\x06IcPort\x18\x02 \x01(\x05\x12\x0e\n\x06NodeId\x18\x03 \x01(\r\"`\n\x05THost\x12)\n\x03Key\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x14\n\x0cHostConfigId\x18\x02 \x01(\x04\x12\x16\n\x0e\x45nforcedNodeId\x18\x03 \x01(\r\"\x80\x01\n\nTDefineBox\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0e\n\x06UserId\x18\x03 \x03(\x0c\x12\'\n\x04Host\x18\x04 \x03(\x0b\x32\x19.NKikimrBlobStorage.THost\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"\x19\n\x08TReadBox\x12\r\n\x05\x42oxId\x18\x01 \x03(\x04\"9\n\nTDeleteBox\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"\xcd\x01\n\x0eTGroupGeometry\x12\x17\n\x0fRealmLevelBegin\x18\x01 \x01(\r\x12\x15\n\rRealmLevelEnd\x18\x02 \x01(\r\x12\x18\n\x10\x44omainLevelBegin\x18\x03 \x01(\r\x12\x16\n\x0e\x44omainLevelEnd\x18\x04 \x01(\r\x12\x15\n\rNumFailRealms\x18\x05 \x01(\r\x12\"\n\x1aNumFailDomainsPerFailRealm\x18\x06 \x01(\r\x12\x1e\n\x16NumVDisksPerFailDomain\x18\x07 \x01(\r\"\x9f\x01\n\x12TGroupUsagePattern\x12\x12\n\nSpaceBytes\x18\x01 \x01(\x04\x12\x11\n\tWriteIOPS\x18\x02 \x01(\x04\x12\x1b\n\x13WriteBytesPerSecond\x18\x03 \x01(\x04\x12\x10\n\x08ReadIOPS\x18\x04 \x01(\x04\x12\x1a\n\x12ReadBytesPerSecond\x18\x05 \x01(\x04\x12\x17\n\x0fInMemCacheBytes\x18\x06 \x01(\x04\"\xe5\x01\n\x0cTPDiskFilter\x12\x44\n\x08Property\x18\x01 \x03(\x0b\x32\x32.NKikimrBlobStorage.TPDiskFilter.TRequiredProperty\x1a\x8e\x01\n\x11TRequiredProperty\x12.\n\x04Type\x18\x01 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskTypeH\x00\x12\x16\n\x0cSharedWithOs\x18\x02 \x01(\x08H\x00\x12\x15\n\x0bReadCentric\x18\x03 \x01(\x08H\x00\x12\x0e\n\x04Kind\x18\x04 \x01(\x04H\x00\x42\n\n\x08Property\"\xe7\x04\n\x12TDefineStoragePool\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x02 \x01(\x04\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x16\n\x0e\x45rasureSpecies\x18\x04 \x01(\t\x12\x34\n\x08Geometry\x18\x05 \x01(\x0b\x32\".NKikimrBlobStorage.TGroupGeometry\x12\x11\n\tVDiskKind\x18\x06 \x01(\t\x12<\n\x0cUsagePattern\x18\x07 \x01(\x0b\x32&.NKikimrBlobStorage.TGroupUsagePattern\x12\x0c\n\x04Kind\x18\x08 \x01(\t\x12\x11\n\tNumGroups\x18\t \x01(\r\x12\x0e\n\x06UserId\x18\n \x03(\x0c\x12\x35\n\x0bPDiskFilter\x18\x0b \x03(\x0b\x32 .NKikimrBlobStorage.TPDiskFilter\x12N\n\x0e\x45xistingGroups\x18\x0c \x01(\x0b\x32\x36.NKikimrBlobStorage.TDefineStoragePool.TExistingGroups\x12.\n\x07ScopeId\x18\r \x01(\x0b\x32\x1d.NActorsInterconnect.TScopeId\x12\x1d\n\x15RandomizeGroupMapping\x18\x0e \x01(\x08\x12\x1d\n\x15\x45xpectedGroupSlotSize\x18\x0f \x03(\x04\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\x12\x16\n\x0e\x45ncryptionMode\x18\x65 \x01(\r\x1a\"\n\x0fTExistingGroups\x12\x0f\n\x07GroupId\x18\x01 \x03(\r\"F\n\x10TReadStoragePool\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x02 \x03(\x04\x12\x0c\n\x04Name\x18\x03 \x03(\t\"X\n\x12TDeleteStoragePool\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x02 \x01(\x04\x12\x1c\n\x14ItemConfigGeneration\x18\x64 \x01(\x04\"X\n\x0cTGroupStatus\"H\n\x01\x45\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x46ULL\x10\x01\x12\x0b\n\x07PARTIAL\x10\x02\x12\x0c\n\x08\x44\x45GRADED\x10\x03\x12\x11\n\rDISINTEGRATED\x10\x04\"X\n\x0fTDriveLifeStage\"E\n\x01\x45\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0c\n\x08NOT_SEEN\x10\x01\x12\r\n\tALLOCATED\x10\x02\x12\x0b\n\x07REMOVED\x10\x03\x12\t\n\x05\x45RROR\x10\x04\"U\n\x16TSerialManagementStage\";\n\x01\x45\x12\x13\n\x0f\x44ISCOVER_SERIAL\x10\x00\x12\x10\n\x0c\x43HECK_SERIAL\x10\x01\x12\x0f\n\x0bONLY_SERIAL\x10\x02\"\x80\x02\n\x12TUpdateDriveStatus\x12-\n\x07HostKey\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x30\n\x06Status\x18\x03 \x01(\x0e\x32 .NKikimrBlobStorage.EDriveStatus\x12\x0f\n\x07PDiskId\x18\x04 \x01(\r\x12\x0e\n\x06Serial\x18\x05 \x01(\t\x12\x1d\n\x15StatusChangeTimestamp\x18\x06 \x01(\x04\x12;\n\x0e\x44\x65\x63ommitStatus\x18\x07 \x01(\x0e\x32#.NKikimrBlobStorage.EDecommitStatus\"O\n\x10TReadDriveStatus\x12-\n\x07HostKey\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x0c\n\x04Path\x18\x02 \x01(\t\"\x16\n\x14TProposeStoragePools\"\x12\n\x10TQueryBaseConfig\"\x0f\n\rTReadSettings\"+\n\x08TPDiskId\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\"\xcd\x01\n\x12TReassignGroupDisk\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x02 \x01(\r\x12\x14\n\x0c\x46\x61ilRealmIdx\x18\x03 \x01(\r\x12\x15\n\rFailDomainIdx\x18\x04 \x01(\r\x12\x10\n\x08VDiskIdx\x18\x05 \x01(\r\x12\x33\n\rTargetPDiskId\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TPDiskId\x12\x19\n\x11SuppressDonorMode\x18\x07 \x01(\x08\"!\n\x0eTSanitizeGroup\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\"^\n\x0bTClusterFit\x12;\n\tAlgorithm\x18\x01 \x01(\x0e\x32(.NKikimrBlobStorage.EClusterFitAlgorithm\x12\x12\n\nIterations\x18\x02 \x01(\x04\"M\n\x0cTVSlotMetric\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x0e\n\x06Metric\x18\x02 \x01(\x04\"\xe9\x01\n\x11TClusterFitConfig\x12\x33\n\nBaseConfig\x18\x01 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TBaseConfig\x12;\n\x0bStoragePool\x18\x02 \x03(\x0b\x32&.NKikimrBlobStorage.TDefineStoragePool\x12\x30\n\x06Metric\x18\x03 \x03(\x0b\x32 .NKikimrBlobStorage.TVSlotMetric\x12\x30\n\x07Request\x18\x04 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TClusterFit\"\x8d\x02\n\x0bTMergeBoxes\x12\x13\n\x0bOriginBoxId\x18\x01 \x01(\x04\x12\x1b\n\x13OriginBoxGeneration\x18\x02 \x01(\x04\x12\x13\n\x0bTargetBoxId\x18\x03 \x01(\x04\x12\x1b\n\x13TargetBoxGeneration\x18\x04 \x01(\x04\x12K\n\x10StoragePoolIdMap\x18\x05 \x03(\x0b\x32\x31.NKikimrBlobStorage.TMergeBoxes.TStoragePoolIdMap\x1aM\n\x11TStoragePoolIdMap\x12\x1b\n\x13OriginStoragePoolId\x18\x01 \x01(\x04\x12\x1b\n\x13TargetStoragePoolId\x18\x02 \x01(\x04\"\xb9\x01\n\x0bTMoveGroups\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x1b\n\x13OriginStoragePoolId\x18\x02 \x01(\x04\x12#\n\x1bOriginStoragePoolGeneration\x18\x03 \x01(\x04\x12\x1b\n\x13TargetStoragePoolId\x18\x04 \x01(\x04\x12#\n\x1bTargetStoragePoolGeneration\x18\x05 \x01(\x04\x12\x17\n\x0f\x45xplicitGroupId\x18\x06 \x03(\r\"X\n\x11TAddMigrationPlan\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x35\n\x0bMoveCommand\x18\x02 \x03(\x0b\x32 .NKikimrBlobStorage.TMoveCommand\"$\n\x14TDeleteMigrationPlan\x12\x0c\n\x04Name\x18\x01 \x01(\t\"!\n\x0fTEnableSelfHeal\x12\x0e\n\x06\x45nable\x18\x01 \x01(\x08\"\"\n\x10TEnableDonorMode\x12\x0e\n\x06\x45nable\x18\x01 \x01(\x08\"\xae\x06\n\x0eTDeclareIntent\x12;\n\x07Intents\x18\x01 \x03(\x0b\x32*.NKikimrBlobStorage.TDeclareIntent.TIntent\x12\x15\n\rDropUniqueIds\x18\x02 \x03(\t\x1a]\n\x0eTAffectedGroup\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12:\n\x06Impact\x18\x02 \x01(\x0e\x32*.NKikimrBlobStorage.TDeclareIntent.EImpact\x1ai\n\x0bTDenyReason\x12\x0f\n\x07Message\x18\x01 \x01(\t\x12I\n\x0e\x41\x66\x66\x65\x63tedGroups\x18\x02 \x03(\x0b\x32\x31.NKikimrBlobStorage.TDeclareIntent.TAffectedGroup\x1a\xe8\x02\n\x07TIntent\x12\x10\n\x08UniqueId\x18\x01 \x01(\t\x12\x36\n\x04Kind\x18\x02 \x01(\x0e\x32(.NKikimrBlobStorage.TDeclareIntent.EKind\x12\x16\n\x0e\x42\x65ginTimestamp\x18\x03 \x01(\x04\x12\x14\n\x0c\x45ndTimestamp\x18\x04 \x01(\x04\x12?\n\x06\x41\x63tion\x18\x05 \x01(\x0e\x32/.NKikimrBlobStorage.TDeclareIntent.EDriveAction\x12-\n\x07HostKey\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x0c\n\x04Path\x18\x07 \x01(\t\x12\x0f\n\x07PDiskId\x18\x08 \x01(\r\x12\x12\n\nDriveSerNo\x18\t \x01(\t\x12\x42\n\nDenyReason\x18\x64 \x01(\x0b\x32..NKikimrBlobStorage.TDeclareIntent.TDenyReason\"#\n\x05\x45Kind\x12\x0b\n\x07REQUEST\x10\x00\x12\r\n\tSTATEMENT\x10\x01\"(\n\x0c\x45\x44riveAction\x12\x0b\n\x07REPLACE\x10\x00\x12\x0b\n\x07OFFLINE\x10\x01\"D\n\x07\x45Impact\x12\x11\n\rGROUP_OFFLINE\x10\x00\x12\x13\n\x0fGROUP_DATA_LOSS\x10\x01\x12\x11\n\rGROUP_FRAGILE\x10\x02\"\r\n\x0bTReadIntent\"n\n\x0eTDropDonorDisk\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12-\n\x07VDiskId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\"j\n\nTWipeVDisk\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12-\n\x07VDiskId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\"0\n\x14TSetScrubPeriodicity\x12\x18\n\x10ScrubPeriodicity\x18\x01 \x01(\r\"\xa8\x01\n\x0fTAddDriveSerial\x12\x0e\n\x06Serial\x18\x01 \x01(\t\x12\r\n\x05\x42oxId\x18\x02 \x01(\x04\x12\x0c\n\x04Kind\x18\x03 \x01(\x04\x12\x31\n\tPDiskType\x18\x04 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskType\x12\x35\n\x0bPDiskConfig\x18\x05 \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\"$\n\x12TRemoveDriveSerial\x12\x0e\n\x06Serial\x18\x01 \x01(\t\"$\n\x12TForgetDriveSerial\x12\x0e\n\x06Serial\x18\x01 \x01(\t\"O\n\x10TMigrateToSerial\x12;\n\x05Stage\x18\x01 \x01(\x0e\x32,.NKikimrBlobStorage.TSerialManagementStage.E\"@\n\x1cTSetPDiskSpaceMarginPromille\x12 \n\x18PDiskSpaceMarginPromille\x18\x01 \x01(\r\"\xdf\x02\n\x0fTUpdateSettings\x12\x17\n\x0f\x44\x65\x66\x61ultMaxSlots\x18\x01 \x03(\r\x12\x16\n\x0e\x45nableSelfHeal\x18\x02 \x03(\x08\x12\x17\n\x0f\x45nableDonorMode\x18\x03 \x03(\x08\x12\x1f\n\x17ScrubPeriodicitySeconds\x18\x04 \x03(\x04\x12 \n\x18PDiskSpaceMarginPromille\x18\x05 \x03(\r\x12\x17\n\x0fGroupReserveMin\x18\x06 \x03(\r\x12\x1b\n\x13GroupReservePartPPM\x18\x07 \x03(\r\x12\x1e\n\x16MaxScrubbedDisksAtOnce\x18\x08 \x03(\r\x12\x45\n\x15PDiskSpaceColorBorder\x18\t \x03(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\x12\"\n\x1a\x45nableGroupLayoutSanitizer\x18\n \x03(\x08\"9\n\x11TBoxStoragePoolId\x12\r\n\x05\x42oxId\x18\x01 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x02 \x01(\x04\"\xf0\x01\n\x15TAllocateVirtualGroup\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06HiveId\x18\x02 \x01(\x04\x12\x19\n\x0fStoragePoolName\x18\x03 \x01(\tH\x00\x12>\n\rStoragePoolId\x18\x04 \x01(\x0b\x32%.NKikimrBlobStorage.TBoxStoragePoolIdH\x00\x12:\n\x0f\x43hannelProfiles\x18\x05 \x03(\x0b\x32!.NKikimrBlobDepot.TChannelProfile\x12\x13\n\x0b\x42lobDepotId\x18\x06 \x01(\x04\x42\r\n\x0bStoragePool\"o\n\x0fTDecommitGroups\x12\x10\n\x08GroupIds\x18\x01 \x03(\r\x12\x0e\n\x06HiveId\x18\x02 \x01(\x04\x12:\n\x0f\x43hannelProfiles\x18\x03 \x03(\x0b\x32!.NKikimrBlobDepot.TChannelProfile\"\xe1\x14\n\x0eTConfigRequest\x12<\n\x07\x43ommand\x18\x01 \x03(\x0b\x32+.NKikimrBlobStorage.TConfigRequest.TCommand\x12\x10\n\x08Rollback\x18\x02 \x01(\x08\x12\x1f\n\x17IgnoreGroupSanityChecks\x18\x03 \x01(\x08\x12\"\n\x1aIgnoreGroupFailModelChecks\x18\x04 \x01(\x08\x12\x1d\n\x15IgnoreVSlotQuotaCheck\x18\x05 \x01(\x08\x12\x1a\n\x12\x41llowUnusableDisks\x18\x06 \x01(\x08\x12\x1a\n\x12IgnoreGroupReserve\x18\x07 \x01(\x08\x12\"\n\x1aIgnoreDegradedGroupsChecks\x18\x08 \x01(\x08\x12\'\n\x1fIgnoreDisintegratedGroupsChecks\x18\x0b \x01(\x08\x12$\n\x1cSettleOnlyOnOperationalDisks\x18\t \x01(\x08\x12\x0c\n\x04\x43ito\x18\n \x01(\x08\x1a\xe1\x11\n\x08TCommand\x12\x41\n\x10\x44\x65\x66ineHostConfig\x18\x01 \x01(\x0b\x32%.NKikimrBlobStorage.TDefineHostConfigH\x00\x12=\n\x0eReadHostConfig\x18\x02 \x01(\x0b\x32#.NKikimrBlobStorage.TReadHostConfigH\x00\x12\x41\n\x10\x44\x65leteHostConfig\x18\x04 \x01(\x0b\x32%.NKikimrBlobStorage.TDeleteHostConfigH\x00\x12\x33\n\tDefineBox\x18\x05 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TDefineBoxH\x00\x12/\n\x07ReadBox\x18\x06 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TReadBoxH\x00\x12\x33\n\tDeleteBox\x18\x08 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TDeleteBoxH\x00\x12\x43\n\x11\x44\x65\x66ineStoragePool\x18\t \x01(\x0b\x32&.NKikimrBlobStorage.TDefineStoragePoolH\x00\x12?\n\x0fReadStoragePool\x18\n \x01(\x0b\x32$.NKikimrBlobStorage.TReadStoragePoolH\x00\x12\x43\n\x11\x44\x65leteStoragePool\x18\x0c \x01(\x0b\x32&.NKikimrBlobStorage.TDeleteStoragePoolH\x00\x12\x43\n\x11UpdateDriveStatus\x18\r \x01(\x0b\x32&.NKikimrBlobStorage.TUpdateDriveStatusH\x00\x12?\n\x0fReadDriveStatus\x18\x0e \x01(\x0b\x32$.NKikimrBlobStorage.TReadDriveStatusH\x00\x12G\n\x13ProposeStoragePools\x18\x0f \x01(\x0b\x32(.NKikimrBlobStorage.TProposeStoragePoolsH\x00\x12?\n\x0fQueryBaseConfig\x18\x10 \x01(\x0b\x32$.NKikimrBlobStorage.TQueryBaseConfigH\x00\x12\x35\n\nMergeBoxes\x18\x17 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TMergeBoxesH\x00\x12\x35\n\nMoveGroups\x18\x18 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TMoveGroupsH\x00\x12\x41\n\x10\x41\x64\x64MigrationPlan\x18\x19 \x01(\x0b\x32%.NKikimrBlobStorage.TAddMigrationPlanH\x00\x12G\n\x13\x44\x65leteMigrationPlan\x18\x1a \x01(\x0b\x32(.NKikimrBlobStorage.TDeleteMigrationPlanH\x00\x12=\n\x0e\x45nableSelfHeal\x18\x1b \x01(\x0b\x32#.NKikimrBlobStorage.TEnableSelfHealH\x00\x12;\n\rDeclareIntent\x18\x1c \x01(\x0b\x32\".NKikimrBlobStorage.TDeclareIntentH\x00\x12\x35\n\nReadIntent\x18\x1d \x01(\x0b\x32\x1f.NKikimrBlobStorage.TReadIntentH\x00\x12>\n\x0f\x45nableDonorMode\x18\x1e \x01(\x0b\x32#.NKikimrBlobStorage.TEnableSelfHealH\x00\x12;\n\rDropDonorDisk\x18\x1f \x01(\x0b\x32\".NKikimrBlobStorage.TDropDonorDiskH\x00\x12G\n\x13SetScrubPeriodicity\x18  \x01(\x0b\x32(.NKikimrBlobStorage.TSetScrubPeriodicityH\x00\x12=\n\x0e\x41\x64\x64\x44riveSerial\x18! \x01(\x0b\x32#.NKikimrBlobStorage.TAddDriveSerialH\x00\x12\x43\n\x11RemoveDriveSerial\x18\" \x01(\x0b\x32&.NKikimrBlobStorage.TRemoveDriveSerialH\x00\x12\x43\n\x11\x46orgetDriveSerial\x18$ \x01(\x0b\x32&.NKikimrBlobStorage.TForgetDriveSerialH\x00\x12?\n\x0fMigrateToSerial\x18# \x01(\x0b\x32$.NKikimrBlobStorage.TMigrateToSerialH\x00\x12W\n\x1bSetPDiskSpaceMarginPromille\x18% \x01(\x0b\x32\x30.NKikimrBlobStorage.TSetPDiskSpaceMarginPromilleH\x00\x12=\n\x0eUpdateSettings\x18& \x01(\x0b\x32#.NKikimrBlobStorage.TUpdateSettingsH\x00\x12I\n\x14\x41llocateVirtualGroup\x18\' \x01(\x0b\x32).NKikimrBlobStorage.TAllocateVirtualGroupH\x00\x12=\n\x0e\x44\x65\x63ommitGroups\x18( \x01(\x0b\x32#.NKikimrBlobStorage.TDecommitGroupsH\x00\x12\x33\n\tWipeVDisk\x18) \x01(\x0b\x32\x1e.NKikimrBlobStorage.TWipeVDiskH\x00\x12;\n\rSanitizeGroup\x18* \x01(\x0b\x32\".NKikimrBlobStorage.TSanitizeGroupH\x00\x12\x39\n\x0cReadSettings\x18+ \x01(\x0b\x32!.NKikimrBlobStorage.TReadSettingsH\x00\x12\x43\n\x11ReassignGroupDisk\x18\x13 \x01(\x0b\x32&.NKikimrBlobStorage.TReassignGroupDiskH\x00\x42\t\n\x07\x43ommand\"\xdf\x0e\n\x0bTBaseConfig\x12\x35\n\x05PDisk\x18\x01 \x03(\x0b\x32&.NKikimrBlobStorage.TBaseConfig.TPDisk\x12\x35\n\x05VSlot\x18\x02 \x03(\x0b\x32&.NKikimrBlobStorage.TBaseConfig.TVSlot\x12\x35\n\x05Group\x18\x03 \x03(\x0b\x32&.NKikimrBlobStorage.TBaseConfig.TGroup\x12\x33\n\x04Node\x18\x04 \x03(\x0b\x32%.NKikimrBlobStorage.TBaseConfig.TNode\x1a\xbc\x04\n\x06TPDisk\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12,\n\x04Type\x18\x04 \x01(\x0e\x32\x1e.NKikimrBlobStorage.EPDiskType\x12\x37\n\x0cSharedWithOs\x18\x05 \x01(\x0e\x32!.NKikimrBlobStorage.ETriStateBool\x12\x36\n\x0bReadCentric\x18\x06 \x01(\x0e\x32!.NKikimrBlobStorage.ETriStateBool\x12\x0c\n\x04Kind\x18\x07 \x01(\x04\x12\x35\n\x0bPDiskConfig\x18\x08 \x01(\x0b\x32 .NKikimrBlobStorage.TPDiskConfig\x12\x0c\n\x04Guid\x18\t \x01(\x04\x12\r\n\x05\x42oxId\x18\n \x01(\x04\x12\x16\n\x0eNumStaticSlots\x18\x0b \x01(\r\x12\x35\n\x0b\x44riveStatus\x18\x0c \x01(\x0e\x32 .NKikimrBlobStorage.EDriveStatus\x12\x19\n\x11\x45xpectedSlotCount\x18\r \x01(\r\x12\x37\n\x0cPDiskMetrics\x18\x0e \x01(\x0b\x32!.NKikimrBlobStorage.TPDiskMetrics\x12\"\n\x1a\x44riveStatusChangeTimestamp\x18\x0f \x01(\x04\x12;\n\x0e\x44\x65\x63ommitStatus\x18\x10 \x01(\x0e\x32#.NKikimrBlobStorage.EDecommitStatus\x1a\x8b\x04\n\x06TVSlot\x12-\n\x07VSlotId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x0f\n\x07GroupId\x18\x02 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x03 \x01(\r\x12\x11\n\tVDiskKind\x18\x04 \x01(\t\x12\x14\n\x0c\x46\x61ilRealmIdx\x18\x05 \x01(\r\x12\x15\n\rFailDomainIdx\x18\x06 \x01(\r\x12\x10\n\x08VDiskIdx\x18\x07 \x01(\r\x12\x15\n\rAllocatedSize\x18\x08 \x01(\x04\x12\x37\n\x0cVDiskMetrics\x18\t \x01(\x0b\x32!.NKikimrBlobStorage.TVDiskMetrics\x12\x0e\n\x06Status\x18\n \x01(\t\x12\x41\n\x06\x44onors\x18\x0b \x03(\x0b\x32\x31.NKikimrBlobStorage.TBaseConfig.TVSlot.TDonorDisk\x12\r\n\x05Ready\x18\x0c \x01(\x08\x1a\xa3\x01\n\nTDonorDisk\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12-\n\x07VSlotId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x37\n\x0cVDiskMetrics\x18\x03 \x01(\x0b\x32!.NKikimrBlobStorage.TVDiskMetrics\x1a\xb1\x02\n\x06TGroup\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x02 \x01(\r\x12\x16\n\x0e\x45rasureSpecies\x18\x03 \x01(\t\x12-\n\x07VSlotId\x18\x04 \x03(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\r\n\x05\x42oxId\x18\x05 \x01(\x04\x12\x15\n\rStoragePoolId\x18\x06 \x01(\x04\x12\x17\n\x0fSeenOperational\x18\x07 \x01(\x08\x12;\n\x0fOperatingStatus\x18\x08 \x01(\x0e\x32\".NKikimrBlobStorage.TGroupStatus.E\x12:\n\x0e\x45xpectedStatus\x18\t \x01(\x0e\x32\".NKikimrBlobStorage.TGroupStatus.E\x1a\xf4\x01\n\x05TNode\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x1c\n\x10PhysicalLocation\x18\x02 \x01(\x0c\x42\x02\x18\x01\x12-\n\x07HostKey\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.THostKey\x12\x34\n\x08Location\x18\x04 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12\x1c\n\x14LastConnectTimestamp\x18\x05 \x01(\x04\x12\x1f\n\x17LastDisconnectTimestamp\x18\x06 \x01(\x04\x12\x19\n\x11LastSeenTimestamp\x18\x07 \x01(\x04\"\x90\x01\n\x0cTMoveCommand\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12\x14\n\x0cOriginNodeId\x18\x02 \x01(\r\x12\x15\n\rOriginPDiskId\x18\x03 \x01(\r\x12\x15\n\rOriginVSlotId\x18\x04 \x01(\r\x12\x14\n\x0cTargetNodeId\x18\x05 \x01(\r\x12\x15\n\rTargetPDiskId\x18\x06 \x01(\r\"y\n\nTPDiskStat\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x0c\n\x04\x46qdn\x18\x03 \x01(\t\x12\x0e\n\x06IcPort\x18\x04 \x01(\x05\x12\x0c\n\x04Path\x18\x05 \x01(\t\x12\x1e\n\x16NumSlotsAfterMigration\x18\x06 \x01(\r\"\xda\x01\n\x0fTReassignedItem\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12*\n\x04\x46rom\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12(\n\x02To\x18\x03 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x10\n\x08\x46romFqdn\x18\x04 \x01(\t\x12\x10\n\x08\x46romPath\x18\x05 \x01(\t\x12\x0e\n\x06ToFqdn\x18\x06 \x01(\t\x12\x0e\n\x06ToPath\x18\x07 \x01(\t\"\xec\x0c\n\x0fTConfigResponse\x12;\n\x06Status\x18\x01 \x03(\x0b\x32+.NKikimrBlobStorage.TConfigResponse.TStatus\x12\x0f\n\x07Success\x18\x02 \x01(\x08\x12\x18\n\x10\x45rrorDescription\x18\x03 \x01(\t\x1a\xf0\x0b\n\x07TStatus\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x18\n\x10\x45rrorDescription\x18\x02 \x01(\t\x12K\n\nFailReason\x18\x0c \x01(\x0e\x32\x37.NKikimrBlobStorage.TConfigResponse.TStatus.EFailReason\x12I\n\tFailParam\x18\r \x03(\x0b\x32\x36.NKikimrBlobStorage.TConfigResponse.TStatus.TFailParam\x12\x39\n\nHostConfig\x18\x03 \x03(\x0b\x32%.NKikimrBlobStorage.TDefineHostConfig\x12+\n\x03\x42ox\x18\x04 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TDefineBox\x12;\n\x0b\x44riveStatus\x18\x05 \x03(\x0b\x32&.NKikimrBlobStorage.TUpdateDriveStatus\x12;\n\x0bStoragePool\x18\x06 \x03(\x0b\x32&.NKikimrBlobStorage.TDefineStoragePool\x12\x33\n\nBaseConfig\x18\x07 \x01(\x0b\x32\x1f.NKikimrBlobStorage.TBaseConfig\x12\x0f\n\x07GroupId\x18\x08 \x03(\r\x12\x1d\n\x15\x41ssignedStoragePoolId\x18\t \x01(\x04\x12\x35\n\x0bMoveCommand\x18\n \x03(\x0b\x32 .NKikimrBlobStorage.TMoveCommand\x12\x31\n\tPDiskStat\x18\x0b \x03(\x0b\x32\x1e.NKikimrBlobStorage.TPDiskStat\x12;\n\x0eReassignedItem\x18\x0e \x03(\x0b\x32#.NKikimrBlobStorage.TReassignedItem\x12\x31\n\tWipeVDisk\x18\x11 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TWipeVDisk\x12\x32\n\x06Intent\x18\x0f \x01(\x0b\x32\".NKikimrBlobStorage.TDeclareIntent\x12\x0f\n\x07\x41lready\x18\x10 \x01(\x08\x12\x35\n\x08Settings\x18\x12 \x01(\x0b\x32#.NKikimrBlobStorage.TUpdateSettings\x1a\x8e\x03\n\nTFailParam\x12\x0e\n\x04\x46qdn\x18\x01 \x01(\tH\x00\x12\x10\n\x06IcPort\x18\x02 \x01(\x05H\x00\x12\x10\n\x06NodeId\x18\x03 \x01(\rH\x00\x12\x11\n\x07PDiskId\x18\x04 \x01(\rH\x00\x12\x0e\n\x04Path\x18\x05 \x01(\tH\x00\x12\x16\n\x0cHostConfigId\x18\x06 \x01(\x04H\x00\x12\x0f\n\x05\x42oxId\x18\x07 \x01(\x04H\x00\x12\x17\n\rStoragePoolId\x18\x08 \x01(\x04H\x00\x12&\n\x1cItemConfigGenerationProvided\x18\t \x01(\x04H\x00\x12&\n\x1cItemConfigGenerationExpected\x18\n \x01(\x04H\x00\x12\x11\n\x07GroupId\x18\x0b \x01(\rH\x00\x12/\n\x07VDiskId\x18\x0c \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskIDH\x00\x12/\n\x07VSlotId\x18\r \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotIdH\x00\x12\x19\n\x0fStoragePoolName\x18\x0e \x01(\tH\x00\x42\x07\n\x05Value\"\xf3\x01\n\x0b\x45\x46\x61ilReason\x12\x0c\n\x08kGeneric\x10\x00\x12\x11\n\rkHostNotFound\x10\x01\x12\x12\n\x0ekPDiskNotFound\x10\x02\x12\x17\n\x13kHostConfigNotFound\x10\x03\x12!\n\x1dkItemConfigGenerationMismatch\x10\x04\x12\x10\n\x0ckMayLoseData\x10\x05\x12\x15\n\x11kVDiskIdIncorrect\x10\x06\x12\x12\n\x0ekVSlotNotFound\x10\x07\x12\x13\n\x0fkDiskIsNotDonor\x10\x08\x12\x0c\n\x08kAlready\x10\t\x12\x13\n\x0fkMayGetDegraded\x10\n*:\n\nEPDiskType\x12\x07\n\x03ROT\x10\x00\x12\x07\n\x03SSD\x10\x01\x12\x08\n\x04NVME\x10\x02\x12\x10\n\x0cUNKNOWN_TYPE\x10\x03*=\n\x12\x45VirtualGroupState\x12\x07\n\x03NEW\x10\x00\x12\x11\n\rCREATE_FAILED\x10\x01\x12\x0b\n\x07WORKING\x10\x02*f\n\x0c\x45\x44riveStatus\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\n\n\x06\x42ROKEN\x10\x03\x12\n\n\x06\x46\x41ULTY\x10\x05\x12\x11\n\rTO_BE_REMOVED\x10\x06\"\x04\x08\x04\x10\x04*e\n\x0f\x45\x44\x65\x63ommitStatus\x12\x12\n\x0e\x44\x45\x43OMMIT_UNSET\x10\x00\x12\x11\n\rDECOMMIT_NONE\x10\x01\x12\x14\n\x10\x44\x45\x43OMMIT_PENDING\x10\x02\x12\x15\n\x11\x44\x45\x43OMMIT_IMMINENT\x10\x03*C\n\x14\x45\x43lusterFitAlgorithm\x12\r\n\tQUADRATIC\x10\x00\x12\r\n\tHUNGARIAN\x10\x01\x12\r\n\tANNEALING\x10\x02*3\n\rETriStateBool\x12\n\n\x06kFalse\x10\x00\x12\t\n\x05kTrue\x10\x01\x12\x0b\n\x07kNotSet\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TBASECONFIG_TNODE.fields_by_name['PhysicalLocation']._options = None
  _TBASECONFIG_TNODE.fields_by_name['PhysicalLocation']._serialized_options = b'\030\001'
  _EPDISKTYPE._serialized_start=13533
  _EPDISKTYPE._serialized_end=13591
  _EVIRTUALGROUPSTATE._serialized_start=13593
  _EVIRTUALGROUPSTATE._serialized_end=13654
  _EDRIVESTATUS._serialized_start=13656
  _EDRIVESTATUS._serialized_end=13758
  _EDECOMMITSTATUS._serialized_start=13760
  _EDECOMMITSTATUS._serialized_end=13861
  _ECLUSTERFITALGORITHM._serialized_start=13863
  _ECLUSTERFITALGORITHM._serialized_end=13930
  _ETRISTATEBOOL._serialized_start=13932
  _ETRISTATEBOOL._serialized_end=13983
  _THOSTCONFIGDRIVE._serialized_start=286
  _THOSTCONFIGDRIVE._serialized_end=476
  _TDEFINEHOSTCONFIG._serialized_start=479
  _TDEFINEHOSTCONFIG._serialized_end=683
  _TREADHOSTCONFIG._serialized_start=685
  _TREADHOSTCONFIG._serialized_end=724
  _TDELETEHOSTCONFIG._serialized_start=726
  _TDELETEHOSTCONFIG._serialized_end=797
  _THOSTKEY._serialized_start=799
  _THOSTKEY._serialized_end=855
  _THOST._serialized_start=857
  _THOST._serialized_end=953
  _TDEFINEBOX._serialized_start=956
  _TDEFINEBOX._serialized_end=1084
  _TREADBOX._serialized_start=1086
  _TREADBOX._serialized_end=1111
  _TDELETEBOX._serialized_start=1113
  _TDELETEBOX._serialized_end=1170
  _TGROUPGEOMETRY._serialized_start=1173
  _TGROUPGEOMETRY._serialized_end=1378
  _TGROUPUSAGEPATTERN._serialized_start=1381
  _TGROUPUSAGEPATTERN._serialized_end=1540
  _TPDISKFILTER._serialized_start=1543
  _TPDISKFILTER._serialized_end=1772
  _TPDISKFILTER_TREQUIREDPROPERTY._serialized_start=1630
  _TPDISKFILTER_TREQUIREDPROPERTY._serialized_end=1772
  _TDEFINESTORAGEPOOL._serialized_start=1775
  _TDEFINESTORAGEPOOL._serialized_end=2390
  _TDEFINESTORAGEPOOL_TEXISTINGGROUPS._serialized_start=2356
  _TDEFINESTORAGEPOOL_TEXISTINGGROUPS._serialized_end=2390
  _TREADSTORAGEPOOL._serialized_start=2392
  _TREADSTORAGEPOOL._serialized_end=2462
  _TDELETESTORAGEPOOL._serialized_start=2464
  _TDELETESTORAGEPOOL._serialized_end=2552
  _TGROUPSTATUS._serialized_start=2554
  _TGROUPSTATUS._serialized_end=2642
  _TGROUPSTATUS_E._serialized_start=2570
  _TGROUPSTATUS_E._serialized_end=2642
  _TDRIVELIFESTAGE._serialized_start=2644
  _TDRIVELIFESTAGE._serialized_end=2732
  _TDRIVELIFESTAGE_E._serialized_start=2663
  _TDRIVELIFESTAGE_E._serialized_end=2732
  _TSERIALMANAGEMENTSTAGE._serialized_start=2734
  _TSERIALMANAGEMENTSTAGE._serialized_end=2819
  _TSERIALMANAGEMENTSTAGE_E._serialized_start=2760
  _TSERIALMANAGEMENTSTAGE_E._serialized_end=2819
  _TUPDATEDRIVESTATUS._serialized_start=2822
  _TUPDATEDRIVESTATUS._serialized_end=3078
  _TREADDRIVESTATUS._serialized_start=3080
  _TREADDRIVESTATUS._serialized_end=3159
  _TPROPOSESTORAGEPOOLS._serialized_start=3161
  _TPROPOSESTORAGEPOOLS._serialized_end=3183
  _TQUERYBASECONFIG._serialized_start=3185
  _TQUERYBASECONFIG._serialized_end=3203
  _TREADSETTINGS._serialized_start=3205
  _TREADSETTINGS._serialized_end=3220
  _TPDISKID._serialized_start=3222
  _TPDISKID._serialized_end=3265
  _TREASSIGNGROUPDISK._serialized_start=3268
  _TREASSIGNGROUPDISK._serialized_end=3473
  _TSANITIZEGROUP._serialized_start=3475
  _TSANITIZEGROUP._serialized_end=3508
  _TCLUSTERFIT._serialized_start=3510
  _TCLUSTERFIT._serialized_end=3604
  _TVSLOTMETRIC._serialized_start=3606
  _TVSLOTMETRIC._serialized_end=3683
  _TCLUSTERFITCONFIG._serialized_start=3686
  _TCLUSTERFITCONFIG._serialized_end=3919
  _TMERGEBOXES._serialized_start=3922
  _TMERGEBOXES._serialized_end=4191
  _TMERGEBOXES_TSTORAGEPOOLIDMAP._serialized_start=4114
  _TMERGEBOXES_TSTORAGEPOOLIDMAP._serialized_end=4191
  _TMOVEGROUPS._serialized_start=4194
  _TMOVEGROUPS._serialized_end=4379
  _TADDMIGRATIONPLAN._serialized_start=4381
  _TADDMIGRATIONPLAN._serialized_end=4469
  _TDELETEMIGRATIONPLAN._serialized_start=4471
  _TDELETEMIGRATIONPLAN._serialized_end=4507
  _TENABLESELFHEAL._serialized_start=4509
  _TENABLESELFHEAL._serialized_end=4542
  _TENABLEDONORMODE._serialized_start=4544
  _TENABLEDONORMODE._serialized_end=4578
  _TDECLAREINTENT._serialized_start=4581
  _TDECLAREINTENT._serialized_end=5395
  _TDECLAREINTENT_TAFFECTEDGROUP._serialized_start=4683
  _TDECLAREINTENT_TAFFECTEDGROUP._serialized_end=4776
  _TDECLAREINTENT_TDENYREASON._serialized_start=4778
  _TDECLAREINTENT_TDENYREASON._serialized_end=4883
  _TDECLAREINTENT_TINTENT._serialized_start=4886
  _TDECLAREINTENT_TINTENT._serialized_end=5246
  _TDECLAREINTENT_EKIND._serialized_start=5248
  _TDECLAREINTENT_EKIND._serialized_end=5283
  _TDECLAREINTENT_EDRIVEACTION._serialized_start=5285
  _TDECLAREINTENT_EDRIVEACTION._serialized_end=5325
  _TDECLAREINTENT_EIMPACT._serialized_start=5327
  _TDECLAREINTENT_EIMPACT._serialized_end=5395
  _TREADINTENT._serialized_start=5397
  _TREADINTENT._serialized_end=5410
  _TDROPDONORDISK._serialized_start=5412
  _TDROPDONORDISK._serialized_end=5522
  _TWIPEVDISK._serialized_start=5524
  _TWIPEVDISK._serialized_end=5630
  _TSETSCRUBPERIODICITY._serialized_start=5632
  _TSETSCRUBPERIODICITY._serialized_end=5680
  _TADDDRIVESERIAL._serialized_start=5683
  _TADDDRIVESERIAL._serialized_end=5851
  _TREMOVEDRIVESERIAL._serialized_start=5853
  _TREMOVEDRIVESERIAL._serialized_end=5889
  _TFORGETDRIVESERIAL._serialized_start=5891
  _TFORGETDRIVESERIAL._serialized_end=5927
  _TMIGRATETOSERIAL._serialized_start=5929
  _TMIGRATETOSERIAL._serialized_end=6008
  _TSETPDISKSPACEMARGINPROMILLE._serialized_start=6010
  _TSETPDISKSPACEMARGINPROMILLE._serialized_end=6074
  _TUPDATESETTINGS._serialized_start=6077
  _TUPDATESETTINGS._serialized_end=6428
  _TBOXSTORAGEPOOLID._serialized_start=6430
  _TBOXSTORAGEPOOLID._serialized_end=6487
  _TALLOCATEVIRTUALGROUP._serialized_start=6490
  _TALLOCATEVIRTUALGROUP._serialized_end=6730
  _TDECOMMITGROUPS._serialized_start=6732
  _TDECOMMITGROUPS._serialized_end=6843
  _TCONFIGREQUEST._serialized_start=6846
  _TCONFIGREQUEST._serialized_end=9503
  _TCONFIGREQUEST_TCOMMAND._serialized_start=7230
  _TCONFIGREQUEST_TCOMMAND._serialized_end=9503
  _TBASECONFIG._serialized_start=9506
  _TBASECONFIG._serialized_end=11393
  _TBASECONFIG_TPDISK._serialized_start=9740
  _TBASECONFIG_TPDISK._serialized_end=10312
  _TBASECONFIG_TVSLOT._serialized_start=10315
  _TBASECONFIG_TVSLOT._serialized_end=10838
  _TBASECONFIG_TVSLOT_TDONORDISK._serialized_start=10675
  _TBASECONFIG_TVSLOT_TDONORDISK._serialized_end=10838
  _TBASECONFIG_TGROUP._serialized_start=10841
  _TBASECONFIG_TGROUP._serialized_end=11146
  _TBASECONFIG_TNODE._serialized_start=11149
  _TBASECONFIG_TNODE._serialized_end=11393
  _TMOVECOMMAND._serialized_start=11396
  _TMOVECOMMAND._serialized_end=11540
  _TPDISKSTAT._serialized_start=11542
  _TPDISKSTAT._serialized_end=11663
  _TREASSIGNEDITEM._serialized_start=11666
  _TREASSIGNEDITEM._serialized_end=11884
  _TCONFIGRESPONSE._serialized_start=11887
  _TCONFIGRESPONSE._serialized_end=13531
  _TCONFIGRESPONSE_TSTATUS._serialized_start=12011
  _TCONFIGRESPONSE_TSTATUS._serialized_end=13531
  _TCONFIGRESPONSE_TSTATUS_TFAILPARAM._serialized_start=12887
  _TCONFIGRESPONSE_TSTATUS_TFAILPARAM._serialized_end=13285
  _TCONFIGRESPONSE_TSTATUS_EFAILREASON._serialized_start=13288
  _TCONFIGRESPONSE_TSTATUS_EFAILREASON._serialized_end=13531
# @@protoc_insertion_point(module_scope)
