# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/rate_limiter.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.yq.libs.config.protos import storage_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_storage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ydb/core/yq/libs/config/protos/rate_limiter.proto\x12\x0bNYq.NConfig\x1a,ydb/core/yq/libs/config/protos/storage.proto\"(\n\x08TLimiter\x12\x1c\n\x14\x43oordinationNodePath\x18\x01 \x01(\t\"\xb7\x01\n\x12TRateLimiterConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x1b\n\x13\x43ontrolPlaneEnabled\x18\x02 \x01(\x08\x12\x18\n\x10\x44\x61taPlaneEnabled\x18\x03 \x01(\x08\x12\x30\n\x08\x44\x61tabase\x18\x04 \x01(\x0b\x32\x1e.NYq.NConfig.TYdbStorageConfig\x12\'\n\x08Limiters\x18\x05 \x03(\x0b\x32\x15.NYq.NConfig.TLimiterB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.rate_limiter_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TLIMITER._serialized_start=112
  _TLIMITER._serialized_end=152
  _TRATELIMITERCONFIG._serialized_start=155
  _TRATELIMITERCONFIG._serialized_end=338
# @@protoc_insertion_point(module_scope)
