# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_disk.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blobstorage_disk_color_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__color__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/core/protos/blobstorage_disk.proto\x12\x12NKikimrBlobStorage\x1a,ydb/core/protos/blobstorage_disk_color.proto\"\xcf\x03\n\x0bTPDiskState\"\xbf\x03\n\x01\x45\x12\x0b\n\x07Initial\x10\x00\x12\x15\n\x11InitialFormatRead\x10\x01\x12\x1a\n\x16InitialFormatReadError\x10\x02\x12\x15\n\x11InitialSysLogRead\x10\x03\x12\x1a\n\x16InitialSysLogReadError\x10\x04\x12\x1b\n\x17InitialSysLogParseError\x10\x05\x12\x18\n\x14InitialCommonLogRead\x10\x06\x12\x1d\n\x19InitialCommonLogReadError\x10\x07\x12\x1e\n\x1aInitialCommonLogParseError\x10\x08\x12\x19\n\x15\x43ommonLoggerInitError\x10\t\x12\n\n\x06Normal\x10\n\x12\x11\n\rOpenFileError\x10\x0b\x12\x13\n\x0f\x43hunkQuotaError\x10\x0c\x12\x11\n\rDeviceIoError\x10\r\x12\x0e\n\nReserved14\x10\x0e\x12\x0e\n\nReserved15\x10\x0f\x12\x0e\n\nReserved16\x10\x10\x12\x0c\n\x07Missing\x10\xfc\x01\x12\x0c\n\x07Timeout\x10\xfd\x01\x12\x15\n\x10NodeDisconnected\x10\xfe\x01\x12\x0c\n\x07Unknown\x10\xff\x01\"a\n\x08TVDiskID\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x17\n\x0fGroupGeneration\x18\x02 \x01(\r\x12\x0c\n\x04Ring\x18\x03 \x01(\r\x12\x0e\n\x06\x44omain\x18\x04 \x01(\r\x12\r\n\x05VDisk\x18\x05 \x01(\r\"<\n\x08TVSlotId\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x0f\n\x07VSlotId\x18\x03 \x01(\r\"\x99\x02\n\rTVDiskMetrics\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x18\n\x10SatisfactionRank\x18\x02 \x01(\r\x12\x15\n\rAvailableSize\x18\x03 \x01(\x04\x12\x15\n\rAllocatedSize\x18\x04 \x01(\x04\x12\x13\n\x0bStatusFlags\x18\x07 \x01(\r\x12-\n\x07VSlotId\x18\x08 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVSlotId\x12\x11\n\tOccupancy\x18\t \x01(\x01\x12:\n\nSpaceColor\x18\n \x01(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\"\xab\x02\n\rTPDiskMetrics\x12\x0f\n\x07PDiskId\x18\x01 \x01(\r\x12\x15\n\rAvailableSize\x18\x02 \x01(\x04\x12\x11\n\tTotalSize\x18\x03 \x01(\x04\x12\x19\n\x11MaxReadThroughput\x18\x04 \x01(\x04\x12\x1a\n\x12MaxWriteThroughput\x18\x05 \x01(\x04\x12\x15\n\rNonRealTimeMs\x18\x06 \x01(\x04\x12\x14\n\x0cSlowDeviceMs\x18\x07 \x01(\x04\x12\x0f\n\x07MaxIOPS\x18\x08 \x01(\r\x12\x1f\n\x17\x45nforcedDynamicSlotSize\x18\t \x01(\x04\x12\x30\n\x05State\x18\n \x01(\x0e\x32!.NKikimrBlobStorage.TPDiskState.E\x12\x17\n\x0fUpdateTimestamp\x18\x0b \x01(\x04\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_disk_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPDISKSTATE._serialized_start=109
  _TPDISKSTATE._serialized_end=572
  _TPDISKSTATE_E._serialized_start=125
  _TPDISKSTATE_E._serialized_end=572
  _TVDISKID._serialized_start=574
  _TVDISKID._serialized_end=671
  _TVSLOTID._serialized_start=673
  _TVSLOTID._serialized_end=733
  _TVDISKMETRICS._serialized_start=736
  _TVDISKMETRICS._serialized_end=1017
  _TPDISKMETRICS._serialized_start=1020
  _TPDISKMETRICS._serialized_end=1319
# @@protoc_insertion_point(module_scope)
