# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/gateways.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.providers.common.proto import gateways_config_pb2 as ydb_dot_library_dot_yql_dot_providers_dot_common_dot_proto_dot_gateways__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/core/yq/libs/config/protos/gateways.proto\x12\x0bNYq.NConfig\x1a<ydb/library/yql/providers/common/proto/gateways_config.proto\"\x91\x02\n\x0fTGatewaysConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\"\n\x02\x44q\x18\x02 \x01(\x0b\x32\x16.NYql.TDqGatewayConfig\x12\"\n\x02Pq\x18\x03 \x01(\x0b\x32\x16.NYql.TPqGatewayConfig\x12$\n\x03Ydb\x18\x04 \x01(\x0b\x32\x17.NYql.TYdbGatewayConfig\x12\"\n\x02S3\x18\x05 \x01(\x0b\x32\x16.NYql.TS3GatewayConfig\x12,\n\x07Solomon\x18\x06 \x01(\x0b\x32\x1b.NYql.TSolomonGatewayConfig\x12-\n\x0bHttpGateway\x18\x07 \x01(\x0b\x32\x18.NYql.THttpGatewayConfigB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.gateways_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TGATEWAYSCONFIG._serialized_start=125
  _TGATEWAYSCONFIG._serialized_end=398
# @@protoc_insertion_point(module_scope)
