# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/datashard_load.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import tx_datashard_pb2 as ydb_dot_core_dot_protos_dot_tx__datashard__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/datashard_load.proto\x12\x14NKikimrDataShardLoad\x1a\"ydb/core/protos/tx_datashard.proto\"\xd5\n\n\x16TEvYCSBTestLoadRequest\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x1a\n\x12NotifyWhenFinished\x18\x02 \x01(\x08\x12L\n\nTableSetup\x18\x03 \x01(\x0b\x32\x38.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TTableSetup\x12N\n\x0bTargetShard\x18\x04 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TTargetShard\x12J\n\x08LoadStop\x18\x14 \x01(\x0b\x32\x36.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TLoadStopH\x00\x12T\n\x0fUpsertBulkStart\x18\x15 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TUpdateStartH\x00\x12Y\n\x14UpsertLocalMkqlStart\x18\x16 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TUpdateStartH\x00\x12S\n\x0eUpsertKqpStart\x18\x17 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TUpdateStartH\x00\x12W\n\x12UpsertProposeStart\x18\x18 \x01(\x0b\x32\x39.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TUpdateStartH\x00\x12T\n\x11ReadIteratorStart\x18\x19 \x01(\x0b\x32\x37.NKikimrDataShardLoad.TEvYCSBTestLoadRequest.TReadStartH\x00\x1a/\n\tTLoadStop\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x15\n\rRemoveAllTags\x18\x02 \x01(\x08\x1aX\n\x0cTTargetShard\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\x12\x12\n\nWorkingDir\x18\x03 \x01(\t\x12\x11\n\tTableName\x18\x04 \x01(\t\x1ak\n\x0cTUpdateStart\x12\x10\n\x08RowCount\x18\x01 \x01(\x04\x12\x10\n\x08Inflight\x18\x02 \x01(\r\x12\x12\n\x07KeyFrom\x18\x03 \x01(\x04:\x01\x30\x12\x10\n\x08Infinite\x18\x04 \x01(\x08\x12\x11\n\tBatchSize\x18\x05 \x01(\r\x1a\xb5\x01\n\nTReadStart\x12\x10\n\x08RowCount\x18\x01 \x01(\x04\x12\x11\n\tReadCount\x18\x02 \x01(\x04\x12\x11\n\tInflights\x18\x03 \x03(\r\x12\x0e\n\x06\x43hunks\x18\x04 \x03(\r\x12\x39\n\x0cResultFormat\x18\x05 \x01(\x0e\x32#.NKikimrTxDataShard.EScanDataFormat\x12\x10\n\x08Infinite\x18\x06 \x01(\x08\x12\x12\n\nNoFullScan\x18\x07 \x01(\x08\x1a\xb7\x01\n\x0bTTableSetup\x12\x12\n\nWorkingDir\x18\x01 \x01(\t\x12\x11\n\tTableName\x18\x02 \x01(\t\x12\x11\n\tDropTable\x18\x03 \x01(\x08\x12\x13\n\x0b\x43reateTable\x18\x04 \x01(\x08\x12\x13\n\x08MinParts\x18\x05 \x01(\x04:\x01\x31\x12\x13\n\x08MaxParts\x18\x06 \x01(\x04:\x01\x31\x12\x1b\n\rMaxPartSizeMb\x18\x07 \x01(\x04:\x04\x32\x30\x30\x30\x12\x12\n\nSkipWarmup\x18\x08 \x01(\x08\x42\t\n\x07\x43ommand\"W\n\x13TEvTestLoadResponse\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12\x0e\n\x06\x43ookie\x18\x03 \x01(\x04\x12\x0b\n\x03Tag\x18\x04 \x01(\x04\"\x95\x01\n\x0bTLoadReport\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x12\n\nDurationMs\x18\x02 \x01(\x04\x12\x14\n\x0cOperationsOK\x18\x03 \x01(\x04\x12\x17\n\x0fOperationsError\x18\x04 \x01(\x04\x12\x0c\n\x04Info\x18\x05 \x01(\t\x12\x14\n\x0cSubtestCount\x18\x06 \x01(\x04\x12\x12\n\nPrefixInfo\x18\x07 \x01(\t\"\x18\n\x16TEvTestLoadInfoRequest\"M\n\x17TEvTestLoadInfoResponse\x12\x32\n\x07Reports\x18\x01 \x03(\x0b\x32!.NKikimrDataShardLoad.TLoadReport\"j\n\x13TEvTestLoadFinished\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x31\n\x06Report\x18\x02 \x01(\x0b\x32!.NKikimrDataShardLoad.TLoadReport\x12\x13\n\x0b\x45rrorReason\x18\x03 \x01(\tB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.datashard_load_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TEVYCSBTESTLOADREQUEST._serialized_start=99
  _TEVYCSBTESTLOADREQUEST._serialized_end=1464
  _TEVYCSBTESTLOADREQUEST_TLOADSTOP._serialized_start=837
  _TEVYCSBTESTLOADREQUEST_TLOADSTOP._serialized_end=884
  _TEVYCSBTESTLOADREQUEST_TTARGETSHARD._serialized_start=886
  _TEVYCSBTESTLOADREQUEST_TTARGETSHARD._serialized_end=974
  _TEVYCSBTESTLOADREQUEST_TUPDATESTART._serialized_start=976
  _TEVYCSBTESTLOADREQUEST_TUPDATESTART._serialized_end=1083
  _TEVYCSBTESTLOADREQUEST_TREADSTART._serialized_start=1086
  _TEVYCSBTESTLOADREQUEST_TREADSTART._serialized_end=1267
  _TEVYCSBTESTLOADREQUEST_TTABLESETUP._serialized_start=1270
  _TEVYCSBTESTLOADREQUEST_TTABLESETUP._serialized_end=1453
  _TEVTESTLOADRESPONSE._serialized_start=1466
  _TEVTESTLOADRESPONSE._serialized_end=1553
  _TLOADREPORT._serialized_start=1556
  _TLOADREPORT._serialized_end=1705
  _TEVTESTLOADINFOREQUEST._serialized_start=1707
  _TEVTESTLOADINFOREQUEST._serialized_end=1731
  _TEVTESTLOADINFORESPONSE._serialized_start=1733
  _TEVTESTLOADINFORESPONSE._serialized_end=1810
  _TEVTESTLOADFINISHED._serialized_start=1812
  _TEVTESTLOADFINISHED._serialized_end=1918
# @@protoc_insertion_point(module_scope)
