# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/node_broker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/node_broker.proto\x12\x11NKikimrNodeBroker\x1a,library/cpp/actors/protos/interconnect.proto\"C\n\nTListNodes\x12\x12\n\x08MinEpoch\x18\x01 \x01(\x04H\x00\x12\x17\n\rCachedVersion\x18\x02 \x01(\x04H\x00\x42\x08\n\x06\x46ilter\"\xa3\x01\n\tTNodeInfo\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\x12\x13\n\x0bResolveHost\x18\x04 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x05 \x01(\t\x12\x34\n\x08Location\x18\x06 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12\x0e\n\x06\x45xpire\x18\x07 \x01(\x04\"R\n\x06TEpoch\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x12\r\n\x05Start\x18\x03 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x04 \x01(\x04\x12\x0f\n\x07NextEnd\x18\x05 \x01(\x04\"\xa7\x01\n\nTNodesInfo\x12\x0e\n\x06\x44omain\x18\x01 \x01(\r\x12+\n\x05Nodes\x18\x02 \x03(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\x12\x32\n\x0c\x45xpiredNodes\x18\x03 \x03(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\x12(\n\x05\x45poch\x18\x04 \x01(\x0b\x32\x19.NKikimrNodeBroker.TEpoch\"\x1e\n\x0cTResolveNode\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\"\xa7\x01\n\x07TStatus\x12.\n\x04\x43ode\x18\x01 \x01(\x0e\x32 .NKikimrNodeBroker.TStatus.ECode\x12\x0e\n\x06Reason\x18\x02 \x01(\t\"\\\n\x05\x45\x43ode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0e\n\nERROR_TEMP\x10\x03\x12\x11\n\rWRONG_REQUEST\x10\x04\x12\x10\n\x0cUNAUTHORIZED\x10\x05\"g\n\rTResolvedNode\x12*\n\x06Status\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TStatus\x12*\n\x04Node\x18\x02 \x01(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\"\xd2\x01\n\x14TRegistrationRequest\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x13\n\x0bResolveHost\x18\x03 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x04 \x01(\t\x12\x34\n\x08Location\x18\x05 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12\x13\n\x0b\x46ixedNodeId\x18\x06 \x01(\x08\x12\x0c\n\x04Path\x18\x07 \x01(\t\x12\x1f\n\x17\x41uthorizedByCertificate\x18\x08 \x01(\x08\"\x9b\x01\n\x15TRegistrationResponse\x12*\n\x06Status\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TStatus\x12*\n\x04Node\x18\x02 \x01(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\x12\x15\n\rScopeTabletId\x18\x03 \x01(\x04\x12\x13\n\x0bScopePathId\x18\x04 \x01(\x04\"%\n\x13TExtendLeaseRequest\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\"\x8c\x01\n\x14TExtendLeaseResponse\x12*\n\x06Status\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TStatus\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x0e\n\x06\x45xpire\x18\x03 \x01(\x04\x12(\n\x05\x45poch\x18\x04 \x01(\x0b\x32\x19.NKikimrNodeBroker.TEpoch\"\x8e\x01\n\x07TConfig\x12!\n\rEpochDuration\x18\x01 \x01(\x04:\n3600000000\x12:\n\rBannedNodeIds\x18\x02 \x03(\x0b\x32#.NKikimrNodeBroker.TConfig.TNodeIds\x1a$\n\x08TNodeIds\x12\x0c\n\x04\x46rom\x18\x01 \x01(\r\x12\n\n\x02To\x18\x02 \x01(\r\"\x13\n\x11TGetConfigRequest\"@\n\x12TGetConfigResponse\x12*\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TConfig\"?\n\x11TSetConfigRequest\x12*\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TConfig\"@\n\x12TSetConfigResponse\x12*\n\x06Status\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TStatusB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.node_broker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TLISTNODES._serialized_start=102
  _TLISTNODES._serialized_end=169
  _TNODEINFO._serialized_start=172
  _TNODEINFO._serialized_end=335
  _TEPOCH._serialized_start=337
  _TEPOCH._serialized_end=419
  _TNODESINFO._serialized_start=422
  _TNODESINFO._serialized_end=589
  _TRESOLVENODE._serialized_start=591
  _TRESOLVENODE._serialized_end=621
  _TSTATUS._serialized_start=624
  _TSTATUS._serialized_end=791
  _TSTATUS_ECODE._serialized_start=699
  _TSTATUS_ECODE._serialized_end=791
  _TRESOLVEDNODE._serialized_start=793
  _TRESOLVEDNODE._serialized_end=896
  _TREGISTRATIONREQUEST._serialized_start=899
  _TREGISTRATIONREQUEST._serialized_end=1109
  _TREGISTRATIONRESPONSE._serialized_start=1112
  _TREGISTRATIONRESPONSE._serialized_end=1267
  _TEXTENDLEASEREQUEST._serialized_start=1269
  _TEXTENDLEASEREQUEST._serialized_end=1306
  _TEXTENDLEASERESPONSE._serialized_start=1309
  _TEXTENDLEASERESPONSE._serialized_end=1449
  _TCONFIG._serialized_start=1452
  _TCONFIG._serialized_end=1594
  _TCONFIG_TNODEIDS._serialized_start=1558
  _TCONFIG_TNODEIDS._serialized_end=1594
  _TGETCONFIGREQUEST._serialized_start=1596
  _TGETCONFIGREQUEST._serialized_end=1615
  _TGETCONFIGRESPONSE._serialized_start=1617
  _TGETCONFIGRESPONSE._serialized_end=1681
  _TSETCONFIGREQUEST._serialized_start=1683
  _TSETCONFIGREQUEST._serialized_end=1746
  _TSETCONFIGRESPONSE._serialized_start=1748
  _TSETCONFIGRESPONSE._serialized_end=1812
# @@protoc_insertion_point(module_scope)
