# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/pdiskfit.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/pdiskfit.proto\x12\tNPDiskFIT\"\x9c\x05\n\x0fTFakeVDiskState\x12\x35\n\x08LogItems\x18\x01 \x03(\x0b\x32#.NPDiskFIT.TFakeVDiskState.TLogItem\x12:\n\rInFlightItems\x18\x02 \x03(\x0b\x32#.NPDiskFIT.TFakeVDiskState.TLogItem\x12\x16\n\x0e\x46irstLsnToKeep\x18\x03 \x01(\x04\x12\x15\n\rBlocksInChunk\x18\x04 \x01(\r\x12\x31\n\x06\x43hunks\x18\x05 \x03(\x0b\x32!.NPDiskFIT.TFakeVDiskState.TChunk\x12?\n\x0eWritesInFlight\x18\x06 \x03(\x0b\x32\'.NPDiskFIT.TFakeVDiskState.TWriteRecord\x1ay\n\x08TLogItem\x12\x0b\n\x03Lsn\x18\x01 \x01(\x04\x12\x11\n\tSignature\x18\x02 \x01(\r\x12\x0f\n\x07\x44\x61taLen\x18\x03 \x01(\r\x12\x10\n\x08\x43hecksum\x18\x04 \x01(\r\x12\x14\n\x0c\x43ommitChunks\x18\x05 \x03(\r\x12\x14\n\x0c\x44\x65leteChunks\x18\x06 \x03(\r\x1a\x94\x01\n\x06TChunk\x12\x10\n\x08\x43hunkIdx\x18\x01 \x01(\r\x12\x38\n\x06\x42locks\x18\x02 \x03(\x0b\x32(.NPDiskFIT.TFakeVDiskState.TChunk.TBlock\x12\x13\n\x0b\x43ommitState\x18\x03 \x01(\r\x1a)\n\x06TBlock\x12\r\n\x05Index\x18\x01 \x01(\r\x12\x10\n\x08\x43hecksum\x18\x02 \x01(\r\x1a\x61\n\x0cTWriteRecord\x12\x10\n\x08\x43hunkIdx\x18\x01 \x01(\r\x12\x16\n\x0eOffsetInBlocks\x18\x02 \x01(\r\x12\x14\n\x0cSizeInBlocks\x18\x03 \x01(\r\x12\x11\n\tChecksums\x18\x04 \x03(\r\"q\n\x14TObjectWithStateDict\x12\x34\n\x05Items\x18\x01 \x03(\x0b\x32%.NPDiskFIT.TObjectWithStateDict.TItem\x1a#\n\x05TItem\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x0c')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.pdiskfit_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TFAKEVDISKSTATE._serialized_start=46
  _TFAKEVDISKSTATE._serialized_end=714
  _TFAKEVDISKSTATE_TLOGITEM._serialized_start=343
  _TFAKEVDISKSTATE_TLOGITEM._serialized_end=464
  _TFAKEVDISKSTATE_TCHUNK._serialized_start=467
  _TFAKEVDISKSTATE_TCHUNK._serialized_end=615
  _TFAKEVDISKSTATE_TCHUNK_TBLOCK._serialized_start=574
  _TFAKEVDISKSTATE_TCHUNK_TBLOCK._serialized_end=615
  _TFAKEVDISKSTATE_TWRITERECORD._serialized_start=617
  _TFAKEVDISKSTATE_TWRITERECORD._serialized_end=714
  _TOBJECTWITHSTATEDICT._serialized_start=716
  _TOBJECTWITHSTATEDICT._serialized_end=829
  _TOBJECTWITHSTATEDICT_TITEM._serialized_start=794
  _TOBJECTWITHSTATEDICT_TITEM._serialized_end=829
# @@protoc_insertion_point(module_scope)
