# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/console_tenant.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blobstorage_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__config__pb2
from ydb.public.api.protos import ydb_cms_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__cms__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/console_tenant.proto\x12\x0eNKikimrConsole\x1a(ydb/core/protos/blobstorage_config.proto\x1a#ydb/public/api/protos/ydb_cms.proto\x1a)ydb/public/api/protos/ydb_operation.proto\"Z\n\x14TCreateTenantRequest\x12/\n\x07Request\x18\x01 \x01(\x0b\x32\x1e.Ydb.Cms.CreateDatabaseRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"J\n\x15TCreateTenantResponse\x12\x31\n\x08Response\x18\x01 \x01(\x0b\x32\x1f.Ydb.Cms.CreateDatabaseResponse\"`\n\x17TGetTenantStatusRequest\x12\x32\n\x07Request\x18\x01 \x01(\x0b\x32!.Ydb.Cms.GetDatabaseStatusRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"P\n\x18TGetTenantStatusResponse\x12\x34\n\x08Response\x18\x01 \x01(\x0b\x32\".Ydb.Cms.GetDatabaseStatusResponse\"X\n\x13TAlterTenantRequest\x12.\n\x07Request\x18\x01 \x01(\x0b\x32\x1d.Ydb.Cms.AlterDatabaseRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"H\n\x14TAlterTenantResponse\x12\x30\n\x08Response\x18\x01 \x01(\x0b\x32\x1e.Ydb.Cms.AlterDatabaseResponse\"X\n\x13TListTenantsRequest\x12.\n\x07Request\x18\x01 \x01(\x0b\x32\x1d.Ydb.Cms.ListDatabasesRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"H\n\x14TListTenantsResponse\x12\x30\n\x08Response\x18\x01 \x01(\x0b\x32\x1e.Ydb.Cms.ListDatabasesResponse\"Z\n\x14TRemoveTenantRequest\x12/\n\x07Request\x18\x01 \x01(\x0b\x32\x1e.Ydb.Cms.RemoveDatabaseRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"J\n\x15TRemoveTenantResponse\x12\x31\n\x08Response\x18\x01 \x01(\x0b\x32\x1f.Ydb.Cms.RemoveDatabaseResponse\"_\n\x14TGetOperationRequest\x12\x34\n\x07Request\x18\x01 \x01(\x0b\x32#.Ydb.Operations.GetOperationRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"O\n\x15TGetOperationResponse\x12\x36\n\x08Response\x18\x01 \x01(\x0b\x32$.Ydb.Operations.GetOperationResponse\"l\n\x1dTDescribeTenantOptionsRequest\x12\x38\n\x07Request\x18\x01 \x01(\x0b\x32\'.Ydb.Cms.DescribeDatabaseOptionsRequest\x12\x11\n\tUserToken\x18\x02 \x01(\x0c\"\\\n\x1eTDescribeTenantOptionsResponse\x12:\n\x08Response\x18\x01 \x01(\x0b\x32(.Ydb.Cms.DescribeDatabaseOptionsResponse\"\x86\x01\n\x17TUpdateTenantPoolConfig\x12\x0e\n\x06Tenant\x18\x01 \x01(\t\x12\x10\n\x08PoolType\x18\x02 \x01(\t\x12\x36\n\x06\x43onfig\x18\x03 \x01(\x0b\x32&.NKikimrBlobStorage.TDefineStoragePool\x12\x11\n\tUserToken\x18\x04 \x01(\x0c\"t\n\rTSlotLocation\x12\x12\n\nDataCenter\x18\x01 \x01(\t\x12\x1b\n\rForceLocation\x18\x02 \x01(\x08:\x04true\x12\x18\n\x10\x43ollocationGroup\x18\x03 \x01(\r\x12\x18\n\x10\x46orceCollocation\x18\x04 \x01(\x08\"~\n\x15TAvailabilityZoneKind\x12\x0c\n\x04Kind\x18\x01 \x01(\t\x12\x18\n\x0e\x44\x61taCenterName\x18\x02 \x01(\tH\x00\x12\x35\n\x0cSlotLocation\x18\x03 \x01(\x0b\x32\x1d.NKikimrConsole.TSlotLocationH\x00\x42\x06\n\x04Zone\"7\n\x14TAvailabilityZoneSet\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x11\n\tZoneKinds\x18\x02 \x03(\t\"i\n\x16TComputationalUnitKind\x12\x0c\n\x04Kind\x18\x01 \x01(\t\x12\x18\n\x0eTenantSlotType\x18\x02 \x01(\tH\x00\x12\x1b\n\x13\x41vailabilityZoneSet\x18\n \x01(\tB\n\n\x08Resource\"k\n\rTClusterQuota\x12#\n\x1b\x43omputationalUnitsLoadQuota\x18\x01 \x01(\x04\x12\x1f\n\x17\x43omputationalUnitsQuota\x18\x02 \x01(\x04\x12\x14\n\x0cTenantsQuota\x18\x03 \x01(\x04\"\xe1\x02\n\x0eTTenantsConfig\x12 \n\x18\x44\x65\x66\x61ultStorageUnitsQuota\x18\x01 \x01(\x04\x12&\n\x1e\x44\x65\x66\x61ultComputationalUnitsQuota\x18\x02 \x01(\x04\x12\x44\n\x15\x41vailabilityZoneKinds\x18\x03 \x03(\x0b\x32%.NKikimrConsole.TAvailabilityZoneKind\x12\x42\n\x14\x41vailabilityZoneSets\x18\x04 \x03(\x0b\x32$.NKikimrConsole.TAvailabilityZoneSet\x12\x46\n\x16\x43omputationalUnitKinds\x18\x05 \x03(\x0b\x32&.NKikimrConsole.TComputationalUnitKind\x12\x33\n\x0c\x43lusterQuota\x18\x06 \x01(\x0b\x32\x1d.NKikimrConsole.TClusterQuotaB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.console_tenant_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TCREATETENANTREQUEST._serialized_start=178
  _TCREATETENANTREQUEST._serialized_end=268
  _TCREATETENANTRESPONSE._serialized_start=270
  _TCREATETENANTRESPONSE._serialized_end=344
  _TGETTENANTSTATUSREQUEST._serialized_start=346
  _TGETTENANTSTATUSREQUEST._serialized_end=442
  _TGETTENANTSTATUSRESPONSE._serialized_start=444
  _TGETTENANTSTATUSRESPONSE._serialized_end=524
  _TALTERTENANTREQUEST._serialized_start=526
  _TALTERTENANTREQUEST._serialized_end=614
  _TALTERTENANTRESPONSE._serialized_start=616
  _TALTERTENANTRESPONSE._serialized_end=688
  _TLISTTENANTSREQUEST._serialized_start=690
  _TLISTTENANTSREQUEST._serialized_end=778
  _TLISTTENANTSRESPONSE._serialized_start=780
  _TLISTTENANTSRESPONSE._serialized_end=852
  _TREMOVETENANTREQUEST._serialized_start=854
  _TREMOVETENANTREQUEST._serialized_end=944
  _TREMOVETENANTRESPONSE._serialized_start=946
  _TREMOVETENANTRESPONSE._serialized_end=1020
  _TGETOPERATIONREQUEST._serialized_start=1022
  _TGETOPERATIONREQUEST._serialized_end=1117
  _TGETOPERATIONRESPONSE._serialized_start=1119
  _TGETOPERATIONRESPONSE._serialized_end=1198
  _TDESCRIBETENANTOPTIONSREQUEST._serialized_start=1200
  _TDESCRIBETENANTOPTIONSREQUEST._serialized_end=1308
  _TDESCRIBETENANTOPTIONSRESPONSE._serialized_start=1310
  _TDESCRIBETENANTOPTIONSRESPONSE._serialized_end=1402
  _TUPDATETENANTPOOLCONFIG._serialized_start=1405
  _TUPDATETENANTPOOLCONFIG._serialized_end=1539
  _TSLOTLOCATION._serialized_start=1541
  _TSLOTLOCATION._serialized_end=1657
  _TAVAILABILITYZONEKIND._serialized_start=1659
  _TAVAILABILITYZONEKIND._serialized_end=1785
  _TAVAILABILITYZONESET._serialized_start=1787
  _TAVAILABILITYZONESET._serialized_end=1842
  _TCOMPUTATIONALUNITKIND._serialized_start=1844
  _TCOMPUTATIONALUNITKIND._serialized_end=1949
  _TCLUSTERQUOTA._serialized_start=1951
  _TCLUSTERQUOTA._serialized_end=2058
  _TTENANTSCONFIG._serialized_start=2061
  _TTENANTSCONFIG._serialized_end=2414
# @@protoc_insertion_point(module_scope)
