# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/ydb_persqueue_cluster_discovery.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;ydb/public/api/protos/ydb_persqueue_cluster_discovery.proto\x12\x1eYdb.PersQueue.ClusterDiscovery\x1a\x1bgoogle/protobuf/empty.proto\x1a)ydb/public/api/protos/ydb_operation.proto\"o\n\x12WriteSessionParams\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x11\n\tsource_id\x18\x02 \x01(\x0c\x12\x17\n\x0fpartition_group\x18\x03 \x01(\r\x12\x1e\n\x16preferred_cluster_name\x18\x04 \x01(\t\"@\n\x0b\x43lusterInfo\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x11\n\tavailable\x18\x03 \x01(\x08\"|\n\x11ReadSessionParams\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x1b\n\x11mirror_to_cluster\x18\x02 \x01(\tH\x00\x12.\n\x0c\x61ll_original\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x42\x0b\n\tread_rule\"\xc3\x02\n\x14WriteSessionClusters\x12=\n\x08\x63lusters\x18\x01 \x03(\x0b\x32+.Ydb.PersQueue.ClusterDiscovery.ClusterInfo\x12n\n primary_cluster_selection_reason\x18\x02 \x01(\x0e\x32\x44.Ydb.PersQueue.ClusterDiscovery.WriteSessionClusters.SelectionReason\"|\n\x0fSelectionReason\x12 \n\x1cSELECTION_REASON_UNSPECIFIED\x10\x00\x12\x15\n\x11\x43LIENT_PREFERENCE\x10\x01\x12\x13\n\x0f\x43LIENT_LOCATION\x10\x02\x12\x1b\n\x17\x43ONSISTENT_DISTRIBUTION\x10\x03\"T\n\x13ReadSessionClusters\x12=\n\x08\x63lusters\x18\x01 \x03(\x0b\x32+.Ydb.PersQueue.ClusterDiscovery.ClusterInfo\"\x83\x02\n\x17\x44iscoverClustersRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12J\n\x0ewrite_sessions\x18\x02 \x03(\x0b\x32\x32.Ydb.PersQueue.ClusterDiscovery.WriteSessionParams\x12H\n\rread_sessions\x18\x03 \x03(\x0b\x32\x31.Ydb.PersQueue.ClusterDiscovery.ReadSessionParams\x12\x17\n\x0fminimal_version\x18\x04 \x01(\x03\"H\n\x18\x44iscoverClustersResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xd5\x01\n\x16\x44iscoverClustersResult\x12U\n\x17write_sessions_clusters\x18\x01 \x03(\x0b\x32\x34.Ydb.PersQueue.ClusterDiscovery.WriteSessionClusters\x12S\n\x16read_sessions_clusters\x18\x02 \x03(\x0b\x32\x33.Ydb.PersQueue.ClusterDiscovery.ReadSessionClusters\x12\x0f\n\x07version\x18\x03 \x01(\x03\x42/\n*com.yandex.ydb.persqueue.cluster_discovery\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.ydb_persqueue_cluster_discovery_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*com.yandex.ydb.persqueue.cluster_discovery\370\001\001'
  _WRITESESSIONPARAMS._serialized_start=167
  _WRITESESSIONPARAMS._serialized_end=278
  _CLUSTERINFO._serialized_start=280
  _CLUSTERINFO._serialized_end=344
  _READSESSIONPARAMS._serialized_start=346
  _READSESSIONPARAMS._serialized_end=470
  _WRITESESSIONCLUSTERS._serialized_start=473
  _WRITESESSIONCLUSTERS._serialized_end=796
  _WRITESESSIONCLUSTERS_SELECTIONREASON._serialized_start=672
  _WRITESESSIONCLUSTERS_SELECTIONREASON._serialized_end=796
  _READSESSIONCLUSTERS._serialized_start=798
  _READSESSIONCLUSTERS._serialized_end=882
  _DISCOVERCLUSTERSREQUEST._serialized_start=885
  _DISCOVERCLUSTERSREQUEST._serialized_end=1144
  _DISCOVERCLUSTERSRESPONSE._serialized_start=1146
  _DISCOVERCLUSTERSRESPONSE._serialized_end=1218
  _DISCOVERCLUSTERSRESULT._serialized_start=1221
  _DISCOVERCLUSTERSRESULT._serialized_end=1434
# @@protoc_insertion_point(module_scope)
