# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tenant_slot_broker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ydb/core/protos/tenant_slot_broker.proto\x12\x17NKikimrTenantSlotBroker\x1a&library/cpp/actors/protos/actors.proto\"/\n\x07TConfig\x12$\n\x12PendingSlotTimeout\x18\x01 \x01(\x04:\x08\x31\x35\x30\x30\x30\x30\x30\x30\"\xaa\x01\n\x0fTSlotAllocation\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12\x15\n\rDataCenterNum\x18\x02 \x01(\x04\x12\x12\n\nDataCenter\x18\x07 \x01(\t\x12\r\n\x05\x43ount\x18\x03 \x01(\x04\x12\x1b\n\rForceLocation\x18\x04 \x01(\x08:\x04true\x12\x18\n\x10\x43ollocationGroup\x18\x05 \x01(\r\x12\x18\n\x10\x46orceCollocation\x18\x06 \x01(\x08\"%\n\x0fTGetTenantState\x12\x12\n\nTenantName\x18\x01 \x01(\t\"\xdb\x03\n\x0cTTenantState\x12\x12\n\nTenantName\x18\x01 \x01(\t\x12?\n\rRequiredSlots\x18\x02 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12>\n\x0cPendingSlots\x18\x03 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12>\n\x0cMissingSlots\x18\x04 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12@\n\x0eMisplacedSlots\x18\x05 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12<\n\nSplitSlots\x18\x06 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12=\n\x0bPinnedSlots\x18\x07 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\x12\x37\n\rAssignedSlots\x18\x08 \x03(\x0b\x32 .NKikimrTenantSlotBroker.TSlotId\"c\n\x0cTAlterTenant\x12\x12\n\nTenantName\x18\x01 \x01(\t\x12?\n\rRequiredSlots\x18\x02 \x03(\x0b\x32(.NKikimrTenantSlotBroker.TSlotAllocation\"H\n\rTRegisterPool\x12(\n\x08\x43lientId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\"\x0e\n\x0cTListTenants\"F\n\x0cTTenantsList\x12\x36\n\x07Tenants\x18\x01 \x03(\x0b\x32%.NKikimrTenantSlotBroker.TTenantState\"\x0f\n\rTGetSlotStats\"R\n\rTSlotCounters\x12\x12\n\nDataCenter\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x11\n\tConnected\x18\x03 \x01(\x04\x12\x0c\n\x04\x46ree\x18\x04 \x01(\x04\"J\n\nTSlotStats\x12<\n\x0cSlotCounters\x18\x01 \x03(\x0b\x32&.NKikimrTenantSlotBroker.TSlotCounters\")\n\x07TSlotId\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0e\n\x06SlotId\x18\x02 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tenant_slot_broker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TCONFIG._serialized_start=109
  _TCONFIG._serialized_end=156
  _TSLOTALLOCATION._serialized_start=159
  _TSLOTALLOCATION._serialized_end=329
  _TGETTENANTSTATE._serialized_start=331
  _TGETTENANTSTATE._serialized_end=368
  _TTENANTSTATE._serialized_start=371
  _TTENANTSTATE._serialized_end=846
  _TALTERTENANT._serialized_start=848
  _TALTERTENANT._serialized_end=947
  _TREGISTERPOOL._serialized_start=949
  _TREGISTERPOOL._serialized_end=1021
  _TLISTTENANTS._serialized_start=1023
  _TLISTTENANTS._serialized_end=1037
  _TTENANTSLIST._serialized_start=1039
  _TTENANTSLIST._serialized_end=1109
  _TGETSLOTSTATS._serialized_start=1111
  _TGETSLOTSTATS._serialized_end=1126
  _TSLOTCOUNTERS._serialized_start=1128
  _TSLOTCOUNTERS._serialized_end=1210
  _TSLOTSTATS._serialized_start=1212
  _TSLOTSTATS._serialized_end=1286
  _TSLOTID._serialized_start=1288
  _TSLOTID._serialized_end=1329
# @@protoc_insertion_point(module_scope)
