# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_mediator_timecast.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/tx_mediator_timecast.proto\x12\x19NKikimrTxMediatorTimecast\"\x1a\n\x08TEvWatch\x12\x0e\n\x06\x42ucket\x18\x01 \x03(\r\"U\n\tTEvUpdate\x12\x10\n\x08Mediator\x18\x01 \x01(\x04\x12\x0e\n\x06\x42ucket\x18\x02 \x01(\r\x12\x13\n\x0bTimeBarrier\x18\x04 \x01(\x06\x12\x11\n\tExemption\x18\x05 \x03(\x06\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_mediator_timecast_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVWATCH._serialized_start=73
  _TEVWATCH._serialized_end=99
  _TEVUPDATE._serialized_start=101
  _TEVUPDATE._serialized_end=186
# @@protoc_insertion_point(module_scope)
