# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/quotas_manager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3ydb/core/yq/libs/config/protos/quotas_manager.proto\x12\x0bNYq.NConfig\"*\n\x0bTQuotaLimit\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Limit\x18\x02 \x01(\x04\"]\n\nTQuotaList\x12\x13\n\x0bSubjectType\x18\x01 \x01(\t\x12\x11\n\tSubjectId\x18\x02 \x01(\t\x12\'\n\x05Limit\x18\x03 \x03(\x0b\x32\x18.NYq.NConfig.TQuotaLimit\"k\n\x17TQuotaDescriptionConfig\x12\x13\n\x0bSubjectType\x18\x01 \x01(\t\x12\x12\n\nMetricName\x18\x02 \x01(\t\x12\x14\n\x0c\x44\x65\x66\x61ultLimit\x18\x03 \x01(\x04\x12\x11\n\tHardLimit\x18\x04 \x01(\x04\"\xe4\x01\n\x14TQuotasManagerConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\'\n\x06Quotas\x18\x02 \x03(\x0b\x32\x17.NYq.NConfig.TQuotaList\x12?\n\x11QuotaDescriptions\x18\x03 \x03(\x0b\x32$.NYq.NConfig.TQuotaDescriptionConfig\x12\x1a\n\x12LimitRefreshPeriod\x18\x04 \x01(\t\x12\x1a\n\x12UsageRefreshPeriod\x18\x05 \x01(\t\x12\x19\n\x11\x45nablePermissions\x18\x06 \x01(\x08\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.quotas_manager_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TQUOTALIMIT._serialized_start=68
  _TQUOTALIMIT._serialized_end=110
  _TQUOTALIST._serialized_start=112
  _TQUOTALIST._serialized_end=205
  _TQUOTADESCRIPTIONCONFIG._serialized_start=207
  _TQUOTADESCRIPTIONCONFIG._serialized_end=314
  _TQUOTASMANAGERCONFIG._serialized_start=317
  _TQUOTASMANAGERCONFIG._serialized_end=545
# @@protoc_insertion_point(module_scope)
