# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/grpc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import msgbus_pb2 as ydb_dot_core_dot_protos_dot_msgbus__pb2
from ydb.core.protos import msgbus_kv_pb2 as ydb_dot_core_dot_protos_dot_msgbus__kv__pb2
from ydb.core.protos import msgbus_pq_pb2 as ydb_dot_core_dot_protos_dot_msgbus__pq__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aydb/core/protos/grpc.proto\x12\rNKikimrClient\x1a\x1cydb/core/protos/msgbus.proto\x1a\x1fydb/core/protos/msgbus_kv.proto\x1a\x1fydb/core/protos/msgbus_pq.proto2\xd3\x13\n\x0bTGRpcServer\x12<\n\x07Request\x12\x17.NKikimrClient.TRequest\x1a\x18.NKikimrClient.TResponse\x12L\n\x0fSchemeOperation\x12\x1f.NKikimrClient.TSchemeOperation\x1a\x18.NKikimrClient.TResponse\x12X\n\x15SchemeOperationStatus\x12%.NKikimrClient.TSchemeOperationStatus\x1a\x18.NKikimrClient.TResponse\x12J\n\x0eSchemeDescribe\x12\x1e.NKikimrClient.TSchemeDescribe\x1a\x18.NKikimrClient.TResponse\x12:\n\x06WhoAmI\x12\x16.NKikimrClient.TWhoAmI\x1a\x18.NKikimrClient.TResponse\x12\x46\n\x0cLoginRequest\x12\x1c.NKikimrClient.TLoginRequest\x1a\x18.NKikimrClient.TResponse\x12K\n\x0b\x43hooseProxy\x12\".NKikimrClient.TChooseProxyRequest\x1a\x18.NKikimrClient.TResponse\x12N\n\x10PersQueueRequest\x12 .NKikimrClient.TPersQueueRequest\x1a\x18.NKikimrClient.TResponse\x12J\n\x0eSchemeInitRoot\x12\x1e.NKikimrClient.TSchemeInitRoot\x1a\x18.NKikimrClient.TResponse\x12\x38\n\x05\x42SAdm\x12\x15.NKikimrClient.TBSAdm\x1a\x18.NKikimrClient.TResponse\x12K\n\x0bResolveNode\x12\".NKikimrClient.TResolveNodeRequest\x1a\x18.NKikimrClient.TResponse\x12\x45\n\x08\x46illNode\x12\x1f.NKikimrClient.TFillNodeRequest\x1a\x18.NKikimrClient.TResponse\x12G\n\tDrainNode\x12 .NKikimrClient.TDrainNodeRequest\x1a\x18.NKikimrClient.TResponse\x12W\n\x11\x42lobStorageConfig\x12(.NKikimrClient.TBlobStorageConfigRequest\x1a\x18.NKikimrClient.TResponse\x12N\n\x10HiveCreateTablet\x12 .NKikimrClient.THiveCreateTablet\x1a\x18.NKikimrClient.TResponse\x12X\n\x15LocalEnumerateTablets\x12%.NKikimrClient.TLocalEnumerateTablets\x1a\x18.NKikimrClient.TResponse\x12\x45\n\x08KeyValue\x12\x1f.NKikimrClient.TKeyValueRequest\x1a\x18.NKikimrClient.TResponse\x12U\n\x10TestShardControl\x12\'.NKikimrClient.TTestShardControlRequest\x1a\x18.NKikimrClient.TResponse\x12\x61\n\x0cRegisterNode\x12\'.NKikimrClient.TNodeRegistrationRequest\x1a(.NKikimrClient.TNodeRegistrationResponse\x12\x45\n\nCmsRequest\x12\x1a.NKikimrClient.TCmsRequest\x1a\x1b.NKikimrClient.TCmsResponse\x12\x45\n\nSqsRequest\x12\x1a.NKikimrClient.TSqsRequest\x1a\x1b.NKikimrClient.TSqsResponse\x12Q\n\x0e\x43onsoleRequest\x12\x1e.NKikimrClient.TConsoleRequest\x1a\x1f.NKikimrClient.TConsoleResponse\x12@\n\tLocalMKQL\x12\x19.NKikimrClient.TLocalMKQL\x1a\x18.NKikimrClient.TResponse\x12H\n\rLocalSchemeTx\x12\x1d.NKikimrClient.TLocalSchemeTx\x1a\x18.NKikimrClient.TResponse\x12P\n\x11TabletKillRequest\x12!.NKikimrClient.TTabletKillRequest\x1a\x18.NKikimrClient.TResponse\x12P\n\x11InterconnectDebug\x12!.NKikimrClient.TInterconnectDebug\x1a\x18.NKikimrClient.TResponse\x12R\n\x12TabletStateRequest\x12\".NKikimrClient.TTabletStateRequest\x1a\x18.NKikimrClient.TResponse\x12U\n\x16\x42lobStorageLoadRequest\x12!.NKikimrClient.TBsTestLoadRequest\x1a\x18.NKikimrClient.TResponse\x12O\n\x15\x42lobStorageGetRequest\x12\x1c.NKikimrClient.TBsGetRequest\x1a\x18.NKikimrClient.TResponse\x12S\n\x14\x44\x61taShardLoadRequest\x12!.NKikimrClient.TDsTestLoadRequest\x1a\x18.NKikimrClient.TResponse\x12\x36\n\x08\x44\x62Schema\x12\x14.NKikimrClient.TJSON\x1a\x14.NKikimrClient.TJSON\x12\x39\n\x0b\x44\x62Operation\x12\x14.NKikimrClient.TJSON\x1a\x14.NKikimrClient.TJSON\x12\x35\n\x07\x44\x62\x42\x61tch\x12\x14.NKikimrClient.TJSON\x1a\x14.NKikimrClient.TJSONb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.grpc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TGRPCSERVER._serialized_start=142
  _TGRPCSERVER._serialized_end=2657
# @@protoc_insertion_point(module_scope)
