# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_vdisk_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ydb/core/protos/blobstorage_vdisk_config.proto\x12\x12NKikimrBlobStorage\"\xc1\x03\n\x0cTVDiskConfig\x12\x1d\n\x15\x46reshBufSizeLogoBlobs\x18\n \x01(\x04\x12\x1c\n\x14\x46reshBufSizeBarriers\x18\x0b \x01(\x04\x12\x1a\n\x12\x46reshBufSizeBlocks\x18\x0c \x01(\x04\x12#\n\x1b\x46reshCompThresholdLogoBlobs\x18\r \x01(\x04\x12\"\n\x1a\x46reshCompThresholdBarriers\x18\x0e \x01(\x04\x12 \n\x18\x46reshCompThresholdBlocks\x18\x0f \x01(\x04\x12\x1a\n\x12\x46reshReadReadyMode\x18\x14 \x01(\x08\x12\x14\n\x0c\x46reshUseDreg\x18\x15 \x01(\x08\x12\x16\n\x0e\x41llowKeepFlags\x18( \x01(\x08\x12#\n\x1bHullCompLevel0MaxSstsAtOnce\x18- \x01(\r\x12\x1e\n\x16HullCompSortedPartsNum\x18. \x01(\r\x12\x1f\n\x17ReplInterconnectChannel\x18\x32 \x01(\r\x12\x19\n\x11\x42\x61rrierValidation\x18< \x01(\x08\x12\"\n\x1a\x45nableOverseerLsnReporting\x18= \x01(\x08\"\xb9\x02\n\nTVDiskKind\x12\x37\n\x04Kind\x18\x01 \x01(\x0e\x32).NKikimrBlobStorage.TVDiskKind.EVDiskKind\x12;\n\x08\x42\x61seKind\x18\x02 \x01(\x0e\x32).NKikimrBlobStorage.TVDiskKind.EVDiskKind\x12\x30\n\x06\x43onfig\x18\x03 \x01(\x0b\x32 .NKikimrBlobStorage.TVDiskConfig\"\x82\x01\n\nEVDiskKind\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\t\n\x05Test1\x10\x01\x12\t\n\x05Test2\x10\x02\x12\t\n\x05Test3\x10\x03\x12\x07\n\x03Log\x10\n\x12\r\n\tLocalMode\x10\x0b\x12\n\n\x06\x45xtra2\x10\x16\x12\n\n\x06\x45xtra3\x10\x17\x12\n\n\x06\x45xtra4\x10\x18\x12\n\n\x06\x45xtra5\x10\x19\"D\n\x0eTAllVDiskKinds\x12\x32\n\nVDiskKinds\x18\x01 \x03(\x0b\x32\x1e.NKikimrBlobStorage.TVDiskKind\"\xb0\x01\n\x0fTIncrHugeConfig\x12\"\n\x12MinHugeBlobInBytes\x18\x01 \x01(\r:\x06\x35\x30\x30\x30\x30\x30\x12\x19\n\x0eMinCleanChunks\x18\x02 \x01(\r:\x01\x38\x12\x1d\n\x12MinAllocationBatch\x18\x03 \x01(\r:\x01\x34\x12!\n\x12UnalignedBlockSize\x18\x04 \x01(\r:\x05\x35\x30\x30\x30\x30\x12\x1c\n\x11MaxInFlightWrites\x18\x05 \x01(\r:\x01\x35\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_vdisk_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TVDISKCONFIG._serialized_start=71
  _TVDISKCONFIG._serialized_end=520
  _TVDISKKIND._serialized_start=523
  _TVDISKKIND._serialized_end=836
  _TVDISKKIND_EVDISKKIND._serialized_start=706
  _TVDISKKIND_EVDISKKIND._serialized_end=836
  _TALLVDISKKINDS._serialized_start=838
  _TALLVDISKKINDS._serialized_end=906
  _TINCRHUGECONFIG._serialized_start=909
  _TINCRHUGECONFIG._serialized_end=1085
# @@protoc_insertion_point(module_scope)
