# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/draft/ydb_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos.annotations import validation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_annotations_dot_validation__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_query_stats_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__query__stats__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_value_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/public/api/protos/draft/ydb_query.proto\x12\tYdb.Query\x1a\x32ydb/public/api/protos/annotations/validation.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a+ydb/public/api/protos/ydb_query_stats.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a%ydb/public/api/protos/ydb_value.proto\"\x1c\n\x14\x43reateSessionRequestJ\x04\x08\x01\x10\x02\"\xa3\x01\n\x15\x43reateSessionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x1b\n\nsession_id\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x07node_id\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"3\n\x14\x44\x65leteSessionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"k\n\x15\x44\x65leteSessionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"1\n\x12PingSessionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\x9b\x01\n\x13PingSessionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\x0esession_status\x18\x03 \x01(\x0e\x32\x18.Ydb.Query.SessionStatus\"\x1a\n\x18SerializableModeSettings\"6\n\x12OnlineModeSettings\x12 \n\x18\x61llow_inconsistent_reads\x18\x01 \x01(\x08\"\x13\n\x11StaleModeSettings\"\x16\n\x14SnapshotModeSettings\"\x9b\x02\n\x13TransactionSettings\x12\x46\n\x17serializable_read_write\x18\x01 \x01(\x0b\x32#.Ydb.Query.SerializableModeSettingsH\x00\x12\x39\n\x10online_read_only\x18\x02 \x01(\x0b\x32\x1d.Ydb.Query.OnlineModeSettingsH\x00\x12\x37\n\x0fstale_read_only\x18\x03 \x01(\x0b\x32\x1c.Ydb.Query.StaleModeSettingsH\x00\x12=\n\x12snapshot_read_only\x18\x04 \x01(\x0b\x32\x1f.Ydb.Query.SnapshotModeSettingsH\x00\x42\t\n\x07tx_mode\"\x84\x01\n\x12TransactionControl\x12\x18\n\x05tx_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x12\x32\n\x08\x62\x65gin_tx\x18\x02 \x01(\x0b\x32\x1e.Ydb.Query.TransactionSettingsH\x00\x12\x11\n\tcommit_tx\x18\n \x01(\x08\x42\r\n\x0btx_selector\"k\n\x17\x42\x65ginTransactionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x33\n\x0btx_settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Query.TransactionSettings\"&\n\x0fTransactionMeta\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\x9b\x01\n\x18\x42\x65ginTransactionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12+\n\x07tx_meta\x18\x03 \x01(\x0b\x32\x1a.Ydb.Query.TransactionMeta\"O\n\x18\x43ommitTransactionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x16\n\x05tx_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"o\n\x19\x43ommitTransactionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"Q\n\x1aRollbackTransactionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x16\n\x05tx_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"q\n\x1bRollbackTransactionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"?\n\x0cQueryContent\x12!\n\x06syntax\x18\x01 \x01(\x0e\x32\x11.Ydb.Query.Syntax\x12\x0c\n\x04text\x18\x02 \x01(\t\"\x9e\x03\n\x13\x45xecuteQueryRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12&\n\texec_mode\x18\x02 \x01(\x0e\x32\x13.Ydb.Query.ExecMode\x12\x31\n\ntx_control\x18\x03 \x01(\x0b\x32\x1d.Ydb.Query.TransactionControl\x12\x30\n\rquery_content\x18\x04 \x01(\x0b\x32\x17.Ydb.Query.QueryContentH\x00\x12\x42\n\nparameters\x18\x06 \x03(\x0b\x32..Ydb.Query.ExecuteQueryRequest.ParametersEntry\x12(\n\nstats_mode\x18\x08 \x01(\x0e\x32\x14.Ydb.Query.StatsMode\x12\x1c\n\x14parallel_result_sets\x18\t \x01(\x08\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\x42\x07\n\x05queryJ\x04\x08\x07\x10\x08\"-\n\rResultSetMeta\x12\x1c\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x0b.Ydb.Column\"\xc7\x02\n\x18\x45xecuteQueryResponsePart\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\"\n\x10result_set_index\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\"\n\nresult_set\x18\x04 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12+\n\x07tx_meta\x18\x05 \x01(\x0b\x32\x1a.Ydb.Query.TransactionMeta\x12\x32\n\x10result_sets_meta\x18\x06 \x03(\x0b\x32\x18.Ydb.Query.ResultSetMeta\x12.\n\nexec_stats\x18\x07 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"@\n\rSavedScriptId\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x08revision\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\x8d\x05\n\x14\x45xecuteScriptRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\nsession_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12&\n\texec_mode\x18\x04 \x01(\x0e\x32\x13.Ydb.Query.ExecMode\x12\x31\n\x0escript_content\x18\x05 \x01(\x0b\x32\x17.Ydb.Query.QueryContentH\x00\x12-\n\tscript_id\x18\x06 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptIdH\x00\x12\x43\n\nparameters\x18\x07 \x03(\x0b\x32/.Ydb.Query.ExecuteScriptRequest.ParametersEntry\x12\x12\n\npersistent\x18\x08 \x01(\x08\x12\x1f\n\x0e\x65xecution_name\x18\t \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12(\n\nstats_mode\x18\x0b \x01(\x0e\x32\x14.Ydb.Query.StatsMode\x12\\\n\nattributes\x18\x0c \x03(\x0b\x32/.Ydb.Query.ExecuteScriptRequest.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06scriptJ\x04\x08\x03\x10\x04J\x04\x08\n\x10\x0bJ\x04\x08\r\x10\x0e\"\xeb\x03\n\x15\x45xecuteScriptMetadata\x12\x1d\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12*\n\x0b\x65xec_status\x18\x02 \x01(\x0e\x32\x15.Ydb.Query.ExecStatus\x12\x31\n\x0escript_content\x18\x03 \x01(\x0b\x32\x17.Ydb.Query.QueryContentH\x00\x12-\n\tscript_id\x18\x04 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptIdH\x00\x12]\n\nattributes\x18\x05 \x03(\x0b\x32\x30.Ydb.Query.ExecuteScriptMetadata.AttributesEntryB\x17\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x07\n\x05\x08\x01\x10\x80 \x12\x31\n\x0fresult_set_meta\x18\x06 \x03(\x0b\x32\x18.Ydb.Query.ResultSetMeta\x12&\n\texec_mode\x18\x07 \x01(\x0e\x32\x13.Ydb.Query.ExecMode\x12.\n\nexec_stats\x18\x08 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x08\n\x06script\"\xa0\x01\n\x19\x46\x65tchScriptResultsRequest\x12\x1d\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1e\n\x0b\x66\x65tch_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x12\x1d\n\x0brows_offset\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1c\n\nrows_limit\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0B\x07\n\x05\x66\x65tch\"\xdb\x01\n\x1a\x46\x65tchScriptResultsResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\"\n\x10result_set_index\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\"\n\nresult_set\x18\x04 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12!\n\x10next_fetch_token\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"]\n\x0bSavedScript\x12$\n\x02id\x18\x01 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptId\x12(\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x17.Ydb.Query.QueryContent\"=\n\x11SaveScriptRequest\x12(\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x17.Ydb.Query.QueryContent\"\x95\x01\n\x12SaveScriptResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12+\n\tscript_id\x18\x03 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptId\"N\n\x12ListScriptsRequest\x12\x1b\n\npage_token\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\tpage_size\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\xb4\x01\n\x13ListScriptsResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x07scripts\x18\x03 \x03(\x0b\x32\x16.Ydb.Query.SavedScript\x12 \n\x0fnext_page_token\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"B\n\x13\x44\x65leteScriptRequest\x12+\n\tscript_id\x18\x01 \x01(\x0b\x32\x18.Ydb.Query.SavedScriptId\"j\n\x14\x44\x65leteScriptResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage*b\n\rSessionStatus\x12\x1e\n\x1aSESSION_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14SESSION_STATUS_READY\x10\x01\x12\x17\n\x13SESSION_STATUS_BUSY\x10\x02*B\n\x06Syntax\x12\x16\n\x12SYNTAX_UNSPECIFIED\x10\x00\x12\x11\n\rSYNTAX_YQL_V1\x10\x01\x12\r\n\tSYNTAX_PG\x10\x02*\x86\x01\n\x08\x45xecMode\x12\x19\n\x15\x45XEC_MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x45XEC_MODE_PARSE\x10\n\x12\x16\n\x12\x45XEC_MODE_VALIDATE\x10\x14\x12\x15\n\x11\x45XEC_MODE_EXPLAIN\x10\x1e\x12\x15\n\x11\x45XEC_MODE_EXECUTE\x10\x03\"\x04\x08\x04\x10\x04*\x7f\n\tStatsMode\x12\x1a\n\x16STATS_MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATS_MODE_NONE\x10\x01\x12\x14\n\x10STATS_MODE_BASIC\x10\x02\x12\x13\n\x0fSTATS_MODE_FULL\x10\x03\x12\x16\n\x12STATS_MODE_PROFILE\x10\x04*\xaa\x01\n\nExecStatus\x12\x1b\n\x17\x45XEC_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14\x45XEC_STATUS_STARTING\x10\n\x12\x17\n\x13\x45XEC_STATUS_ABORTED\x10\x14\x12\x19\n\x15\x45XEC_STATUS_CANCELLED\x10\x1e\x12\x19\n\x15\x45XEC_STATUS_COMPLETED\x10(\x12\x16\n\x12\x45XEC_STATUS_FAILED\x10\x32\x42&\n\x14\x63om.yandex.ydb.queryB\x0bQueryProtos\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.draft.ydb_query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.yandex.ydb.queryB\013QueryProtos\370\001\001'
  _CREATESESSIONRESPONSE.fields_by_name['session_id']._options = None
  _CREATESESSIONRESPONSE.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATESESSIONRESPONSE.fields_by_name['node_id']._options = None
  _CREATESESSIONRESPONSE.fields_by_name['node_id']._serialized_options = b'\262\346*\004>= 0'
  _DELETESESSIONREQUEST.fields_by_name['session_id']._options = None
  _DELETESESSIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _PINGSESSIONREQUEST.fields_by_name['session_id']._options = None
  _PINGSESSIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _TRANSACTIONCONTROL.fields_by_name['tx_id']._options = None
  _TRANSACTIONCONTROL.fields_by_name['tx_id']._serialized_options = b'\242\346*\003\030\200\010'
  _BEGINTRANSACTIONREQUEST.fields_by_name['session_id']._options = None
  _BEGINTRANSACTIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _TRANSACTIONMETA.fields_by_name['id']._options = None
  _TRANSACTIONMETA.fields_by_name['id']._serialized_options = b'\242\346*\003\030\200\010'
  _COMMITTRANSACTIONREQUEST.fields_by_name['session_id']._options = None
  _COMMITTRANSACTIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _COMMITTRANSACTIONREQUEST.fields_by_name['tx_id']._options = None
  _COMMITTRANSACTIONREQUEST.fields_by_name['tx_id']._serialized_options = b'\242\346*\003\030\200\010'
  _ROLLBACKTRANSACTIONREQUEST.fields_by_name['session_id']._options = None
  _ROLLBACKTRANSACTIONREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _ROLLBACKTRANSACTIONREQUEST.fields_by_name['tx_id']._options = None
  _ROLLBACKTRANSACTIONREQUEST.fields_by_name['tx_id']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTEQUERYREQUEST_PARAMETERSENTRY._options = None
  _EXECUTEQUERYREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _EXECUTEQUERYREQUEST.fields_by_name['session_id']._options = None
  _EXECUTEQUERYREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTEQUERYRESPONSEPART.fields_by_name['result_set_index']._options = None
  _EXECUTEQUERYRESPONSEPART.fields_by_name['result_set_index']._serialized_options = b'\262\346*\004>= 0'
  _SAVEDSCRIPTID.fields_by_name['id']._options = None
  _SAVEDSCRIPTID.fields_by_name['id']._serialized_options = b'\242\346*\003\030\200\010'
  _SAVEDSCRIPTID.fields_by_name['revision']._options = None
  _SAVEDSCRIPTID.fields_by_name['revision']._serialized_options = b'\262\346*\004>= 0'
  _EXECUTESCRIPTREQUEST_PARAMETERSENTRY._options = None
  _EXECUTESCRIPTREQUEST_PARAMETERSENTRY._serialized_options = b'8\001'
  _EXECUTESCRIPTREQUEST_ATTRIBUTESENTRY._options = None
  _EXECUTESCRIPTREQUEST_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _EXECUTESCRIPTREQUEST.fields_by_name['session_id']._options = None
  _EXECUTESCRIPTREQUEST.fields_by_name['session_id']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTESCRIPTREQUEST.fields_by_name['execution_name']._options = None
  _EXECUTESCRIPTREQUEST.fields_by_name['execution_name']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTESCRIPTREQUEST.fields_by_name['attributes']._options = None
  _EXECUTESCRIPTREQUEST.fields_by_name['attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 '
  _EXECUTESCRIPTMETADATA_ATTRIBUTESENTRY._options = None
  _EXECUTESCRIPTMETADATA_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _EXECUTESCRIPTMETADATA.fields_by_name['execution_id']._options = None
  _EXECUTESCRIPTMETADATA.fields_by_name['execution_id']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTESCRIPTMETADATA.fields_by_name['attributes']._options = None
  _EXECUTESCRIPTMETADATA.fields_by_name['attributes']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\007\n\005\010\001\020\200 '
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['execution_id']._options = None
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['execution_id']._serialized_options = b'\242\346*\003\030\200\010'
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['fetch_token']._options = None
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['fetch_token']._serialized_options = b'\242\346*\003\030\200\010'
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['rows_offset']._options = None
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['rows_offset']._serialized_options = b'\262\346*\004>= 0'
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['rows_limit']._options = None
  _FETCHSCRIPTRESULTSREQUEST.fields_by_name['rows_limit']._serialized_options = b'\262\346*\004>= 0'
  _FETCHSCRIPTRESULTSRESPONSE.fields_by_name['result_set_index']._options = None
  _FETCHSCRIPTRESULTSRESPONSE.fields_by_name['result_set_index']._serialized_options = b'\262\346*\004>= 0'
  _FETCHSCRIPTRESULTSRESPONSE.fields_by_name['next_fetch_token']._options = None
  _FETCHSCRIPTRESULTSRESPONSE.fields_by_name['next_fetch_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTSCRIPTSREQUEST.fields_by_name['page_token']._options = None
  _LISTSCRIPTSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTSCRIPTSREQUEST.fields_by_name['page_size']._options = None
  _LISTSCRIPTSREQUEST.fields_by_name['page_size']._serialized_options = b'\262\346*\004>= 0'
  _LISTSCRIPTSRESPONSE.fields_by_name['next_page_token']._options = None
  _LISTSCRIPTSRESPONSE.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _SESSIONSTATUS._serialized_start=5355
  _SESSIONSTATUS._serialized_end=5453
  _SYNTAX._serialized_start=5455
  _SYNTAX._serialized_end=5521
  _EXECMODE._serialized_start=5524
  _EXECMODE._serialized_end=5658
  _STATSMODE._serialized_start=5660
  _STATSMODE._serialized_end=5787
  _EXECSTATUS._serialized_start=5790
  _EXECSTATUS._serialized_end=5960
  _CREATESESSIONREQUEST._serialized_start=330
  _CREATESESSIONREQUEST._serialized_end=358
  _CREATESESSIONRESPONSE._serialized_start=361
  _CREATESESSIONRESPONSE._serialized_end=524
  _DELETESESSIONREQUEST._serialized_start=526
  _DELETESESSIONREQUEST._serialized_end=577
  _DELETESESSIONRESPONSE._serialized_start=579
  _DELETESESSIONRESPONSE._serialized_end=686
  _PINGSESSIONREQUEST._serialized_start=688
  _PINGSESSIONREQUEST._serialized_end=737
  _PINGSESSIONRESPONSE._serialized_start=740
  _PINGSESSIONRESPONSE._serialized_end=895
  _SERIALIZABLEMODESETTINGS._serialized_start=897
  _SERIALIZABLEMODESETTINGS._serialized_end=923
  _ONLINEMODESETTINGS._serialized_start=925
  _ONLINEMODESETTINGS._serialized_end=979
  _STALEMODESETTINGS._serialized_start=981
  _STALEMODESETTINGS._serialized_end=1000
  _SNAPSHOTMODESETTINGS._serialized_start=1002
  _SNAPSHOTMODESETTINGS._serialized_end=1024
  _TRANSACTIONSETTINGS._serialized_start=1027
  _TRANSACTIONSETTINGS._serialized_end=1310
  _TRANSACTIONCONTROL._serialized_start=1313
  _TRANSACTIONCONTROL._serialized_end=1445
  _BEGINTRANSACTIONREQUEST._serialized_start=1447
  _BEGINTRANSACTIONREQUEST._serialized_end=1554
  _TRANSACTIONMETA._serialized_start=1556
  _TRANSACTIONMETA._serialized_end=1594
  _BEGINTRANSACTIONRESPONSE._serialized_start=1597
  _BEGINTRANSACTIONRESPONSE._serialized_end=1752
  _COMMITTRANSACTIONREQUEST._serialized_start=1754
  _COMMITTRANSACTIONREQUEST._serialized_end=1833
  _COMMITTRANSACTIONRESPONSE._serialized_start=1835
  _COMMITTRANSACTIONRESPONSE._serialized_end=1946
  _ROLLBACKTRANSACTIONREQUEST._serialized_start=1948
  _ROLLBACKTRANSACTIONREQUEST._serialized_end=2029
  _ROLLBACKTRANSACTIONRESPONSE._serialized_start=2031
  _ROLLBACKTRANSACTIONRESPONSE._serialized_end=2144
  _QUERYCONTENT._serialized_start=2146
  _QUERYCONTENT._serialized_end=2209
  _EXECUTEQUERYREQUEST._serialized_start=2212
  _EXECUTEQUERYREQUEST._serialized_end=2626
  _EXECUTEQUERYREQUEST_PARAMETERSENTRY._serialized_start=2545
  _EXECUTEQUERYREQUEST_PARAMETERSENTRY._serialized_end=2611
  _RESULTSETMETA._serialized_start=2628
  _RESULTSETMETA._serialized_end=2673
  _EXECUTEQUERYRESPONSEPART._serialized_start=2676
  _EXECUTEQUERYRESPONSEPART._serialized_end=3003
  _SAVEDSCRIPTID._serialized_start=3005
  _SAVEDSCRIPTID._serialized_end=3069
  _EXECUTESCRIPTREQUEST._serialized_start=3072
  _EXECUTESCRIPTREQUEST._serialized_end=3725
  _EXECUTESCRIPTREQUEST_PARAMETERSENTRY._serialized_start=2545
  _EXECUTESCRIPTREQUEST_PARAMETERSENTRY._serialized_end=2611
  _EXECUTESCRIPTREQUEST_ATTRIBUTESENTRY._serialized_start=3648
  _EXECUTESCRIPTREQUEST_ATTRIBUTESENTRY._serialized_end=3697
  _EXECUTESCRIPTMETADATA._serialized_start=3728
  _EXECUTESCRIPTMETADATA._serialized_end=4219
  _EXECUTESCRIPTMETADATA_ATTRIBUTESENTRY._serialized_start=3648
  _EXECUTESCRIPTMETADATA_ATTRIBUTESENTRY._serialized_end=3697
  _FETCHSCRIPTRESULTSREQUEST._serialized_start=4222
  _FETCHSCRIPTRESULTSREQUEST._serialized_end=4382
  _FETCHSCRIPTRESULTSRESPONSE._serialized_start=4385
  _FETCHSCRIPTRESULTSRESPONSE._serialized_end=4604
  _SAVEDSCRIPT._serialized_start=4606
  _SAVEDSCRIPT._serialized_end=4699
  _SAVESCRIPTREQUEST._serialized_start=4701
  _SAVESCRIPTREQUEST._serialized_end=4762
  _SAVESCRIPTRESPONSE._serialized_start=4765
  _SAVESCRIPTRESPONSE._serialized_end=4914
  _LISTSCRIPTSREQUEST._serialized_start=4916
  _LISTSCRIPTSREQUEST._serialized_end=4994
  _LISTSCRIPTSRESPONSE._serialized_start=4997
  _LISTSCRIPTSRESPONSE._serialized_end=5177
  _DELETESCRIPTREQUEST._serialized_start=5179
  _DELETESCRIPTREQUEST._serialized_end=5245
  _DELETESCRIPTRESPONSE._serialized_start=5247
  _DELETESCRIPTRESPONSE._serialized_end=5353
# @@protoc_insertion_point(module_scope)
