# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_coordinator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/counters_coordinator.proto\x12\x1aNKikimr.NFlatTxCoordinator\x1a\x1eydb/core/protos/counters.proto*,\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00*W\n\x13\x45\x43umulativeCounters\x12@\n\x1d\x43OUNTER_REQ_ACQUIRE_READ_STEP\x10\x00\x1a\x1d\x82\xd6\x1b\x19\n\x17\x41\x63quireReadStepRequests*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\xf1\x02\n\x08\x45TxTypes\x12\x1d\n\x0bTXTYPE_INIT\x10\x00\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12\x1d\n\x0bTXTYPE_STEP\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxStep\x12@\n\x1dTXTYPE_MEDIATOR_CONFIRMATIONS\x10\x02\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxMediatorConfirmations\x12\x34\n\x17TXTYPE_RESTART_MEDIATOR\x10\x03\x1a\x17\x8a\xd6\x1b\x13\n\x11TxRestartMediator\x12\x35\n\x18TXTYPE_ACQUIRE_READ_STEP\x10\x04\x1a\x17\x8a\xd6\x1b\x13\n\x11TxAcquireReadStep\x12\x39\n\x1aTXTYPE_SUBSCRIBE_READ_STEP\x10\x05\x1a\x19\x8a\xd6\x1b\x15\n\x13TxSubscribeReadStep\x12=\n\x1cTXTYPE_UNSUBSCRIBE_READ_STEP\x10\x06\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxUnsubscribeReadStepB\'\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x0b\x43oordinator')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_coordinator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\013Coordinator'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQ_ACQUIRE_READ_STEP"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQ_ACQUIRE_READ_STEP"]._serialized_options = b'\202\326\033\031\n\027AcquireReadStepRequests'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STEP"]._serialized_options = b'\212\326\033\010\n\006TxStep'
  _ETXTYPES.values_by_name["TXTYPE_MEDIATOR_CONFIRMATIONS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MEDIATOR_CONFIRMATIONS"]._serialized_options = b'\212\326\033\031\n\027TxMediatorConfirmations'
  _ETXTYPES.values_by_name["TXTYPE_RESTART_MEDIATOR"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESTART_MEDIATOR"]._serialized_options = b'\212\326\033\023\n\021TxRestartMediator'
  _ETXTYPES.values_by_name["TXTYPE_ACQUIRE_READ_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ACQUIRE_READ_STEP"]._serialized_options = b'\212\326\033\023\n\021TxAcquireReadStep'
  _ETXTYPES.values_by_name["TXTYPE_SUBSCRIBE_READ_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SUBSCRIBE_READ_STEP"]._serialized_options = b'\212\326\033\025\n\023TxSubscribeReadStep'
  _ETXTYPES.values_by_name["TXTYPE_UNSUBSCRIBE_READ_STEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UNSUBSCRIBE_READ_STEP"]._serialized_options = b'\212\326\033\027\n\025TxUnsubscribeReadStep'
  _ESIMPLECOUNTERS._serialized_start=106
  _ESIMPLECOUNTERS._serialized_end=150
  _ECUMULATIVECOUNTERS._serialized_start=152
  _ECUMULATIVECOUNTERS._serialized_end=239
  _EPERCENTILECOUNTERS._serialized_start=241
  _EPERCENTILECOUNTERS._serialized_end=319
  _ETXTYPES._serialized_start=322
  _ETXTYPES._serialized_end=691
# @@protoc_insertion_point(module_scope)
