# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/protos/clickhouse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.protos import common_pb2 as ydb_dot_library_dot_yql_dot_protos_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/library/yql/protos/clickhouse.proto\x12\x0bNYql.NProto\x1a#ydb/library/yql/protos/common.proto\"\x86\x01\n\x17TClickHouseRunnerConfig\x12\x1b\n\rMaxResultRows\x18\x03 \x01(\r:\x04\x31\x30\x30\x30\x12 \n\x0eMaxResultBytes\x18\x04 \x01(\r:\x08\x33\x30\x30\x30\x30\x30\x30\x30\x12,\n\x10MaxExecutionTime\x18\x05 \x01(\x0b\x32\x12.NYql.NProto.TTimeB\x15\n\x13ru.yandex.yql.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.protos.clickhouse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023ru.yandex.yql.proto'
  _TCLICKHOUSERUNNERCONFIG._serialized_start=94
  _TCLICKHOUSERUNNERCONFIG._serialized_end=228
# @@protoc_insertion_point(module_scope)
