# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/scheme_board.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import flat_tx_scheme_pb2 as ydb_dot_core_dot_protos_dot_flat__tx__scheme__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/scheme_board.proto\x12\x12NKikimrSchemeBoard\x1a$ydb/core/protos/flat_tx_scheme.proto\"/\n\x11TLocalPathIdRange\x12\r\n\x05\x42\x65gin\x18\x01 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x02 \x01(\x04\"1\n\x0cTEvHandshake\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"\xe8\x02\n\tTEvUpdate\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x42\n\x13\x44\x65letedLocalPathIds\x18\x03 \x01(\x0b\x32%.NKikimrSchemeBoard.TLocalPathIdRange\x12\x0c\n\x04Path\x18\x04 \x01(\t\x12\x13\n\x0bLocalPathId\x18\x05 \x01(\x04\x12\x19\n\nIsDeletion\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x44\n\x14\x44\x65scribeSchemeResult\x18\x07 \x01(\x0b\x32&.NKikimrScheme.TEvDescribeSchemeResult\x12\x16\n\x07NeedAck\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0bPathOwnerId\x18\t \x01(\x04\x12\x43\n\x14MigratedLocalPathIds\x18\n \x01(\x0b\x32%.NKikimrSchemeBoard.TLocalPathIdRange\"l\n\x0cTEvUpdateAck\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\x12\x0f\n\x07Version\x18\x04 \x01(\x04\x12\x13\n\x0bPathOwnerId\x18\x05 \x01(\x04\"8\n\x13TEvCommitGeneration\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"\xd5\x01\n\x0cTEvSubscribe\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0bPathOwnerId\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\x12\x15\n\rDomainOwnerId\x18\x04 \x01(\x04\x12\x44\n\x0c\x43\x61pabilities\x18\x05 \x01(\x0b\x32..NKikimrSchemeBoard.TEvSubscribe.TCapabilities\x1a\x30\n\rTCapabilities\x12\x1f\n\x10\x41\x63kNotifications\x18\x01 \x01(\x08:\x05\x66\x61lse\"H\n\x0eTEvUnsubscribe\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0bPathOwnerId\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\"\xcc\x01\n\tTEvNotify\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0bPathOwnerId\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\x12\x19\n\nIsDeletion\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x44\n\x14\x44\x65scribeSchemeResult\x18\x05 \x01(\x0b\x32&.NKikimrScheme.TEvDescribeSchemeResult\x12\x0f\n\x07Version\x18\x06 \x01(\x04\x12\x15\n\x06Strong\x18\x07 \x01(\x08:\x05\x66\x61lse\"\x1f\n\x0cTEvNotifyAck\x12\x0f\n\x07Version\x18\x01 \x01(\x04\"O\n\x15TEvSyncVersionRequest\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x13\n\x0bPathOwnerId\x18\x02 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x03 \x01(\x04\":\n\x16TEvSyncVersionResponse\x12\x0f\n\x07Version\x18\x01 \x01(\x04\x12\x0f\n\x07Partial\x18\x02 \x01(\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.scheme_board_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TLOCALPATHIDRANGE._serialized_start=96
  _TLOCALPATHIDRANGE._serialized_end=143
  _TEVHANDSHAKE._serialized_start=145
  _TEVHANDSHAKE._serialized_end=194
  _TEVUPDATE._serialized_start=197
  _TEVUPDATE._serialized_end=557
  _TEVUPDATEACK._serialized_start=559
  _TEVUPDATEACK._serialized_end=667
  _TEVCOMMITGENERATION._serialized_start=669
  _TEVCOMMITGENERATION._serialized_end=725
  _TEVSUBSCRIBE._serialized_start=728
  _TEVSUBSCRIBE._serialized_end=941
  _TEVSUBSCRIBE_TCAPABILITIES._serialized_start=893
  _TEVSUBSCRIBE_TCAPABILITIES._serialized_end=941
  _TEVUNSUBSCRIBE._serialized_start=943
  _TEVUNSUBSCRIBE._serialized_end=1015
  _TEVNOTIFY._serialized_start=1018
  _TEVNOTIFY._serialized_end=1222
  _TEVNOTIFYACK._serialized_start=1224
  _TEVNOTIFYACK._serialized_end=1255
  _TEVSYNCVERSIONREQUEST._serialized_start=1257
  _TEVSYNCVERSIONREQUEST._serialized_end=1336
  _TEVSYNCVERSIONRESPONSE._serialized_start=1338
  _TEVSYNCVERSIONRESPONSE._serialized_end=1396
# @@protoc_insertion_point(module_scope)
