# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_sysview_processor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ydb/core/protos/counters_sysview_processor.proto\x12\x10NKikimr.NSysView\x1a\x1eydb/core/protos/counters.proto*\xea\x02\n\x08\x45TxTypes\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x00\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12\x1d\n\x0bTXTYPE_INIT\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12\'\n\x10TXTYPE_CONFIGURE\x10\x02\x1a\x11\x8a\xd6\x1b\r\n\x0bTxConfigure\x12#\n\x0eTXTYPE_COLLECT\x10\x03\x1a\x0f\x8a\xd6\x1b\x0b\n\tTxCollect\x12\'\n\x10TXTYPE_AGGREGATE\x10\x04\x1a\x11\x8a\xd6\x1b\r\n\x0bTxAggregate\x12\x34\n\x17TXTYPE_INTERVAL_SUMMARY\x10\x05\x1a\x17\x8a\xd6\x1b\x13\n\x11TxIntervalSummary\x12\x34\n\x17TXTYPE_INTERVAL_METRICS\x10\x06\x1a\x17\x8a\xd6\x1b\x13\n\x11TxIntervalMetrics\x12\x30\n\x15TXTYPE_TOP_PARTITIONS\x10\x07\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxTopPartitionsB,\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x10SysViewProcessor')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_sysview_processor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\020SysViewProcessor'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE"]._serialized_options = b'\212\326\033\r\n\013TxConfigure'
  _ETXTYPES.values_by_name["TXTYPE_COLLECT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_COLLECT"]._serialized_options = b'\212\326\033\013\n\tTxCollect'
  _ETXTYPES.values_by_name["TXTYPE_AGGREGATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_AGGREGATE"]._serialized_options = b'\212\326\033\r\n\013TxAggregate'
  _ETXTYPES.values_by_name["TXTYPE_INTERVAL_SUMMARY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INTERVAL_SUMMARY"]._serialized_options = b'\212\326\033\023\n\021TxIntervalSummary'
  _ETXTYPES.values_by_name["TXTYPE_INTERVAL_METRICS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INTERVAL_METRICS"]._serialized_options = b'\212\326\033\023\n\021TxIntervalMetrics'
  _ETXTYPES.values_by_name["TXTYPE_TOP_PARTITIONS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_TOP_PARTITIONS"]._serialized_options = b'\212\326\033\021\n\017TxTopPartitions'
  _ETXTYPES._serialized_start=103
  _ETXTYPES._serialized_end=465
# @@protoc_insertion_point(module_scope)
