# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_sequenceshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/protos/counters_sequenceshard.proto\x12\x16NKikimr.NSequenceShard\x1a\x1eydb/core/protos/counters.proto*,\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00*4\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\x86\x04\n\x08\x45TxTypes\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x00\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12\x1d\n\x0bTXTYPE_INIT\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12=\n\x1cTXTYPE_MARK_SCHEMESHARD_PIPE\x10\x02\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxMarkSchemeShardPipe\x12\x32\n\x16TXTYPE_CREATE_SEQUENCE\x10\x03\x1a\x16\x8a\xd6\x1b\x12\n\x10TxCreateSequence\x12\x36\n\x18TXTYPE_ALLOCATE_SEQUENCE\x10\x04\x1a\x18\x8a\xd6\x1b\x14\n\x12TxAllocateSequence\x12.\n\x14TXTYPE_DROP_SEQUENCE\x10\x05\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxDropSequence\x12\x32\n\x16TXTYPE_UPDATE_SEQUENCE\x10\x06\x1a\x16\x8a\xd6\x1b\x12\n\x10TxUpdateSequence\x12\x32\n\x16TXTYPE_FREEZE_SEQUENCE\x10\x07\x1a\x16\x8a\xd6\x1b\x12\n\x10TxFreezeSequence\x12\x34\n\x17TXTYPE_RESTORE_SEQUENCE\x10\x08\x1a\x17\x8a\xd6\x1b\x13\n\x11TxRestoreSequence\x12\x36\n\x18TXTYPE_REDIRECT_SEQUENCE\x10\t\x1a\x18\x8a\xd6\x1b\x14\n\x12TxRedirectSequenceB)\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\rSequenceShard')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_sequenceshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\rSequenceShard'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_MARK_SCHEMESHARD_PIPE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MARK_SCHEMESHARD_PIPE"]._serialized_options = b'\212\326\033\027\n\025TxMarkSchemeShardPipe'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_SEQUENCE"]._serialized_options = b'\212\326\033\022\n\020TxCreateSequence'
  _ETXTYPES.values_by_name["TXTYPE_ALLOCATE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ALLOCATE_SEQUENCE"]._serialized_options = b'\212\326\033\024\n\022TxAllocateSequence'
  _ETXTYPES.values_by_name["TXTYPE_DROP_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DROP_SEQUENCE"]._serialized_options = b'\212\326\033\020\n\016TxDropSequence'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SEQUENCE"]._serialized_options = b'\212\326\033\022\n\020TxUpdateSequence'
  _ETXTYPES.values_by_name["TXTYPE_FREEZE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FREEZE_SEQUENCE"]._serialized_options = b'\212\326\033\022\n\020TxFreezeSequence'
  _ETXTYPES.values_by_name["TXTYPE_RESTORE_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESTORE_SEQUENCE"]._serialized_options = b'\212\326\033\023\n\021TxRestoreSequence'
  _ETXTYPES.values_by_name["TXTYPE_REDIRECT_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REDIRECT_SEQUENCE"]._serialized_options = b'\212\326\033\024\n\022TxRedirectSequence'
  _ESIMPLECOUNTERS._serialized_start=104
  _ESIMPLECOUNTERS._serialized_end=148
  _ECUMULATIVECOUNTERS._serialized_start=150
  _ECUMULATIVECOUNTERS._serialized_end=202
  _EPERCENTILECOUNTERS._serialized_start=204
  _EPERCENTILECOUNTERS._serialized_end=282
  _ETXTYPES._serialized_start=285
  _ETXTYPES._serialized_end=803
# @@protoc_insertion_point(module_scope)
