# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/resource_broker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/resource_broker.proto\x12\x15NKikimrResourceBroker\";\n\nTResources\x12\x10\n\x08Resource\x18\x01 \x03(\x04\x12\x0b\n\x03\x43pu\x18\x02 \x01(\x04\x12\x0e\n\x06Memory\x18\x03 \x01(\x04\"^\n\x0cTQueueConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06Weight\x18\x02 \x01(\r\x12\x30\n\x05Limit\x18\x03 \x01(\x0b\x32!.NKikimrResourceBroker.TResources\"G\n\x0bTTaskConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x17\n\x0f\x44\x65\x66\x61ultDuration\x18\x03 \x01(\x04\"\xb9\x01\n\x15TResourceBrokerConfig\x12\x33\n\x06Queues\x18\x01 \x03(\x0b\x32#.NKikimrResourceBroker.TQueueConfig\x12\x31\n\x05Tasks\x18\x02 \x03(\x0b\x32\".NKikimrResourceBroker.TTaskConfig\x12\x38\n\rResourceLimit\x18\x03 \x01(\x0b\x32!.NKikimrResourceBroker.TResources\"?\n\x1bTResourceBrokerConfigResult\x12\x0f\n\x07Success\x18\x01 \x01(\x08\x12\x0f\n\x07Message\x18\x02 \x01(\t*$\n\rEResourceType\x12\x07\n\x03\x43PU\x10\x00\x12\n\n\x06MEMORY\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.resource_broker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ERESOURCETYPE._serialized_start=547
  _ERESOURCETYPE._serialized_end=583
  _TRESOURCES._serialized_start=64
  _TRESOURCES._serialized_end=123
  _TQUEUECONFIG._serialized_start=125
  _TQUEUECONFIG._serialized_end=219
  _TTASKCONFIG._serialized_start=221
  _TTASKCONFIG._serialized_end=292
  _TRESOURCEBROKERCONFIG._serialized_start=295
  _TRESOURCEBROKERCONFIG._serialized_end=480
  _TRESOURCEBROKERCONFIGRESULT._serialized_start=482
  _TRESOURCEBROKERCONFIGRESULT._serialized_end=545
# @@protoc_insertion_point(module_scope)
