# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/http_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/http_config.proto\x12\rNKikimrConfig\"\x93\x01\n\x11THttpServerConfig\x12\x12\n\x04Port\x18\x01 \x01(\r:\x04\x38\x37\x37\x31\x12\x12\n\x07Threads\x18\x02 \x01(\r:\x01\x35\x12\x1c\n\x0eMaxConnections\x18\x03 \x01(\r:\x04\x31\x30\x30\x30\x12\x19\n\x0cMaxQueueSize\x18\x04 \x01(\r:\x03\x35\x30\x30\x12\x1d\n\x0f\x45nableKeepAlive\x18\x05 \x01(\x08:\x04trueB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.http_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _THTTPSERVERCONFIG._serialized_start=53
  _THTTPSERVERCONFIG._serialized_end=200
# @@protoc_insertion_point(module_scope)
