# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/s3/proto/source.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ydb/library/yql/providers/s3/proto/source.proto\x12\x08NYql.NS3\"#\n\x05TPath\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0c\n\x04Size\x18\x02 \x01(\x04\"\x83\x02\n\x07TSource\x12\x0b\n\x03Url\x18\x01 \x01(\t\x12\r\n\x05Token\x18\x02 \x01(\t\x12\'\n\x0e\x44\x65precatedPath\x18\x03 \x03(\x0b\x32\x0f.NYql.NS3.TPath\x12\x14\n\x07RowType\x18\x04 \x01(\tH\x00\x88\x01\x01\x12\x13\n\x06\x46ormat\x18\x05 \x01(\tH\x01\x88\x01\x01\x12\x31\n\x08Settings\x18\x06 \x03(\x0b\x32\x1f.NYql.NS3.TSource.SettingsEntry\x12\r\n\x05\x41rrow\x18\x07 \x01(\x08\x1a/\n\rSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\n\n\x08_RowTypeB\t\n\x07_FormatB\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.s3.proto.source_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TSOURCE_SETTINGSENTRY._options = None
  _TSOURCE_SETTINGSENTRY._serialized_options = b'8\001'
  _TPATH._serialized_start=61
  _TPATH._serialized_end=96
  _TSOURCE._serialized_start=99
  _TSOURCE._serialized_end=358
  _TSOURCE_SETTINGSENTRY._serialized_start=288
  _TSOURCE_SETTINGSENTRY._serialized_end=335
# @@protoc_insertion_point(module_scope)
