# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_columnshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import long_tx_service_pb2 as ydb_dot_core_dot_protos_dot_long__tx__service__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import ssa_pb2 as ydb_dot_core_dot_protos_dot_ssa__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/tx_columnshard.proto\x12\x14NKikimrTxColumnShard\x1a&library/cpp/actors/protos/actors.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a%ydb/core/protos/long_tx_service.proto\x1a ydb/core/protos/subdomains.proto\x1a\x19ydb/core/protos/ssa.proto\"\xd8\x01\n\nTReadStats\x12\x16\n\x0e\x42\x65ginTimestamp\x18\x01 \x01(\x04\x12\x14\n\x0c\x44urationUsec\x18\x02 \x01(\x04\x12\x15\n\rSelectedIndex\x18\x03 \x01(\r\x12\x15\n\rIndexGranules\x18\x04 \x01(\x04\x12\x15\n\rIndexPortions\x18\x05 \x01(\x04\x12\x14\n\x0cIndexBatches\x18\x06 \x01(\x04\x12\x19\n\x11NotIndexedBatches\x18\x07 \x01(\x04\x12\x13\n\x0bUsedColumns\x18\x08 \x01(\r\x12\x11\n\tDataBytes\x18\t \x01(\x04\"\xbf\x01\n\x10TLogicalMetadata\x12\x0f\n\x07NumRows\x18\x01 \x01(\r\x12\x34\n\x0c\x46irstPkValue\x18\x02 \x03(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstant\x12\x33\n\x0bLastPkValue\x18\x03 \x03(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstant\x12\x10\n\x08RawBytes\x18\x04 \x01(\x04\x12\x1d\n\x15\x44irtyWriteTimeSeconds\x18\x05 \x01(\x04\"u\n\tTMetadata\x12\x0e\n\x06\x46ormat\x18\x01 \x01(\r\x12\x0e\n\x06Schema\x18\x02 \x01(\x0c\x12\x33\n\tReadStats\x18\x03 \x01(\x0b\x32 .NKikimrTxColumnShard.TReadStats\x12\x13\n\x0bLogicalMeta\x18\x04 \x01(\x0c\"7\n\x0eTEvictMetadata\x12\x10\n\x08TierName\x18\x01 \x01(\t\x12\x13\n\x0bTierVersion\x18\x02 \x01(\r\"\xea\x01\n\x08TEvWrite\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x13\n\x0bTxInitiator\x18\x02 \x01(\x04\x12\x0f\n\x07WriteId\x18\x03 \x01(\x04\x12\x0f\n\x07TableId\x18\x04 \x01(\x04\x12\x0f\n\x07\x44\x65\x64upId\x18\x05 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x06 \x01(\x0c\x12-\n\x04Meta\x18\x07 \x01(\x0b\x32\x1f.NKikimrTxColumnShard.TMetadata\x12\x31\n\x08LongTxId\x18\x08 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\"x\n\x0eTEvWriteResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x13\n\x0bTxInitiator\x18\x03 \x01(\x04\x12\x0f\n\x07WriteId\x18\x04 \x01(\x04\x12\x0f\n\x07TableId\x18\x05 \x01(\x04\x12\x0f\n\x07\x44\x65\x64upId\x18\x06 \x01(\t\"\xb8\x03\n\x07TEvRead\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x13\n\x0bTxInitiator\x18\x02 \x01(\x04\x12\x10\n\x08PlanStep\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\x12\x0f\n\x07TableId\x18\x05 \x01(\x04\x12\x11\n\tColumnIds\x18\x06 \x03(\r\x12\x13\n\x0b\x43olumnNames\x18\x07 \x03(\t\x12\x42\n\x10GreaterPredicate\x18\x08 \x01(\x0b\x32(.NKikimrTxColumnShard.TEvRead.TPredicate\x12?\n\rLessPredicate\x18\t \x01(\x0b\x32(.NKikimrTxColumnShard.TEvRead.TPredicate\x12\x13\n\x0bOlapProgram\x18\n \x01(\x0c\x12:\n\x0fOlapProgramType\x18\x0b \x01(\x0e\x32!.NKikimrSchemeOp.EOlapProgramType\x1a\x41\n\nTPredicate\x12\x13\n\x0b\x43olumnNames\x18\x01 \x03(\t\x12\x0b\n\x03Row\x18\x02 \x01(\x0c\x12\x11\n\tInclusive\x18\x03 \x01(\x08\"\xd3\x01\n\rTEvReadResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x13\n\x0bTxInitiator\x18\x03 \x01(\x04\x12\x10\n\x08PlanStep\x18\x04 \x01(\x04\x12\x0c\n\x04TxId\x18\x05 \x01(\x04\x12\x0f\n\x07TableId\x18\x06 \x01(\x04\x12\r\n\x05\x42\x61tch\x18\x07 \x01(\r\x12\x10\n\x08\x46inished\x18\x08 \x01(\x08\x12\x0c\n\x04\x44\x61ta\x18\t \x01(\x0c\x12-\n\x04Meta\x18\n \x01(\x0b\x32\x1f.NKikimrTxColumnShard.TMetadata\"\xec\x01\n\x15TEvProposeTransaction\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x36\n\x06TxKind\x18\x02 \x01(\x0e\x32&.NKikimrTxColumnShard.ETransactionKind\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x0e\n\x06TxBody\x18\x04 \x01(\x0c\x12\x15\n\rSchemeShardId\x18\x05 \x01(\x04\x12>\n\x10ProcessingParams\x18\x06 \x01(\x0b\x32$.NKikimrSubDomains.TProcessingParams\"\x8b\x02\n\x1bTEvProposeTransactionResult\x12\x33\n\x06Status\x18\x01 \x01(\x0e\x32#.NKikimrTxColumnShard.EResultStatus\x12\x36\n\x06TxKind\x18\x02 \x01(\x0e\x32&.NKikimrTxColumnShard.ETransactionKind\x12\x0e\n\x06Origin\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\x12\x0f\n\x07MinStep\x18\x05 \x01(\x04\x12\x0f\n\x07MaxStep\x18\x06 \x01(\x04\x12\x15\n\rStatusMessage\x18\x07 \x01(\t\x12\x1a\n\x12\x44omainCoordinators\x18\x08 \x03(\x06\x12\x0c\n\x04Step\x18\t \x01(\x04\",\n\x1cTEvCancelTransactionProposal\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"%\n\x15TEvNotifyTxCompletion\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\";\n\x1bTEvNotifyTxCompletionResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"6\n\rTCommitTxBody\x12\x13\n\x0bTxInitiator\x18\x01 \x01(\x04\x12\x10\n\x08WriteIds\x18\x02 \x03(\x04\"\x81\x01\n\x18TSchemaPresetVersionInfo\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x11\n\tSinceStep\x18\x02 \x01(\x04\x12\x11\n\tSinceTxId\x18\x03 \x01(\x04\x12\x33\n\x06Schema\x18\x04 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\"\x8d\x01\n\x1dTTtlSettingsPresetVersionInfo\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x11\n\tSinceStep\x18\x02 \x01(\x04\x12\x11\n\tSinceTxId\x18\x03 \x01(\x04\x12:\n\x0bTtlSettings\x18\x04 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\"\xb4\x02\n\x11TTableVersionInfo\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\x12\x11\n\tSinceStep\x18\x02 \x01(\x04\x12\x11\n\tSinceTxId\x18\x03 \x01(\x04\x12\x33\n\x06Schema\x18\x04 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\x12\x16\n\x0eSchemaPresetId\x18\x05 \x01(\r\x12:\n\x0bTtlSettings\x18\x06 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\x12\x1b\n\x13TtlSettingsPresetId\x18\x07 \x01(\r\x12\x1e\n\x16SchemaPresetVersionAdj\x18\x08 \x01(\x04\x12#\n\x1bTtlSettingsPresetVersionAdj\x18\t \x01(\x04\"\xe0\x02\n\x0cTCreateTable\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\x12\x33\n\x06Schema\x18\x02 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\x12?\n\x0cSchemaPreset\x18\x03 \x01(\x0b\x32).NKikimrSchemeOp.TColumnTableSchemaPreset\x12:\n\x0bTtlSettings\x18\x04 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\x12I\n\x11TtlSettingsPreset\x18\x05 \x01(\x0b\x32..NKikimrSchemeOp.TColumnTableTtlSettingsPreset\x12\x1e\n\x16SchemaPresetVersionAdj\x18\x06 \x01(\x04\x12#\n\x1bTtlSettingsPresetVersionAdj\x18\x07 \x01(\x04\"\x82\x01\n\nTInitShard\x12\x18\n\x10\x44\x61taChannelCount\x18\x01 \x01(\r\x12\x13\n\x0bOwnerPathId\x18\x02 \x01(\x04\x12\x32\n\x06Tables\x18\x03 \x03(\x0b\x32\".NKikimrTxColumnShard.TCreateTable\x12\x11\n\tOwnerPath\x18\x04 \x01(\t\"\x96\x03\n\x0bTAlterTable\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\x12\x35\n\tAlterBody\x18\x02 \x01(\x0b\x32\".NKikimrSchemeOp.TAlterColumnTable\x12\x33\n\x06Schema\x18\x03 \x01(\x0b\x32#.NKikimrSchemeOp.TColumnTableSchema\x12?\n\x0cSchemaPreset\x18\x04 \x01(\x0b\x32).NKikimrSchemeOp.TColumnTableSchemaPreset\x12:\n\x0bTtlSettings\x18\x05 \x01(\x0b\x32%.NKikimrSchemeOp.TColumnDataLifeCycle\x12I\n\x11TtlSettingsPreset\x18\x06 \x01(\x0b\x32..NKikimrSchemeOp.TColumnTableTtlSettingsPreset\x12\x1e\n\x16SchemaPresetVersionAdj\x18\x07 \x01(\x04\x12#\n\x1bTtlSettingsPresetVersionAdj\x18\x08 \x01(\x04\"\x1c\n\nTDropTable\x12\x0e\n\x06PathId\x18\x01 \x01(\x04\"C\n\rTEnsureTables\x12\x32\n\x06Tables\x18\x01 \x03(\x0b\x32\".NKikimrTxColumnShard.TCreateTable\"\x91\x02\n\x0bTAlterStore\x12\x35\n\tAlterBody\x18\x01 \x01(\x0b\x32\".NKikimrSchemeOp.TAlterColumnStore\x12\x1c\n\x14\x44roppedSchemaPresets\x18\x02 \x03(\r\x12@\n\rSchemaPresets\x18\x03 \x03(\x0b\x32).NKikimrSchemeOp.TColumnTableSchemaPreset\x12\x12\n\nReserved_4\x18\x04 \x03(\r\x12\x42\n\nReserved_5\x18\x05 \x03(\x0b\x32..NKikimrSchemeOp.TColumnTableTtlSettingsPreset\x12\x13\n\x0bStorePathId\x18\x06 \x01(\x04\"1\n\x0cTSchemaSeqNo\x12\x12\n\nGeneration\x18\x01 \x01(\r\x12\r\n\x05Round\x18\x02 \x01(\x04\"\x8f\x01\n\x11TIndexPortionMeta\x12\x14\n\nIsInserted\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bIsCompacted\x18\x02 \x01(\x08H\x00\x12\x1a\n\x10IsSplitCompacted\x18\x03 \x01(\x08H\x00\x12\x13\n\tIsEvicted\x18\x04 \x01(\x08H\x00\x12\x10\n\x08TierName\x18\x05 \x01(\tB\n\n\x08Produced\"\xd7\x01\n\x10TIndexColumnMeta\x12\x0f\n\x07NumRows\x18\x01 \x01(\r\x12\x10\n\x08RawBytes\x18\x02 \x01(\r\x12\x30\n\x08MinValue\x18\x03 \x01(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstant\x12\x30\n\x08MaxValue\x18\x04 \x01(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstant\x12<\n\x0bPortionMeta\x18\x05 \x01(\x0b\x32\'.NKikimrTxColumnShard.TIndexPortionMeta\"\xe9\x02\n\rTSchemaTxBody\x12\x31\n\x05SeqNo\x18\x01 \x01(\x0b\x32\".NKikimrTxColumnShard.TSchemaSeqNo\x12\x35\n\tInitShard\x18\x02 \x01(\x0b\x32 .NKikimrTxColumnShard.TInitShardH\x00\x12;\n\x0c\x45nsureTables\x18\x03 \x01(\x0b\x32#.NKikimrTxColumnShard.TEnsureTablesH\x00\x12\x35\n\tDropTable\x18\x04 \x01(\x0b\x32 .NKikimrTxColumnShard.TDropTableH\x00\x12\x37\n\nAlterTable\x18\x05 \x01(\x0b\x32!.NKikimrTxColumnShard.TAlterTableH\x00\x12\x37\n\nAlterStore\x18\x06 \x01(\x0b\x32!.NKikimrTxColumnShard.TAlterStoreH\x00\x42\x08\n\x06TxBody\"y\n\nTTtlTxBody\x12\x15\n\rTtlColumnName\x18\x01 \x01(\t\x12\x17\n\x0fUnixTimeSeconds\x18\x02 \x01(\x04\x12\x13\n\x0bTtlPresetId\x18\x03 \x01(\r\x12\x15\n\rTtlPresetName\x18\x04 \x01(\t\x12\x0f\n\x07PathIds\x18\x05 \x03(\x04\":\n\nTBlobRange\x12\x0e\n\x06\x42lobId\x18\x01 \x01(\x0c\x12\x0e\n\x06Offset\x18\x02 \x01(\x04\x12\x0c\n\x04Size\x18\x03 \x01(\x04\"I\n\x11TEvReadBlobRanges\x12\x34\n\nBlobRanges\x18\x01 \x03(\x0b\x32 .NKikimrTxColumnShard.TBlobRange\"\xd1\x01\n\x17TEvReadBlobRangesResult\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x46\n\x07Results\x18\x02 \x03(\x0b\x32\x35.NKikimrTxColumnShard.TEvReadBlobRangesResult.TResult\x1a\\\n\x07TResult\x12\x33\n\tBlobRange\x18\x01 \x01(\x0b\x32 .NKikimrTxColumnShard.TBlobRange\x12\x0e\n\x06Status\x18\x02 \x01(\r\x12\x0c\n\x04\x44\x61ta\x18\x03 \x01(\x0c*\xb3\x01\n\rEResultStatus\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0c\n\x08PREPARED\x10\x01\x12\x0b\n\x07SUCCESS\x10\x02\x12\x0b\n\x07\x41\x42ORTED\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x0b\n\x07TIMEOUT\x10\x05\x12\x0c\n\x08OUTDATED\x10\x06\x12\x10\n\x0cSCHEMA_ERROR\x10\x07\x12\x12\n\x0eSCHEMA_CHANGED\x10\x08\x12\x0e\n\nOVERLOADED\x10\t\x12\r\n\x07UNKNOWN\x10\xff\xff\x03*!\n\rEResultFormat\x12\x10\n\x0c\x46ORMAT_ARROW\x10\x01*]\n\x10\x45TransactionKind\x12\x10\n\x0cTX_KIND_NONE\x10\x00\x12\x12\n\x0eTX_KIND_SCHEMA\x10\x01\x12\x12\n\x0eTX_KIND_COMMIT\x10\x02\x12\x0f\n\x0bTX_KIND_TTL\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_columnshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ERESULTSTATUS._serialized_start=5665
  _ERESULTSTATUS._serialized_end=5844
  _ERESULTFORMAT._serialized_start=5846
  _ERESULTFORMAT._serialized_end=5879
  _ETRANSACTIONKIND._serialized_start=5881
  _ETRANSACTIONKIND._serialized_end=5974
  _TREADSTATS._serialized_start=241
  _TREADSTATS._serialized_end=457
  _TLOGICALMETADATA._serialized_start=460
  _TLOGICALMETADATA._serialized_end=651
  _TMETADATA._serialized_start=653
  _TMETADATA._serialized_end=770
  _TEVICTMETADATA._serialized_start=772
  _TEVICTMETADATA._serialized_end=827
  _TEVWRITE._serialized_start=830
  _TEVWRITE._serialized_end=1064
  _TEVWRITERESULT._serialized_start=1066
  _TEVWRITERESULT._serialized_end=1186
  _TEVREAD._serialized_start=1189
  _TEVREAD._serialized_end=1629
  _TEVREAD_TPREDICATE._serialized_start=1564
  _TEVREAD_TPREDICATE._serialized_end=1629
  _TEVREADRESULT._serialized_start=1632
  _TEVREADRESULT._serialized_end=1843
  _TEVPROPOSETRANSACTION._serialized_start=1846
  _TEVPROPOSETRANSACTION._serialized_end=2082
  _TEVPROPOSETRANSACTIONRESULT._serialized_start=2085
  _TEVPROPOSETRANSACTIONRESULT._serialized_end=2352
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_start=2354
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_end=2398
  _TEVNOTIFYTXCOMPLETION._serialized_start=2400
  _TEVNOTIFYTXCOMPLETION._serialized_end=2437
  _TEVNOTIFYTXCOMPLETIONRESULT._serialized_start=2439
  _TEVNOTIFYTXCOMPLETIONRESULT._serialized_end=2498
  _TCOMMITTXBODY._serialized_start=2500
  _TCOMMITTXBODY._serialized_end=2554
  _TSCHEMAPRESETVERSIONINFO._serialized_start=2557
  _TSCHEMAPRESETVERSIONINFO._serialized_end=2686
  _TTTLSETTINGSPRESETVERSIONINFO._serialized_start=2689
  _TTTLSETTINGSPRESETVERSIONINFO._serialized_end=2830
  _TTABLEVERSIONINFO._serialized_start=2833
  _TTABLEVERSIONINFO._serialized_end=3141
  _TCREATETABLE._serialized_start=3144
  _TCREATETABLE._serialized_end=3496
  _TINITSHARD._serialized_start=3499
  _TINITSHARD._serialized_end=3629
  _TALTERTABLE._serialized_start=3632
  _TALTERTABLE._serialized_end=4038
  _TDROPTABLE._serialized_start=4040
  _TDROPTABLE._serialized_end=4068
  _TENSURETABLES._serialized_start=4070
  _TENSURETABLES._serialized_end=4137
  _TALTERSTORE._serialized_start=4140
  _TALTERSTORE._serialized_end=4413
  _TSCHEMASEQNO._serialized_start=4415
  _TSCHEMASEQNO._serialized_end=4464
  _TINDEXPORTIONMETA._serialized_start=4467
  _TINDEXPORTIONMETA._serialized_end=4610
  _TINDEXCOLUMNMETA._serialized_start=4613
  _TINDEXCOLUMNMETA._serialized_end=4828
  _TSCHEMATXBODY._serialized_start=4831
  _TSCHEMATXBODY._serialized_end=5192
  _TTTLTXBODY._serialized_start=5194
  _TTTLTXBODY._serialized_end=5315
  _TBLOBRANGE._serialized_start=5317
  _TBLOBRANGE._serialized_end=5375
  _TEVREADBLOBRANGES._serialized_start=5377
  _TEVREADBLOBRANGES._serialized_end=5450
  _TEVREADBLOBRANGESRESULT._serialized_start=5453
  _TEVREADBLOBRANGESRESULT._serialized_end=5662
  _TEVREADBLOBRANGESRESULT_TRESULT._serialized_start=5570
  _TEVREADBLOBRANGESRESULT_TRESULT._serialized_end=5662
# @@protoc_insertion_point(module_scope)
