# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/scheme_type_metadata.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/scheme_type_metadata.proto\x12\x19NKikimrSchemeTypeMetadata\"\x99\x01\n\tTMetadata\x12\x38\n\x04Type\x18\x01 \x03(\x0b\x32*.NKikimrSchemeTypeMetadata.TMetadata.TType\x1aR\n\x05TType\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\x0c\x12\r\n\x05\x46lags\x18\x03 \x01(\r\x12\x0f\n\x07MaxSize\x18\x04 \x01(\r\x12\x0f\n\x07MinSize\x18\x05 \x01(\rB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.scheme_type_metadata_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TMETADATA._serialized_start=74
  _TMETADATA._serialized_end=227
  _TMETADATA_TTYPE._serialized_start=145
  _TMETADATA_TTYPE._serialized_end=227
# @@protoc_insertion_point(module_scope)
