# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/sqs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/sqs.proto\x12\x0cNKikimr.NSQS\"%\n\x11TAuthentification\x12\x10\n\x08UserName\x18\x01 \x01(\t\"]\n\x0cTCredentials\x12\x14\n\nOAuthToken\x18\x01 \x01(\tH\x00\x12\x13\n\tTvmTicket\x18\x02 \x01(\tH\x00\x12\x15\n\x0bStaticCreds\x18\x03 \x01(\tH\x00\x42\x0b\n\tAccessKey\"\xc1\x01\n\x06TError\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0f\n\x07Message\x18\x02 \x01(\t\x12\x11\n\tErrorCode\x18\x04 \x01(\t\x12*\n\x05\x44\x65\x62ug\x18\x03 \x01(\x0b\x32\x1b.NKikimr.NSQS.TError.TDebug\x1aW\n\x06TDebug\x12\x1d\n\x15TransactionStatusCode\x18\x01 \x01(\r\x12\x15\n\rMiniKQLErrors\x18\x02 \x01(\x0c\x12\x17\n\x0f\x44\x61taShardErrors\x18\x03 \x01(\x0c\")\n\nTAttribute\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x0c\"]\n\x11TMessageAttribute\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08\x44\x61taType\x18\x02 \x01(\t\x12\x13\n\x0bStringValue\x18\x03 \x01(\t\x12\x13\n\x0b\x42inaryValue\x18\x04 \x01(\x0c\"\xd2\x01\n\x1fTChangeMessageVisibilityRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x15\n\rReceiptHandle\x18\x03 \x01(\x0c\x12\x19\n\x11VisibilityTimeout\x18\x04 \x01(\r\x12\n\n\x02Id\x18\x05 \x01(\t\"f\n TChangeMessageVisibilityResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"\xd9\x01\n$TChangeMessageVisibilityBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12>\n\x07\x45ntries\x18\x03 \x03(\x0b\x32-.NKikimr.NSQS.TChangeMessageVisibilityRequest\"\xa0\x01\n%TChangeMessageVisibilityBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12?\n\x07\x45ntries\x18\x03 \x03(\x0b\x32..NKikimr.NSQS.TChangeMessageVisibilityResponse\"\x82\x03\n\x13TCreateQueueRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12,\n\nAttributes\x18\x03 \x03(\x0b\x32\x18.NKikimr.NSQS.TAttribute\x12\x11\n\x06Shards\x18\x04 \x01(\x04:\x01\x34\x12\x15\n\nPartitions\x18\x05 \x01(\x04:\x01\x38\x12\x17\n\x0f\x45nableAutosplit\x18\x08 \x01(\x08\x12\x1f\n\x0bSizeToSplit\x18\t \x01(\x04:\n1073741824\x12\x33\n%EnableOutOfOrderTransactionsExecution\x18\x06 \x01(\x08:\x04true\x12\x17\n\x0f\x43ustomQueueName\x18\n \x01(\t\x12\x18\n\x10\x43reatedTimestamp\x18\x0b \x01(\x04\"s\n\x14TCreateQueueResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x11\n\tQueueName\x18\x03 \x01(\t\x12\x10\n\x08QueueUrl\x18\x04 \x01(\t\"\x86\x01\n\x12TCreateUserRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x10\n\x08UserName\x18\x02 \x01(\t\"M\n\x13TCreateUserResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\"\xaa\x01\n\x1aTGetQueueAttributesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\r\n\x05Names\x18\x03 \x03(\t\x12\n\n\x02Id\x18\x04 \x01(\t\"\x8d\x04\n\x1bTGetQueueAttributesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x0f \x01(\t\x12#\n\x1b\x41pproximateNumberOfMessages\x18\x03 \x01(\x04\x12*\n\"ApproximateNumberOfMessagesDelayed\x18\x04 \x01(\x04\x12-\n%ApproximateNumberOfMessagesNotVisible\x18\x05 \x01(\x04\x12\x18\n\x10\x43reatedTimestamp\x18\x06 \x01(\x04\x12\x14\n\x0c\x44\x65laySeconds\x18\x07 \x01(\x04\x12\x1d\n\x15LastModifiedTimestamp\x18\x08 \x01(\x04\x12\x1a\n\x12MaximumMessageSize\x18\t \x01(\x04\x12\x1e\n\x16MessageRetentionPeriod\x18\n \x01(\x04\x12%\n\x1dReceiveMessageWaitTimeSeconds\x18\x0b \x01(\x04\x12\x19\n\x11VisibilityTimeout\x18\x0c \x01(\x04\x12\x11\n\tFifoQueue\x18\r \x01(\x08\x12!\n\x19\x43ontentBasedDeduplication\x18\x0e \x01(\x08\x12\x15\n\rRedrivePolicy\x18\x10 \x01(\t\x12\x10\n\x08QueueArn\x18\x11 \x01(\t\"\xcb\x01\n\x1fTGetQueueAttributesBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\r\n\x05Names\x18\x03 \x03(\t\x12\x39\n\x07\x45ntries\x18\x04 \x03(\x0b\x32(.NKikimr.NSQS.TGetQueueAttributesRequest\"\x96\x01\n TGetQueueAttributesBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12:\n\x07\x45ntries\x18\x03 \x03(\x0b\x32).NKikimr.NSQS.TGetQueueAttributesResponse\"\x88\x01\n\x13TGetQueueUrlRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\"`\n\x14TGetQueueUrlResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x10\n\x08QueueUrl\x18\x03 \x01(\t\"\xad\x01\n\x15TDeleteMessageRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x15\n\rReceiptHandle\x18\x03 \x01(\x0c\x12\n\n\x02Id\x18\x04 \x01(\t\"\\\n\x16TDeleteMessageResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"\xc5\x01\n\x1aTDeleteMessageBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x34\n\x07\x45ntries\x18\x03 \x03(\x0b\x32#.NKikimr.NSQS.TDeleteMessageRequest\"\x8c\x01\n\x1bTDeleteMessageBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x35\n\x07\x45ntries\x18\x03 \x03(\x0b\x32$.NKikimr.NSQS.TDeleteMessageResponse\"\x94\x01\n\x13TDeleteQueueRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"Z\n\x14TDeleteQueueResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"\xae\x01\n\x18TDeleteQueueBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x32\n\x07\x45ntries\x18\x02 \x03(\x0b\x32!.NKikimr.NSQS.TDeleteQueueRequest\"\x88\x01\n\x19TDeleteQueueBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x33\n\x07\x45ntries\x18\x03 \x03(\x0b\x32\".NKikimr.NSQS.TDeleteQueueResponse\"\x86\x01\n\x12TDeleteUserRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x10\n\x08UserName\x18\x02 \x01(\t\"M\n\x13TDeleteUserResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\"\x8d\x01\n\x12TListQueuesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x17\n\x0fQueueNamePrefix\x18\x02 \x01(\t\"\xbe\x01\n\x13TListQueuesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12<\n\x06Queues\x18\x03 \x03(\x0b\x32,.NKikimr.NSQS.TListQueuesResponse.TQueueType\x1a\x31\n\nTQueueType\x12\x11\n\tQueueName\x18\x01 \x01(\t\x12\x10\n\x08QueueUrl\x18\x02 \x01(\t\"\x8b\x01\n\x11TListUsersRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x16\n\x0eUserNamePrefix\x18\x02 \x01(\t\"_\n\x12TListUsersResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x11\n\tUserNames\x18\x03 \x03(\t\"\x93\x01\n\x12TPurgeQueueRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\n\n\x02Id\x18\x03 \x01(\t\"Y\n\x13TPurgeQueueResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x03 \x01(\t\x12\n\n\x02Id\x18\x04 \x01(\t\"\xac\x01\n\x17TPurgeQueueBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x31\n\x07\x45ntries\x18\x02 \x03(\x0b\x32 .NKikimr.NSQS.TPurgeQueueRequest\"\x86\x01\n\x18TPurgeQueueBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x32\n\x07\x45ntries\x18\x03 \x03(\x0b\x32!.NKikimr.NSQS.TPurgeQueueResponse\"\xb2\x02\n\x16TReceiveMessageRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x1b\n\x13MaxNumberOfMessages\x18\x03 \x01(\r\x12\x1f\n\x17ReceiveRequestAttemptId\x18\x04 \x01(\t\x12\x19\n\x11VisibilityTimeout\x18\x05 \x01(\r\x12\x17\n\x0fWaitTimeSeconds\x18\x06 \x01(\r\x12\x15\n\rAttributeName\x18\x07 \x03(\t\x12\x1c\n\x14MessageAttributeName\x18\x08 \x03(\t\"\xb3\x04\n\x17TReceiveMessageResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12@\n\x08Messages\x18\x03 \x03(\x0b\x32..NKikimr.NSQS.TReceiveMessageResponse.TMessage\x12\x1f\n\x17ReceiveRequestAttemptId\x18\x04 \x01(\t\x1a\xfc\x02\n\x08TMessage\x12(\n ApproximateFirstReceiveTimestamp\x18\x01 \x01(\x04\x12\x1f\n\x17\x41pproximateReceiveCount\x18\x02 \x01(\x04\x12\x11\n\tMessageId\x18\x03 \x01(\t\x12\x1e\n\x16MessageDeduplicationId\x18\x04 \x01(\t\x12\x16\n\x0eMessageGroupId\x18\x05 \x01(\t\x12\x18\n\x10MD5OfMessageBody\x18\x06 \x01(\t\x12\x1e\n\x16MD5OfMessageAttributes\x18\x0c \x01(\t\x12:\n\x11MessageAttributes\x18\x07 \x03(\x0b\x32\x1f.NKikimr.NSQS.TMessageAttribute\x12\x0c\n\x04\x44\x61ta\x18\x08 \x01(\x0c\x12\x15\n\rReceiptHandle\x18\t \x01(\x0c\x12\x15\n\rSentTimestamp\x18\n \x01(\x04\x12\x16\n\x0eSequenceNumber\x18\x0b \x01(\x04\x12\x10\n\x08SenderId\x18\r \x01(\t\"\xb3\x02\n\x13TSendMessageRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x16\n\x0eMessageGroupId\x18\x03 \x01(\t\x12\x1e\n\x16MessageDeduplicationId\x18\x04 \x01(\t\x12\x13\n\x0bMessageBody\x18\x05 \x01(\x0c\x12:\n\x11MessageAttributes\x18\x06 \x03(\x0b\x32\x1f.NKikimr.NSQS.TMessageAttribute\x12\n\n\x02Id\x18\x07 \x01(\t\x12\x14\n\x0c\x44\x65laySeconds\x18\x08 \x01(\x04\"\xbf\x01\n\x14TSendMessageResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x1e\n\x16MD5OfMessageAttributes\x18\x03 \x01(\t\x12\x18\n\x10MD5OfMessageBody\x18\x04 \x01(\t\x12\x11\n\tMessageId\x18\x05 \x01(\t\x12\x16\n\x0eSequenceNumber\x18\x06 \x01(\x04\x12\n\n\x02Id\x18\x07 \x01(\t\"\xc1\x01\n\x18TSendMessageBatchRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12\x32\n\x07\x45ntries\x18\x03 \x03(\x0b\x32!.NKikimr.NSQS.TSendMessageRequest\"\x88\x01\n\x19TSendMessageBatchResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x33\n\x07\x45ntries\x18\x03 \x03(\x0b\x32\".NKikimr.NSQS.TSendMessageResponse\"\xbd\x01\n\x1aTSetQueueAttributesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\x12\x11\n\tQueueName\x18\x02 \x01(\t\x12,\n\nAttributes\x18\x03 \x03(\x0b\x32\x18.NKikimr.NSQS.TAttribute\"U\n\x1bTSetQueueAttributesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\"8\n\x0cTPermissions\x12\x0f\n\x07Subject\x18\x01 \x01(\t\x12\x17\n\x0fPermissionNames\x18\x02 \x03(\t\"\xa4\x01\n\x12TPermissionsAction\x12+\n\x05Grant\x18\x01 \x01(\x0b\x32\x1a.NKikimr.NSQS.TPermissionsH\x00\x12,\n\x06Revoke\x18\x02 \x01(\x0b\x32\x1a.NKikimr.NSQS.TPermissionsH\x00\x12)\n\x03Set\x18\x03 \x01(\x0b\x32\x1a.NKikimr.NSQS.TPermissionsH\x00\x42\x08\n\x06\x41\x63tion\"\xd9\x01\n\x19TModifyPermissionsRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12\x10\n\x08Resource\x18\x01 \x01(\t\x12\x31\n\x07\x41\x63tions\x18\x02 \x03(\x0b\x32 .NKikimr.NSQS.TPermissionsAction\x12\x17\n\x08\x43learACL\x18\x03 \x01(\x08:\x05\x66\x61lse\x12-\n\x04\x41uth\x18\x04 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\"T\n\x1aTModifyPermissionsResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\"\x87\x01\n\x17TListPermissionsRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12-\n\x04\x41uth\x18\x02 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\"~\n\x11TQueuePermissions\x12/\n\x0bPermissions\x18\x01 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\x12\x38\n\x14\x45\x66\x66\x65\x63tivePermissions\x18\x02 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\"\x80\x01\n\x13TAccountPermissions\x12/\n\x0bPermissions\x18\x01 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\x12\x38\n\x14\x45\x66\x66\x65\x63tivePermissions\x18\x02 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\"\x82\x01\n\x15TDirectoryPermissions\x12/\n\x0bPermissions\x18\x01 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\x12\x38\n\x14\x45\x66\x66\x65\x63tivePermissions\x18\x02 \x03(\x0b\x32\x1a.NKikimr.NSQS.TPermissions\"\x9b\x02\n\x18TListPermissionsResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12;\n\x10QueuePermissions\x18\x03 \x01(\x0b\x32\x1f.NKikimr.NSQS.TQueuePermissionsH\x00\x12=\n\x12\x41\x63\x63ountPermissions\x18\x04 \x01(\x0b\x32\x1f.NKikimr.NSQS.TQueuePermissionsH\x00\x12?\n\x14\x44irectoryPermissions\x18\x05 \x01(\x0b\x32\x1f.NKikimr.NSQS.TQueuePermissionsH\x00\x42\n\n\x08NodeType\"\x97\x01\n\"TListDeadLetterSourceQueuesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12\x11\n\tQueueName\x18\x01 \x01(\t\x12-\n\x04\x41uth\x18\x02 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\"\xde\x01\n#TListDeadLetterSourceQueuesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12L\n\x06Queues\x18\x03 \x03(\x0b\x32<.NKikimr.NSQS.TListDeadLetterSourceQueuesResponse.TQueueType\x1a\x31\n\nTQueueType\x12\x11\n\tQueueName\x18\x01 \x01(\t\x12\x10\n\x08QueueUrl\x18\x02 \x01(\t\"u\n\x13TCountQueuesRequest\x12/\n\x0b\x43redentials\x18\x64 \x01(\x0b\x32\x1a.NKikimr.NSQS.TCredentials\x12-\n\x04\x41uth\x18\x01 \x01(\x0b\x32\x1f.NKikimr.NSQS.TAuthentification\"]\n\x14TCountQueuesResponse\x12#\n\x05\x45rror\x18\x01 \x01(\x0b\x32\x14.NKikimr.NSQS.TError\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\r\n\x05\x43ount\x18\x03 \x01(\x04')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.sqs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TAUTHENTIFICATION._serialized_start=43
  _TAUTHENTIFICATION._serialized_end=80
  _TCREDENTIALS._serialized_start=82
  _TCREDENTIALS._serialized_end=175
  _TERROR._serialized_start=178
  _TERROR._serialized_end=371
  _TERROR_TDEBUG._serialized_start=284
  _TERROR_TDEBUG._serialized_end=371
  _TATTRIBUTE._serialized_start=373
  _TATTRIBUTE._serialized_end=414
  _TMESSAGEATTRIBUTE._serialized_start=416
  _TMESSAGEATTRIBUTE._serialized_end=509
  _TCHANGEMESSAGEVISIBILITYREQUEST._serialized_start=512
  _TCHANGEMESSAGEVISIBILITYREQUEST._serialized_end=722
  _TCHANGEMESSAGEVISIBILITYRESPONSE._serialized_start=724
  _TCHANGEMESSAGEVISIBILITYRESPONSE._serialized_end=826
  _TCHANGEMESSAGEVISIBILITYBATCHREQUEST._serialized_start=829
  _TCHANGEMESSAGEVISIBILITYBATCHREQUEST._serialized_end=1046
  _TCHANGEMESSAGEVISIBILITYBATCHRESPONSE._serialized_start=1049
  _TCHANGEMESSAGEVISIBILITYBATCHRESPONSE._serialized_end=1209
  _TCREATEQUEUEREQUEST._serialized_start=1212
  _TCREATEQUEUEREQUEST._serialized_end=1598
  _TCREATEQUEUERESPONSE._serialized_start=1600
  _TCREATEQUEUERESPONSE._serialized_end=1715
  _TCREATEUSERREQUEST._serialized_start=1718
  _TCREATEUSERREQUEST._serialized_end=1852
  _TCREATEUSERRESPONSE._serialized_start=1854
  _TCREATEUSERRESPONSE._serialized_end=1931
  _TGETQUEUEATTRIBUTESREQUEST._serialized_start=1934
  _TGETQUEUEATTRIBUTESREQUEST._serialized_end=2104
  _TGETQUEUEATTRIBUTESRESPONSE._serialized_start=2107
  _TGETQUEUEATTRIBUTESRESPONSE._serialized_end=2632
  _TGETQUEUEATTRIBUTESBATCHREQUEST._serialized_start=2635
  _TGETQUEUEATTRIBUTESBATCHREQUEST._serialized_end=2838
  _TGETQUEUEATTRIBUTESBATCHRESPONSE._serialized_start=2841
  _TGETQUEUEATTRIBUTESBATCHRESPONSE._serialized_end=2991
  _TGETQUEUEURLREQUEST._serialized_start=2994
  _TGETQUEUEURLREQUEST._serialized_end=3130
  _TGETQUEUEURLRESPONSE._serialized_start=3132
  _TGETQUEUEURLRESPONSE._serialized_end=3228
  _TDELETEMESSAGEREQUEST._serialized_start=3231
  _TDELETEMESSAGEREQUEST._serialized_end=3404
  _TDELETEMESSAGERESPONSE._serialized_start=3406
  _TDELETEMESSAGERESPONSE._serialized_end=3498
  _TDELETEMESSAGEBATCHREQUEST._serialized_start=3501
  _TDELETEMESSAGEBATCHREQUEST._serialized_end=3698
  _TDELETEMESSAGEBATCHRESPONSE._serialized_start=3701
  _TDELETEMESSAGEBATCHRESPONSE._serialized_end=3841
  _TDELETEQUEUEREQUEST._serialized_start=3844
  _TDELETEQUEUEREQUEST._serialized_end=3992
  _TDELETEQUEUERESPONSE._serialized_start=3994
  _TDELETEQUEUERESPONSE._serialized_end=4084
  _TDELETEQUEUEBATCHREQUEST._serialized_start=4087
  _TDELETEQUEUEBATCHREQUEST._serialized_end=4261
  _TDELETEQUEUEBATCHRESPONSE._serialized_start=4264
  _TDELETEQUEUEBATCHRESPONSE._serialized_end=4400
  _TDELETEUSERREQUEST._serialized_start=4403
  _TDELETEUSERREQUEST._serialized_end=4537
  _TDELETEUSERRESPONSE._serialized_start=4539
  _TDELETEUSERRESPONSE._serialized_end=4616
  _TLISTQUEUESREQUEST._serialized_start=4619
  _TLISTQUEUESREQUEST._serialized_end=4760
  _TLISTQUEUESRESPONSE._serialized_start=4763
  _TLISTQUEUESRESPONSE._serialized_end=4953
  _TLISTQUEUESRESPONSE_TQUEUETYPE._serialized_start=4904
  _TLISTQUEUESRESPONSE_TQUEUETYPE._serialized_end=4953
  _TLISTUSERSREQUEST._serialized_start=4956
  _TLISTUSERSREQUEST._serialized_end=5095
  _TLISTUSERSRESPONSE._serialized_start=5097
  _TLISTUSERSRESPONSE._serialized_end=5192
  _TPURGEQUEUEREQUEST._serialized_start=5195
  _TPURGEQUEUEREQUEST._serialized_end=5342
  _TPURGEQUEUERESPONSE._serialized_start=5344
  _TPURGEQUEUERESPONSE._serialized_end=5433
  _TPURGEQUEUEBATCHREQUEST._serialized_start=5436
  _TPURGEQUEUEBATCHREQUEST._serialized_end=5608
  _TPURGEQUEUEBATCHRESPONSE._serialized_start=5611
  _TPURGEQUEUEBATCHRESPONSE._serialized_end=5745
  _TRECEIVEMESSAGEREQUEST._serialized_start=5748
  _TRECEIVEMESSAGEREQUEST._serialized_end=6054
  _TRECEIVEMESSAGERESPONSE._serialized_start=6057
  _TRECEIVEMESSAGERESPONSE._serialized_end=6620
  _TRECEIVEMESSAGERESPONSE_TMESSAGE._serialized_start=6240
  _TRECEIVEMESSAGERESPONSE_TMESSAGE._serialized_end=6620
  _TSENDMESSAGEREQUEST._serialized_start=6623
  _TSENDMESSAGEREQUEST._serialized_end=6930
  _TSENDMESSAGERESPONSE._serialized_start=6933
  _TSENDMESSAGERESPONSE._serialized_end=7124
  _TSENDMESSAGEBATCHREQUEST._serialized_start=7127
  _TSENDMESSAGEBATCHREQUEST._serialized_end=7320
  _TSENDMESSAGEBATCHRESPONSE._serialized_start=7323
  _TSENDMESSAGEBATCHRESPONSE._serialized_end=7459
  _TSETQUEUEATTRIBUTESREQUEST._serialized_start=7462
  _TSETQUEUEATTRIBUTESREQUEST._serialized_end=7651
  _TSETQUEUEATTRIBUTESRESPONSE._serialized_start=7653
  _TSETQUEUEATTRIBUTESRESPONSE._serialized_end=7738
  _TPERMISSIONS._serialized_start=7740
  _TPERMISSIONS._serialized_end=7796
  _TPERMISSIONSACTION._serialized_start=7799
  _TPERMISSIONSACTION._serialized_end=7963
  _TMODIFYPERMISSIONSREQUEST._serialized_start=7966
  _TMODIFYPERMISSIONSREQUEST._serialized_end=8183
  _TMODIFYPERMISSIONSRESPONSE._serialized_start=8185
  _TMODIFYPERMISSIONSRESPONSE._serialized_end=8269
  _TLISTPERMISSIONSREQUEST._serialized_start=8272
  _TLISTPERMISSIONSREQUEST._serialized_end=8407
  _TQUEUEPERMISSIONS._serialized_start=8409
  _TQUEUEPERMISSIONS._serialized_end=8535
  _TACCOUNTPERMISSIONS._serialized_start=8538
  _TACCOUNTPERMISSIONS._serialized_end=8666
  _TDIRECTORYPERMISSIONS._serialized_start=8669
  _TDIRECTORYPERMISSIONS._serialized_end=8799
  _TLISTPERMISSIONSRESPONSE._serialized_start=8802
  _TLISTPERMISSIONSRESPONSE._serialized_end=9085
  _TLISTDEADLETTERSOURCEQUEUESREQUEST._serialized_start=9088
  _TLISTDEADLETTERSOURCEQUEUESREQUEST._serialized_end=9239
  _TLISTDEADLETTERSOURCEQUEUESRESPONSE._serialized_start=9242
  _TLISTDEADLETTERSOURCEQUEUESRESPONSE._serialized_end=9464
  _TLISTDEADLETTERSOURCEQUEUESRESPONSE_TQUEUETYPE._serialized_start=4904
  _TLISTDEADLETTERSOURCEQUEUESRESPONSE_TQUEUETYPE._serialized_end=4953
  _TCOUNTQUEUESREQUEST._serialized_start=9466
  _TCOUNTQUEUESREQUEST._serialized_end=9583
  _TCOUNTQUEUESRESPONSE._serialized_start=9585
  _TCOUNTQUEUESRESPONSE._serialized_end=9678
# @@protoc_insertion_point(module_scope)
