# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/index_builder.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_table_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__table__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ydb/core/protos/index_builder.proto\x12\x13NKikimrIndexBuilder\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a%ydb/public/api/protos/ydb_table.proto\"\xd7\x01\n\x13TIndexBuildSettings\x12\x13\n\x0bsource_path\x18\x01 \x01(\t\x12$\n\x05index\x18\x02 \x01(\x0b\x32\x15.Ydb.Table.TableIndex\x12\x1b\n\x0emax_batch_rows\x18\x03 \x01(\r:\x03\x35\x30\x30\x12 \n\x0fmax_batch_bytes\x18\x04 \x01(\x04:\x07\x38\x33\x38\x38\x36\x30\x38\x12 \n\x14max_shards_in_flight\x18\x05 \x01(\r:\x02\x33\x32\x12$\n\x18max_retries_upload_batch\x18\x06 \x01(\r:\x02\x35\x30\"\xc4\x01\n\x0bTIndexBuild\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12/\n\x05State\x18\x03 \x01(\x0e\x32 .Ydb.Table.IndexBuildState.State\x12:\n\x08Settings\x18\x04 \x01(\x0b\x32(.NKikimrIndexBuilder.TIndexBuildSettings\x12\x13\n\x08Progress\x18\x05 \x01(\x02:\x01\x30\"\xac\x01\n\x10TEvCreateRequest\x12\x38\n\x0fOperationParams\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12:\n\x08Settings\x18\x04 \x01(\x0b\x32(.NKikimrIndexBuilder.TIndexBuildSettings\"\xab\x01\n\x11TEvCreateResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x34\n\nIndexBuild\x18\x04 \x01(\x0b\x32 .NKikimrIndexBuilder.TIndexBuild\";\n\rTEvGetRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\x12\x14\n\x0cIndexBuildId\x18\x02 \x01(\x04\"\x9a\x01\n\x0eTEvGetResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x34\n\nIndexBuild\x18\x03 \x01(\x0b\x32 .NKikimrIndexBuilder.TIndexBuild\"L\n\x10TEvCancelRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x14\n\x0cIndexBuildId\x18\x03 \x01(\x04\"u\n\x11TEvCancelResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"L\n\x10TEvForgetRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x14\n\x0cIndexBuildId\x18\x03 \x01(\x04\"u\n\x11TEvForgetResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"K\n\x0eTEvListRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\x12\x10\n\x08PageSize\x18\x02 \x01(\x04\x12\x11\n\tPageToken\x18\x03 \x01(\t\"\xaf\x01\n\x0fTEvListResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x31\n\x07\x45ntries\x18\x03 \x03(\x0b\x32 .NKikimrIndexBuilder.TIndexBuild\x12\x15\n\rNextPageToken\x18\x04 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.index_builder_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TINDEXBUILDSETTINGS._serialized_start=236
  _TINDEXBUILDSETTINGS._serialized_end=451
  _TINDEXBUILD._serialized_start=454
  _TINDEXBUILD._serialized_end=650
  _TEVCREATEREQUEST._serialized_start=653
  _TEVCREATEREQUEST._serialized_end=825
  _TEVCREATERESPONSE._serialized_start=828
  _TEVCREATERESPONSE._serialized_end=999
  _TEVGETREQUEST._serialized_start=1001
  _TEVGETREQUEST._serialized_end=1060
  _TEVGETRESPONSE._serialized_start=1063
  _TEVGETRESPONSE._serialized_end=1217
  _TEVCANCELREQUEST._serialized_start=1219
  _TEVCANCELREQUEST._serialized_end=1295
  _TEVCANCELRESPONSE._serialized_start=1297
  _TEVCANCELRESPONSE._serialized_end=1414
  _TEVFORGETREQUEST._serialized_start=1416
  _TEVFORGETREQUEST._serialized_end=1492
  _TEVFORGETRESPONSE._serialized_start=1494
  _TEVFORGETRESPONSE._serialized_end=1611
  _TEVLISTREQUEST._serialized_start=1613
  _TEVLISTREQUEST._serialized_end=1688
  _TEVLISTRESPONSE._serialized_start=1691
  _TEVLISTRESPONSE._serialized_end=1866
# @@protoc_insertion_point(module_scope)
