# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_counters_aggregator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ydb/core/protos/tablet_counters_aggregator.proto\x12\x1fNKikimrTabletCountersAggregator\"E\n\x0fTTabletCounters\x12\x16\n\x0eSimpleCounters\x18\x01 \x03(\x04\x12\x1a\n\x12\x43umulativeCounters\x18\x02 \x03(\x04\"\xba\x01\n\x13TTabletCountersInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12J\n\x10\x45xecutorCounters\x18\x02 \x01(\x0b\x32\x30.NKikimrTabletCountersAggregator.TTabletCounters\x12\x45\n\x0b\x41ppCounters\x18\x03 \x01(\x0b\x32\x30.NKikimrTabletCountersAggregator.TTabletCounters\"-\n\x18TEvTabletCountersRequest\x12\x11\n\tTabletIds\x18\x01 \x03(\x04\"g\n\x19TEvTabletCountersResponse\x12J\n\x0c\x43ountersInfo\x18\x01 \x03(\x0b\x32\x34.NKikimrTabletCountersAggregator.TTabletCountersInfoB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_counters_aggregator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TTABLETCOUNTERS._serialized_start=85
  _TTABLETCOUNTERS._serialized_end=154
  _TTABLETCOUNTERSINFO._serialized_start=157
  _TTABLETCOUNTERSINFO._serialized_end=343
  _TEVTABLETCOUNTERSREQUEST._serialized_start=345
  _TEVTABLETCOUNTERSREQUEST._serialized_end=390
  _TEVTABLETCOUNTERSRESPONSE._serialized_start=392
  _TEVTABLETCOUNTERSRESPONSE._serialized_end=495
# @@protoc_insertion_point(module_scope)
