# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/mon.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/mon.proto\x12\x0fNKikimrMonProto\":\n\tTSockAddr\x12\x0e\n\x06\x46\x61mily\x18\x01 \x01(\r\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\"X\n\x14TEvMonitoringRequest\x12\x13\n\x0bHttpRequest\x18\x01 \x01(\t\x12+\n\x07\x41\x64\x64ress\x18\x02 \x01(\x0b\x32\x1a.NKikimrMonProto.TSockAddr\"-\n\x15TEvMonitoringResponse\x12\x14\n\x0cHttpResponse\x18\x01 \x01(\t')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.mon_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TSOCKADDR._serialized_start=46
  _TSOCKADDR._serialized_end=104
  _TEVMONITORINGREQUEST._serialized_start=106
  _TEVMONITORINGREQUEST._serialized_end=194
  _TEVMONITORINGRESPONSE._serialized_start=196
  _TEVMONITORINGRESPONSE._serialized_end=241
# @@protoc_insertion_point(module_scope)
