# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/test_shard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ydb/core/protos/test_shard.proto\x12\nNTestShard\"\x90\x07\n\x0cTStateServer\x1a\xb3\x01\n\x06TWrite\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0b\n\x03Key\x18\x03 \x01(\t\x12:\n\x0bOriginState\x18\x04 \x01(\x0e\x32%.NTestShard.TStateServer.EEntityState\x12:\n\x0bTargetState\x18\x05 \x01(\x0e\x32%.NTestShard.TStateServer.EEntityState\x1a@\n\x0cTWriteResult\x12\x30\n\x06Status\x18\x01 \x01(\x0e\x32 .NTestShard.TStateServer.EStatus\x1a=\n\x05TRead\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0e\n\x06\x43ookie\x18\x03 \x01(\x0c\x1a\xd6\x01\n\x0bTReadResult\x12\x30\n\x06Status\x18\x01 \x01(\x0e\x32 .NTestShard.TStateServer.EStatus\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x0c\x12\x39\n\x05Items\x18\x03 \x03(\x0b\x32*.NTestShard.TStateServer.TReadResult.TItem\x1aJ\n\x05TItem\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\x34\n\x05State\x18\x02 \x01(\x0e\x32%.NTestShard.TStateServer.EEntityState\x1a\x33\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x1a\xb3\x01\n\x08TRequest\x12\x30\n\x05Write\x18\x01 \x01(\x0b\x32\x1f.NTestShard.TStateServer.TWriteH\x00\x12.\n\x04Read\x18\x02 \x01(\x0b\x32\x1e.NTestShard.TStateServer.TReadH\x00\x12:\n\nTabletInfo\x18\x03 \x01(\x0b\x32$.NTestShard.TStateServer.TTabletInfoH\x00\x42\t\n\x07\x43ommand\"]\n\x0c\x45\x45ntityState\x12\n\n\x06\x41\x42SENT\x10\x00\x12\x11\n\rWRITE_PENDING\x10\x01\x12\r\n\tCONFIRMED\x10\x02\x12\x12\n\x0e\x44\x45LETE_PENDING\x10\x03\x12\x0b\n\x07\x44\x45LETED\x10\x04\"&\n\x07\x45Status\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x08\n\x04RACE\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.test_shard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TSTATESERVER._serialized_start=49
  _TSTATESERVER._serialized_end=961
  _TSTATESERVER_TWRITE._serialized_start=66
  _TSTATESERVER_TWRITE._serialized_end=245
  _TSTATESERVER_TWRITERESULT._serialized_start=247
  _TSTATESERVER_TWRITERESULT._serialized_end=311
  _TSTATESERVER_TREAD._serialized_start=313
  _TSTATESERVER_TREAD._serialized_end=374
  _TSTATESERVER_TREADRESULT._serialized_start=377
  _TSTATESERVER_TREADRESULT._serialized_end=591
  _TSTATESERVER_TREADRESULT_TITEM._serialized_start=517
  _TSTATESERVER_TREADRESULT_TITEM._serialized_end=591
  _TSTATESERVER_TTABLETINFO._serialized_start=593
  _TSTATESERVER_TTABLETINFO._serialized_end=644
  _TSTATESERVER_TREQUEST._serialized_start=647
  _TSTATESERVER_TREQUEST._serialized_end=826
  _TSTATESERVER_EENTITYSTATE._serialized_start=828
  _TSTATESERVER_EENTITYSTATE._serialized_end=921
  _TSTATESERVER_ESTATUS._serialized_start=923
  _TSTATESERVER_ESTATUS._serialized_end=961
# @@protoc_insertion_point(module_scope)
