# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_database.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/tablet_database.proto\x12\rNKikimrTablet\x1a\x1aydb/core/protos/base.proto\"\x80\t\n\x11TExecutorSettings\x12H\n\x0e\x44\x61tabasePolicy\x18\x01 \x01(\x0b\x32\x30.NKikimrTablet.TExecutorSettings.TDatabasePolicy\x12J\n\x0fRuntimeSettings\x18\x02 \x01(\x0b\x32\x31.NKikimrTablet.TExecutorSettings.TRuntimeSettings\x1a\x96\x01\n\x14TLocalityGroupPolicy\x12\x17\n\x0fLocalityGroupId\x18\x01 \x01(\r\x12\x19\n\x11MaxChunkSizeBytes\x18\x02 \x01(\r\x12\x18\n\x10MaxBlobSizeBytes\x18\x03 \x01(\r\x12\x1a\n\x12TabletChannelIndex\x18\x04 \x01(\r\x12\x14\n\x0cKeepInMemory\x18\x05 \x01(\x08\x1a\x97\x04\n\x11TCompactionPolicy\x12\x1b\n\x13InMemSizeToSnapshot\x18\x01 \x01(\x04\x12\x1c\n\x14InMemStepsToSnapshot\x18\x02 \x01(\r\x12!\n\x19InMemForceStepsToSnapshot\x18\x03 \x01(\r\x12 \n\x18InMemForceSizeToSnapshot\x18\x04 \x01(\x04\x12 \n\x18InMemForceTimeToSnapshot\x18\x05 \x01(\x04\x12\x1c\n\x14InMemCompactionQueue\x18\x06 \x01(\r\x12X\n\nGeneration\x18\n \x03(\x0b\x32\x44.NKikimrTablet.TExecutorSettings.TCompactionPolicy.TGenerationPolicy\x1a\xe7\x01\n\x11TGenerationPolicy\x12\x14\n\x0cGenerationId\x18\x01 \x01(\r\x12\x15\n\rSizeToCompact\x18\x02 \x01(\x04\x12\x16\n\x0e\x43ountToCompact\x18\x03 \x01(\r\x12\x1a\n\x12TimeFromCompaction\x18\x04 \x01(\x04\x12\x1b\n\x13\x46orceCountToCompact\x18\n \x01(\r\x12\x1a\n\x12\x46orceSizeToCompact\x18\x0b \x01(\x04\x12\x1f\n\x17\x46orceTimeFromCompaction\x18\x0c \x01(\x04\x12\x17\n\x0f\x43ompactionQueue\x18\x14 \x01(\r\x1a\x8d\x02\n\x0fTDatabasePolicy\x12\x15\n\rMainCacheSize\x18\x01 \x01(\x04\x12\x17\n\x0f\x45xecutorTxInFly\x18\x02 \x01(\r\x12\"\n\x1aTabletMetaInfoChannelIndex\x18\x03 \x01(\r\x12L\n\x10\x43ompactionPolicy\x18\n \x01(\x0b\x32\x32.NKikimrTablet.TExecutorSettings.TCompactionPolicy\x12R\n\x13LocalityGroupPolicy\x18\x0b \x03(\x0b\x32\x35.NKikimrTablet.TExecutorSettings.TLocalityGroupPolicyJ\x04\x08\x64\x10\x65\x1a\x12\n\x10TRuntimeSettings\"}\n\x11TCompactionBroker\x12:\n\x05Queue\x18\x01 \x03(\x0b\x32+.NKikimrTablet.TCompactionBroker.TQueueType\x1a,\n\nTQueueType\x12\x0f\n\x07QueueID\x18\x01 \x01(\r\x12\r\n\x05Quota\x18\x02 \x01(\r\"P\n\x1cTEvSetCompactionBrokerConfig\x12\x30\n\x06\x43onfig\x18\x01 \x01(\x0b\x32 .NKikimrTablet.TCompactionBroker\"`\n\"TEvSetCompactionBrokerConfigResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Reason\x18\x02 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_database_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEXECUTORSETTINGS._serialized_start=85
  _TEXECUTORSETTINGS._serialized_end=1237
  _TEXECUTORSETTINGS_TLOCALITYGROUPPOLICY._serialized_start=257
  _TEXECUTORSETTINGS_TLOCALITYGROUPPOLICY._serialized_end=407
  _TEXECUTORSETTINGS_TCOMPACTIONPOLICY._serialized_start=410
  _TEXECUTORSETTINGS_TCOMPACTIONPOLICY._serialized_end=945
  _TEXECUTORSETTINGS_TCOMPACTIONPOLICY_TGENERATIONPOLICY._serialized_start=714
  _TEXECUTORSETTINGS_TCOMPACTIONPOLICY_TGENERATIONPOLICY._serialized_end=945
  _TEXECUTORSETTINGS_TDATABASEPOLICY._serialized_start=948
  _TEXECUTORSETTINGS_TDATABASEPOLICY._serialized_end=1217
  _TEXECUTORSETTINGS_TRUNTIMESETTINGS._serialized_start=1219
  _TEXECUTORSETTINGS_TRUNTIMESETTINGS._serialized_end=1237
  _TCOMPACTIONBROKER._serialized_start=1239
  _TCOMPACTIONBROKER._serialized_end=1364
  _TCOMPACTIONBROKER_TQUEUETYPE._serialized_start=1320
  _TCOMPACTIONBROKER_TQUEUETYPE._serialized_end=1364
  _TEVSETCOMPACTIONBROKERCONFIG._serialized_start=1366
  _TEVSETCOMPACTIONBROKERCONFIG._serialized_end=1446
  _TEVSETCOMPACTIONBROKERCONFIGRESULT._serialized_start=1448
  _TEVSETCOMPACTIONBROKERCONFIGRESULT._serialized_end=1544
# @@protoc_insertion_point(module_scope)
