# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/grpc_status_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/core/protos/grpc_status_proxy.proto\x12\x10NKikimrGRpcProxy\"\x15\n\x13TEvGetStatusRequest\"&\n\x14TEvGetStatusResponse\x12\x0e\n\x06Weight\x18\x01 \x01(\x04\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.grpc_status_proxy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TEVGETSTATUSREQUEST._serialized_start=61
  _TEVGETSTATUSREQUEST._serialized_end=82
  _TEVGETSTATUSRESPONSE._serialized_start=84
  _TEVGETSTATUSRESPONSE._serialized_end=122
# @@protoc_insertion_point(module_scope)
