# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/read_actors_factory.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.providers.s3.proto import retry_config_pb2 as ydb_dot_library_dot_yql_dot_providers_dot_s3_dot_proto_dot_retry__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8ydb/core/yq/libs/config/protos/read_actors_factory.proto\x12\x0bNYq.NConfig\x1a\x35ydb/library/yql/providers/s3/proto/retry_config.proto\"\x88\x01\n\x19TS3ReadActorFactoryConfig\x12+\n\x0bRetryConfig\x18\x01 \x01(\x0b\x32\x16.NYql.NS3.TRetryConfig\x12\x13\n\x0bRowsInBatch\x18\x02 \x01(\x04\x12\x13\n\x0bMaxInflight\x18\x03 \x01(\x04\x12\x14\n\x0c\x44\x61taInflight\x18\x04 \x01(\x04\"5\n\x19TPqReadActorFactoryConfig\x12\x18\n\x10\x43ookieCommitMode\x18\x01 \x01(\x08\"\xae\x01\n\x18TReadActorsFactoryConfig\x12H\n\x18S3ReadActorFactoryConfig\x18\x01 \x01(\x0b\x32&.NYq.NConfig.TS3ReadActorFactoryConfig\x12H\n\x18PqReadActorFactoryConfig\x18\x02 \x01(\x0b\x32&.NYq.NConfig.TPqReadActorFactoryConfigB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.read_actors_factory_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TS3READACTORFACTORYCONFIG._serialized_start=129
  _TS3READACTORFACTORYCONFIG._serialized_end=265
  _TPQREADACTORFACTORYCONFIG._serialized_start=267
  _TPQREADACTORFACTORYCONFIG._serialized_end=320
  _TREADACTORSFACTORYCONFIG._serialized_start=323
  _TREADACTORSFACTORYCONFIG._serialized_end=497
# @@protoc_insertion_point(module_scope)
