# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/table_stats.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/table_stats.proto\x12\x11NKikimrTableStats\".\n\x10THistogramBucket\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\r\n\x05Value\x18\x02 \x01(\x04\"B\n\nTHistogram\x12\x34\n\x07\x42uckets\x18\x01 \x03(\x0b\x32#.NKikimrTableStats.THistogramBucket\"\x9e\x05\n\x0bTTableStats\x12\x10\n\x08\x44\x61taSize\x18\x01 \x01(\x04\x12\x10\n\x08RowCount\x18\x02 \x01(\x04\x12\x11\n\tIndexSize\x18\x03 \x01(\x04\x12\x11\n\tInMemSize\x18\x04 \x01(\x04\x12\x16\n\x0eLastAccessTime\x18\x05 \x01(\x04\x12\x16\n\x0eLastUpdateTime\x18\x06 \x01(\x04\x12\x38\n\x11RowCountHistogram\x18\x07 \x01(\x0b\x32\x1d.NKikimrTableStats.THistogram\x12\x38\n\x11\x44\x61taSizeHistogram\x18\x08 \x01(\x0b\x32\x1d.NKikimrTableStats.THistogram\x12\x1c\n\x14ImmediateTxCompleted\x18\t \x01(\x04\x12\x1a\n\x12PlannedTxCompleted\x18\n \x01(\x04\x12\x1c\n\x14TxRejectedByOverload\x18\x0b \x01(\x04\x12\x19\n\x11TxRejectedBySpace\x18\x0c \x01(\x04\x12\x19\n\x11TxCompleteLagMsec\x18\r \x01(\x04\x12\x17\n\x0fInFlightTxCount\x18\x0e \x01(\x04\x12\x12\n\nRowUpdates\x18\x14 \x01(\x04\x12\x12\n\nRowDeletes\x18\x15 \x01(\x04\x12\x10\n\x08RowReads\x18\x16 \x01(\x04\x12\x12\n\nRangeReads\x18\x17 \x01(\x04\x12\x15\n\rRangeReadRows\x18\x19 \x01(\x04\x12\x11\n\tPartCount\x18\x18 \x01(\x04\x12\x36\n\x0fKeyAccessSample\x18\x1a \x01(\x0b\x32\x1d.NKikimrTableStats.THistogram\x12\x14\n\x0cSearchHeight\x18\x1b \x01(\x04\x12\x1c\n\x14LastFullCompactionTs\x18\x1c \x01(\x04\x12\x16\n\x0eHasLoanedParts\x18\x1d \x01(\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.table_stats_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _THISTOGRAMBUCKET._serialized_start=56
  _THISTOGRAMBUCKET._serialized_end=102
  _THISTOGRAM._serialized_start=104
  _THISTOGRAM._serialized_end=170
  _TTABLESTATS._serialized_start=173
  _TTABLESTATS._serialized_end=843
# @@protoc_insertion_point(module_scope)
