# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/scheme_log.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import type_info_pb2 as ydb_dot_core_dot_protos_dot_type__info__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ydb/core/protos/scheme_log.proto\x12\x11NTabletFlatScheme\x1a$ydb/core/protos/flat_scheme_op.proto\x1a\x1fydb/core/protos/type_info.proto\"\xa1\x08\n\x0cTAlterRecord\x12=\n\tDeltaType\x18\x01 \x02(\x0e\x32*.NTabletFlatScheme.TAlterRecord.EDeltaType\x12\x0f\n\x07TableId\x18\x02 \x01(\r\x12\x11\n\tTableName\x18\x03 \x01(\t\x12\x10\n\x08\x43olumnId\x18\x04 \x01(\r\x12\x10\n\x08\x46\x61milyId\x18\x07 \x01(\r\x12\x0e\n\x06RoomId\x18\x08 \x01(\r\x12\r\n\x05\x41nnex\x18\x10 \x01(\r\x12\x16\n\x0b\x42yKeyFilter\x18\x11 \x01(\r:\x01\x30\x12\x19\n\x11\x45raseCacheEnabled\x18\x14 \x01(\x08\x12\x19\n\x11\x45raseCacheMinRows\x18\x15 \x01(\r\x12\x1a\n\x12\x45raseCacheMaxBytes\x18\x16 \x01(\r\x12\x19\n\nColdBorrow\x18\x17 \x01(\x08:\x05\x66\x61lse\x12\x0c\n\x04Main\x18\t \x01(\r\x12\r\n\x05\x42lobs\x18\x0f \x01(\r\x12\r\n\x05Outer\x18\x13 \x01(\r\x12\r\n\x05\x43odec\x18\x0b \x01(\r\x12\x10\n\x08InMemory\x18\x0c \x01(\x08\x12\r\n\x05\x43\x61\x63he\x18\r \x01(\r\x12\r\n\x05Large\x18\x0e \x01(\r\x12\r\n\x05Small\x18\x12 \x01(\r\x12\x12\n\nColumnName\x18\x05 \x01(\t\x12\x12\n\nColumnType\x18\x06 \x01(\r\x12/\n\x0e\x43olumnTypeInfo\x18\x19 \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x12\x0f\n\x07\x44\x65\x66\x61ult\x18\n \x01(\x0c\x12\x16\n\x07NotNull\x18\x18 \x01(\x08:\x05\x66\x61lse\x12\x19\n\x11\x45xecutorCacheSize\x18\x64 \x01(\x04\x12<\n\x10\x43ompactionPolicy\x18\x65 \x01(\x0b\x32\".NKikimrSchemeOp.TCompactionPolicy\x12 \n\x18\x45xecutorAllowLogBatching\x18\x66 \x01(\x08\x12\x1e\n\x16\x45xecutorLogFlushPeriod\x18g \x01(\x04\x12\x1c\n\x14\x45xecutorLimitInFlyTx\x18h \x01(\r\x12\x1f\n\x17\x45xecutorResourceProfile\x18i \x01(\t\x12#\n\x1b\x45xecutorLogFastCommitTactic\x18j \x01(\x08\"\xea\x01\n\nEDeltaType\x12\x0c\n\x08\x41\x64\x64Table\x10\x01\x12\r\n\tDropTable\x10\x02\x12\r\n\tAddColumn\x10\x03\x12\x0e\n\nDropColumn\x10\x04\x12\x12\n\x0e\x41\x64\x64\x43olumnToKey\x10\x05\x12\x15\n\x11\x41\x64\x64\x43olumnToFamily\x10\x06\x12\r\n\tAddFamily\x10\x07\x12\x16\n\x12UpdateExecutorInfo\x10\x08\x12\x17\n\x13SetCompactionPolicy\x10\t\x12\x0b\n\x07SetRoom\x10\n\x12\r\n\tSetFamily\x10\x0b\x12\x0b\n\x07SetRedo\x10\x0c\x12\x0c\n\x08SetTable\x10\r\"@\n\x0eTSchemeChanges\x12.\n\x05\x44\x65lta\x18\x01 \x03(\x0b\x32\x1f.NTabletFlatScheme.TAlterRecordB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.scheme_log_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TALTERRECORD._serialized_start=127
  _TALTERRECORD._serialized_end=1184
  _TALTERRECORD_EDELTATYPE._serialized_start=950
  _TALTERRECORD_EDELTATYPE._serialized_end=1184
  _TSCHEMECHANGES._serialized_start=1186
  _TSCHEMECHANGES._serialized_end=1250
# @@protoc_insertion_point(module_scope)
