# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/draft/ydb_logstore.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_value_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__value__pb2
from ydb.public.api.protos import ydb_scheme_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__scheme__pb2
from ydb.public.api.protos import ydb_table_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__table__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ydb/public/api/protos/draft/ydb_logstore.proto\x12\x0cYdb.LogStore\x1a)ydb/public/api/protos/ydb_operation.proto\x1a%ydb/public/api/protos/ydb_value.proto\x1a&ydb/public/api/protos/ydb_scheme.proto\x1a%ydb/public/api/protos/ydb_table.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xb4\x01\n\x0b\x43ompression\x12:\n\x11\x63ompression_codec\x18\x01 \x01(\x0e\x32\x1f.Ydb.LogStore.Compression.Codec\x12\x19\n\x11\x63ompression_level\x18\x02 \x01(\x05\"N\n\x05\x43odec\x12\x15\n\x11\x43ODEC_UNSPECIFIED\x10\x00\x12\x0f\n\x0b\x43ODEC_PLAIN\x10\x01\x12\r\n\tCODEC_LZ4\x10\x02\x12\x0e\n\nCODEC_ZSTD\x10\x03\"3\n\nColumnMeta\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x17\n\x04type\x18\x02 \x01(\x0b\x32\t.Ydb.Type\"\x80\x01\n\x06Schema\x12)\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x18.Ydb.LogStore.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x02 \x03(\t\x12\x36\n\x13\x64\x65\x66\x61ult_compression\x18\x03 \x01(\x0b\x32\x19.Ydb.LogStore.Compression\"B\n\x0cSchemaPreset\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x06schema\x18\x02 \x01(\x0b\x32\x14.Ydb.LogStore.Schema\"J\n\nTierConfig\x12\x0c\n\x04name\x18\x01 \x01(\t\x12.\n\x0b\x63ompression\x18\x02 \x01(\x0b\x32\x19.Ydb.LogStore.Compression\">\n\x04Tier\x12\x0c\n\x04name\x18\x01 \x01(\t\x12(\n\x08\x65viction\x18\x02 \x01(\x0b\x32\x16.Ydb.Table.TtlSettings\"9\n\x0fTieringSettings\x12\x17\n\ntiering_id\x18\x02 \x01(\tH\x00\x88\x01\x01\x42\r\n\x0b_tiering_id\"\xaa\x01\n\x15\x43reateLogStoreRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x14\n\x0cshards_count\x18\x03 \x01(\r\x12\x32\n\x0eschema_presets\x18\x04 \x03(\x0b\x32\x1a.Ydb.LogStore.SchemaPreset\"F\n\x16\x43reateLogStoreResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"b\n\x17\x44\x65scribeLogStoreRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xac\x01\n\x16\x44\x65scribeLogStoreResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12\x14\n\x0cshards_count\x18\x02 \x01(\r\x12\x32\n\x0eschema_presets\x18\x03 \x03(\x0b\x32\x1a.Ydb.LogStore.SchemaPreset\x12\'\n\x05tiers\x18\x04 \x03(\x0b\x32\x18.Ydb.LogStore.TierConfig\"H\n\x18\x44\x65scribeLogStoreResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"^\n\x13\x44ropLogStoreRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"D\n\x14\x44ropLogStoreResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xac\x02\n\x14\x41lterLogStoreRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x37\n\x11set_schema_preset\x18\x03 \x01(\x0b\x32\x1a.Ydb.LogStore.SchemaPresetH\x00\x12\x1c\n\x12\x64rop_schema_preset\x18\x04 \x01(\tH\x00\x12,\n\x08set_tier\x18\x05 \x01(\x0b\x32\x18.Ydb.LogStore.TierConfigH\x01\x12\x13\n\tdrop_tier\x18\x06 \x01(\tH\x01\x42\x1c\n\x1aschema_preset_modificationB\x13\n\x11tier_modification\"E\n\x15\x41lterLogStoreResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xc2\x03\n\x15\x43reateLogTableRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1c\n\x12schema_preset_name\x18\x03 \x01(\tH\x00\x12&\n\x06schema\x18\x04 \x01(\x0b\x32\x14.Ydb.LogStore.SchemaH\x00\x12.\n\x0cttl_settings\x18\x05 \x01(\x0b\x32\x16.Ydb.Table.TtlSettingsH\x01\x12\x39\n\x10tiering_settings\x18\x06 \x01(\x0b\x32\x1d.Ydb.LogStore.TieringSettingsH\x01\x12\x14\n\x0cshards_count\x18\x07 \x01(\r\x12\x18\n\x10sharding_columns\x18\x08 \x03(\t\x12\x35\n\rsharding_type\x18\t \x01(\x0e\x32\x1e.Ydb.LogStore.ShardingHashType\x12\x1b\n\x13\x61\x63tive_shards_count\x18\n \x01(\rB\x16\n\x14schema_specificationB\x13\n\x11ttl_specification\"F\n\x16\x43reateLogTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"b\n\x17\x44\x65scribeLogTableRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"\xff\x02\n\x16\x44\x65scribeLogTableResult\x12\x1f\n\x04self\x18\x01 \x01(\x0b\x32\x11.Ydb.Scheme.Entry\x12\x1a\n\x12schema_preset_name\x18\x02 \x01(\t\x12$\n\x06schema\x18\x03 \x01(\x0b\x32\x14.Ydb.LogStore.Schema\x12.\n\x0cttl_settings\x18\x05 \x01(\x0b\x32\x16.Ydb.Table.TtlSettingsH\x00\x12\x39\n\x10tiering_settings\x18\x04 \x01(\x0b\x32\x1d.Ydb.LogStore.TieringSettingsH\x00\x12\x14\n\x0cshards_count\x18\x06 \x01(\r\x12\x18\n\x10sharding_columns\x18\x07 \x03(\t\x12\x35\n\rsharding_type\x18\x08 \x01(\x0e\x32\x1e.Ydb.LogStore.ShardingHashType\x12\x1b\n\x13\x61\x63tive_shards_count\x18\t \x01(\rB\x13\n\x11ttl_specification\"H\n\x18\x44\x65scribeLogTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"^\n\x13\x44ropLogTableRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\"D\n\x14\x44ropLogTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x95\x02\n\x14\x41lterLogTableRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x33\n\x11\x64rop_ttl_settings\x18\x03 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\x32\n\x10set_ttl_settings\x18\x04 \x01(\x0b\x32\x16.Ydb.Table.TtlSettingsH\x00\x12=\n\x14set_tiering_settings\x18\x05 \x01(\x0b\x32\x1d.Ydb.LogStore.TieringSettingsH\x00\x42\x0c\n\nttl_action\"E\n\x15\x41lterLogTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation*a\n\x10ShardingHashType\x12\x19\n\x15HASH_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12HASH_TYPE_MODULO_N\x10\x01\x12\x1a\n\x16HASH_TYPE_LOGS_SPECIAL\x10\x02\x42,\n\x17\x63om.yandex.ydb.logstoreB\x0eLogStoreProtos\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.draft.ydb_logstore_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027com.yandex.ydb.logstoreB\016LogStoreProtos\370\001\001'
  _SHARDINGHASHTYPE._serialized_start=3624
  _SHARDINGHASHTYPE._serialized_end=3721
  _COMPRESSION._serialized_start=255
  _COMPRESSION._serialized_end=435
  _COMPRESSION_CODEC._serialized_start=357
  _COMPRESSION_CODEC._serialized_end=435
  _COLUMNMETA._serialized_start=437
  _COLUMNMETA._serialized_end=488
  _SCHEMA._serialized_start=491
  _SCHEMA._serialized_end=619
  _SCHEMAPRESET._serialized_start=621
  _SCHEMAPRESET._serialized_end=687
  _TIERCONFIG._serialized_start=689
  _TIERCONFIG._serialized_end=763
  _TIER._serialized_start=765
  _TIER._serialized_end=827
  _TIERINGSETTINGS._serialized_start=829
  _TIERINGSETTINGS._serialized_end=886
  _CREATELOGSTOREREQUEST._serialized_start=889
  _CREATELOGSTOREREQUEST._serialized_end=1059
  _CREATELOGSTORERESPONSE._serialized_start=1061
  _CREATELOGSTORERESPONSE._serialized_end=1131
  _DESCRIBELOGSTOREREQUEST._serialized_start=1133
  _DESCRIBELOGSTOREREQUEST._serialized_end=1231
  _DESCRIBELOGSTORERESULT._serialized_start=1234
  _DESCRIBELOGSTORERESULT._serialized_end=1406
  _DESCRIBELOGSTORERESPONSE._serialized_start=1408
  _DESCRIBELOGSTORERESPONSE._serialized_end=1480
  _DROPLOGSTOREREQUEST._serialized_start=1482
  _DROPLOGSTOREREQUEST._serialized_end=1576
  _DROPLOGSTORERESPONSE._serialized_start=1578
  _DROPLOGSTORERESPONSE._serialized_end=1646
  _ALTERLOGSTOREREQUEST._serialized_start=1649
  _ALTERLOGSTOREREQUEST._serialized_end=1949
  _ALTERLOGSTORERESPONSE._serialized_start=1951
  _ALTERLOGSTORERESPONSE._serialized_end=2020
  _CREATELOGTABLEREQUEST._serialized_start=2023
  _CREATELOGTABLEREQUEST._serialized_end=2473
  _CREATELOGTABLERESPONSE._serialized_start=2475
  _CREATELOGTABLERESPONSE._serialized_end=2545
  _DESCRIBELOGTABLEREQUEST._serialized_start=2547
  _DESCRIBELOGTABLEREQUEST._serialized_end=2645
  _DESCRIBELOGTABLERESULT._serialized_start=2648
  _DESCRIBELOGTABLERESULT._serialized_end=3031
  _DESCRIBELOGTABLERESPONSE._serialized_start=3033
  _DESCRIBELOGTABLERESPONSE._serialized_end=3105
  _DROPLOGTABLEREQUEST._serialized_start=3107
  _DROPLOGTABLEREQUEST._serialized_end=3201
  _DROPLOGTABLERESPONSE._serialized_start=3203
  _DROPLOGTABLERESPONSE._serialized_end=3271
  _ALTERLOGTABLEREQUEST._serialized_start=3274
  _ALTERLOGTABLEREQUEST._serialized_end=3551
  _ALTERLOGTABLERESPONSE._serialized_start=3553
  _ALTERLOGTABLERESPONSE._serialized_end=3622
# @@protoc_insertion_point(module_scope)
