# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/follower_group.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/follower_group.proto\x12\x0bNKikimrHive\"\xb0\x02\n\x0eTFollowerGroup\x12\x15\n\rFollowerCount\x18\x01 \x01(\r\x12\x1c\n\x14\x41llowLeaderPromotion\x18\x02 \x01(\x08\x12\x17\n\x0f\x41llowClientRead\x18\x03 \x01(\x08\x12\x16\n\x0e\x41llowedNodeIDs\x18\x04 \x03(\r\x12#\n\x17\x41llowedDataCenterNumIDs\x18\x05 \x03(\rB\x02\x18\x01\x12\x1d\n\x15RequireAllDataCenters\x18\x06 \x01(\x08\x12\x15\n\rLocalNodeOnly\x18\x07 \x01(\x08\x12\x1d\n\x15RequireDifferentNodes\x18\x08 \x01(\x08\x12\"\n\x1a\x46ollowerCountPerDataCenter\x18\t \x01(\x08\x12\x1a\n\x12\x41llowedDataCenters\x18\n \x03(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.follower_group_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TFOLLOWERGROUP.fields_by_name['AllowedDataCenterNumIDs']._options = None
  _TFOLLOWERGROUP.fields_by_name['AllowedDataCenterNumIDs']._serialized_options = b'\030\001'
  _TFOLLOWERGROUP._serialized_start=54
  _TFOLLOWERGROUP._serialized_end=358
# @@protoc_insertion_point(module_scope)
