# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import tx_proxy_pb2 as ydb_dot_core_dot_protos_dot_tx__proxy__pb2
from ydb.core.protos import scheme_log_pb2 as ydb_dot_core_dot_protos_dot_scheme__log__pb2
from ydb.library.mkql_proto.protos import minikql_pb2 as ydb_dot_library_dot_mkql__proto_dot_protos_dot_minikql__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fydb/core/protos/tablet_tx.proto\x12\x13NKikimrTabletTxBase\x1a\x1eydb/core/protos/tx_proxy.proto\x1a ydb/core/protos/scheme_log.proto\x1a+ydb/library/mkql_proto/protos/minikql.proto\"H\n\x0cTEvLocalMKQL\x12\x38\n\x07Program\x18\x01 \x01(\x0b\x32\'.NKikimrTxUserProxy.TMiniKQLTransaction\"\x88\x02\n\x14TEvLocalMKQLResponse\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x0e\n\x06Status\x18\x02 \x01(\x05\x12\x14\n\x0c\x45ngineStatus\x18\n \x01(\r\x12\x1c\n\x14\x45ngineResponseStatus\x18\x0b \x01(\r\x12\x15\n\rMiniKQLErrors\x18\x0c \x01(\x0c\x12\x41\n ExecutionEngineEvaluatedResponse\x18\r \x01(\x0b\x32\x17.NKikimrMiniKQL.TResult\x12\x42\n\x0e\x43ompileResults\x18\x0e \x01(\x0b\x32*.NKikimrTxUserProxy.TMiniKQLCompileResults\"\\\n\x10TEvLocalSchemeTx\x12\x38\n\rSchemeChanges\x18\x01 \x01(\x0b\x32!.NTabletFlatScheme.TSchemeChanges\x12\x0e\n\x06\x44ryRun\x18\x02 \x01(\x08\"\x86\x01\n\x18TEvLocalSchemeTxResponse\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x0e\n\x06Status\x18\x02 \x01(\x05\x12\x13\n\x0b\x45rrorReason\x18\x03 \x01(\t\x12\x35\n\nFullScheme\x18\x04 \x01(\x0b\x32!.NTabletFlatScheme.TSchemeChanges\"\xbe\x01\n\x13TEvLocalReadColumns\x12\x11\n\tTableName\x18\x01 \x01(\t\x12\x0f\n\x07\x43olumns\x18\x02 \x03(\t\x12\x0f\n\x07MaxRows\x18\x03 \x01(\x04\x12\x10\n\x08MaxBytes\x18\x04 \x01(\x04\x12\x0f\n\x07\x46romKey\x18\x05 \x01(\x0c\x12\x18\n\x10\x46romKeyInclusive\x18\x06 \x01(\x08\x12\r\n\x05ToKey\x18\x07 \x01(\x0c\x12\x16\n\x0eToKeyInclusive\x18\x08 \x01(\x08\x12\x0e\n\x06\x46ormat\x18\t \x01(\t\"\xa8\x01\n\x1bTEvLocalReadColumnsResponse\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x0e\n\x06Status\x18\x02 \x01(\r\x12\x18\n\x10\x45rrorDescription\x18\x03 \x01(\t\x12\x0e\n\x06\x42locks\x18\x04 \x01(\x0c\x12\x0f\n\x07LastKey\x18\x05 \x01(\x0c\x12\x18\n\x10LastKeyInclusive\x18\x06 \x01(\x08\x12\x12\n\nEndOfShard\x18\x07 \x01(\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVLOCALMKQL._serialized_start=167
  _TEVLOCALMKQL._serialized_end=239
  _TEVLOCALMKQLRESPONSE._serialized_start=242
  _TEVLOCALMKQLRESPONSE._serialized_end=506
  _TEVLOCALSCHEMETX._serialized_start=508
  _TEVLOCALSCHEMETX._serialized_end=600
  _TEVLOCALSCHEMETXRESPONSE._serialized_start=603
  _TEVLOCALSCHEMETXRESPONSE._serialized_end=737
  _TEVLOCALREADCOLUMNS._serialized_start=740
  _TEVLOCALREADCOLUMNS._serialized_end=930
  _TEVLOCALREADCOLUMNSRESPONSE._serialized_start=933
  _TEVLOCALREADCOLUMNSRESPONSE._serialized_end=1101
# @@protoc_insertion_point(module_scope)
