# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/draft/datastreams.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/public/api/protos/draft/datastreams.proto\x12\x12Ydb.DataStreams.V1\x1a)ydb/public/api/protos/ydb_operation.proto\x1a google/protobuf/descriptor.proto\".\n\x0f\x45nhancedMetrics\x12\x1b\n\x13shard_level_metrics\x18\x01 \x03(\t\"k\n\nChildShard\x12\x38\n\x0ehash_key_range\x18\x01 \x01(\x0b\x32 .Ydb.DataStreams.V1.HashKeyRange\x12\x15\n\rparent_shards\x18\x02 \x03(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xb3\x01\n\x08\x43onsumer\x12\x14\n\x0c\x63onsumer_arn\x18\x01 \x01(\t\x12)\n\x1b\x63onsumer_creation_timestamp\x18\x02 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\x12\x15\n\rconsumer_name\x18\x03 \x01(\t\x12O\n\x0f\x63onsumer_status\x18\x04 \x01(\x0e\x32\x36.Ydb.DataStreams.V1.ConsumerDescription.ConsumerStatus\"B\n\x0cHashKeyRange\x12\x19\n\x11starting_hash_key\x18\x01 \x01(\t\x12\x17\n\x0f\x65nding_hash_key\x18\x02 \x01(\t\"\xac\x01\n\x06Record\x12\x17\n\ttimestamp\x18\x01 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x04\xd8\xb0\x1c\x01\x12\x36\n\nencryption\x18\x03 \x01(\x0e\x32\".Ydb.DataStreams.V1.EncryptionType\x12\x15\n\rpartition_key\x18\x04 \x01(\t\x12\x17\n\x0fsequence_number\x18\x05 \x01(\t\x12\r\n\x05\x63odec\x18\x06 \x01(\x05\"\x8c\x05\n\x11StreamDescription\x12;\n\x0f\x65ncryption_type\x18\x01 \x01(\x0e\x32\".Ydb.DataStreams.V1.EncryptionType\x12@\n\x13\x65nhanced_monitoring\x18\x02 \x03(\x0b\x32#.Ydb.DataStreams.V1.EnhancedMetrics\x12\x17\n\x0fhas_more_shards\x18\x03 \x01(\x08\x12\x0e\n\x06key_id\x18\x04 \x01(\t\x12\x1e\n\x16retention_period_hours\x18\x05 \x01(\x05\x12)\n\x06shards\x18\x06 \x03(\x0b\x32\x19.Ydb.DataStreams.V1.Shard\x12\x12\n\nstream_arn\x18\x07 \x01(\t\x12\'\n\x19stream_creation_timestamp\x18\x08 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\x12I\n\rstream_status\x18\t \x01(\x0e\x32\x32.Ydb.DataStreams.V1.StreamDescription.StreamStatus\x12\x13\n\x0bstream_name\x18\n \x01(\t\x12\x1e\n\x16write_quota_kb_per_sec\x18\x0b \x01(\x05\x12\r\n\x05owner\x18\x0c \x01(\t\x12\x18\n\x10storage_limit_mb\x18\r \x01(\x03\x12\x42\n\x13stream_mode_details\x18\x0e \x01(\x0b\x32%.Ydb.DataStreams.V1.StreamModeDetails\"Z\n\x0cStreamStatus\x12\x14\n\x10STATUS_UNDEFINED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08\x44\x45LETING\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\x12\x0c\n\x08UPDATING\x10\x04\"]\n\x13SequenceNumberRange\x12 \n\x18starting_sequence_number\x18\x01 \x01(\t\x12$\n\x16\x65nding_sequence_number\x18\x02 \x01(\tB\x04\xd8\xb0\x1c\x03\"\xe2\x01\n\x05Shard\x12&\n\x18\x61\x64jacent_parent_shard_id\x18\x01 \x01(\tB\x04\xd8\xb0\x1c\x03\x12\x38\n\x0ehash_key_range\x18\x02 \x01(\x0b\x32 .Ydb.DataStreams.V1.HashKeyRange\x12\x1d\n\x0fparent_shard_id\x18\x03 \x01(\tB\x04\xd8\xb0\x1c\x03\x12\x46\n\x15sequence_number_range\x18\x04 \x01(\x0b\x32\'.Ydb.DataStreams.V1.SequenceNumberRange\x12\x10\n\x08shard_id\x18\x05 \x01(\t\"\xa0\x02\n\x13\x43onsumerDescription\x12\x14\n\x0c\x63onsumer_arn\x18\x01 \x01(\t\x12)\n\x1b\x63onsumer_creation_timestamp\x18\x02 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\x12\x15\n\rconsumer_name\x18\x03 \x01(\t\x12O\n\x0f\x63onsumer_status\x18\x04 \x01(\x0e\x32\x36.Ydb.DataStreams.V1.ConsumerDescription.ConsumerStatus\x12\x12\n\nstream_arn\x18\x05 \x01(\t\"L\n\x0e\x43onsumerStatus\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\x0c\n\x08\x44\x45LETING\x10\x02\x12\n\n\x06\x41\x43TIVE\x10\x03\"\x9a\x02\n\x0bShardFilter\x12\x10\n\x08shard_id\x18\x01 \x01(\t\x12\x17\n\ttimestamp\x18\x02 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\x12=\n\x04type\x18\x03 \x01(\x0e\x32/.Ydb.DataStreams.V1.ShardFilter.ShardFilterType\"\xa0\x01\n\x0fShardFilterType\x12\x18\n\x14SHARD_TYPE_UNDEFINED\x10\x00\x12\x12\n\x0e\x41\x46TER_SHARD_ID\x10\x01\x12\x13\n\x0f\x41T_TRIM_HORIZON\x10\x02\x12\x15\n\x11\x46ROM_TRIM_HORIZON\x10\x03\x12\r\n\tAT_LATEST\x10\x04\x12\x10\n\x0c\x41T_TIMESTAMP\x10\x05\x12\x12\n\x0e\x46ROM_TIMESTAMP\x10\x06\"y\n\x10StartingPosition\x12\x17\n\ttimestamp\x18\x01 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\x12\x17\n\x0fsequence_number\x18\x02 \x01(\t\x12\x33\n\x04type\x18\x03 \x01(\x0e\x32%.Ydb.DataStreams.V1.ShardIteratorType\"\x98\x03\n\x18StreamDescriptionSummary\x12\x16\n\x0e\x63onsumer_count\x18\x01 \x01(\x05\x12;\n\x0f\x65ncryption_type\x18\x02 \x01(\x0e\x32\".Ydb.DataStreams.V1.EncryptionType\x12@\n\x13\x65nhanced_monitoring\x18\x03 \x03(\x0b\x32#.Ydb.DataStreams.V1.EnhancedMetrics\x12\x0e\n\x06key_id\x18\x04 \x01(\t\x12\x18\n\x10open_shard_count\x18\x05 \x01(\x05\x12\x1e\n\x16retention_period_hours\x18\x06 \x01(\x05\x12\x12\n\nstream_arn\x18\x07 \x01(\t\x12\'\n\x19stream_creation_timestamp\x18\x08 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\x12\x13\n\x0bstream_name\x18\t \x01(\t\x12I\n\rstream_status\x18\n \x01(\x0e\x32\x32.Ydb.DataStreams.V1.StreamDescription.StreamStatus\"\xbe\x01\n\x15SubscribeToShardEvent\x12\x34\n\x0c\x63hild_shards\x18\x01 \x03(\x0b\x32\x1e.Ydb.DataStreams.V1.ChildShard\x12$\n\x1c\x63ontinuation_sequence_number\x18\x02 \x01(\t\x12\x1c\n\x14millis_behind_latest\x18\x03 \x01(\x05\x12+\n\x07records\x18\x04 \x03(\x0b\x32\x1a.Ydb.DataStreams.V1.Record\"\x90\x08\n\x1bSubscribeToShardEventStream\x12\x64\n\x1ainternal_failure_exception\x18\x01 \x01(\x0b\x32>.Ydb.DataStreams.V1.SubscribeToShardEventStream.ExceptionEventH\x00\x12\x65\n\x1bkms_access_denied_exception\x18\x02 \x01(\x0b\x32>.Ydb.DataStreams.V1.SubscribeToShardEventStream.ExceptionEventH\x00\x12`\n\x16kms_disabled_exception\x18\x03 \x01(\x0b\x32>.Ydb.DataStreams.V1.SubscribeToShardEventStream.ExceptionEventH\x00\x12\x65\n\x1bkms_invalid_state_exception\x18\x04 \x01(\x0b\x32>.Ydb.DataStreams.V1.SubscribeToShardEventStream.ExceptionEventH\x00\x12\x61\n\x17kms_not_found_exception\x18\x05 \x01(\x0b\x32>.Ydb.DataStreams.V1.SubscribeToShardEventStream.ExceptionEventH\x00\x12]\n\x13kms_opt_in_required\x18\x06 \x01(\x0b\x32>.Ydb.DataStreams.V1.SubscribeToShardEventStream.ExceptionEventH\x00\x12\x62\n\x18kms_throttling_exception\x18\x07 \x01(\x0b\x32>.Ydb.DataStreams.V1.SubscribeToShardEventStream.ExceptionEventH\x00\x12\x63\n\x19resource_in_use_exception\x18\x08 \x01(\x0b\x32>.Ydb.DataStreams.V1.SubscribeToShardEventStream.ExceptionEventH\x00\x12\x66\n\x1cresource_not_found_exception\x18\t \x01(\x0b\x32>.Ydb.DataStreams.V1.SubscribeToShardEventStream.ExceptionEventH\x00\x12M\n\x18subscribe_to_shard_event\x18\n \x01(\x0b\x32).Ydb.DataStreams.V1.SubscribeToShardEventH\x00\x1a\x10\n\x0e\x45xceptionEventB\x07\n\x05\x65vent\"!\n\x03Tag\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"H\n\x11StreamModeDetails\x12\x33\n\x0bstream_mode\x18\x01 \x01(\x0e\x32\x1e.Ydb.DataStreams.V1.StreamMode\"\xb4\x02\n\x13\x43reateStreamRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x12\x13\n\x0bshard_count\x18\x03 \x01(\x05\x12\x1e\n\x16write_quota_kb_per_sec\x18\x04 \x01(\x05\x12 \n\x16retention_period_hours\x18\x05 \x01(\x05H\x00\x12%\n\x1bretention_storage_megabytes\x18\x06 \x01(\x05H\x00\x12\x42\n\x13stream_mode_details\x18\x07 \x01(\x0b\x32%.Ydb.DataStreams.V1.StreamModeDetailsB\x0b\n\tretention\"D\n\x14\x43reateStreamResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x43reateStreamResult\"\x88\x01\n\x13\x44\x65leteStreamRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12!\n\x19\x65nforce_consumer_deletion\x18\x02 \x01(\x08\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"D\n\x14\x44\x65leteStreamResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x44\x65leteStreamResult\"\x94\x01\n\x12ListStreamsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12#\n\x1b\x65xclusive_start_stream_name\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x0f\n\x07recurse\x18\x04 \x01(\x08\"C\n\x13ListStreamsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"C\n\x11ListStreamsResult\x12\x18\n\x10has_more_streams\x18\x01 \x01(\x08\x12\x14\n\x0cstream_names\x18\x02 \x03(\t\"\x8e\x02\n\x11ListShardsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12 \n\x18\x65xclusive_start_shard_id\x18\x02 \x01(\t\x12\x13\n\x0bmax_results\x18\x03 \x01(\x05\x12\x12\n\nnext_token\x18\x04 \x01(\t\x12\x35\n\x0cshard_filter\x18\x05 \x01(\x0b\x32\x1f.Ydb.DataStreams.V1.ShardFilter\x12\'\n\x19stream_creation_timestamp\x18\x06 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\x12\x13\n\x0bstream_name\x18\x07 \x01(\t\"B\n\x12ListShardsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Q\n\x10ListShardsResult\x12\x12\n\nnext_token\x18\x01 \x01(\t\x12)\n\x06shards\x18\x02 \x03(\x0b\x32\x19.Ydb.DataStreams.V1.Shard\"\x86\x01\n\x14SetWriteQuotaRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x12\x1e\n\x16write_quota_kb_per_sec\x18\x03 \x01(\x05\"E\n\x15SetWriteQuotaResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13SetWriteQuotaResult\"\xbb\x02\n\x13UpdateStreamRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x12\x1e\n\x16write_quota_kb_per_sec\x18\x03 \x01(\x05\x12\x1a\n\x12target_shard_count\x18\x04 \x01(\x05\x12 \n\x16retention_period_hours\x18\x05 \x01(\x05H\x00\x12%\n\x1bretention_storage_megabytes\x18\x06 \x01(\x05H\x00\x12\x42\n\x13stream_mode_details\x18\x07 \x01(\x0b\x32%.Ydb.DataStreams.V1.StreamModeDetailsB\x0b\n\tretention\"D\n\x14UpdateStreamResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12UpdateStreamResult\"\xbd\x01\n\x1aListStreamConsumersRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x13\n\x0bmax_results\x18\x02 \x01(\x05\x12\x12\n\nnext_token\x18\x03 \x01(\t\x12\x12\n\nstream_arn\x18\x04 \x01(\t\x12\'\n\x19stream_creation_timestamp\x18\x05 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\"K\n\x1bListStreamConsumersResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"`\n\x19ListStreamConsumersResult\x12\x12\n\nnext_token\x18\x01 \x01(\t\x12/\n\tconsumers\x18\x02 \x03(\x0b\x32\x1c.Ydb.DataStreams.V1.Consumer\"\x98\x01\n\x15\x44\x65scribeStreamRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12 \n\x18\x65xclusive_start_shard_id\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"F\n\x16\x44\x65scribeStreamResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"Y\n\x14\x44\x65scribeStreamResult\x12\x41\n\x12stream_description\x18\x01 \x01(\x0b\x32%.Ydb.DataStreams.V1.StreamDescription\"\x85\x01\n\x1dRegisterStreamConsumerRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x15\n\rconsumer_name\x18\x02 \x01(\t\x12\x12\n\nstream_arn\x18\x03 \x01(\t\"N\n\x1eRegisterStreamConsumerResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"N\n\x1cRegisterStreamConsumerResult\x12.\n\x08\x63onsumer\x18\x01 \x01(\x0b\x32\x1c.Ydb.DataStreams.V1.Consumer\"\x9d\x01\n\x1f\x44\x65registerStreamConsumerRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x14\n\x0c\x63onsumer_arn\x18\x02 \x01(\t\x12\x15\n\rconsumer_name\x18\x03 \x01(\t\x12\x12\n\nstream_arn\x18\x04 \x01(\t\"P\n DeregisterStreamConsumerResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\" \n\x1e\x44\x65registerStreamConsumerResult\"\x9b\x01\n\x1d\x44\x65scribeStreamConsumerRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x14\n\x0c\x63onsumer_arn\x18\x02 \x01(\t\x12\x15\n\rconsumer_name\x18\x03 \x01(\t\x12\x12\n\nstream_arn\x18\x04 \x01(\t\"N\n\x1e\x44\x65scribeStreamConsumerResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"e\n\x1c\x44\x65scribeStreamConsumerResult\x12\x45\n\x14\x63onsumer_description\x18\x01 \x01(\x0b\x32\'.Ydb.DataStreams.V1.ConsumerDescription\"^\n\x16PutRecordsRequestEntry\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x42\x04\xd8\xb0\x1c\x01\x12\x19\n\x11\x65xplicit_hash_key\x18\x02 \x01(\t\x12\x15\n\rpartition_key\x18\x03 \x01(\t\"y\n\x15PutRecordsResultEntry\x12\x1b\n\rerror_message\x18\x02 \x01(\tB\x04\xd8\xb0\x1c\x03\x12\x18\n\nerror_code\x18\x03 \x01(\tB\x04\xd8\xb0\x1c\x03\x12\x17\n\x0fsequence_number\x18\x04 \x01(\t\x12\x10\n\x08shard_id\x18\x05 \x01(\t\"u\n\x11GetRecordsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\r\n\x05limit\x18\x02 \x01(\x05\x12\x16\n\x0eshard_iterator\x18\x03 \x01(\t\"B\n\x12GetRecordsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xb0\x01\n\x10GetRecordsResult\x12\x34\n\x0c\x63hild_shards\x18\x01 \x03(\x0b\x32\x1e.Ydb.DataStreams.V1.ChildShard\x12\x1c\n\x14millis_behind_latest\x18\x02 \x01(\x03\x12\x1b\n\x13next_shard_iterator\x18\x03 \x01(\t\x12+\n\x07records\x18\x04 \x03(\x0b\x32\x1a.Ydb.DataStreams.V1.Record\"\xce\x01\n\x10PutRecordRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x42\x04\xd8\xb0\x1c\x01\x12\x19\n\x11\x65xplicit_hash_key\x18\x03 \x01(\t\x12\x15\n\rpartition_key\x18\x04 \x01(\t\x12$\n\x1csequence_number_for_ordering\x18\x05 \x01(\t\x12\x13\n\x0bstream_name\x18\x06 \x01(\t\"A\n\x11PutRecordResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"y\n\x0fPutRecordResult\x12;\n\x0f\x65ncryption_type\x18\x01 \x01(\x0e\x32\".Ydb.DataStreams.V1.EncryptionType\x12\x17\n\x0fsequence_number\x18\x02 \x01(\t\x12\x10\n\x08shard_id\x18\x03 \x01(\t\"\xa0\x01\n\x11PutRecordsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\x07records\x18\x02 \x03(\x0b\x32*.Ydb.DataStreams.V1.PutRecordsRequestEntry\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"B\n\x12PutRecordsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\xa8\x01\n\x10PutRecordsResult\x12;\n\x0f\x65ncryption_type\x18\x01 \x01(\x0e\x32\".Ydb.DataStreams.V1.EncryptionType\x12\x1b\n\x13\x66\x61iled_record_count\x18\x02 \x01(\x05\x12:\n\x07records\x18\x03 \x03(\x0b\x32).Ydb.DataStreams.V1.PutRecordsResultEntry\"\xfa\x01\n\x17GetShardIteratorRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x10\n\x08shard_id\x18\x02 \x01(\t\x12\x42\n\x13shard_iterator_type\x18\x03 \x01(\x0e\x32%.Ydb.DataStreams.V1.ShardIteratorType\x12 \n\x18starting_sequence_number\x18\x04 \x01(\t\x12\x13\n\x0bstream_name\x18\x05 \x01(\t\x12\x17\n\ttimestamp\x18\x06 \x01(\x03\x42\x04\xd8\xb0\x1c\x02\"H\n\x18GetShardIteratorResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"0\n\x16GetShardIteratorResult\x12\x16\n\x0eshard_iterator\x18\x01 \x01(\t\"\xbd\x01\n\x17SubscribeToShardRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x14\n\x0c\x63onsumer_arn\x18\x02 \x01(\t\x12\x10\n\x08shard_id\x18\x03 \x01(\t\x12?\n\x11starting_position\x18\x04 \x01(\x0b\x32$.Ydb.DataStreams.V1.StartingPosition\"H\n\x18SubscribeToShardResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"_\n\x16SubscribeToShardResult\x12\x45\n\x0c\x65vent_stream\x18\x01 \x01(\x0b\x32/.Ydb.DataStreams.V1.SubscribeToShardEventStream\"v\n\x16\x41\x64\x64TagsToStreamRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\"G\n\x17\x41\x64\x64TagsToStreamResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x17\n\x15\x41\x64\x64TagsToStreamResult\"\x96\x01\n$DecreaseStreamRetentionPeriodRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x12\x1e\n\x16retention_period_hours\x18\x03 \x01(\x05\"U\n%DecreaseStreamRetentionPeriodResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"%\n#DecreaseStreamRetentionPeriodResult\"R\n\x15\x44\x65scribeLimitsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\"F\n\x16\x44\x65scribeLimitsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"E\n\x14\x44\x65scribeLimitsResult\x12\x18\n\x10open_shard_count\x18\x01 \x01(\x05\x12\x13\n\x0bshard_limit\x18\x02 \x01(\x05\"n\n\x1c\x44\x65scribeStreamSummaryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\"M\n\x1d\x44\x65scribeStreamSummaryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"o\n\x1b\x44\x65scribeStreamSummaryResult\x12P\n\x1astream_description_summary\x18\x01 \x01(\x0b\x32,.Ydb.DataStreams.V1.StreamDescriptionSummary\"\x8f\x01\n DisableEnhancedMonitoringRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\x13shard_level_metrics\x18\x02 \x03(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"Q\n!DisableEnhancedMonitoringResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x80\x01\n\x1f\x44isableEnhancedMonitoringResult\x12#\n\x1b\x63urrent_shard_level_metrics\x18\x01 \x03(\t\x12#\n\x1b\x64\x65sired_shard_level_metrics\x18\x02 \x03(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"\x8e\x01\n\x1f\x45nableEnhancedMonitoringRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\x13shard_level_metrics\x18\x02 \x03(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"P\n EnableEnhancedMonitoringResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x7f\n\x1e\x45nableEnhancedMonitoringResult\x12#\n\x1b\x63urrent_shard_level_metrics\x18\x01 \x03(\t\x12#\n\x1b\x64\x65sired_shard_level_metrics\x18\x02 \x03(\t\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"\x96\x01\n$IncreaseStreamRetentionPeriodRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1e\n\x16retention_period_hours\x18\x02 \x01(\x05\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\"U\n%IncreaseStreamRetentionPeriodResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"%\n#IncreaseStreamRetentionPeriodResult\"\x9a\x01\n\x18ListTagsForStreamRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\x17\x65xclusive_start_tag_key\x18\x02 \x01(\t\x12\r\n\x05limit\x18\x03 \x01(\x05\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"I\n\x19ListTagsForStreamResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"W\n\x17ListTagsForStreamResult\x12\x15\n\rhas_more_tags\x18\x01 \x01(\x08\x12%\n\x04tags\x18\x02 \x03(\x0b\x32\x17.Ydb.DataStreams.V1.Tag\"\x9d\x01\n\x12MergeShardsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\x17\x61\x64jacent_shard_to_merge\x18\x02 \x01(\t\x12\x16\n\x0eshard_to_merge\x18\x03 \x01(\t\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"C\n\x13MergeShardsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11MergeShardsResult\"\x7f\n\x1bRemoveTagsFromStreamRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x12\x10\n\x08tag_keys\x18\x03 \x03(\t\"L\n\x1cRemoveTagsFromStreamResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x1c\n\x1aRemoveTagsFromStreamResult\"\x9a\x01\n\x11SplitShardRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x15new_starting_hash_key\x18\x02 \x01(\t\x12\x16\n\x0eshard_to_split\x18\x03 \x01(\t\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"B\n\x12SplitShardResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x12\n\x10SplitShardResult\"\xbb\x01\n\x1cStartStreamEncryptionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\x0f\x65ncryption_type\x18\x02 \x01(\x0e\x32\".Ydb.DataStreams.V1.EncryptionType\x12\x0e\n\x06key_id\x18\x03 \x01(\t\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"M\n\x1dStartStreamEncryptionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x1d\n\x1bStartStreamEncryptionResult\"\xba\x01\n\x1bStopStreamEncryptionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12;\n\x0f\x65ncryption_type\x18\x02 \x01(\x0e\x32\".Ydb.DataStreams.V1.EncryptionType\x12\x0e\n\x06key_id\x18\x03 \x01(\t\x12\x13\n\x0bstream_name\x18\x04 \x01(\t\"L\n\x1cStopStreamEncryptionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x1c\n\x1aStopStreamEncryptionResult\"\x92\x02\n\x17UpdateShardCountRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12M\n\x0cscaling_type\x18\x02 \x01(\x0e\x32\x37.Ydb.DataStreams.V1.UpdateShardCountRequest.ScalingType\x12\x13\n\x0bstream_name\x18\x03 \x01(\t\x12\x1a\n\x12target_shard_count\x18\x04 \x01(\x05\"<\n\x0bScalingType\x12\x18\n\x14SCALING_TYPE_UNKNOWN\x10\x00\x12\x13\n\x0fUNIFORM_SCALING\x10\x01\"H\n\x18UpdateShardCountResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"f\n\x16UpdateShardCountResult\x12\x1b\n\x13\x63urrent_shard_count\x18\x01 \x01(\x05\x12\x13\n\x0bstream_name\x18\x02 \x01(\t\x12\x1a\n\x12target_shard_count\x18\x03 \x01(\x05\"\xac\x01\n\x17UpdateStreamModeRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\nstream_arn\x18\x02 \x01(\t\x12\x42\n\x13stream_mode_details\x18\x03 \x01(\x0b\x32%.Ydb.DataStreams.V1.StreamModeDetails\"H\n\x18UpdateStreamModeResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x18\n\x16UpdateStreamModeResult*\x86\x01\n\x18\x45\x46ieldTransformationType\x12\x12\n\x0eTRANSFORM_NONE\x10\x00\x12\x14\n\x10TRANSFORM_BASE64\x10\x01\x12 \n\x1cTRANSFORM_DOUBLE_S_TO_INT_MS\x10\x02\x12\x1e\n\x1aTRANSFORM_EMPTY_TO_NOTHING\x10\x03*=\n\x0e\x45ncryptionType\x12\x18\n\x14\x45NCRYPTION_UNDEFINED\x10\x00\x12\x08\n\x04NONE\x10\x01\x12\x07\n\x03KMS\x10\x02*G\n\nStreamMode\x12\x19\n\x15STREAM_MODE_UNDEFINED\x10\x00\x12\x0f\n\x0bPROVISIONED\x10\x01\x12\r\n\tON_DEMAND\x10\x02*\x94\x01\n\x11ShardIteratorType\x12\x1c\n\x18SHARD_ITERATOR_UNDEFINED\x10\x00\x12\x16\n\x12\x41T_SEQUENCE_NUMBER\x10\x01\x12\x19\n\x15\x41\x46TER_SEQUENCE_NUMBER\x10\x02\x12\x10\n\x0c\x41T_TIMESTAMP\x10\x03\x12\x10\n\x0cTRIM_HORIZON\x10\x04\x12\n\n\x06LATEST\x10\x05:g\n\x10\x46ieldTransformer\x12\x1d.google.protobuf.FieldOptions\x18\x8b\xc6\x03 \x01(\x0e\x32,.Ydb.DataStreams.V1.EFieldTransformationTypeB\"\n\x1d\x63om.yandex.ydb.datastreams.v1\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.draft.datastreams_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(FieldTransformer)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\035com.yandex.ydb.datastreams.v1\370\001\001'
  _CONSUMER.fields_by_name['consumer_creation_timestamp']._options = None
  _CONSUMER.fields_by_name['consumer_creation_timestamp']._serialized_options = b'\330\260\034\002'
  _RECORD.fields_by_name['timestamp']._options = None
  _RECORD.fields_by_name['timestamp']._serialized_options = b'\330\260\034\002'
  _RECORD.fields_by_name['data']._options = None
  _RECORD.fields_by_name['data']._serialized_options = b'\330\260\034\001'
  _STREAMDESCRIPTION.fields_by_name['stream_creation_timestamp']._options = None
  _STREAMDESCRIPTION.fields_by_name['stream_creation_timestamp']._serialized_options = b'\330\260\034\002'
  _SEQUENCENUMBERRANGE.fields_by_name['ending_sequence_number']._options = None
  _SEQUENCENUMBERRANGE.fields_by_name['ending_sequence_number']._serialized_options = b'\330\260\034\003'
  _SHARD.fields_by_name['adjacent_parent_shard_id']._options = None
  _SHARD.fields_by_name['adjacent_parent_shard_id']._serialized_options = b'\330\260\034\003'
  _SHARD.fields_by_name['parent_shard_id']._options = None
  _SHARD.fields_by_name['parent_shard_id']._serialized_options = b'\330\260\034\003'
  _CONSUMERDESCRIPTION.fields_by_name['consumer_creation_timestamp']._options = None
  _CONSUMERDESCRIPTION.fields_by_name['consumer_creation_timestamp']._serialized_options = b'\330\260\034\002'
  _SHARDFILTER.fields_by_name['timestamp']._options = None
  _SHARDFILTER.fields_by_name['timestamp']._serialized_options = b'\330\260\034\002'
  _STARTINGPOSITION.fields_by_name['timestamp']._options = None
  _STARTINGPOSITION.fields_by_name['timestamp']._serialized_options = b'\330\260\034\002'
  _STREAMDESCRIPTIONSUMMARY.fields_by_name['stream_creation_timestamp']._options = None
  _STREAMDESCRIPTIONSUMMARY.fields_by_name['stream_creation_timestamp']._serialized_options = b'\330\260\034\002'
  _LISTSHARDSREQUEST.fields_by_name['stream_creation_timestamp']._options = None
  _LISTSHARDSREQUEST.fields_by_name['stream_creation_timestamp']._serialized_options = b'\330\260\034\002'
  _LISTSTREAMCONSUMERSREQUEST.fields_by_name['stream_creation_timestamp']._options = None
  _LISTSTREAMCONSUMERSREQUEST.fields_by_name['stream_creation_timestamp']._serialized_options = b'\330\260\034\002'
  _PUTRECORDSREQUESTENTRY.fields_by_name['data']._options = None
  _PUTRECORDSREQUESTENTRY.fields_by_name['data']._serialized_options = b'\330\260\034\001'
  _PUTRECORDSRESULTENTRY.fields_by_name['error_message']._options = None
  _PUTRECORDSRESULTENTRY.fields_by_name['error_message']._serialized_options = b'\330\260\034\003'
  _PUTRECORDSRESULTENTRY.fields_by_name['error_code']._options = None
  _PUTRECORDSRESULTENTRY.fields_by_name['error_code']._serialized_options = b'\330\260\034\003'
  _PUTRECORDREQUEST.fields_by_name['data']._options = None
  _PUTRECORDREQUEST.fields_by_name['data']._serialized_options = b'\330\260\034\001'
  _GETSHARDITERATORREQUEST.fields_by_name['timestamp']._options = None
  _GETSHARDITERATORREQUEST.fields_by_name['timestamp']._serialized_options = b'\330\260\034\002'
  _EFIELDTRANSFORMATIONTYPE._serialized_start=14278
  _EFIELDTRANSFORMATIONTYPE._serialized_end=14412
  _ENCRYPTIONTYPE._serialized_start=14414
  _ENCRYPTIONTYPE._serialized_end=14475
  _STREAMMODE._serialized_start=14477
  _STREAMMODE._serialized_end=14548
  _SHARDITERATORTYPE._serialized_start=14551
  _SHARDITERATORTYPE._serialized_end=14699
  _ENHANCEDMETRICS._serialized_start=146
  _ENHANCEDMETRICS._serialized_end=192
  _CHILDSHARD._serialized_start=194
  _CHILDSHARD._serialized_end=301
  _CONSUMER._serialized_start=304
  _CONSUMER._serialized_end=483
  _HASHKEYRANGE._serialized_start=485
  _HASHKEYRANGE._serialized_end=551
  _RECORD._serialized_start=554
  _RECORD._serialized_end=726
  _STREAMDESCRIPTION._serialized_start=729
  _STREAMDESCRIPTION._serialized_end=1381
  _STREAMDESCRIPTION_STREAMSTATUS._serialized_start=1291
  _STREAMDESCRIPTION_STREAMSTATUS._serialized_end=1381
  _SEQUENCENUMBERRANGE._serialized_start=1383
  _SEQUENCENUMBERRANGE._serialized_end=1476
  _SHARD._serialized_start=1479
  _SHARD._serialized_end=1705
  _CONSUMERDESCRIPTION._serialized_start=1708
  _CONSUMERDESCRIPTION._serialized_end=1996
  _CONSUMERDESCRIPTION_CONSUMERSTATUS._serialized_start=1920
  _CONSUMERDESCRIPTION_CONSUMERSTATUS._serialized_end=1996
  _SHARDFILTER._serialized_start=1999
  _SHARDFILTER._serialized_end=2281
  _SHARDFILTER_SHARDFILTERTYPE._serialized_start=2121
  _SHARDFILTER_SHARDFILTERTYPE._serialized_end=2281
  _STARTINGPOSITION._serialized_start=2283
  _STARTINGPOSITION._serialized_end=2404
  _STREAMDESCRIPTIONSUMMARY._serialized_start=2407
  _STREAMDESCRIPTIONSUMMARY._serialized_end=2815
  _SUBSCRIBETOSHARDEVENT._serialized_start=2818
  _SUBSCRIBETOSHARDEVENT._serialized_end=3008
  _SUBSCRIBETOSHARDEVENTSTREAM._serialized_start=3011
  _SUBSCRIBETOSHARDEVENTSTREAM._serialized_end=4051
  _SUBSCRIBETOSHARDEVENTSTREAM_EXCEPTIONEVENT._serialized_start=4026
  _SUBSCRIBETOSHARDEVENTSTREAM_EXCEPTIONEVENT._serialized_end=4042
  _TAG._serialized_start=4053
  _TAG._serialized_end=4086
  _STREAMMODEDETAILS._serialized_start=4088
  _STREAMMODEDETAILS._serialized_end=4160
  _CREATESTREAMREQUEST._serialized_start=4163
  _CREATESTREAMREQUEST._serialized_end=4471
  _CREATESTREAMRESPONSE._serialized_start=4473
  _CREATESTREAMRESPONSE._serialized_end=4541
  _CREATESTREAMRESULT._serialized_start=4543
  _CREATESTREAMRESULT._serialized_end=4563
  _DELETESTREAMREQUEST._serialized_start=4566
  _DELETESTREAMREQUEST._serialized_end=4702
  _DELETESTREAMRESPONSE._serialized_start=4704
  _DELETESTREAMRESPONSE._serialized_end=4772
  _DELETESTREAMRESULT._serialized_start=4774
  _DELETESTREAMRESULT._serialized_end=4794
  _LISTSTREAMSREQUEST._serialized_start=4797
  _LISTSTREAMSREQUEST._serialized_end=4945
  _LISTSTREAMSRESPONSE._serialized_start=4947
  _LISTSTREAMSRESPONSE._serialized_end=5014
  _LISTSTREAMSRESULT._serialized_start=5016
  _LISTSTREAMSRESULT._serialized_end=5083
  _LISTSHARDSREQUEST._serialized_start=5086
  _LISTSHARDSREQUEST._serialized_end=5356
  _LISTSHARDSRESPONSE._serialized_start=5358
  _LISTSHARDSRESPONSE._serialized_end=5424
  _LISTSHARDSRESULT._serialized_start=5426
  _LISTSHARDSRESULT._serialized_end=5507
  _SETWRITEQUOTAREQUEST._serialized_start=5510
  _SETWRITEQUOTAREQUEST._serialized_end=5644
  _SETWRITEQUOTARESPONSE._serialized_start=5646
  _SETWRITEQUOTARESPONSE._serialized_end=5715
  _SETWRITEQUOTARESULT._serialized_start=5717
  _SETWRITEQUOTARESULT._serialized_end=5738
  _UPDATESTREAMREQUEST._serialized_start=5741
  _UPDATESTREAMREQUEST._serialized_end=6056
  _UPDATESTREAMRESPONSE._serialized_start=6058
  _UPDATESTREAMRESPONSE._serialized_end=6126
  _UPDATESTREAMRESULT._serialized_start=6128
  _UPDATESTREAMRESULT._serialized_end=6148
  _LISTSTREAMCONSUMERSREQUEST._serialized_start=6151
  _LISTSTREAMCONSUMERSREQUEST._serialized_end=6340
  _LISTSTREAMCONSUMERSRESPONSE._serialized_start=6342
  _LISTSTREAMCONSUMERSRESPONSE._serialized_end=6417
  _LISTSTREAMCONSUMERSRESULT._serialized_start=6419
  _LISTSTREAMCONSUMERSRESULT._serialized_end=6515
  _DESCRIBESTREAMREQUEST._serialized_start=6518
  _DESCRIBESTREAMREQUEST._serialized_end=6670
  _DESCRIBESTREAMRESPONSE._serialized_start=6672
  _DESCRIBESTREAMRESPONSE._serialized_end=6742
  _DESCRIBESTREAMRESULT._serialized_start=6744
  _DESCRIBESTREAMRESULT._serialized_end=6833
  _REGISTERSTREAMCONSUMERREQUEST._serialized_start=6836
  _REGISTERSTREAMCONSUMERREQUEST._serialized_end=6969
  _REGISTERSTREAMCONSUMERRESPONSE._serialized_start=6971
  _REGISTERSTREAMCONSUMERRESPONSE._serialized_end=7049
  _REGISTERSTREAMCONSUMERRESULT._serialized_start=7051
  _REGISTERSTREAMCONSUMERRESULT._serialized_end=7129
  _DEREGISTERSTREAMCONSUMERREQUEST._serialized_start=7132
  _DEREGISTERSTREAMCONSUMERREQUEST._serialized_end=7289
  _DEREGISTERSTREAMCONSUMERRESPONSE._serialized_start=7291
  _DEREGISTERSTREAMCONSUMERRESPONSE._serialized_end=7371
  _DEREGISTERSTREAMCONSUMERRESULT._serialized_start=7373
  _DEREGISTERSTREAMCONSUMERRESULT._serialized_end=7405
  _DESCRIBESTREAMCONSUMERREQUEST._serialized_start=7408
  _DESCRIBESTREAMCONSUMERREQUEST._serialized_end=7563
  _DESCRIBESTREAMCONSUMERRESPONSE._serialized_start=7565
  _DESCRIBESTREAMCONSUMERRESPONSE._serialized_end=7643
  _DESCRIBESTREAMCONSUMERRESULT._serialized_start=7645
  _DESCRIBESTREAMCONSUMERRESULT._serialized_end=7746
  _PUTRECORDSREQUESTENTRY._serialized_start=7748
  _PUTRECORDSREQUESTENTRY._serialized_end=7842
  _PUTRECORDSRESULTENTRY._serialized_start=7844
  _PUTRECORDSRESULTENTRY._serialized_end=7965
  _GETRECORDSREQUEST._serialized_start=7967
  _GETRECORDSREQUEST._serialized_end=8084
  _GETRECORDSRESPONSE._serialized_start=8086
  _GETRECORDSRESPONSE._serialized_end=8152
  _GETRECORDSRESULT._serialized_start=8155
  _GETRECORDSRESULT._serialized_end=8331
  _PUTRECORDREQUEST._serialized_start=8334
  _PUTRECORDREQUEST._serialized_end=8540
  _PUTRECORDRESPONSE._serialized_start=8542
  _PUTRECORDRESPONSE._serialized_end=8607
  _PUTRECORDRESULT._serialized_start=8609
  _PUTRECORDRESULT._serialized_end=8730
  _PUTRECORDSREQUEST._serialized_start=8733
  _PUTRECORDSREQUEST._serialized_end=8893
  _PUTRECORDSRESPONSE._serialized_start=8895
  _PUTRECORDSRESPONSE._serialized_end=8961
  _PUTRECORDSRESULT._serialized_start=8964
  _PUTRECORDSRESULT._serialized_end=9132
  _GETSHARDITERATORREQUEST._serialized_start=9135
  _GETSHARDITERATORREQUEST._serialized_end=9385
  _GETSHARDITERATORRESPONSE._serialized_start=9387
  _GETSHARDITERATORRESPONSE._serialized_end=9459
  _GETSHARDITERATORRESULT._serialized_start=9461
  _GETSHARDITERATORRESULT._serialized_end=9509
  _SUBSCRIBETOSHARDREQUEST._serialized_start=9512
  _SUBSCRIBETOSHARDREQUEST._serialized_end=9701
  _SUBSCRIBETOSHARDRESPONSE._serialized_start=9703
  _SUBSCRIBETOSHARDRESPONSE._serialized_end=9775
  _SUBSCRIBETOSHARDRESULT._serialized_start=9777
  _SUBSCRIBETOSHARDRESULT._serialized_end=9872
  _ADDTAGSTOSTREAMREQUEST._serialized_start=9874
  _ADDTAGSTOSTREAMREQUEST._serialized_end=9992
  _ADDTAGSTOSTREAMRESPONSE._serialized_start=9994
  _ADDTAGSTOSTREAMRESPONSE._serialized_end=10065
  _ADDTAGSTOSTREAMRESULT._serialized_start=10067
  _ADDTAGSTOSTREAMRESULT._serialized_end=10090
  _DECREASESTREAMRETENTIONPERIODREQUEST._serialized_start=10093
  _DECREASESTREAMRETENTIONPERIODREQUEST._serialized_end=10243
  _DECREASESTREAMRETENTIONPERIODRESPONSE._serialized_start=10245
  _DECREASESTREAMRETENTIONPERIODRESPONSE._serialized_end=10330
  _DECREASESTREAMRETENTIONPERIODRESULT._serialized_start=10332
  _DECREASESTREAMRETENTIONPERIODRESULT._serialized_end=10369
  _DESCRIBELIMITSREQUEST._serialized_start=10371
  _DESCRIBELIMITSREQUEST._serialized_end=10453
  _DESCRIBELIMITSRESPONSE._serialized_start=10455
  _DESCRIBELIMITSRESPONSE._serialized_end=10525
  _DESCRIBELIMITSRESULT._serialized_start=10527
  _DESCRIBELIMITSRESULT._serialized_end=10596
  _DESCRIBESTREAMSUMMARYREQUEST._serialized_start=10598
  _DESCRIBESTREAMSUMMARYREQUEST._serialized_end=10708
  _DESCRIBESTREAMSUMMARYRESPONSE._serialized_start=10710
  _DESCRIBESTREAMSUMMARYRESPONSE._serialized_end=10787
  _DESCRIBESTREAMSUMMARYRESULT._serialized_start=10789
  _DESCRIBESTREAMSUMMARYRESULT._serialized_end=10900
  _DISABLEENHANCEDMONITORINGREQUEST._serialized_start=10903
  _DISABLEENHANCEDMONITORINGREQUEST._serialized_end=11046
  _DISABLEENHANCEDMONITORINGRESPONSE._serialized_start=11048
  _DISABLEENHANCEDMONITORINGRESPONSE._serialized_end=11129
  _DISABLEENHANCEDMONITORINGRESULT._serialized_start=11132
  _DISABLEENHANCEDMONITORINGRESULT._serialized_end=11260
  _ENABLEENHANCEDMONITORINGREQUEST._serialized_start=11263
  _ENABLEENHANCEDMONITORINGREQUEST._serialized_end=11405
  _ENABLEENHANCEDMONITORINGRESPONSE._serialized_start=11407
  _ENABLEENHANCEDMONITORINGRESPONSE._serialized_end=11487
  _ENABLEENHANCEDMONITORINGRESULT._serialized_start=11489
  _ENABLEENHANCEDMONITORINGRESULT._serialized_end=11616
  _INCREASESTREAMRETENTIONPERIODREQUEST._serialized_start=11619
  _INCREASESTREAMRETENTIONPERIODREQUEST._serialized_end=11769
  _INCREASESTREAMRETENTIONPERIODRESPONSE._serialized_start=11771
  _INCREASESTREAMRETENTIONPERIODRESPONSE._serialized_end=11856
  _INCREASESTREAMRETENTIONPERIODRESULT._serialized_start=11858
  _INCREASESTREAMRETENTIONPERIODRESULT._serialized_end=11895
  _LISTTAGSFORSTREAMREQUEST._serialized_start=11898
  _LISTTAGSFORSTREAMREQUEST._serialized_end=12052
  _LISTTAGSFORSTREAMRESPONSE._serialized_start=12054
  _LISTTAGSFORSTREAMRESPONSE._serialized_end=12127
  _LISTTAGSFORSTREAMRESULT._serialized_start=12129
  _LISTTAGSFORSTREAMRESULT._serialized_end=12216
  _MERGESHARDSREQUEST._serialized_start=12219
  _MERGESHARDSREQUEST._serialized_end=12376
  _MERGESHARDSRESPONSE._serialized_start=12378
  _MERGESHARDSRESPONSE._serialized_end=12445
  _MERGESHARDSRESULT._serialized_start=12447
  _MERGESHARDSRESULT._serialized_end=12466
  _REMOVETAGSFROMSTREAMREQUEST._serialized_start=12468
  _REMOVETAGSFROMSTREAMREQUEST._serialized_end=12595
  _REMOVETAGSFROMSTREAMRESPONSE._serialized_start=12597
  _REMOVETAGSFROMSTREAMRESPONSE._serialized_end=12673
  _REMOVETAGSFROMSTREAMRESULT._serialized_start=12675
  _REMOVETAGSFROMSTREAMRESULT._serialized_end=12703
  _SPLITSHARDREQUEST._serialized_start=12706
  _SPLITSHARDREQUEST._serialized_end=12860
  _SPLITSHARDRESPONSE._serialized_start=12862
  _SPLITSHARDRESPONSE._serialized_end=12928
  _SPLITSHARDRESULT._serialized_start=12930
  _SPLITSHARDRESULT._serialized_end=12948
  _STARTSTREAMENCRYPTIONREQUEST._serialized_start=12951
  _STARTSTREAMENCRYPTIONREQUEST._serialized_end=13138
  _STARTSTREAMENCRYPTIONRESPONSE._serialized_start=13140
  _STARTSTREAMENCRYPTIONRESPONSE._serialized_end=13217
  _STARTSTREAMENCRYPTIONRESULT._serialized_start=13219
  _STARTSTREAMENCRYPTIONRESULT._serialized_end=13248
  _STOPSTREAMENCRYPTIONREQUEST._serialized_start=13251
  _STOPSTREAMENCRYPTIONREQUEST._serialized_end=13437
  _STOPSTREAMENCRYPTIONRESPONSE._serialized_start=13439
  _STOPSTREAMENCRYPTIONRESPONSE._serialized_end=13515
  _STOPSTREAMENCRYPTIONRESULT._serialized_start=13517
  _STOPSTREAMENCRYPTIONRESULT._serialized_end=13545
  _UPDATESHARDCOUNTREQUEST._serialized_start=13548
  _UPDATESHARDCOUNTREQUEST._serialized_end=13822
  _UPDATESHARDCOUNTREQUEST_SCALINGTYPE._serialized_start=13762
  _UPDATESHARDCOUNTREQUEST_SCALINGTYPE._serialized_end=13822
  _UPDATESHARDCOUNTRESPONSE._serialized_start=13824
  _UPDATESHARDCOUNTRESPONSE._serialized_end=13896
  _UPDATESHARDCOUNTRESULT._serialized_start=13898
  _UPDATESHARDCOUNTRESULT._serialized_end=14000
  _UPDATESTREAMMODEREQUEST._serialized_start=14003
  _UPDATESTREAMMODEREQUEST._serialized_end=14175
  _UPDATESTREAMMODERESPONSE._serialized_start=14177
  _UPDATESTREAMMODERESPONSE._serialized_end=14249
  _UPDATESTREAMMODERESULT._serialized_start=14251
  _UPDATESTREAMMODERESULT._serialized_end=14275
# @@protoc_insertion_point(module_scope)
