# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/channel_purpose.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/channel_purpose.proto\x12\x16NKikimrStorageSettings\"\x9e\x01\n\x0fTChannelPurpose\x12\x41\n\x07Purpose\x18\x01 \x01(\x0e\x32\x30.NKikimrStorageSettings.TChannelPurpose.EPurpose\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\"7\n\x08\x45Purpose\x12\n\n\x06SysLog\x10\x01\x12\x07\n\x03Log\x10\x02\x12\x08\n\x04\x44\x61ta\x10\x03\x12\x0c\n\x08\x45xternal\x10\x04\"\\\n\x0cTStorageRoom\x12\x0e\n\x06RoomId\x18\x01 \x01(\r\x12<\n\x0b\x45xplanation\x18\x02 \x03(\x0b\x32\'.NKikimrStorageSettings.TChannelPurposeB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.channel_purpose_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TCHANNELPURPOSE._serialized_start=66
  _TCHANNELPURPOSE._serialized_end=224
  _TCHANNELPURPOSE_EPURPOSE._serialized_start=169
  _TCHANNELPURPOSE_EPURPOSE._serialized_end=224
  _TSTORAGEROOM._serialized_start=226
  _TSTORAGEROOM._serialized_end=318
# @@protoc_insertion_point(module_scope)
