# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: library/cpp/actors/protos/actors.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&library/cpp/actors/protos/actors.proto\x12\x0cNActorsProto\"(\n\x08TActorId\x12\r\n\x05RawX1\x18\x01 \x02(\x06\x12\r\n\x05RawX2\x18\x02 \x02(\x06\"\x18\n\x08TTraceId\x12\x0c\n\x04\x44\x61ta\x18\x01 \x01(\x0c\"W\n\x12TCallbackException\x12\'\n\x07\x41\x63torId\x18\x01 \x02(\x0b\x32\x16.NActorsProto.TActorId\x12\x18\n\x10\x45xceptionMessage\x18\x02 \x02(\t\"\xee\x02\n\x0fTRemoteHttpInfo\x12\x0e\n\x06Method\x18\x01 \x01(\r\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12>\n\x0bQueryParams\x18\x03 \x03(\x0b\x32).NActorsProto.TRemoteHttpInfo.TQueryParam\x12=\n\nPostParams\x18\x04 \x03(\x0b\x32).NActorsProto.TRemoteHttpInfo.TQueryParam\x12\x13\n\x0bPostContent\x18\x08 \x01(\x0c\x12\x36\n\x07Headers\x18\t \x03(\x0b\x32%.NActorsProto.TRemoteHttpInfo.THeader\x12\x12\n\nRemoteAddr\x18\x07 \x01(\t\x1a)\n\x0bTQueryParam\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\x1a&\n\x07THeader\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\tJ\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07\x42*\n\x16ru.yandex.kikimr.protoB\x10NActorsBaseProto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'library.cpp.actors.protos.actors_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.protoB\020NActorsBaseProto'
  _TACTORID._serialized_start=56
  _TACTORID._serialized_end=96
  _TTRACEID._serialized_start=98
  _TTRACEID._serialized_end=122
  _TCALLBACKEXCEPTION._serialized_start=124
  _TCALLBACKEXCEPTION._serialized_end=211
  _TREMOTEHTTPINFO._serialized_start=214
  _TREMOTEHTTPINFO._serialized_end=580
  _TREMOTEHTTPINFO_TQUERYPARAM._serialized_start=487
  _TREMOTEHTTPINFO_TQUERYPARAM._serialized_end=528
  _TREMOTEHTTPINFO_THEADER._serialized_start=530
  _TREMOTEHTTPINFO_THEADER._serialized_end=568
# @@protoc_insertion_point(module_scope)
