# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_mediator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/core/protos/counters_mediator.proto\x12\x13NKikimr.NTxMediator\x1a\x1eydb/core/protos/counters.proto*R\n\x08\x45TxTypes\x12\x1d\n\x0bTXTYPE_INIT\x10\x00\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12\'\n\x10TXTYPE_CONFIGURE\x10\x01\x1a\x11\x8a\xd6\x1b\r\n\x0bTxConfigureB$\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x08Mediator')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_mediator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\010Mediator'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE"]._serialized_options = b'\212\326\033\r\n\013TxConfigure'
  _ETXTYPES._serialized_start=96
  _ETXTYPES._serialized_end=178
# @@protoc_insertion_point(module_scope)
