# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/auth.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aydb/core/protos/auth.proto\x12\x0cNKikimrProto\"\xdd\x0c\n\x0bTAuthConfig\x12=\n\x12UserRegistryConfig\x18\x01 \x01(\x0b\x32!.NKikimrProto.TUserRegistryConfig\x12+\n\tTVMConfig\x18\x02 \x01(\x0b\x32\x18.NKikimrProto.TTVMConfig\x12\x19\n\x11StaffApiUserToken\x18\x03 \x01(\t\x12\x31\n\x10\x42lackBoxEndpoint\x18\x04 \x01(\t:\x17\x62lackbox.yandex-team.ru\x12\x43\n\x15\x41\x63\x63\x65ssServiceEndpoint\x18\x05 \x01(\t:$as.private-api.cloud.yandex.net:4286\x12Q\n\x1aUserAccountServiceEndpoint\x18\x06 \x01(\t:-api-adapter.private-api.cloud.yandex.net:8443\x12T\n\x1dServiceAccountServiceEndpoint\x18\x07 \x01(\t:-api-adapter.private-api.cloud.yandex.net:8443\x12/\n\rStaffEndpoint\x18\n \x01(\t:\x18staff-api.yandex-team.ru\x12\x1b\n\rGrpcCacheSize\x18\x10 \x01(\r:\x04\x31\x30\x32\x34\x12\"\n\x13GrpcSuccessLifeTime\x18\x11 \x01(\x04:\x05\x36\x30\x30\x30\x30\x12 \n\x11GrpcErrorLifeTime\x18\x12 \x01(\x04:\x05\x31\x30\x30\x30\x30\x12\x19\n\x0bUseBlackBox\x18\x14 \x01(\x08:\x04true\x12\x1f\n\x10UseAccessService\x18\x15 \x01(\x08:\x05\x66\x61lse\x12/\n CacheAccessServiceAuthentication\x18\x16 \x01(\x08:\x05\x66\x61lse\x12.\n\x1f\x43\x61\x63heAccessServiceAuthorization\x18\x17 \x01(\x08:\x05\x66\x61lse\x12\x16\n\x08UseStaff\x18\x19 \x01(\x08:\x04true\x12$\n\x15UseUserAccountService\x18\x1a \x01(\x08:\x05\x66\x61lse\x12\'\n\x18UseServiceAccountService\x18\x1b \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x10UseLoginProvider\x18\x1d \x01(\x08:\x04true\x12!\n\x13UseAccessServiceTLS\x18\x1f \x01(\x08:\x04true\x12&\n\x18UseUserAccountServiceTLS\x18  \x01(\x08:\x04true\x12)\n\x1bUseServiceAccountServiceTLS\x18! \x01(\x08:\x04true\x12%\n\x17\x43\x61\x63heUserAccountService\x18% \x01(\x08:\x04true\x12(\n\x1a\x43\x61\x63heServiceAccountService\x18& \x01(\x08:\x04true\x12\x1d\n\x10TvmServiceDomain\x18( \x01(\t:\x03tvm\x12 \n\x0e\x42lackBoxDomain\x18) \x01(\t:\x08\x62lackbox\x12\x1f\n\x13\x41\x63\x63\x65ssServiceDomain\x18* \x01(\t:\x02\x61s\x12#\n\x11UserAccountDomain\x18+ \x01(\t:\x08passport\x12\x1e\n\rServiceDomain\x18, \x01(\t:\x07service\x12\x1d\n\x0f\x44omainLoginOnly\x18- \x01(\x08:\x04true\x12\x19\n\rRefreshPeriod\x18\x32 \x01(\t:\x02\x31s\x12\x17\n\x0bRefreshTime\x18\x33 \x01(\t:\x02\x31h\x12\x14\n\x08LifeTime\x18\x34 \x01(\t:\x02\x31h\x12\x17\n\nExpireTime\x18\x35 \x01(\t:\x03\x32\x34h\x12\x19\n\rTVMExpireTime\x18\x36 \x01(\t:\x02\x32m\x12\x1f\n\x13MinErrorRefreshTime\x18\x37 \x01(\t:\x02\x31s\x12\x1f\n\x13MaxErrorRefreshTime\x18\x38 \x01(\t:\x02\x31m\x12=\n\x0cPathToRootCA\x18< \x01(\t:\'/etc/ssl/certs/YandexInternalRootCA.pem\x12/\n AccessServiceGrpcKeepAliveTimeMs\x18\x46 \x01(\r:\x05\x31\x30\x30\x30\x30\x12\x31\n#AccessServiceGrpcKeepAliveTimeoutMs\x18G \x01(\r:\x04\x31\x30\x30\x30\"$\n\x13TUserRegistryConfig\x12\r\n\x05Query\x18\x01 \x01(\t\"\xc2\x01\n\nTTVMConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12\x14\n\x0cServiceTVMId\x18\x02 \x01(\r\x12\x12\n\nPublicKeys\x18\x03 \x01(\t\x12\x1e\n\x10UpdatePublicKeys\x18\x04 \x01(\x08:\x04true\x12-\n\x1eUpdatePublicKeysSuccessTimeout\x18\x05 \x01(\x04:\x05\x38\x32\x38\x30\x30\x12*\n\x1eUpdatePublicKeysFailureTimeout\x18\x06 \x01(\x04:\x02\x31\x30\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.auth_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TAUTHCONFIG._serialized_start=45
  _TAUTHCONFIG._serialized_end=1674
  _TUSERREGISTRYCONFIG._serialized_start=1676
  _TUSERREGISTRYCONFIG._serialized_end=1712
  _TTVMCONFIG._serialized_start=1715
  _TTVMCONFIG._serialized_end=1909
# @@protoc_insertion_point(module_scope)
