# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/proto/dq_tasks.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.library.yql.dq.proto import dq_transport_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__transport__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/library/yql/dq/proto/dq_tasks.proto\x12\rNYql.NDqProto\x1a\x19google/protobuf/any.proto\x1a&library/cpp/actors/protos/actors.proto\x1a+ydb/library/yql/dq/proto/dq_transport.proto\"\xa6\x01\n\x08TProgram\x12\x16\n\x0eRuntimeVersion\x18\x01 \x01(\r\x12\x0b\n\x03Raw\x18\x02 \x01(\x0c\x12\x33\n\x08Settings\x18\x03 \x01(\x0b\x32!.NYql.NDqProto.TProgram.TSettings\x1a@\n\tTSettings\x12\x12\n\nHasMapJoin\x18\x01 \x01(\x08\x12\x0f\n\x07HasSort\x18\x02 \x01(\x08\x12\x0e\n\x06HasUdf\x18\x03 \x01(\x08\"8\n\x06TDqUri\x12\x10\n\x08Protocol\x18\x01 \x01(\t\x12\x0b\n\x03Uri\x18\x02 \x01(\t\x12\x0f\n\x07ShardId\x18\x03 \x01(\r\"\x80\x01\n\tTEndpoint\x12)\n\x07\x41\x63torId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorIdH\x00\x12\x12\n\x08TabletId\x18\x02 \x01(\x06H\x00\x12$\n\x03Uri\x18\x03 \x01(\x0b\x32\x15.NYql.NDqProto.TDqUriH\x00\x42\x0e\n\x0c\x45ndpointType\"\xf8\x02\n\x08TChannel\x12\n\n\x02Id\x18\x01 \x01(\x04\x12>\n\x10TransportVersion\x18\x02 \x01(\x0e\x32$.NYql.NDqProto.EDataTransportVersion\x12\x11\n\tSrcTaskId\x18\x03 \x01(\x04\x12\x11\n\tDstTaskId\x18\x04 \x01(\x04\x12-\n\x0bSrcEndpoint\x18\x05 \x01(\x0b\x32\x18.NYql.NDqProto.TEndpoint\x12-\n\x0b\x44stEndpoint\x18\x06 \x01(\x0b\x32\x18.NYql.NDqProto.TEndpoint\x12\x14\n\x0cIsPersistent\x18\x07 \x01(\x08\x12\x10\n\x08InMemory\x18\x08 \x01(\x08\x12<\n\x11\x43heckpointingMode\x18\t \x01(\x0e\x32!.NYql.NDqProto.ECheckpointingMode\x12\x36\n\x0eWatermarksMode\x18\n \x01(\x0e\x32\x1e.NYql.NDqProto.EWatermarksMode\"\x10\n\x0eTUnionAllInput\"|\n\x0cTSourceInput\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12&\n\x08Settings\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x36\n\x0eWatermarksMode\x18\x03 \x01(\x0e\x32\x1e.NYql.NDqProto.EWatermarksMode\"0\n\x0bTSortColumn\x12\x0e\n\x06\x43olumn\x18\x01 \x01(\t\x12\x11\n\tAscending\x18\x02 \x01(\x08\">\n\x0bTMergeInput\x12/\n\x0bSortColumns\x18\x01 \x03(\x0b\x32\x1a.NYql.NDqProto.TSortColumn\"\xfe\x01\n\nTTaskInput\x12)\n\x08\x43hannels\x18\x01 \x03(\x0b\x32\x17.NYql.NDqProto.TChannel\x12\x31\n\x08UnionAll\x18\n \x01(\x0b\x32\x1d.NYql.NDqProto.TUnionAllInputH\x00\x12-\n\x06Source\x18\x0b \x01(\x0b\x32\x1b.NYql.NDqProto.TSourceInputH\x00\x12+\n\x05Merge\x18\x0c \x01(\x0b\x32\x1a.NYql.NDqProto.TMergeInputH\x00\x12.\n\tTransform\x18\x1e \x01(\x0b\x32\x1b.NYql.NDqProto.TDqTransformB\x06\n\x04Type\"\x10\n\x0eTTaskOutputMap\"d\n\x13TRangePartitionInfo\x12\x14\n\x0c\x45ndKeyPrefix\x18\x01 \x01(\x0c\x12\x13\n\x0bIsInclusive\x18\x02 \x01(\x08\x12\x0f\n\x07IsPoint\x18\x03 \x01(\x08\x12\x11\n\tChannelId\x18\x04 \x01(\x04\"g\n\x19TTaskOutputRangePartition\x12\x12\n\nKeyColumns\x18\x01 \x03(\t\x12\x36\n\nPartitions\x18\x02 \x03(\x0b\x32\".NYql.NDqProto.TRangePartitionInfo\"\x16\n\x14TTaskOutputBroadcast\"G\n\x18TTaskOutputHashPartition\x12\x12\n\nKeyColumns\x18\x01 \x03(\t\x12\x17\n\x0fPartitionsCount\x18\x02 \x01(\r\"\x14\n\x12TTaskOutputEffects\"G\n\x0fTTaskOutputSink\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12&\n\x08Settings\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"\xc4\x03\n\x0bTTaskOutput\x12)\n\x08\x43hannels\x18\x01 \x03(\x0b\x32\x17.NYql.NDqProto.TChannel\x12,\n\x03Map\x18\n \x01(\x0b\x32\x1d.NYql.NDqProto.TTaskOutputMapH\x00\x12\x42\n\x0eRangePartition\x18\x0b \x01(\x0b\x32(.NYql.NDqProto.TTaskOutputRangePartitionH\x00\x12@\n\rHashPartition\x18\x0c \x01(\x0b\x32\'.NYql.NDqProto.TTaskOutputHashPartitionH\x00\x12\x38\n\tBroadcast\x18\r \x01(\x0b\x32#.NYql.NDqProto.TTaskOutputBroadcastH\x00\x12\x34\n\x07\x45\x66\x66\x65\x63ts\x18\x0e \x01(\x0b\x32!.NYql.NDqProto.TTaskOutputEffectsH\x00\x12.\n\x04Sink\x18\x0f \x01(\x0b\x32\x1e.NYql.NDqProto.TTaskOutputSinkH\x00\x12.\n\tTransform\x18\x1e \x01(\x0b\x32\x1b.NYql.NDqProto.TDqTransformB\x06\n\x04Type\"k\n\x0cTDqTransform\x12\x0c\n\x04Type\x18\x01 \x01(\t\x12\x11\n\tInputType\x18\x02 \x01(\x0c\x12\x12\n\nOutputType\x18\x03 \x01(\x0c\x12&\n\x08Settings\x18\x04 \x01(\x0b\x32\x14.google.protobuf.Any\"\xc8\x03\n\x07TDqTask\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x0f\n\x07StageId\x18\t \x01(\r\x12*\n\x08\x45xecuter\x18\x02 \x01(\x0b\x32\x18.NYql.NDqProto.TEndpoint\x12(\n\x07Program\x18\x03 \x01(\x0b\x32\x17.NYql.NDqProto.TProgram\x12:\n\nParameters\x18\x04 \x03(\x0b\x32&.NYql.NDqProto.TDqTask.ParametersEntry\x12)\n\x06Inputs\x18\x05 \x03(\x0b\x32\x19.NYql.NDqProto.TTaskInput\x12+\n\x07Outputs\x18\x06 \x03(\x0b\x32\x1a.NYql.NDqProto.TTaskOutput\x12\"\n\x04Meta\x18\x07 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x17\n\x0f\x43reateSuspended\x18\x08 \x01(\x08\x12\x13\n\x0bRateLimiter\x18\n \x01(\t\x12\x1b\n\x13RateLimiterResource\x18\x0b \x01(\t\x1aG\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.NYql.NDqProto.TData:\x02\x38\x01*Q\n\x0f\x45RuntimeVersion\x12\x1f\n\x1bRUNTIME_VERSION_UNSPECIFIED\x10\x00\x12\x1d\n\x17RUNTIME_VERSION_YQL_1_0\x10\xa0\x8d\x06*U\n\x12\x45\x43heckpointingMode\x12\x1e\n\x1a\x43HECKPOINTING_MODE_DEFAULT\x10\x00\x12\x1f\n\x1b\x43HECKPOINTING_MODE_DISABLED\x10\x01*L\n\x0f\x45WatermarksMode\x12\x1b\n\x17WATERMARKS_MODE_DEFAULT\x10\x00\x12\x1c\n\x18WATERMARKS_MODE_DISABLED\x10\x01\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.proto.dq_tasks_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TDQTASK_PARAMETERSENTRY._options = None
  _TDQTASK_PARAMETERSENTRY._serialized_options = b'8\001'
  _ERUNTIMEVERSION._serialized_start=2862
  _ERUNTIMEVERSION._serialized_end=2943
  _ECHECKPOINTINGMODE._serialized_start=2945
  _ECHECKPOINTINGMODE._serialized_end=3030
  _EWATERMARKSMODE._serialized_start=3032
  _EWATERMARKSMODE._serialized_end=3108
  _TPROGRAM._serialized_start=171
  _TPROGRAM._serialized_end=337
  _TPROGRAM_TSETTINGS._serialized_start=273
  _TPROGRAM_TSETTINGS._serialized_end=337
  _TDQURI._serialized_start=339
  _TDQURI._serialized_end=395
  _TENDPOINT._serialized_start=398
  _TENDPOINT._serialized_end=526
  _TCHANNEL._serialized_start=529
  _TCHANNEL._serialized_end=905
  _TUNIONALLINPUT._serialized_start=907
  _TUNIONALLINPUT._serialized_end=923
  _TSOURCEINPUT._serialized_start=925
  _TSOURCEINPUT._serialized_end=1049
  _TSORTCOLUMN._serialized_start=1051
  _TSORTCOLUMN._serialized_end=1099
  _TMERGEINPUT._serialized_start=1101
  _TMERGEINPUT._serialized_end=1163
  _TTASKINPUT._serialized_start=1166
  _TTASKINPUT._serialized_end=1420
  _TTASKOUTPUTMAP._serialized_start=1422
  _TTASKOUTPUTMAP._serialized_end=1438
  _TRANGEPARTITIONINFO._serialized_start=1440
  _TRANGEPARTITIONINFO._serialized_end=1540
  _TTASKOUTPUTRANGEPARTITION._serialized_start=1542
  _TTASKOUTPUTRANGEPARTITION._serialized_end=1645
  _TTASKOUTPUTBROADCAST._serialized_start=1647
  _TTASKOUTPUTBROADCAST._serialized_end=1669
  _TTASKOUTPUTHASHPARTITION._serialized_start=1671
  _TTASKOUTPUTHASHPARTITION._serialized_end=1742
  _TTASKOUTPUTEFFECTS._serialized_start=1744
  _TTASKOUTPUTEFFECTS._serialized_end=1764
  _TTASKOUTPUTSINK._serialized_start=1766
  _TTASKOUTPUTSINK._serialized_end=1837
  _TTASKOUTPUT._serialized_start=1840
  _TTASKOUTPUT._serialized_end=2292
  _TDQTRANSFORM._serialized_start=2294
  _TDQTRANSFORM._serialized_end=2401
  _TDQTASK._serialized_start=2404
  _TDQTASK._serialized_end=2860
  _TDQTASK_PARAMETERSENTRY._serialized_start=2789
  _TDQTASK_PARAMETERSENTRY._serialized_end=2860
# @@protoc_insertion_point(module_scope)
