# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/local.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import follower_group_pb2 as ydb_dot_core_dot_protos_dot_follower__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bydb/core/protos/local.proto\x12\x0cNKikimrLocal\x1a,library/cpp/actors/protos/interconnect.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1cydb/core/protos/tablet.proto\x1a ydb/core/protos/subdomains.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a$ydb/core/protos/follower_group.proto\"\\\n\x13TTabletAvailability\x12\x33\n\x04Type\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x10\n\x08MaxCount\x18\x02 \x01(\x04\"\xd4\x01\n\x0fTEvRegisterNode\x12\x0e\n\x06HiveId\x18\x01 \x01(\x06\x12\x36\n\x0fServicedDomains\x18\x02 \x03(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12:\n\x0eSystemLocation\x18\x03 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12=\n\x12TabletAvailability\x18\x04 \x03(\x0b\x32!.NKikimrLocal.TTabletAvailability\"k\n\x15TEvRegisterNodeResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06HiveId\x18\x02 \x01(\x06\x12\x16\n\x0eHiveGeneration\x18\x03 \x01(\r\"K\n\x0cTLocalConfig\x12;\n\x10ResourceProfiles\x18\x01 \x03(\x0b\x32!.NKikimrSchemeOp.TResourceProfile\"l\n\x07TEvPing\x12\x0e\n\x06HiveId\x18\x01 \x01(\x06\x12\x16\n\x0eHiveGeneration\x18\x02 \x01(\r\x12\r\n\x05Purge\x18\x03 \x01(\x08\x12*\n\x06\x43onfig\x18\x04 \x01(\x0b\x32\x1a.NKikimrLocal.TLocalConfig\"L\n\x10TEvDeadTabletAck\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x12\n\nFollowerId\x18\x03 \x01(\r\"\xc0\x01\n\tTEvStatus\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x15\n\rInbootTablets\x18\x02 \x01(\x04\x12\x15\n\rOnlineTablets\x18\x03 \x01(\x04\x12\x13\n\x0b\x44\x65\x61\x64Tablets\x18\x04 \x01(\x04\x12\x17\n\x0f\x41vailableWeight\x18\x05 \x01(\x04\x12\x34\n\x0fResourceMaximum\x18\x08 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x11\n\tStartTime\x18\x07 \x01(\x04\"\xe6\x01\n\rTEvBootTablet\x12\x33\n\x04Info\x18\x01 \x01(\x0b\x32%.NKikimrTabletBase.TTabletStorageInfo\x12\x1b\n\x13SuggestedGeneration\x18\x02 \x01(\r\x12;\n\x08\x42ootMode\x18\x03 \x01(\x0e\x32\x17.NKikimrLocal.EBootMode:\x10\x42OOT_MODE_LEADER\x12\x32\n\rFollowerGroup\x18\x04 \x01(\x0b\x32\x1b.NKikimrHive.TFollowerGroup\x12\x12\n\nFollowerId\x18\x05 \x01(\r\"I\n\rTEvStopTablet\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nFollowerId\x18\x02 \x01(\r\x12\x12\n\nGeneration\x18\x03 \x01(\r\"o\n\x0fTEvTabletStatus\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\x12\x12\n\nGeneration\x18\x03 \x01(\r\x12\x12\n\nFollowerId\x18\x04 \x01(\r\x12\x12\n\x06Reason\x18\x05 \x01(\r:\x02\x33\x34\"P\n\x13TEvEnumerateTablets\x12\x39\n\nTabletType\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\"\xbe\x02\n\x19TEvEnumerateTabletsResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12G\n\nTabletInfo\x18\x02 \x03(\x0b\x32\x33.NKikimrLocal.TEvEnumerateTabletsResult.TTabletInfo\x1a\xab\x01\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x39\n\nTabletType\x18\x02 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12;\n\x08\x42ootMode\x18\x03 \x01(\x0e\x32\x17.NKikimrLocal.EBootMode:\x10\x42OOT_MODE_LEADER\x12\x12\n\nFollowerId\x18\x04 \x01(\r\"\x86\x02\n\x0eTEvSyncTablets\x12?\n\rInbootTablets\x18\x01 \x03(\x0b\x32(.NKikimrLocal.TEvSyncTablets.TTabletInfo\x12?\n\rOnlineTablets\x18\x02 \x03(\x0b\x32(.NKikimrLocal.TEvSyncTablets.TTabletInfo\x1ar\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12)\n\x08\x42ootMode\x18\x03 \x01(\x0e\x32\x17.NKikimrLocal.EBootMode\x12\x12\n\nFollowerId\x18\x04 \x01(\r\";\n\x13TEvTabletMetricsAck\x12\x10\n\x08TabletId\x18\x01 \x03(\x06\x12\x12\n\nFollowerId\x18\x02 \x03(\r\"6\n\x0cTEvReconnect\x12\x0e\n\x06HiveId\x18\x01 \x01(\x06\x12\x16\n\x0eHiveGeneration\x18\x02 \x01(\r*9\n\tEBootMode\x12\x14\n\x10\x42OOT_MODE_LEADER\x10\x00\x12\x16\n\x12\x42OOT_MODE_FOLLOWER\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.local_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EBOOTMODE._serialized_start=2343
  _EBOOTMODE._serialized_end=2400
  _TTABLETAVAILABILITY._serialized_start=259
  _TTABLETAVAILABILITY._serialized_end=351
  _TEVREGISTERNODE._serialized_start=354
  _TEVREGISTERNODE._serialized_end=566
  _TEVREGISTERNODERESULT._serialized_start=568
  _TEVREGISTERNODERESULT._serialized_end=675
  _TLOCALCONFIG._serialized_start=677
  _TLOCALCONFIG._serialized_end=752
  _TEVPING._serialized_start=754
  _TEVPING._serialized_end=862
  _TEVDEADTABLETACK._serialized_start=864
  _TEVDEADTABLETACK._serialized_end=940
  _TEVSTATUS._serialized_start=943
  _TEVSTATUS._serialized_end=1135
  _TEVBOOTTABLET._serialized_start=1138
  _TEVBOOTTABLET._serialized_end=1368
  _TEVSTOPTABLET._serialized_start=1370
  _TEVSTOPTABLET._serialized_end=1443
  _TEVTABLETSTATUS._serialized_start=1445
  _TEVTABLETSTATUS._serialized_end=1556
  _TEVENUMERATETABLETS._serialized_start=1558
  _TEVENUMERATETABLETS._serialized_end=1638
  _TEVENUMERATETABLETSRESULT._serialized_start=1641
  _TEVENUMERATETABLETSRESULT._serialized_end=1959
  _TEVENUMERATETABLETSRESULT_TTABLETINFO._serialized_start=1788
  _TEVENUMERATETABLETSRESULT_TTABLETINFO._serialized_end=1959
  _TEVSYNCTABLETS._serialized_start=1962
  _TEVSYNCTABLETS._serialized_end=2224
  _TEVSYNCTABLETS_TTABLETINFO._serialized_start=2110
  _TEVSYNCTABLETS_TTABLETINFO._serialized_end=2224
  _TEVTABLETMETRICSACK._serialized_start=2226
  _TEVTABLETMETRICSACK._serialized_end=2285
  _TEVRECONNECT._serialized_start=2287
  _TEVRECONNECT._serialized_end=2341
# @@protoc_insertion_point(module_scope)
