# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/metrics.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dydb/core/protos/metrics.proto\x12\x13NKikimrMetricsProto\"@\n\x11TMaximumValueUI64\x12\x1b\n\x13LastBucketStartTime\x18\x01 \x01(\x04\x12\x0e\n\x06Values\x18\x02 \x03(\x04')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.metrics_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TMAXIMUMVALUEUI64._serialized_start=54
  _TMAXIMUMVALUEUI64._serialized_end=118
# @@protoc_insertion_point(module_scope)
