# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tracing.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dydb/core/protos/tracing.proto\x12\x0eNKikimrTracing\"2\n\x08TTraceID\x12\x14\n\x0c\x43reationTime\x18\x01 \x01(\x06\x12\x10\n\x08RandomID\x18\x02 \x01(\x06\"1\n\x11TSerializedSignal\x12\x0c\n\x04Type\x18\x01 \x01(\r\x12\x0e\n\x06Signal\x18\x02 \x01(\t\"\xd0\x01\n\x0cTTraceSignal\x12\x0c\n\x04Type\x18\x01 \x01(\r\x12(\n\x06SelfID\x18\x02 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12*\n\x08ParentID\x18\x03 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12(\n\x06RootID\x18\x04 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\x12\x32\n\x07Signals\x18\x05 \x03(\x0b\x32!.NKikimrTracing.TSerializedSignalB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tracing_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TTRACEID._serialized_start=49
  _TTRACEID._serialized_end=99
  _TSERIALIZEDSIGNAL._serialized_start=101
  _TSERIALIZEDSIGNAL._serialized_end=150
  _TTRACESIGNAL._serialized_start=153
  _TTRACESIGNAL._serialized_end=361
# @@protoc_insertion_point(module_scope)
