# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_tracing_signals.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import tracing_pb2 as ydb_dot_core_dot_protos_dot_tracing__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/protos/tablet_tracing_signals.proto\x12\x0eNKikimrTracing\x1a&library/cpp/actors/protos/actors.proto\x1a\x1cydb/core/protos/tablet.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1dydb/core/protos/tracing.proto\"\xc1\x01\n\x0fTOnCancelTablet\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x10\n\x08TabletID\x18\x02 \x01(\x04\x12\x39\n\nTabletType\x18\x03 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x18\n\x10TabletDeadReason\x18\x04 \x01(\r\x12\x1b\n\x13SuggestedGeneration\x18\x05 \x01(\r\x12\x17\n\x0fKnownGeneration\x18\x06 \x01(\r\"\x89\x01\n\x12TOnTabletBootstrap\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x0e\n\x06Leader\x18\x02 \x01(\x08\x12\x1b\n\x13SuggestedGeneration\x18\x03 \x01(\r\x12\x33\n\x13StateStorageProxyID\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\"v\n TOnHandleStateStorageInfoResolve\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fKnownGeneration\x18\x02 \x01(\r\x12\x11\n\tKnownStep\x18\x03 \x01(\r\x12\x13\n\x0bSignatureSz\x18\x04 \x01(\r\"q\n\x1bTOnLockedInitializationPath\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fKnownGeneration\x18\x02 \x01(\r\x12\x11\n\tKnownStep\x18\x03 \x01(\r\x12\x13\n\x0bSignatureSz\x18\x04 \x01(\r\"s\n\x1dTOnHandleStateStorageInfoLock\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fKnownGeneration\x18\x02 \x01(\r\x12\x11\n\tKnownStep\x18\x03 \x01(\r\x12\x13\n\x0bSignatureSz\x18\x04 \x01(\r\"C\n\x15TOnPromoteToCandidate\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fKnownGeneration\x18\x02 \x01(\r\"~\n\x19TOnTabletBlockBlobStorage\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x35\n\x15ReqBlockBlobStorageID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x17\n\x0fKnownGeneration\x18\x03 \x01(\r\"\x9a\x01\n\x15TOnTabletRebuildGraph\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x37\n\x17TabletReqRebuildGraphID\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x35\n\x13RebuildGraphTraceID\x18\x03 \x01(\x0b\x32\x18.NKikimrTracing.TTraceID\"i\n\x11TOnWriteZeroEntry\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x10\n\x08Snapshot\x18\x02 \x01(\x04\x12\x15\n\rZeroConfirmed\x18\x03 \x01(\x04\x12\x18\n\x10LastInGeneration\x18\x04 \x01(\r\"\xb1\x01\n\x1aTOnFollowerPromoteToLeader\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x1b\n\x13SuggestedGeneration\x18\x02 \x01(\r\x12-\n\rKnownLeaderID\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x34\n\x14\x46ollowerStStGuardian\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\"?\n\x16TRebuildGraphBootstrap\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x12\n\nBlockedGen\x18\x02 \x01(\r\"l\n\x18TErrorEntryBeyondBlocked\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12)\n\x06Latest\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x12\n\nBlockedGen\x18\x03 \x01(\r\"d\n\x13TErrorUnknownStatus\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Reason\x18\x03 \x01(\t\"W\n\x17TErrorParsingFromString\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12)\n\x06\x42lobID\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"(\n\x13TErrorSendRefsCheck\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\"I\n\x12TErrorRebuildGraph\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0c\n\x04Step\x18\x03 \x01(\r\"W\n\x12TOnProcessKeyEntry\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12.\n\x0bLatestEntry\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"a\n\x13TOnProcessZeroEntry\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x10\n\x08Snapshot\x18\x03 \x01(\x04\x12\x11\n\tConfirmed\x18\x04 \x01(\x04\"\x82\x02\n\x12TOnProcessLogEntry\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12)\n\x06\x42lobID\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x10\n\x08Snapshot\x18\x03 \x01(\x04\x12\x11\n\tConfirmed\x18\x04 \x01(\x04\x12-\n\nReferences\x18\x05 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12/\n\x0cGcDiscovered\x18\x06 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12)\n\x06GcLeft\x18\x07 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"\x8b\x01\n\x17TOnDiscoverRangeRequest\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\r\n\x05Group\x18\x02 \x01(\r\x12\'\n\x04\x46rom\x18\x03 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12%\n\x02To\x18\x04 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"\x8a\x01\n\x16TOnApplyDiscoveryRange\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\r\n\x05Group\x18\x02 \x01(\r\x12\'\n\x04\x46rom\x18\x03 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12%\n\x02To\x18\x04 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"S\n\x0eTOnMakeHistory\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12.\n\x0bRefsToCheck\x18\x02 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\">\n\x15TOnCheckRefsGetResult\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x12\n\nResponseSz\x18\x02 \x01(\r\"\xb3\x02\n\x14TOnBuildHistoryGraph\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12<\n\x07\x45ntries\x18\x02 \x03(\x0b\x32+.NKikimrTracing.TOnBuildHistoryGraph.TEntry\x1a\xc9\x01\n\x06TEntry\x12\x12\n\nGeneration\x18\x01 \x01(\r\x12\x0c\n\x04Step\x18\x02 \x01(\r\x12\x12\n\nIsSnapshot\x18\x03 \x01(\x08\x12-\n\nReferences\x18\x04 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12/\n\x0cGcDiscovered\x18\x05 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12)\n\x06GcLeft\x18\x06 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\"C\n\x15TOnRebuildGraphResult\x12\x11\n\tTimeStamp\x18\x01 \x01(\x06\x12\x17\n\x0fSerializedTrace\x18\x02 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_tracing_signals_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TONCANCELTABLET._serialized_start=194
  _TONCANCELTABLET._serialized_end=387
  _TONTABLETBOOTSTRAP._serialized_start=390
  _TONTABLETBOOTSTRAP._serialized_end=527
  _TONHANDLESTATESTORAGEINFORESOLVE._serialized_start=529
  _TONHANDLESTATESTORAGEINFORESOLVE._serialized_end=647
  _TONLOCKEDINITIALIZATIONPATH._serialized_start=649
  _TONLOCKEDINITIALIZATIONPATH._serialized_end=762
  _TONHANDLESTATESTORAGEINFOLOCK._serialized_start=764
  _TONHANDLESTATESTORAGEINFOLOCK._serialized_end=879
  _TONPROMOTETOCANDIDATE._serialized_start=881
  _TONPROMOTETOCANDIDATE._serialized_end=948
  _TONTABLETBLOCKBLOBSTORAGE._serialized_start=950
  _TONTABLETBLOCKBLOBSTORAGE._serialized_end=1076
  _TONTABLETREBUILDGRAPH._serialized_start=1079
  _TONTABLETREBUILDGRAPH._serialized_end=1233
  _TONWRITEZEROENTRY._serialized_start=1235
  _TONWRITEZEROENTRY._serialized_end=1340
  _TONFOLLOWERPROMOTETOLEADER._serialized_start=1343
  _TONFOLLOWERPROMOTETOLEADER._serialized_end=1520
  _TREBUILDGRAPHBOOTSTRAP._serialized_start=1522
  _TREBUILDGRAPHBOOTSTRAP._serialized_end=1585
  _TERRORENTRYBEYONDBLOCKED._serialized_start=1587
  _TERRORENTRYBEYONDBLOCKED._serialized_end=1695
  _TERRORUNKNOWNSTATUS._serialized_start=1697
  _TERRORUNKNOWNSTATUS._serialized_end=1797
  _TERRORPARSINGFROMSTRING._serialized_start=1799
  _TERRORPARSINGFROMSTRING._serialized_end=1886
  _TERRORSENDREFSCHECK._serialized_start=1888
  _TERRORSENDREFSCHECK._serialized_end=1928
  _TERRORREBUILDGRAPH._serialized_start=1930
  _TERRORREBUILDGRAPH._serialized_end=2003
  _TONPROCESSKEYENTRY._serialized_start=2005
  _TONPROCESSKEYENTRY._serialized_end=2092
  _TONPROCESSZEROENTRY._serialized_start=2094
  _TONPROCESSZEROENTRY._serialized_end=2191
  _TONPROCESSLOGENTRY._serialized_start=2194
  _TONPROCESSLOGENTRY._serialized_end=2452
  _TONDISCOVERRANGEREQUEST._serialized_start=2455
  _TONDISCOVERRANGEREQUEST._serialized_end=2594
  _TONAPPLYDISCOVERYRANGE._serialized_start=2597
  _TONAPPLYDISCOVERYRANGE._serialized_end=2735
  _TONMAKEHISTORY._serialized_start=2737
  _TONMAKEHISTORY._serialized_end=2820
  _TONCHECKREFSGETRESULT._serialized_start=2822
  _TONCHECKREFSGETRESULT._serialized_end=2884
  _TONBUILDHISTORYGRAPH._serialized_start=2887
  _TONBUILDHISTORYGRAPH._serialized_end=3194
  _TONBUILDHISTORYGRAPH_TENTRY._serialized_start=2993
  _TONBUILDHISTORYGRAPH_TENTRY._serialized_end=3194
  _TONREBUILDGRAPHRESULT._serialized_start=3196
  _TONREBUILDGRAPHRESULT._serialized_end=3263
# @@protoc_insertion_point(module_scope)
