# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/key.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/key.proto\x12\x0cNKikimrProto\"V\n\nTKeyRecord\x12\x17\n\rContainerPath\x18\x01 \x01(\t:\x00\x12\r\n\x03Pin\x18\x02 \x01(\x0c:\x00\x12\x0c\n\x02Id\x18\x03 \x01(\t:\x00\x12\x12\n\x07Version\x18\x04 \x01(\x04:\x01\x30\"4\n\nTKeyConfig\x12&\n\x04Keys\x18\x01 \x03(\x0b\x32\x18.NKikimrProto.TKeyRecordB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.key_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TKEYRECORD._serialized_start=43
  _TKEYRECORD._serialized_end=129
  _TKEYCONFIG._serialized_start=131
  _TKEYCONFIG._serialized_end=183
# @@protoc_insertion_point(module_scope)
