# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/protos/yql_mount.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/library/yql/protos/yql_mount.proto\x12\x0fNYqlMountConfig\"L\n\x0bTMountPoint\x12\x11\n\tRootAlias\x18\x01 \x02(\t\x12\x12\n\nMountPoint\x18\x02 \x02(\t\x12\x16\n\x07Library\x18\x03 \x01(\x08:\x05\x66\x61lse\"A\n\x0cTMountConfig\x12\x31\n\x0bMountPoints\x18\x01 \x03(\x0b\x32\x1c.NYqlMountConfig.TMountPointB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.protos.yql_mount_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TMOUNTPOINT._serialized_start=59
  _TMOUNTPOINT._serialized_end=135
  _TMOUNTCONFIG._serialized_start=137
  _TMOUNTCONFIG._serialized_end=202
# @@protoc_insertion_point(module_scope)
