# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/msgbus_kv.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fydb/core/protos/msgbus_kv.proto\x12\rNKikimrClient\"\xd7\x12\n\x10TKeyValueRequest\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x0e\n\x06\x43ookie\x18\x03 \x01(\x04\x12G\n\x0e\x43mdDeleteRange\x18\x04 \x03(\x0b\x32/.NKikimrClient.TKeyValueRequest.TCmdDeleteRange\x12W\n\x16\x43mdIncrementGeneration\x18\x05 \x01(\x0b\x32\x37.NKikimrClient.TKeyValueRequest.TCmdIncrementGeneration\x12\x39\n\x07\x43mdRead\x18\x06 \x03(\x0b\x32(.NKikimrClient.TKeyValueRequest.TCmdRead\x12\x43\n\x0c\x43mdReadRange\x18\x07 \x03(\x0b\x32-.NKikimrClient.TKeyValueRequest.TCmdReadRange\x12;\n\x08\x43mdWrite\x18\x08 \x03(\x0b\x32).NKikimrClient.TKeyValueRequest.TCmdWrite\x12=\n\tCmdRename\x18\t \x03(\x0b\x32*.NKikimrClient.TKeyValueRequest.TCmdRename\x12\x43\n\x0c\x43mdCopyRange\x18\x0b \x03(\x0b\x32-.NKikimrClient.TKeyValueRequest.TCmdCopyRange\x12=\n\tCmdConcat\x18\x0c \x03(\x0b\x32*.NKikimrClient.TKeyValueRequest.TCmdConcat\x12\x43\n\x0c\x43mdGetStatus\x18\r \x03(\x0b\x32-.NKikimrClient.TKeyValueRequest.TCmdGetStatus\x12O\n\x12\x43mdTrimLeakedBlobs\x18\x0e \x01(\x0b\x32\x33.NKikimrClient.TKeyValueRequest.TCmdTrimLeakedBlobs\x12\x61\n\x1b\x43mdSetExecutorFastLogPolicy\x18\x0f \x01(\x0b\x32<.NKikimrClient.TKeyValueRequest.TCmdSetExecutorFastLogPolicy\x12\x19\n\x11\x44\x65\x61\x64lineInstantMs\x18\n \x01(\x04\x1aM\n\tTKeyRange\x12\x0c\n\x04\x46rom\x18\x01 \x01(\x0c\x12\x13\n\x0bIncludeFrom\x18\x02 \x01(\x08\x12\n\n\x02To\x18\x03 \x01(\x0c\x12\x11\n\tIncludeTo\x18\x04 \x01(\x08\x1aK\n\x0fTCmdDeleteRange\x12\x38\n\x05Range\x18\x01 \x01(\x0b\x32).NKikimrClient.TKeyValueRequest.TKeyRange\x1a\x19\n\x17TCmdIncrementGeneration\x1ar\n\x08TCmdRead\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\x0e\n\x06Offset\x18\x02 \x01(\x04\x12\x0c\n\x04Size\x18\x03 \x01(\x04\x12;\n\x08Priority\x18\x04 \x01(\x0e\x32).NKikimrClient.TKeyValueRequest.EPriority\x1a\xaf\x01\n\rTCmdReadRange\x12\x38\n\x05Range\x18\x01 \x01(\x0b\x32).NKikimrClient.TKeyValueRequest.TKeyRange\x12\x13\n\x0bIncludeData\x18\x02 \x01(\x08\x12\x12\n\nLimitBytes\x18\x03 \x01(\x04\x12;\n\x08Priority\x18\x04 \x01(\x0e\x32).NKikimrClient.TKeyValueRequest.EPriority\x1a\xd6\x02\n\tTCmdWrite\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\r\n\x05Value\x18\x02 \x01(\x0c\x12G\n\x0eStorageChannel\x18\x03 \x01(\x0e\x32/.NKikimrClient.TKeyValueRequest.EStorageChannel\x12;\n\x08Priority\x18\x04 \x01(\x0e\x32).NKikimrClient.TKeyValueRequest.EPriority\x12\x12\n\nKeyToCache\x18\x05 \x01(\x0c\x12G\n\x06Tactic\x18\x06 \x01(\x0e\x32\'.NKikimrClient.TKeyValueRequest.ETactic:\x0eMAX_THROUGHPUT\x12J\n\x11\x41utoselectChannel\x18\x07 \x03(\x0e\x32/.NKikimrClient.TKeyValueRequest.EStorageChannel\x1a,\n\nTCmdRename\x12\x0e\n\x06OldKey\x18\x01 \x01(\x0c\x12\x0e\n\x06NewKey\x18\x02 \x01(\x0c\x1av\n\rTCmdCopyRange\x12\x38\n\x05Range\x18\x01 \x01(\x0b\x32).NKikimrClient.TKeyValueRequest.TKeyRange\x12\x13\n\x0bPrefixToAdd\x18\x02 \x01(\x0c\x12\x16\n\x0ePrefixToRemove\x18\x03 \x01(\x0c\x1a\x46\n\nTCmdConcat\x12\x11\n\tInputKeys\x18\x01 \x03(\x0c\x12\x11\n\tOutputKey\x18\x02 \x01(\x0c\x12\x12\n\nKeepInputs\x18\x03 \x01(\x08\x1aX\n\rTCmdGetStatus\x12G\n\x0eStorageChannel\x18\x01 \x01(\x0e\x32/.NKikimrClient.TKeyValueRequest.EStorageChannel\x1a-\n\x13TCmdTrimLeakedBlobs\x12\x16\n\x0eMaxItemsToTrim\x18\x01 \x01(\r\x1a\x38\n\x1cTCmdSetExecutorFastLogPolicy\x12\x18\n\tIsAllowed\x18\x01 \x01(\x08:\x05\x66\x61lse\"\x94\x01\n\x0f\x45StorageChannel\x12\x08\n\x04MAIN\x10\x00\x12\t\n\x05\x45XTRA\x10\x01\x12\n\n\x06\x45XTRA2\x10\x02\x12\n\n\x06\x45XTRA3\x10\x03\x12\n\n\x06\x45XTRA4\x10\x04\x12\n\n\x06\x45XTRA5\x10\x05\x12\n\n\x06\x45XTRA6\x10\x06\x12\n\n\x06\x45XTRA7\x10\x07\x12\n\n\x06\x45XTRA8\x10\x08\x12\n\n\x06\x45XTRA9\x10\t\x12\x0c\n\x06INLINE\x10\xff\xff\x03\")\n\tEPriority\x12\x0c\n\x08REALTIME\x10\x00\x12\x0e\n\nBACKGROUND\x10\x01\".\n\x07\x45Tactic\x12\x12\n\x0eMAX_THROUGHPUT\x10\x00\x12\x0f\n\x0bMIN_LATENCY\x10\x01\"\xaf\x0e\n\x11TKeyValueResponse\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x16\n\rProtobufError\x18\x90\x03 \x01(\x0c\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x04\x12N\n\x11\x44\x65leteRangeResult\x18\x03 \x03(\x0b\x32\x33.NKikimrClient.TKeyValueResponse.TDeleteRangeResult\x12^\n\x19IncrementGenerationResult\x18\x04 \x01(\x0b\x32;.NKikimrClient.TKeyValueResponse.TIncrementGenerationResult\x12@\n\nReadResult\x18\x05 \x03(\x0b\x32,.NKikimrClient.TKeyValueResponse.TReadResult\x12J\n\x0fReadRangeResult\x18\x06 \x03(\x0b\x32\x31.NKikimrClient.TKeyValueResponse.TReadRangeResult\x12\x42\n\x0bWriteResult\x18\x07 \x03(\x0b\x32-.NKikimrClient.TKeyValueResponse.TWriteResult\x12\x44\n\x0cRenameResult\x18\x08 \x03(\x0b\x32..NKikimrClient.TKeyValueResponse.TRenameResult\x12J\n\x0f\x43opyRangeResult\x18\n \x03(\x0b\x32\x31.NKikimrClient.TKeyValueResponse.TCopyRangeResult\x12\x44\n\x0c\x43oncatResult\x18\x0b \x03(\x0b\x32..NKikimrClient.TKeyValueResponse.TConcatResult\x12J\n\x0fGetStatusResult\x18\x0c \x03(\x0b\x32\x31.NKikimrClient.TKeyValueResponse.TGetStatusResult\x12V\n\x15TrimLeakedBlobsResult\x18\r \x01(\x0b\x32\x37.NKikimrClient.TKeyValueResponse.TTrimLeakedBlobsResult\x12h\n\x1eSetExecutorFastLogPolicyResult\x18\x0e \x01(\x0b\x32@.NKikimrClient.TKeyValueResponse.TSetExecutorFastLogPolicyResult\x12\x13\n\x0b\x45rrorReason\x18\t \x01(\t\x1a\xb1\x01\n\rTKeyValuePair\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\r\n\x05Value\x18\x02 \x01(\x0c\x12\x11\n\tValueSize\x18\x03 \x01(\r\x12\x18\n\x10\x43reationUnixTime\x18\x04 \x01(\x04\x12G\n\x0eStorageChannel\x18\x05 \x01(\x0e\x32/.NKikimrClient.TKeyValueRequest.EStorageChannel\x12\x0e\n\x06Status\x18\x06 \x01(\r\x1a$\n\x12TDeleteRangeResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x1a@\n\x1aTIncrementGenerationResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x1a=\n\x0bTReadResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\r\n\x05Value\x18\x02 \x01(\x0c\x12\x0f\n\x07Message\x18\x03 \x01(\t\x1a`\n\x10TReadRangeResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12<\n\x04Pair\x18\x02 \x03(\x0b\x32..NKikimrClient.TKeyValueResponse.TKeyValuePair\x1a\x33\n\x0cTWriteResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x13\n\x0bStatusFlags\x18\x02 \x01(\r\x1a\x1f\n\rTRenameResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x1a\"\n\x10TCopyRangeResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x1a\x1f\n\rTConcatResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x1a\x80\x01\n\x10TGetStatusResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12G\n\x0eStorageChannel\x18\x02 \x01(\x0e\x32/.NKikimrClient.TKeyValueRequest.EStorageChannel\x12\x13\n\x0bStatusFlags\x18\x03 \x01(\r\x1aW\n\x16TTrimLeakedBlobsResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x17\n\x0fNumItemsTrimmed\x18\x02 \x01(\r\x12\x14\n\x0cNumItemsLeft\x18\x03 \x01(\r\x1a\x31\n\x1fTSetExecutorFastLogPolicyResult\x12\x0e\n\x06Status\x18\x01 \x01(\rB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.msgbus_kv_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TKEYVALUEREQUEST._serialized_start=51
  _TKEYVALUEREQUEST._serialized_end=2442
  _TKEYVALUEREQUEST_TKEYRANGE._serialized_start=947
  _TKEYVALUEREQUEST_TKEYRANGE._serialized_end=1024
  _TKEYVALUEREQUEST_TCMDDELETERANGE._serialized_start=1026
  _TKEYVALUEREQUEST_TCMDDELETERANGE._serialized_end=1101
  _TKEYVALUEREQUEST_TCMDINCREMENTGENERATION._serialized_start=1103
  _TKEYVALUEREQUEST_TCMDINCREMENTGENERATION._serialized_end=1128
  _TKEYVALUEREQUEST_TCMDREAD._serialized_start=1130
  _TKEYVALUEREQUEST_TCMDREAD._serialized_end=1244
  _TKEYVALUEREQUEST_TCMDREADRANGE._serialized_start=1247
  _TKEYVALUEREQUEST_TCMDREADRANGE._serialized_end=1422
  _TKEYVALUEREQUEST_TCMDWRITE._serialized_start=1425
  _TKEYVALUEREQUEST_TCMDWRITE._serialized_end=1767
  _TKEYVALUEREQUEST_TCMDRENAME._serialized_start=1769
  _TKEYVALUEREQUEST_TCMDRENAME._serialized_end=1813
  _TKEYVALUEREQUEST_TCMDCOPYRANGE._serialized_start=1815
  _TKEYVALUEREQUEST_TCMDCOPYRANGE._serialized_end=1933
  _TKEYVALUEREQUEST_TCMDCONCAT._serialized_start=1935
  _TKEYVALUEREQUEST_TCMDCONCAT._serialized_end=2005
  _TKEYVALUEREQUEST_TCMDGETSTATUS._serialized_start=2007
  _TKEYVALUEREQUEST_TCMDGETSTATUS._serialized_end=2095
  _TKEYVALUEREQUEST_TCMDTRIMLEAKEDBLOBS._serialized_start=2097
  _TKEYVALUEREQUEST_TCMDTRIMLEAKEDBLOBS._serialized_end=2142
  _TKEYVALUEREQUEST_TCMDSETEXECUTORFASTLOGPOLICY._serialized_start=2144
  _TKEYVALUEREQUEST_TCMDSETEXECUTORFASTLOGPOLICY._serialized_end=2200
  _TKEYVALUEREQUEST_ESTORAGECHANNEL._serialized_start=2203
  _TKEYVALUEREQUEST_ESTORAGECHANNEL._serialized_end=2351
  _TKEYVALUEREQUEST_EPRIORITY._serialized_start=2353
  _TKEYVALUEREQUEST_EPRIORITY._serialized_end=2394
  _TKEYVALUEREQUEST_ETACTIC._serialized_start=2396
  _TKEYVALUEREQUEST_ETACTIC._serialized_end=2442
  _TKEYVALUERESPONSE._serialized_start=2445
  _TKEYVALUERESPONSE._serialized_end=4284
  _TKEYVALUERESPONSE_TKEYVALUEPAIR._serialized_start=3416
  _TKEYVALUERESPONSE_TKEYVALUEPAIR._serialized_end=3593
  _TKEYVALUERESPONSE_TDELETERANGERESULT._serialized_start=3595
  _TKEYVALUERESPONSE_TDELETERANGERESULT._serialized_end=3631
  _TKEYVALUERESPONSE_TINCREMENTGENERATIONRESULT._serialized_start=3633
  _TKEYVALUERESPONSE_TINCREMENTGENERATIONRESULT._serialized_end=3697
  _TKEYVALUERESPONSE_TREADRESULT._serialized_start=3699
  _TKEYVALUERESPONSE_TREADRESULT._serialized_end=3760
  _TKEYVALUERESPONSE_TREADRANGERESULT._serialized_start=3762
  _TKEYVALUERESPONSE_TREADRANGERESULT._serialized_end=3858
  _TKEYVALUERESPONSE_TWRITERESULT._serialized_start=3860
  _TKEYVALUERESPONSE_TWRITERESULT._serialized_end=3911
  _TKEYVALUERESPONSE_TRENAMERESULT._serialized_start=3913
  _TKEYVALUERESPONSE_TRENAMERESULT._serialized_end=3944
  _TKEYVALUERESPONSE_TCOPYRANGERESULT._serialized_start=3946
  _TKEYVALUERESPONSE_TCOPYRANGERESULT._serialized_end=3980
  _TKEYVALUERESPONSE_TCONCATRESULT._serialized_start=3982
  _TKEYVALUERESPONSE_TCONCATRESULT._serialized_end=4013
  _TKEYVALUERESPONSE_TGETSTATUSRESULT._serialized_start=4016
  _TKEYVALUERESPONSE_TGETSTATUSRESULT._serialized_end=4144
  _TKEYVALUERESPONSE_TTRIMLEAKEDBLOBSRESULT._serialized_start=4146
  _TKEYVALUERESPONSE_TTRIMLEAKEDBLOBSRESULT._serialized_end=4233
  _TKEYVALUERESPONSE_TSETEXECUTORFASTLOGPOLICYRESULT._serialized_start=4235
  _TKEYVALUERESPONSE_TSETEXECUTORFASTLOGPOLICYRESULT._serialized_end=4284
# @@protoc_insertion_point(module_scope)
