# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/proto/dq_transport.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/library/yql/dq/proto/dq_transport.proto\x12\rNYql.NDqProto\"<\n\x05TData\x12\x18\n\x10TransportVersion\x18\x01 \x01(\r\x12\x0b\n\x03Raw\x18\x02 \x01(\x0c\x12\x0c\n\x04Rows\x18\x03 \x01(\r*\xa1\x01\n\x15\x45\x44\x61taTransportVersion\x12&\n\"DATA_TRANSPORT_VERSION_UNSPECIFIED\x10\x00\x12\x1c\n\x17\x44\x41TA_TRANSPORT_YSON_1_0\x10\x90N\x12\"\n\x1c\x44\x41TA_TRANSPORT_UV_PICKLE_1_0\x10\xa0\x9c\x01\x12\x1e\n\x18\x44\x41TA_TRANSPORT_ARROW_1_0\x10\xb0\xea\x01\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.proto.dq_transport_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _EDATATRANSPORTVERSION._serialized_start=125
  _EDATATRANSPORTVERSION._serialized_end=286
  _TDATA._serialized_start=62
  _TDATA._serialized_end=122
# @@protoc_insertion_point(module_scope)
