# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/load_test.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blobstorage_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__pb2
from ydb.core.protos import blobstorage_disk_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__pb2
from ydb.core.protos import datashard_load_pb2 as ydb_dot_core_dot_protos_dot_datashard__load__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fydb/core/protos/load_test.proto\x12\x07NKikimr\x1a!ydb/core/protos/blobstorage.proto\x1a&ydb/core/protos/blobstorage_disk.proto\x1a$ydb/core/protos/datashard_load.proto\"\xd8)\n\x12TEvLoadTestRequest\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\x12\x31\n\x04Stop\x18\x03 \x01(\x0b\x32!.NKikimr.TEvLoadTestRequest.TStopH\x00\x12?\n\x0bStorageLoad\x18\x02 \x01(\x0b\x32(.NKikimr.TEvLoadTestRequest.TStorageLoadH\x00\x12\x45\n\x0ePDiskWriteLoad\x18\x04 \x01(\x0b\x32+.NKikimr.TEvLoadTestRequest.TPDiskWriteLoadH\x00\x12;\n\tVDiskLoad\x18\x05 \x01(\x0b\x32&.NKikimr.TEvLoadTestRequest.TVDiskLoadH\x00\x12\x43\n\rPDiskReadLoad\x18\x06 \x01(\x0b\x32*.NKikimr.TEvLoadTestRequest.TPDiskReadLoadH\x00\x12\x41\n\x0cPDiskLogLoad\x18\x07 \x01(\x0b\x32).NKikimr.TEvLoadTestRequest.TPDiskLogLoadH\x00\x12\x41\n\x0cKeyValueLoad\x18\x08 \x01(\x0b\x32).NKikimr.TEvLoadTestRequest.TKeyValueLoadH\x00\x12\x37\n\x07KqpLoad\x18\t \x01(\x0b\x32$.NKikimr.TEvLoadTestRequest.TKqpLoadH\x00\x12=\n\nMemoryLoad\x18\n \x01(\x0b\x32\'.NKikimr.TEvLoadTestRequest.TMemoryLoadH\x00\x12@\n\x08YCSBLoad\x18\x0b \x01(\x0b\x32,.NKikimrDataShardLoad.TEvYCSBTestLoadRequestH\x00\x1a\xdb\x02\n\rTIntervalInfo\x12\x0e\n\x06Weight\x18\x01 \x01(\x01\x12M\n\x07Uniform\x18\x02 \x01(\x0b\x32:.NKikimr.TEvLoadTestRequest.TIntervalInfo.TIntervalUniformH\x00\x12M\n\x07Poisson\x18\x03 \x01(\x0b\x32:.NKikimr.TEvLoadTestRequest.TIntervalInfo.TIntervalPoissonH\x00\x1aN\n\x10TIntervalUniform\x12\r\n\x05MinMs\x18\x01 \x01(\r\x12\r\n\x05MaxMs\x18\x02 \x01(\r\x12\r\n\x05MinUs\x18\x03 \x01(\r\x12\r\n\x05MaxUs\x18\x04 \x01(\r\x1a<\n\x10TIntervalPoisson\x12\x11\n\tFrequency\x18\x01 \x01(\x01\x12\x15\n\rMaxIntervalMs\x18\x02 \x01(\rB\x0e\n\x0c\x44istribution\x1a\x35\n\tTSizeInfo\x12\x0b\n\x03Min\x18\x01 \x01(\r\x12\x0b\n\x03Max\x18\x02 \x01(\r\x12\x0e\n\x06Weight\x18\x03 \x01(\x01\x1a\xc9\t\n\x0cTStorageLoad\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x17\n\x0f\x44urationSeconds\x18\x02 \x01(\r\x12\x1e\n\x0fRequestTracking\x18\x03 \x01(\x08:\x05\x66\x61lse\x12K\n\x07Tablets\x18\x04 \x03(\x0b\x32:.NKikimr.TEvLoadTestRequest.TStorageLoad.TPerTabletProfile\x12\x1b\n\x13ScheduleThresholdUs\x18\x05 \x01(\x04\x12\x1a\n\x12ScheduleRoundingUs\x18\x06 \x01(\x04\x1ay\n\x0cTRequestInfo\x12\x10\n\x08SendTime\x18\x01 \x01(\x02\x12\x0c\n\x04Type\x18\x02 \x01(\x04\x12\x0c\n\x04Size\x18\x03 \x01(\r\x12;\n\x0ePutHandleClass\x18\x04 \x01(\x0e\x32#.NKikimrBlobStorage.EPutHandleClass\x1a\xc0\x01\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\x12\x0f\n\x07GroupId\x18\x03 \x01(\r\x12\x12\n\nGeneration\x18\x04 \x01(\r\x12G\n\x08Requests\x18\x05 \x03(\x0b\x32\x35.NKikimr.TEvLoadTestRequest.TStorageLoad.TRequestInfo\x12 \n\x18ScriptedCycleDurationSec\x18\x06 \x01(\x02\x1a\xae\x05\n\x11TPerTabletProfile\x12\x45\n\x07Tablets\x18\x01 \x03(\x0b\x32\x34.NKikimr.TEvLoadTestRequest.TStorageLoad.TTabletInfo\x12\x34\n\x05Sizes\x18\x02 \x03(\x0b\x32%.NKikimr.TEvLoadTestRequest.TSizeInfo\x12\x41\n\x0eWriteIntervals\x18\x03 \x03(\x0b\x32).NKikimr.TEvLoadTestRequest.TIntervalInfo\x12\x1b\n\x13MaxInFlightRequests\x18\x04 \x01(\r\x12\x18\n\x10MaxInFlightBytes\x18\x05 \x01(\r\x12\x41\n\x0e\x46lushIntervals\x18\x06 \x03(\x0b\x32).NKikimr.TEvLoadTestRequest.TIntervalInfo\x12;\n\x0ePutHandleClass\x18\x07 \x01(\x0e\x32#.NKikimrBlobStorage.EPutHandleClass\x12\x0c\n\x04Soft\x18\x08 \x01(\x08\x12\x1f\n\x17MaxInFlightReadRequests\x18\t \x01(\r\x12\x1c\n\x14MaxInFlightReadBytes\x18\n \x01(\r\x12@\n\rReadIntervals\x18\x0b \x03(\x0b\x32).NKikimr.TEvLoadTestRequest.TIntervalInfo\x12\x38\n\tReadSizes\x18\x0c \x03(\x0b\x32%.NKikimr.TEvLoadTestRequest.TSizeInfo\x12\x1c\n\x14MaxTotalBytesWritten\x18\r \x01(\x04\x12;\n\x0eGetHandleClass\x18\x0e \x01(\x0e\x32#.NKikimrBlobStorage.EGetHandleClass\x1a+\n\x05TStop\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x15\n\rRemoveAllTags\x18\x02 \x01(\x08\x1a\xcd\x03\n\x0fTPDiskWriteLoad\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x11\n\tPDiskGuid\x18\x03 \x01(\x04\x12-\n\x07VDiskId\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x46\n\x06\x43hunks\x18\x05 \x03(\x0b\x32\x36.NKikimr.TEvLoadTestRequest.TPDiskWriteLoad.TChunkInfo\x12\x17\n\x0f\x44urationSeconds\x18\x06 \x01(\r\x12\x16\n\x0eInFlightWrites\x18\x07 \x01(\r\x12\x35\n\x07LogMode\x18\x08 \x01(\x0e\x32$.NKikimr.TEvLoadTestRequest.ELogMode\x12\x18\n\nSequential\x18\t \x01(\x08:\x04true\x12\x15\n\rIntervalMsMin\x18\n \x01(\r\x12\x15\n\rIntervalMsMax\x18\x0b \x01(\r\x12\x14\n\x05Reuse\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10IsWardenlessTest\x18\r \x01(\x08:\x05\x66\x61lse\x1a+\n\nTChunkInfo\x12\r\n\x05Slots\x18\x01 \x01(\r\x12\x0e\n\x06Weight\x18\x02 \x01(\r\x1a\xaa\x04\n\nTVDiskLoad\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12-\n\x07VDiskId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x31\n\tGroupInfo\x18\x10 \x01(\x0b\x32\x1e.NKikimrBlobStorage.TGroupInfo\x12\x10\n\x08TabletId\x18\x05 \x01(\x04\x12\x0f\n\x07\x43hannel\x18\x06 \x01(\r\x12\x12\n\nGeneration\x18\x07 \x01(\r\x12\x17\n\x0f\x44urationSeconds\x18\x08 \x01(\r\x12\x41\n\x0eWriteIntervals\x18\t \x03(\x0b\x32).NKikimr.TEvLoadTestRequest.TIntervalInfo\x12\x39\n\nWriteSizes\x18\n \x03(\x0b\x32%.NKikimr.TEvLoadTestRequest.TSizeInfo\x12\x17\n\x0fInFlightPutsMax\x18\x0b \x01(\r\x12\x1b\n\x13InFlightPutBytesMax\x18\x0c \x01(\x04\x12;\n\x0ePutHandleClass\x18\r \x01(\x0e\x32#.NKikimrBlobStorage.EPutHandleClass\x12J\n\x17\x42\x61rrierAdvanceIntervals\x18\x0e \x03(\x0b\x32).NKikimr.TEvLoadTestRequest.TIntervalInfo\x12\x14\n\x0cStepDistance\x18\x0f \x01(\rJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\x1a\xfe\x02\n\x0eTPDiskReadLoad\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x11\n\tPDiskGuid\x18\x03 \x01(\x04\x12-\n\x07VDiskId\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x45\n\x06\x43hunks\x18\x05 \x03(\x0b\x32\x35.NKikimr.TEvLoadTestRequest.TPDiskReadLoad.TChunkInfo\x12\x17\n\x0f\x44urationSeconds\x18\x06 \x01(\r\x12\x15\n\rInFlightReads\x18\x07 \x01(\r\x12\x19\n\nSequential\x18\t \x01(\x08:\x05\x66\x61lse\x12\x15\n\rIntervalMsMin\x18\n \x01(\r\x12\x15\n\rIntervalMsMax\x18\x0b \x01(\r\x12\x1f\n\x10IsWardenlessTest\x18\r \x01(\x08:\x05\x66\x61lse\x1a+\n\nTChunkInfo\x12\r\n\x05Slots\x18\x01 \x01(\r\x12\x0e\n\x06Weight\x18\x02 \x01(\r\x1a\xad\x03\n\rTPDiskLogLoad\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x11\n\tPDiskGuid\x18\x03 \x01(\x04\x12\x17\n\x0f\x44urationSeconds\x18\x05 \x01(\r\x12H\n\x07Workers\x18\x07 \x03(\x0b\x32\x37.NKikimr.TEvLoadTestRequest.TPDiskLogLoad.TWorkerConfig\x12\x1f\n\x10IsWardenlessTest\x18\x08 \x01(\x08:\x05\x66\x61lse\x1a\xe6\x01\n\rTWorkerConfig\x12-\n\x07VDiskId\x18\x01 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\x12\x13\n\x0bMaxInFlight\x18\x02 \x01(\r\x12\x17\n\x0fSizeIntervalMin\x18\x03 \x01(\r\x12\x17\n\x0fSizeIntervalMax\x18\x04 \x01(\r\x12\x15\n\rBurstInterval\x18\x05 \x01(\x04\x12\x11\n\tBurstSize\x18\x06 \x01(\x04\x12\x17\n\x0fStorageDuration\x18\x07 \x01(\x04\x12\x1c\n\x14MaxTotalBytesWritten\x18\x08 \x01(\x04\x1a\x92\x02\n\rTKeyValueLoad\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x16\n\x0eTargetTabletId\x18\x02 \x01(\x04\x12\x17\n\x0f\x44urationSeconds\x18\x05 \x01(\r\x12H\n\x07Workers\x18\x07 \x03(\x0b\x32\x37.NKikimr.TEvLoadTestRequest.TKeyValueLoad.TWorkerConfig\x1ay\n\rTWorkerConfig\x12\x11\n\tKeyPrefix\x18\x01 \x01(\t\x12\x13\n\x0bMaxInFlight\x18\x02 \x01(\r\x12\x0c\n\x04Size\x18\x0b \x01(\r\x12\x17\n\x08IsInline\x18\t \x01(\x08:\x05\x66\x61lse\x12\x19\n\x0eLoopAtKeyCount\x18\n \x01(\r:\x01\x30\x1a\xbc\x05\n\x08TKqpLoad\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x17\n\x0f\x44urationSeconds\x18\x02 \x01(\r\x12\x16\n\x0eWindowDuration\x18\x03 \x01(\r\x12\x12\n\nWorkingDir\x18\x04 \x01(\t\x12\x15\n\rNumOfSessions\x18\x05 \x01(\r\x12\x18\n\x10IncreaseSessions\x18\x0b \x01(\x08\x12\x1b\n\x13\x44\x65leteTableOnFinish\x18\x06 \x01(\x08\x12\x1e\n\x16UniformPartitionsCount\x18\x07 \x01(\r\x12\x14\n\x0cWorkloadType\x18\x08 \x01(\r\x12\x44\n\x05Stock\x18\t \x01(\x0b\x32\x33.NKikimr.TEvLoadTestRequest.TKqpLoad.TStockWorkloadH\x00\x12>\n\x02Kv\x18\n \x01(\x0b\x32\x30.NKikimr.TEvLoadTestRequest.TKqpLoad.TKvWorkloadH\x00\x1a\x8f\x01\n\x0eTStockWorkload\x12\x19\n\x0cProductCount\x18\x01 \x01(\x04:\x03\x31\x30\x30\x12\x16\n\x08Quantity\x18\x02 \x01(\x04:\x04\x31\x30\x30\x30\x12\x17\n\nOrderCount\x18\x03 \x01(\x04:\x03\x31\x30\x30\x12\x11\n\x05Limit\x18\x04 \x01(\x04:\x02\x31\x30\x12\x1e\n\x10PartitionsByLoad\x18\x05 \x01(\x08:\x04true\x1a\xb5\x01\n\x0bTKvWorkload\x12\x1a\n\x0cInitRowCount\x18\x01 \x01(\x04:\x04\x31\x30\x30\x30\x12\x1e\n\x10PartitionsByLoad\x18\x02 \x01(\x08:\x04true\x12)\n\x0bMaxFirstKey\x18\x03 \x01(\x04:\x14\x31\x38\x34\x34\x36\x37\x34\x34\x30\x37\x33\x37\x30\x39\x35\x35\x31\x36\x31\x35\x12\x14\n\tStringLen\x18\x04 \x01(\x04:\x01\x38\x12\x15\n\nColumnsCnt\x18\x05 \x01(\x04:\x01\x32\x12\x12\n\x07RowsCnt\x18\x06 \x01(\x04:\x01\x31\x42\n\n\x08Workload\x1aZ\n\x0bTMemoryLoad\x12\x0b\n\x03Tag\x18\x01 \x01(\x04\x12\x17\n\x0f\x44urationSeconds\x18\x02 \x01(\r\x12\x11\n\tBlockSize\x18\x03 \x01(\x04\x12\x12\n\nIntervalUs\x18\x04 \x01(\x04\">\n\x08\x45LogMode\x12\x10\n\x0cLOG_PARALLEL\x10\x01\x12\x12\n\x0eLOG_SEQUENTIAL\x10\x02\x12\x0c\n\x08LOG_NONE\x10\x03\x42\t\n\x07\x43ommand\"W\n\x13TEvLoadTestResponse\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12\x0e\n\x06\x43ookie\x18\x03 \x01(\x04\x12\x0b\n\x03Tag\x18\x04 \x01(\x04\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.load_test_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVLOADTESTREQUEST._serialized_start=158
  _TEVLOADTESTREQUEST._serialized_end=5494
  _TEVLOADTESTREQUEST_TINTERVALINFO._serialized_start=834
  _TEVLOADTESTREQUEST_TINTERVALINFO._serialized_end=1181
  _TEVLOADTESTREQUEST_TINTERVALINFO_TINTERVALUNIFORM._serialized_start=1025
  _TEVLOADTESTREQUEST_TINTERVALINFO_TINTERVALUNIFORM._serialized_end=1103
  _TEVLOADTESTREQUEST_TINTERVALINFO_TINTERVALPOISSON._serialized_start=1105
  _TEVLOADTESTREQUEST_TINTERVALINFO_TINTERVALPOISSON._serialized_end=1165
  _TEVLOADTESTREQUEST_TSIZEINFO._serialized_start=1183
  _TEVLOADTESTREQUEST_TSIZEINFO._serialized_end=1236
  _TEVLOADTESTREQUEST_TSTORAGELOAD._serialized_start=1239
  _TEVLOADTESTREQUEST_TSTORAGELOAD._serialized_end=2464
  _TEVLOADTESTREQUEST_TSTORAGELOAD_TREQUESTINFO._serialized_start=1459
  _TEVLOADTESTREQUEST_TSTORAGELOAD_TREQUESTINFO._serialized_end=1580
  _TEVLOADTESTREQUEST_TSTORAGELOAD_TTABLETINFO._serialized_start=1583
  _TEVLOADTESTREQUEST_TSTORAGELOAD_TTABLETINFO._serialized_end=1775
  _TEVLOADTESTREQUEST_TSTORAGELOAD_TPERTABLETPROFILE._serialized_start=1778
  _TEVLOADTESTREQUEST_TSTORAGELOAD_TPERTABLETPROFILE._serialized_end=2464
  _TEVLOADTESTREQUEST_TSTOP._serialized_start=2466
  _TEVLOADTESTREQUEST_TSTOP._serialized_end=2509
  _TEVLOADTESTREQUEST_TPDISKWRITELOAD._serialized_start=2512
  _TEVLOADTESTREQUEST_TPDISKWRITELOAD._serialized_end=2973
  _TEVLOADTESTREQUEST_TPDISKWRITELOAD_TCHUNKINFO._serialized_start=2930
  _TEVLOADTESTREQUEST_TPDISKWRITELOAD_TCHUNKINFO._serialized_end=2973
  _TEVLOADTESTREQUEST_TVDISKLOAD._serialized_start=2976
  _TEVLOADTESTREQUEST_TVDISKLOAD._serialized_end=3530
  _TEVLOADTESTREQUEST_TPDISKREADLOAD._serialized_start=3533
  _TEVLOADTESTREQUEST_TPDISKREADLOAD._serialized_end=3915
  _TEVLOADTESTREQUEST_TPDISKREADLOAD_TCHUNKINFO._serialized_start=2930
  _TEVLOADTESTREQUEST_TPDISKREADLOAD_TCHUNKINFO._serialized_end=2973
  _TEVLOADTESTREQUEST_TPDISKLOGLOAD._serialized_start=3918
  _TEVLOADTESTREQUEST_TPDISKLOGLOAD._serialized_end=4347
  _TEVLOADTESTREQUEST_TPDISKLOGLOAD_TWORKERCONFIG._serialized_start=4117
  _TEVLOADTESTREQUEST_TPDISKLOGLOAD_TWORKERCONFIG._serialized_end=4347
  _TEVLOADTESTREQUEST_TKEYVALUELOAD._serialized_start=4350
  _TEVLOADTESTREQUEST_TKEYVALUELOAD._serialized_end=4624
  _TEVLOADTESTREQUEST_TKEYVALUELOAD_TWORKERCONFIG._serialized_start=4503
  _TEVLOADTESTREQUEST_TKEYVALUELOAD_TWORKERCONFIG._serialized_end=4624
  _TEVLOADTESTREQUEST_TKQPLOAD._serialized_start=4627
  _TEVLOADTESTREQUEST_TKQPLOAD._serialized_end=5327
  _TEVLOADTESTREQUEST_TKQPLOAD_TSTOCKWORKLOAD._serialized_start=4988
  _TEVLOADTESTREQUEST_TKQPLOAD_TSTOCKWORKLOAD._serialized_end=5131
  _TEVLOADTESTREQUEST_TKQPLOAD_TKVWORKLOAD._serialized_start=5134
  _TEVLOADTESTREQUEST_TKQPLOAD_TKVWORKLOAD._serialized_end=5315
  _TEVLOADTESTREQUEST_TMEMORYLOAD._serialized_start=5329
  _TEVLOADTESTREQUEST_TMEMORYLOAD._serialized_end=5419
  _TEVLOADTESTREQUEST_ELOGMODE._serialized_start=5421
  _TEVLOADTESTREQUEST_ELOGMODE._serialized_end=5483
  _TEVLOADTESTRESPONSE._serialized_start=5496
  _TEVLOADTESTRESPONSE._serialized_end=5583
# @@protoc_insertion_point(module_scope)
