# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/kqp_stats.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.dq.actors.protos import dq_stats_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__stats__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fydb/core/protos/kqp_stats.proto\x12\tNKqpProto\x1a/ydb/library/yql/dq/actors/protos/dq_stats.proto\"L\n\x10TKqpStatsCompile\x12\x11\n\tFromCache\x18\x01 \x01(\x08\x12\x12\n\nDurationUs\x18\x02 \x01(\x04\x12\x11\n\tCpuTimeUs\x18\x03 \x01(\x04\"C\n\x18TKqpShardTableExtraStats\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x12\x16\n\x0eShardCpuTimeUs\x18\x02 \x01(\x04\"k\n\x1cTKqpShardTableAggrExtraStats\x12\x16\n\x0e\x41\x66\x66\x65\x63tedShards\x18\x01 \x01(\r\x12\x33\n\x0eShardCpuTimeUs\x18\x02 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\"\xc7\x01\n\x17TKqpScanTableExtraStats\x12\x18\n\x10IScanStartTimeMs\x18\x01 \x01(\x04\x12\x19\n\x11IScanFinishTimeMs\x18\x02 \x01(\x04\x12\x16\n\x0eIScanCpuTimeUs\x18\x03 \x01(\x04\x12\x17\n\x0fIScanWaitTimeUs\x18\x04 \x01(\x04\x12\x17\n\x0fIScanPageFaults\x18\x05 \x01(\x04\x12\x10\n\x08Messages\x18\x06 \x01(\x04\x12\x1b\n\x13MessagesByPageFault\x18\x07 \x01(\x04\"\x1c\n\x1aTKqpComputeActorExtraStats\"J\n\x13TKqpStageExtraStats\x12\x33\n\x0e\x44\x61tashardTasks\x18\x01 \x03(\x0b\x32\x1b.NYql.NDqProto.TDqTaskStats\"\xd3\x01\n\x17TKqpExecutionExtraStats\x12\x16\n\x0e\x41\x66\x66\x65\x63tedShards\x18\x01 \x01(\r\x12\x35\n\x10\x43omputeCpuTimeUs\x18\x02 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12\x34\n\x0fShardsCpuTimeUs\x18\x03 \x01(\x0b\x32\x1b.NYql.NDqProto.TDqStatsAggr\x12\x18\n\x10ResolveCpuTimeUs\x18\x64 \x01(\x04\x12\x19\n\x11ResolveWallTimeUs\x18\x65 \x01(\x04\"\xfa\x01\n\x0eTKqpStatsQuery\x12\x12\n\nDurationUs\x18\x01 \x01(\x04\x12\x30\n\x0b\x43ompilation\x18\x02 \x01(\x0b\x32\x1b.NKqpProto.TKqpStatsCompile\x12\x17\n\x0fWorkerCpuTimeUs\x18\x04 \x01(\x04\x12\x15\n\rReadSetsCount\x18\x05 \x01(\x04\x12\x1b\n\x13MaxShardProgramSize\x18\x06 \x01(\x04\x12\x19\n\x11MaxShardReplySize\x18\x07 \x01(\x04\x12\x34\n\nExecutions\x18\x08 \x03(\x0b\x32 .NYql.NDqProto.TDqExecutionStatsJ\x04\x08\x03\x10\x04\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.kqp_stats_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TKQPSTATSCOMPILE._serialized_start=95
  _TKQPSTATSCOMPILE._serialized_end=171
  _TKQPSHARDTABLEEXTRASTATS._serialized_start=173
  _TKQPSHARDTABLEEXTRASTATS._serialized_end=240
  _TKQPSHARDTABLEAGGREXTRASTATS._serialized_start=242
  _TKQPSHARDTABLEAGGREXTRASTATS._serialized_end=349
  _TKQPSCANTABLEEXTRASTATS._serialized_start=352
  _TKQPSCANTABLEEXTRASTATS._serialized_end=551
  _TKQPCOMPUTEACTOREXTRASTATS._serialized_start=553
  _TKQPCOMPUTEACTOREXTRASTATS._serialized_end=581
  _TKQPSTAGEEXTRASTATS._serialized_start=583
  _TKQPSTAGEEXTRASTATS._serialized_end=657
  _TKQPEXECUTIONEXTRASTATS._serialized_start=660
  _TKQPEXECUTIONEXTRASTATS._serialized_end=871
  _TKQPSTATSQUERY._serialized_start=874
  _TKQPSTATSQUERY._serialized_end=1124
# @@protoc_insertion_point(module_scope)
