# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/statestorage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/statestorage.proto\x12\x13NKikimrStateStorage\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\"-\n\tTEvLookup\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x04\"\xca\x03\n\x07TEvInfo\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\x12\x0e\n\x06\x43ookie\x18\x03 \x01(\x04\x12-\n\rCurrentLeader\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x33\n\x13\x43urrentLeaderTablet\x18\x05 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x19\n\x11\x43urrentGeneration\x18\x06 \x01(\r\x12\x13\n\x0b\x43urrentStep\x18\x07 \x01(\r\x12\x0e\n\x06Locked\x18\x08 \x01(\x08\x12\x11\n\tLockedFor\x18\t \x01(\x04\x12\x11\n\tSignature\x18\n \x01(\x04\x12(\n\x08\x46ollower\x18\x0b \x03(\x0b\x32\x16.NActorsProto.TActorId\x12.\n\x0e\x46ollowerTablet\x18\x0c \x03(\x0b\x32\x16.NActorsProto.TActorId\x12\x32\n\x12\x46ollowerCandidates\x18\r \x03(\x0b\x32\x16.NActorsProto.TActorId\x12\x19\n\x11\x43onfigContentHash\x18\x0e \x01(\x07\"\x14\n\x12TEvReplicaShutdown\"\x10\n\x0eTEvDumpRequest\"5\n\x07TEvDump\x12*\n\x04Info\x18\x01 \x03(\x0b\x32\x1c.NKikimrStateStorage.TEvInfo\"\xec\x01\n\tTEvUpdate\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x04\x12.\n\x0eProposedLeader\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x34\n\x14ProposedLeaderTablet\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x1a\n\x12ProposedGeneration\x18\x05 \x01(\r\x12\x14\n\x0cProposedStep\x18\x06 \x01(\r\x12\x11\n\tSignature\x18\x07 \x01(\x04\x12\x12\n\nIsGuardian\x18\x08 \x01(\x08\"\x1d\n\tTEvDelete\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\"N\n\nTEvCleanup\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12.\n\x0eProposedLeader\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\"\x94\x01\n\x13TEvRegisterFollower\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12(\n\x08\x46ollower\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12.\n\x0e\x46ollowerTablet\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x11\n\tCandidate\x18\x04 \x01(\x08\"S\n\x15TEvUnregisterFollower\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12(\n\x08\x46ollower\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\"\x8a\x01\n\x07TEvLock\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x04\x12.\n\x0eProposedLeader\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x1a\n\x12ProposedGeneration\x18\x04 \x01(\r\x12\x11\n\tSignature\x18\x05 \x01(\x04\">\n\x17TEvReplicaLeaderDemoted\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x11\n\tSignature\x18\x02 \x01(\x04\"\x7f\n\x16TEvReplicaBoardPublish\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0f\n\x07Payload\x18\x02 \x01(\x0c\x12\r\n\x05TtlMs\x18\x03 \x01(\x04\x12\x10\n\x08Register\x18\x04 \x01(\x08\x12%\n\x05Owner\x18\x05 \x01(\x0b\x32\x16.NActorsProto.TActorId\"\x1b\n\x19TEvReplicaBoardPublishAck\"_\n\x15TEvReplicaBoardLookup\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12%\n\x05Owner\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x11\n\tSubscribe\x18\x03 \x01(\x08\"\x18\n\x16TEvReplicaBoardCleanup\"I\n\x0fTBoardEntryInfo\x12%\n\x05Owner\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0f\n\x07Payload\x18\x02 \x01(\x0c\"h\n\x13TEvReplicaBoardInfo\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0f\n\x07\x44ropped\x18\x02 \x01(\x08\x12\x32\n\x04Info\x18\x03 \x03(\x0b\x32$.NKikimrStateStorage.TBoardEntryInfo\"\xcb\x01\n\x13TEndpointBoardEntry\x12\x0f\n\x07\x41\x64\x64ress\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x0c\n\x04Load\x18\x03 \x01(\x02\x12\x0b\n\x03Ssl\x18\x04 \x01(\x08\x12\x10\n\x08Services\x18\x05 \x03(\t\x12\x12\n\nDataCenter\x18\x06 \x01(\t\x12\x0e\n\x06NodeId\x18\x07 \x01(\r\x12\x13\n\x0b\x41\x64\x64ressesV4\x18\x08 \x03(\t\x12\x13\n\x0b\x41\x64\x64ressesV6\x18\t \x03(\t\x12\x1a\n\x12TargetNameOverride\x18\n \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.statestorage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVLOOKUP._serialized_start=127
  _TEVLOOKUP._serialized_end=172
  _TEVINFO._serialized_start=175
  _TEVINFO._serialized_end=633
  _TEVREPLICASHUTDOWN._serialized_start=635
  _TEVREPLICASHUTDOWN._serialized_end=655
  _TEVDUMPREQUEST._serialized_start=657
  _TEVDUMPREQUEST._serialized_end=673
  _TEVDUMP._serialized_start=675
  _TEVDUMP._serialized_end=728
  _TEVUPDATE._serialized_start=731
  _TEVUPDATE._serialized_end=967
  _TEVDELETE._serialized_start=969
  _TEVDELETE._serialized_end=998
  _TEVCLEANUP._serialized_start=1000
  _TEVCLEANUP._serialized_end=1078
  _TEVREGISTERFOLLOWER._serialized_start=1081
  _TEVREGISTERFOLLOWER._serialized_end=1229
  _TEVUNREGISTERFOLLOWER._serialized_start=1231
  _TEVUNREGISTERFOLLOWER._serialized_end=1314
  _TEVLOCK._serialized_start=1317
  _TEVLOCK._serialized_end=1455
  _TEVREPLICALEADERDEMOTED._serialized_start=1457
  _TEVREPLICALEADERDEMOTED._serialized_end=1519
  _TEVREPLICABOARDPUBLISH._serialized_start=1521
  _TEVREPLICABOARDPUBLISH._serialized_end=1648
  _TEVREPLICABOARDPUBLISHACK._serialized_start=1650
  _TEVREPLICABOARDPUBLISHACK._serialized_end=1677
  _TEVREPLICABOARDLOOKUP._serialized_start=1679
  _TEVREPLICABOARDLOOKUP._serialized_end=1774
  _TEVREPLICABOARDCLEANUP._serialized_start=1776
  _TEVREPLICABOARDCLEANUP._serialized_end=1800
  _TBOARDENTRYINFO._serialized_start=1802
  _TBOARDENTRYINFO._serialized_end=1875
  _TEVREPLICABOARDINFO._serialized_start=1877
  _TEVREPLICABOARDINFO._serialized_end=1981
  _TENDPOINTBOARDENTRY._serialized_start=1984
  _TENDPOINTBOARDENTRY._serialized_end=2187
# @@protoc_insertion_point(module_scope)
