# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/ydb_clickhouse_internal.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_table_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__table__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3ydb/public/api/protos/ydb_clickhouse_internal.proto\x12\x16Ydb.ClickhouseInternal\x1a)ydb/public/api/protos/ydb_operation.proto\x1a%ydb/public/api/protos/ydb_table.proto\"\xfa\x01\n\x0bScanRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x03 \x03(\t\x12\x10\n\x08\x66rom_key\x18\x04 \x01(\x0c\x12\x1a\n\x12\x66rom_key_inclusive\x18\x05 \x01(\x08\x12\x0e\n\x06to_key\x18\x06 \x01(\x0c\x12\x18\n\x10to_key_inclusive\x18\x07 \x01(\x08\x12\x10\n\x08max_rows\x18\x08 \x01(\x04\x12\x11\n\tmax_bytes\x18\t \x01(\x04\x12\x13\n\x0bsnapshot_id\x18\n \x01(\t\"<\n\x0cScanResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"W\n\nScanResult\x12\x0e\n\x06\x62locks\x18\x01 \x03(\x0c\x12\x0b\n\x03\x65os\x18\x02 \x01(\x08\x12\x10\n\x08last_key\x18\x03 \x01(\x0c\x12\x1a\n\x12last_key_inclusive\x18\x04 \x01(\x08\"i\n\x18GetShardLocationsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x12\n\ntablet_ids\x18\x02 \x03(\x04\"I\n\x19GetShardLocationsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\";\n\nTabletInfo\x12\x11\n\ttablet_id\x18\x01 \x01(\x04\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04port\x18\x03 \x01(\r\"N\n\x17GetShardLocationsResult\x12\x33\n\x07tablets\x18\x01 \x03(\x0b\x32\".Ydb.ClickhouseInternal.TabletInfo\"\x80\x01\n\x14\x44\x65scribeTableRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x1f\n\x17include_partitions_info\x18\x03 \x01(\x08\"N\n\rPartitionInfo\x12\x11\n\ttablet_id\x18\x01 \x01(\x04\x12\x0f\n\x07\x65nd_key\x18\x02 \x01(\x0c\x12\x19\n\x11\x65nd_key_inclusive\x18\x03 \x01(\x08\"\xa1\x01\n\x13\x44\x65scribeTableResult\x12&\n\x07\x63olumns\x18\x02 \x03(\x0b\x32\x15.Ydb.Table.ColumnMeta\x12\x13\n\x0bprimary_key\x18\x03 \x03(\t\x12\x39\n\npartitions\x18\x04 \x03(\x0b\x32%.Ydb.ClickhouseInternal.PartitionInfo\x12\x12\n\nis_virtual\x18\x05 \x01(\x08\"E\n\x15\x44\x65scribeTableResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"}\n\x15\x43reateSnapshotRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x03(\t\x12\x1b\n\x13ignore_system_views\x18\x03 \x01(\x08\"?\n\x14\x43reateSnapshotResult\x12\x13\n\x0bsnapshot_id\x18\x01 \x01(\t\x12\x12\n\ntimeout_ms\x18\x02 \x01(\x04\"F\n\x16\x43reateSnapshotResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x93\x01\n\x16RefreshSnapshotRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x03(\t\x12\x13\n\x0bsnapshot_id\x18\x03 \x01(\t\x12\x1b\n\x13ignore_system_views\x18\x04 \x01(\x08\",\n\x15RefreshSnapshotResult\x12\x13\n\x0bsnapshot_id\x18\x01 \x01(\t\"G\n\x17RefreshSnapshotResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x93\x01\n\x16\x44iscardSnapshotRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x0c\n\x04path\x18\x02 \x03(\t\x12\x13\n\x0bsnapshot_id\x18\x03 \x01(\t\x12\x1b\n\x13ignore_system_views\x18\x04 \x01(\x08\",\n\x15\x44iscardSnapshotResult\x12\x13\n\x0bsnapshot_id\x18\x01 \x01(\t\"G\n\x17\x44iscardSnapshotResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationB8\n\x19\x63om.yandex.ydb.clickhouseB\x18\x43lickhouseInternalProtos\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.ydb_clickhouse_internal_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031com.yandex.ydb.clickhouseB\030ClickhouseInternalProtos\370\001\001'
  _SCANREQUEST._serialized_start=162
  _SCANREQUEST._serialized_end=412
  _SCANRESPONSE._serialized_start=414
  _SCANRESPONSE._serialized_end=474
  _SCANRESULT._serialized_start=476
  _SCANRESULT._serialized_end=563
  _GETSHARDLOCATIONSREQUEST._serialized_start=565
  _GETSHARDLOCATIONSREQUEST._serialized_end=670
  _GETSHARDLOCATIONSRESPONSE._serialized_start=672
  _GETSHARDLOCATIONSRESPONSE._serialized_end=745
  _TABLETINFO._serialized_start=747
  _TABLETINFO._serialized_end=806
  _GETSHARDLOCATIONSRESULT._serialized_start=808
  _GETSHARDLOCATIONSRESULT._serialized_end=886
  _DESCRIBETABLEREQUEST._serialized_start=889
  _DESCRIBETABLEREQUEST._serialized_end=1017
  _PARTITIONINFO._serialized_start=1019
  _PARTITIONINFO._serialized_end=1097
  _DESCRIBETABLERESULT._serialized_start=1100
  _DESCRIBETABLERESULT._serialized_end=1261
  _DESCRIBETABLERESPONSE._serialized_start=1263
  _DESCRIBETABLERESPONSE._serialized_end=1332
  _CREATESNAPSHOTREQUEST._serialized_start=1334
  _CREATESNAPSHOTREQUEST._serialized_end=1459
  _CREATESNAPSHOTRESULT._serialized_start=1461
  _CREATESNAPSHOTRESULT._serialized_end=1524
  _CREATESNAPSHOTRESPONSE._serialized_start=1526
  _CREATESNAPSHOTRESPONSE._serialized_end=1596
  _REFRESHSNAPSHOTREQUEST._serialized_start=1599
  _REFRESHSNAPSHOTREQUEST._serialized_end=1746
  _REFRESHSNAPSHOTRESULT._serialized_start=1748
  _REFRESHSNAPSHOTRESULT._serialized_end=1792
  _REFRESHSNAPSHOTRESPONSE._serialized_start=1794
  _REFRESHSNAPSHOTRESPONSE._serialized_end=1865
  _DISCARDSNAPSHOTREQUEST._serialized_start=1868
  _DISCARDSNAPSHOTREQUEST._serialized_end=2015
  _DISCARDSNAPSHOTRESULT._serialized_start=2017
  _DISCARDSNAPSHOTRESULT._serialized_end=2061
  _DISCARDSNAPSHOTRESPONSE._serialized_start=2063
  _DISCARDSNAPSHOTRESPONSE._serialized_end=2134
# @@protoc_insertion_point(module_scope)
