# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_disk_color.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/protos/blobstorage_disk_color.proto\x12\x12NKikimrBlobStorage\"\x8c\x01\n\x10TPDiskSpaceColor\"x\n\x01\x45\x12\t\n\x05GREEN\x10\x00\x12\x08\n\x04\x43YAN\x10\n\x12\x10\n\x0cLIGHT_YELLOW\x10\x0f\x12\n\n\x06YELLOW\x10\x14\x12\x10\n\x0cLIGHT_ORANGE\x10\x1e\x12\x0e\n\nPRE_ORANGE\x10#\x12\n\n\x06ORANGE\x10(\x12\x07\n\x03RED\x10\x32\x12\t\n\x05\x42LACK\x10<b\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_disk_color_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TPDISKSPACECOLOR._serialized_start=69
  _TPDISKSPACECOLOR._serialized_end=209
  _TPDISKSPACECOLOR_E._serialized_start=89
  _TPDISKSPACECOLOR_E._serialized_end=209
# @@protoc_insertion_point(module_scope)
