# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_columnshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/counters_columnshard.proto\x12\x14NKikimr.NColumnShard\x1a\x1eydb/core/protos/counters.proto*\xc6\x12\n\x0f\x45SimpleCounters\x12 \n\x0e\x43OUNTER_TABLES\x10\x00\x1a\x0c\x82\xd6\x1b\x08\n\x06Tables\x12-\n\x15\x43OUNTER_TABLE_PRESETS\x10\x01\x1a\x12\x82\xd6\x1b\x0e\n\x0cTablePresets\x12)\n\x13\x43OUNTER_TTL_PRESETS\x10\x02\x1a\x10\x82\xd6\x1b\x0c\n\nTtlPresets\x12\'\n\x12\x43OUNTER_TABLE_TTLS\x10\x03\x1a\x0f\x82\xd6\x1b\x0b\n\tTableTtls\x12\"\n\x0f\x43OUNTER_INDEXES\x10\x04\x1a\r\x82\xd6\x1b\t\n\x07Indexes\x12\x33\n\x18\x43OUNTER_PREPARED_RECORDS\x10\x05\x1a\x15\x82\xd6\x1b\x11\n\x0fPreparedRecords\x12/\n\x16\x43OUNTER_PREPARED_BYTES\x10\x06\x1a\x13\x82\xd6\x1b\x0f\n\rPreparedBytes\x12\x35\n\x19\x43OUNTER_COMMITTED_RECORDS\x10\x07\x1a\x16\x82\xd6\x1b\x12\n\x10\x43ommittedRecords\x12\x31\n\x17\x43OUNTER_COMMITTED_BYTES\x10\x08\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43ommittedBytes\x12,\n\x14\x43OUNTER_INDEX_TABLES\x10\t\x1a\x12\x82\xd6\x1b\x0e\n\x0cIndex/Tables\x12\x30\n\x16\x43OUNTER_INDEX_GRANULES\x10\n\x1a\x14\x82\xd6\x1b\x10\n\x0eIndex/Granules\x12;\n\x1c\x43OUNTER_INDEX_EMPTY_GRANULES\x10\x0b\x1a\x19\x82\xd6\x1b\x15\n\x13Index/EmptyGranules\x12\x45\n!COUNTER_INDEX_OVERLOADED_GRANULES\x10\x0c\x1a\x1e\x82\xd6\x1b\x1a\n\x18Index/OverloadedGranules\x12;\n\x1c\x43OUNTER_INDEX_COLUMN_RECORDS\x10\r\x1a\x19\x82\xd6\x1b\x15\n\x13Index/ColumnRecords\x12H\n#COUNTER_INDEX_COLUMN_METADATA_BYTES\x10\x0e\x1a\x1f\x82\xd6\x1b\x1b\n\x19Index/ColumnMetadataBytes\x12;\n\x19\x43OUNTER_INSERTED_PORTIONS\x10\x0f\x1a\x1c\x82\xd6\x1b\x18\n\x16Index/InsertedPortions\x12\x35\n\x16\x43OUNTER_INSERTED_BLOBS\x10\x10\x1a\x19\x82\xd6\x1b\x15\n\x13Index/InsertedBlobs\x12\x33\n\x15\x43OUNTER_INSERTED_ROWS\x10\x11\x1a\x18\x82\xd6\x1b\x14\n\x12Index/InsertedRows\x12\x35\n\x16\x43OUNTER_INSERTED_BYTES\x10\x12\x1a\x19\x82\xd6\x1b\x15\n\x13Index/InsertedBytes\x12<\n\x1a\x43OUNTER_INSERTED_RAW_BYTES\x10\x13\x1a\x1c\x82\xd6\x1b\x18\n\x16Index/InsertedBytesRaw\x12=\n\x1a\x43OUNTER_COMPACTED_PORTIONS\x10\x14\x1a\x1d\x82\xd6\x1b\x19\n\x17Index/CompactedPortions\x12\x37\n\x17\x43OUNTER_COMPACTED_BLOBS\x10\x15\x1a\x1a\x82\xd6\x1b\x16\n\x14Index/CompactedBlobs\x12\x35\n\x16\x43OUNTER_COMPACTED_ROWS\x10\x16\x1a\x19\x82\xd6\x1b\x15\n\x13Index/CompactedRows\x12\x37\n\x17\x43OUNTER_COMPACTED_BYTES\x10\x17\x1a\x1a\x82\xd6\x1b\x16\n\x14Index/CompactedBytes\x12>\n\x1b\x43OUNTER_COMPACTED_RAW_BYTES\x10\x18\x1a\x1d\x82\xd6\x1b\x19\n\x17Index/CompactedBytesRaw\x12H\n COUNTER_SPLIT_COMPACTED_PORTIONS\x10\x19\x1a\"\x82\xd6\x1b\x1e\n\x1cIndex/SplitCompactedPortions\x12\x42\n\x1d\x43OUNTER_SPLIT_COMPACTED_BLOBS\x10\x1a\x1a\x1f\x82\xd6\x1b\x1b\n\x19Index/SplitCompactedBlobs\x12@\n\x1c\x43OUNTER_SPLIT_COMPACTED_ROWS\x10\x1b\x1a\x1e\x82\xd6\x1b\x1a\n\x18Index/SplitCompactedRows\x12\x42\n\x1d\x43OUNTER_SPLIT_COMPACTED_BYTES\x10\x1c\x1a\x1f\x82\xd6\x1b\x1b\n\x19Index/SplitCompactedBytes\x12I\n!COUNTER_SPLIT_COMPACTED_RAW_BYTES\x10\x1d\x1a\"\x82\xd6\x1b\x1e\n\x1cIndex/SplitCompactedBytesRaw\x12;\n\x19\x43OUNTER_INACTIVE_PORTIONS\x10\x1e\x1a\x1c\x82\xd6\x1b\x18\n\x16Index/InactivePortions\x12\x35\n\x16\x43OUNTER_INACTIVE_BLOBS\x10\x1f\x1a\x19\x82\xd6\x1b\x15\n\x13Index/InactiveBlobs\x12\x33\n\x15\x43OUNTER_INACTIVE_ROWS\x10 \x1a\x18\x82\xd6\x1b\x14\n\x12Index/InactiveRows\x12\x35\n\x16\x43OUNTER_INACTIVE_BYTES\x10!\x1a\x19\x82\xd6\x1b\x15\n\x13Index/InactiveBytes\x12<\n\x1a\x43OUNTER_INACTIVE_RAW_BYTES\x10\"\x1a\x1c\x82\xd6\x1b\x18\n\x16Index/InactiveBytesRaw\x12*\n\x13\x43OUNTER_SCAN_IN_FLY\x10#\x1a\x11\x82\xd6\x1b\r\n\x0bScanTxInFly\x12\x39\n\x18\x43OUNTER_EVICTED_PORTIONS\x10$\x1a\x1b\x82\xd6\x1b\x17\n\x15Index/EvictedPortions\x12\x33\n\x15\x43OUNTER_EVICTED_BLOBS\x10%\x1a\x18\x82\xd6\x1b\x14\n\x12Index/EvictedBlobs\x12\x31\n\x14\x43OUNTER_EVICTED_ROWS\x10&\x1a\x17\x82\xd6\x1b\x13\n\x11Index/EvictedRows\x12\x33\n\x15\x43OUNTER_EVICTED_BYTES\x10\'\x1a\x18\x82\xd6\x1b\x14\n\x12Index/EvictedBytes\x12:\n\x19\x43OUNTER_EVICTED_RAW_BYTES\x10(\x1a\x1b\x82\xd6\x1b\x17\n\x15Index/EvictedBytesRaw\x12,\n\x15\x43OUNTER_WRITES_IN_FLY\x10)\x1a\x11\x82\xd6\x1b\r\n\x0bWritesInFly*\x85!\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00\x12-\n\x15\x43OUNTER_WRITE_SUCCESS\x10\x01\x1a\x12\x82\xd6\x1b\x0e\n\x0cWriteSuccess\x12\'\n\x12\x43OUNTER_WRITE_FAIL\x10\x02\x1a\x0f\x82\xd6\x1b\x0b\n\tWriteFail\x12+\n\x14\x43OUNTER_READ_SUCCESS\x10\x03\x1a\x11\x82\xd6\x1b\r\n\x0bReadSuccess\x12%\n\x11\x43OUNTER_READ_FAIL\x10\x04\x1a\x0e\x82\xd6\x1b\n\n\x08ReadFail\x12\x31\n\x17\x43OUNTER_PREPARE_REQUEST\x10\x05\x1a\x14\x82\xd6\x1b\x10\n\x0ePrepareRequest\x12-\n\x15\x43OUNTER_PREPARE_ERROR\x10\x06\x1a\x12\x82\xd6\x1b\x0e\n\x0cPrepareError\x12\x31\n\x17\x43OUNTER_PREPARE_SUCCESS\x10\x07\x1a\x14\x82\xd6\x1b\x10\n\x0ePrepareSuccess\x12\x34\n\x19\x43OUNTER_PLAN_STEP_IGNORED\x10\x08\x1a\x15\x82\xd6\x1b\x11\n\x0fPlanStepIgnored\x12\x36\n\x1a\x43OUNTER_PLAN_STEP_ACCEPTED\x10\t\x1a\x16\x82\xd6\x1b\x12\n\x10PlanStepAccepted\x12+\n\x14\x43OUNTER_SCANNED_ROWS\x10\n\x1a\x11\x82\xd6\x1b\r\n\x0bScannedRows\x12-\n\x15\x43OUNTER_SCANNED_BYTES\x10\x0b\x1a\x12\x82\xd6\x1b\x0e\n\x0cScannedBytes\x12:\n\x1c\x43OUNTER_UPSERT_BLOBS_WRITTEN\x10\x0c\x1a\x18\x82\xd6\x1b\x14\n\x12UpsertBlobsWritten\x12:\n\x1c\x43OUNTER_UPSERT_BYTES_WRITTEN\x10\r\x1a\x18\x82\xd6\x1b\x14\n\x12UpsertBytesWritten\x12>\n\x1e\x43OUNTER_INDEXING_BLOBS_WRITTEN\x10\x0e\x1a\x1a\x82\xd6\x1b\x16\n\x14IndexingBlobsWritten\x12>\n\x1e\x43OUNTER_INDEXING_BYTES_WRITTEN\x10\x0f\x1a\x1a\x82\xd6\x1b\x16\n\x14IndexingBytesWritten\x12\x42\n COUNTER_COMPACTION_BLOBS_WRITTEN\x10\x10\x1a\x1c\x82\xd6\x1b\x18\n\x16\x43ompactionBlobsWritten\x12\x42\n COUNTER_COMPACTION_BYTES_WRITTEN\x10\x11\x1a\x1c\x82\xd6\x1b\x18\n\x16\x43ompactionBytesWritten\x12\x42\n COUNTER_BLOB_MANAGER_GC_REQUESTS\x10\x12\x1a\x1c\x82\xd6\x1b\x18\n\x16\x42lobManager/GcRequests\x12@\n\x1f\x43OUNTER_BLOB_MANAGER_KEEP_BLOBS\x10\x13\x1a\x1b\x82\xd6\x1b\x17\n\x15\x42lobManager/KeepBlobs\x12I\n$COUNTER_BLOB_MANAGER_DONT_KEEP_BLOBS\x10\x14\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x42lobManager/DontKeepBlobs\x12\x46\n\"COUNTER_BLOB_MANAGER_SKIPPED_BLOBS\x10\x15\x1a\x1e\x82\xd6\x1b\x1a\n\x18\x42lobManager/SkippedBlobs\x12\x36\n\x1a\x43OUNTER_RAW_BYTES_UPSERTED\x10\x16\x1a\x16\x82\xd6\x1b\x12\n\x10RawBytesUpserted\x12\x31\n\x17\x43OUNTER_BLOBS_COMMITTED\x10\x17\x1a\x14\x82\xd6\x1b\x10\n\x0e\x42lobsCommitted\x12\x31\n\x17\x43OUNTER_BYTES_COMMITTED\x10\x18\x1a\x14\x82\xd6\x1b\x10\n\x0e\x42ytesCommitted\x12\x38\n\x1b\x43OUNTER_RAW_BYTES_COMMITTED\x10\x19\x1a\x17\x82\xd6\x1b\x13\n\x11RawBytesCommitted\x12\x44\n!COUNTER_INDEXING_PORTIONS_WRITTEN\x10\x1a\x1a\x1d\x82\xd6\x1b\x19\n\x17IndexingPortionsWritten\x12H\n#COUNTER_COMPACTION_PORTIONS_WRITTEN\x10\x1b\x1a\x1f\x82\xd6\x1b\x1b\n\x19\x43ompactionPortionsWritten\x12S\n)COUNTER_SPLIT_COMPACTION_PORTIONS_WRITTEN\x10\x1c\x1a$\x82\xd6\x1b \n\x1eSplitCompactionPortionsWritten\x12M\n&COUNTER_SPLIT_COMPACTION_BLOBS_WRITTEN\x10\x1d\x1a!\x82\xd6\x1b\x1d\n\x1bSplitCompactionBlobsWritten\x12M\n&COUNTER_SPLIT_COMPACTION_BYTES_WRITTEN\x10\x1e\x1a!\x82\xd6\x1b\x1d\n\x1bSplitCompactionBytesWritten\x12;\n\x1c\x43OUNTER_PORTIONS_DEACTIVATED\x10\x1f\x1a\x19\x82\xd6\x1b\x15\n\x13PortionsDeactivated\x12\x35\n\x19\x43OUNTER_BLOBS_DEACTIVATED\x10 \x1a\x16\x82\xd6\x1b\x12\n\x10\x42lobsDeactivated\x12\x35\n\x19\x43OUNTER_BYTES_DEACTIVATED\x10!\x1a\x16\x82\xd6\x1b\x12\n\x10\x42ytesDeactivated\x12<\n\x1d\x43OUNTER_RAW_BYTES_DEACTIVATED\x10\"\x1a\x19\x82\xd6\x1b\x15\n\x13RawBytesDeactivated\x12\x31\n\x17\x43OUNTER_PORTIONS_ERASED\x10#\x1a\x14\x82\xd6\x1b\x10\n\x0ePortionsErased\x12+\n\x14\x43OUNTER_BLOBS_ERASED\x10$\x1a\x11\x82\xd6\x1b\r\n\x0b\x42lobsErased\x12+\n\x14\x43OUNTER_BYTES_ERASED\x10%\x1a\x11\x82\xd6\x1b\r\n\x0b\x42ytesErased\x12\x32\n\x18\x43OUNTER_RAW_BYTES_ERASED\x10&\x1a\x14\x82\xd6\x1b\x10\n\x0eRawBytesErased\x12\x33\n\x18\x43OUNTER_INDEXING_SUCCESS\x10\'\x1a\x15\x82\xd6\x1b\x11\n\x0fIndexingSuccess\x12-\n\x15\x43OUNTER_INDEXING_FAIL\x10(\x1a\x12\x82\xd6\x1b\x0e\n\x0cIndexingFail\x12\x37\n\x1a\x43OUNTER_COMPACTION_SUCCESS\x10)\x1a\x17\x82\xd6\x1b\x13\n\x11\x43ompactionSuccess\x12\x31\n\x17\x43OUNTER_COMPACTION_FAIL\x10*\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43ompactionFail\x12\x42\n COUNTER_SPLIT_COMPACTION_SUCCESS\x10+\x1a\x1c\x82\xd6\x1b\x18\n\x16SplitCompactionSuccess\x12<\n\x1d\x43OUNTER_SPLIT_COMPACTION_FAIL\x10,\x1a\x19\x82\xd6\x1b\x15\n\x13SplitCompactionFail\x12\x31\n\x17\x43OUNTER_CLEANUP_SUCCESS\x10-\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43leanupSuccess\x12+\n\x14\x43OUNTER_CLEANUP_FAIL\x10.\x1a\x11\x82\xd6\x1b\r\n\x0b\x43leanupFail\x12)\n\x13\x43OUNTER_TTL_SUCCESS\x10/\x1a\x10\x82\xd6\x1b\x0c\n\nTtlSuccess\x12#\n\x10\x43OUNTER_TTL_FAIL\x10\x30\x1a\r\x82\xd6\x1b\t\n\x07TtlFail\x12*\n\x14\x43OUNTER_OUT_OF_SPACE\x10\x31\x1a\x10\x82\xd6\x1b\x0c\n\nOutOfSpace\x12/\n\x16\x43OUNTER_SCAN_RESTARTED\x10\x32\x1a\x13\x82\xd6\x1b\x0f\n\rScanRestarted\x12\x38\n\x1b\x43OUNTER_READ_INDEX_GRANULES\x10\x33\x1a\x17\x82\xd6\x1b\x13\n\x11ReadIndexGranules\x12\x38\n\x1b\x43OUNTER_READ_INDEX_PORTIONS\x10\x34\x1a\x17\x82\xd6\x1b\x13\n\x11ReadIndexPortions\x12\x32\n\x18\x43OUNTER_READ_INDEX_BLOBS\x10\x35\x1a\x14\x82\xd6\x1b\x10\n\x0eReadIndexBlobs\x12\x30\n\x17\x43OUNTER_READ_INDEX_ROWS\x10\x36\x1a\x13\x82\xd6\x1b\x0f\n\rReadIndexRows\x12\x32\n\x18\x43OUNTER_READ_INDEX_BYTES\x10\x37\x1a\x14\x82\xd6\x1b\x10\n\x0eReadIndexBytes\x12\x31\n\x17\x43OUNTER_WRITE_DUPLICATE\x10\x38\x1a\x14\x82\xd6\x1b\x10\n\x0eWriteDuplicate\x12=\n\x1e\x43OUNTER_SMALL_BLOB_WRITE_COUNT\x10\x39\x1a\x19\x82\xd6\x1b\x15\n\x13SmallBlobWriteCount\x12=\n\x1e\x43OUNTER_SMALL_BLOB_WRITE_BYTES\x10:\x1a\x19\x82\xd6\x1b\x15\n\x13SmallBlobWriteBytes\x12?\n\x1f\x43OUNTER_SMALL_BLOB_READ_SUCCESS\x10;\x1a\x1a\x82\xd6\x1b\x16\n\x14SmallBlobReadSuccess\x12;\n\x1d\x43OUNTER_SMALL_BLOB_READ_ERROR\x10<\x1a\x18\x82\xd6\x1b\x14\n\x12SmallBlobReadError\x12;\n\x1d\x43OUNTER_SMALL_BLOB_READ_BYTES\x10=\x1a\x18\x82\xd6\x1b\x14\n\x12SmallBlobReadBytes\x12?\n\x1f\x43OUNTER_SMALL_BLOB_DELETE_COUNT\x10>\x1a\x1a\x82\xd6\x1b\x16\n\x14SmallBlobDeleteCount\x12?\n\x1f\x43OUNTER_SMALL_BLOB_DELETE_BYTES\x10?\x1a\x1a\x82\xd6\x1b\x16\n\x14SmallBlobDeleteBytes\x12\x44\n!COUNTER_EVICTION_PORTIONS_WRITTEN\x10@\x1a\x1d\x82\xd6\x1b\x19\n\x17\x45victionPortionsWritten\x12>\n\x1e\x43OUNTER_EVICTION_BLOBS_WRITTEN\x10\x41\x1a\x1a\x82\xd6\x1b\x16\n\x14\x45victionBlobsWritten\x12>\n\x1e\x43OUNTER_EVICTION_BYTES_WRITTEN\x10\x42\x1a\x1a\x82\xd6\x1b\x16\n\x14\x45victionBytesWritten\x12/\n\x16\x43OUNTER_EXPORT_SUCCESS\x10\x43\x1a\x13\x82\xd6\x1b\x0f\n\rExportSuccess\x12)\n\x13\x43OUNTER_EXPORT_FAIL\x10\x44\x1a\x10\x82\xd6\x1b\x0c\n\nExportFail\x12/\n\x16\x43OUNTER_FORGET_SUCCESS\x10\x45\x1a\x13\x82\xd6\x1b\x0f\n\rForgetSuccess\x12)\n\x13\x43OUNTER_FORGET_FAIL\x10\x46\x1a\x10\x82\xd6\x1b\x0c\n\nForgetFail\x12/\n\x16\x43OUNTER_WRITE_OVERLOAD\x10G\x1a\x13\x82\xd6\x1b\x0f\n\rWriteOverload\x12:\n\x1c\x43OUNTER_WRITE_OVERLOAD_SHARD\x10H\x1a\x18\x82\xd6\x1b\x14\n\x12WriteOverloadShard\x12-\n\x15\x43OUNTER_INDEXING_TIME\x10I\x1a\x12\x82\xd6\x1b\x0e\n\x0cIndexingTime\x12\x31\n\x17\x43OUNTER_COMPACTION_TIME\x10J\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43ompactionTime*\x86\x02\n\x13\x45PercentileCounters\x12+\n\x14\x43OUNTER_SCAN_LATENCY\x10\x00\x1a\x11\x82\xd6\x1b\r\n\x0bScanLatency\x1a\xc1\x01\x92\xd6\x1b\xbc\x01\x12\x07\x08\x90N\x12\x02\x31\x30\x12\x08\x08\xa0\x9c\x01\x12\x02\x32\x30\x12\x08\x08\xd0\x86\x03\x12\x02\x35\x30\x12\t\x08\xa0\x8d\x06\x12\x03\x31\x30\x30\x12\t\x08\xc0\x9a\x0c\x12\x03\x32\x30\x30\x12\t\x08\xa0\xc2\x1e\x12\x03\x35\x30\x30\x12\n\x08\xc0\x84=\x12\x04\x31\x30\x30\x30\x12\n\x08\x80\x89z\x12\x04\x32\x30\x30\x30\x12\x0b\x08\xc0\x96\xb1\x02\x12\x04\x35\x30\x30\x30\x12\x0c\x08\x80\xad\xe2\x04\x12\x05\x31\x30\x30\x30\x30\x12\x0c\x08\x80\xda\xc4\t\x12\x05\x32\x30\x30\x30\x30\x12\x0c\x08\x80\x8e\xce\x1c\x12\x05\x36\x30\x30\x30\x30\x12\r\x08\x80\x9c\x9c\x39\x12\x06\x31\x32\x30\x30\x30\x30\x12\x0e\x08\x80\xc6\x86\x8f\x01\x12\x06\x33\x30\x30\x30\x30\x30\x12\x0e\x08\x80\x8c\x8d\x9e\x02\x12\x06\x36\x30\x30\x30\x30\x30*\xf8\x04\n\x08\x45TxTypes\x12\x1d\n\x0bTXTYPE_INIT\x10\x00\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x01\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12.\n\x14TXTYPE_UPDATE_SCHEMA\x10\x02\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxUpdateSchema\x12\x1f\n\x0cTXTYPE_WRITE\x10\x03\x1a\r\x8a\xd6\x1b\t\n\x07TxWrite\x12\x1d\n\x0bTXTYPE_READ\x10\x04\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxRead\x12#\n\x0eTXTYPE_PROPOSE\x10\x05\x1a\x0f\x8a\xd6\x1b\x0b\n\tTxPropose\x12*\n\x12TXTYPE_WRITE_INDEX\x10\x06\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxWriteIndex\x12%\n\x0fTXTYPE_PLANSTEP\x10\x07\x1a\x10\x8a\xd6\x1b\x0c\n\nTxPlanStep\x12;\n\x1bTXTYPE_NOTIFY_TX_COMPLETION\x10\x08\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxNotifyTxCompletion\x12\x30\n\x15TXTYPE_PROPOSE_CANCEL\x10\t\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxProposeCancel\x12%\n\x0fTXTYPE_PROGRESS\x10\n\x1a\x10\x8a\xd6\x1b\x0c\n\nTxProgress\x12(\n\x11TXTYPE_START_SCAN\x10\x0b\x1a\x11\x8a\xd6\x1b\r\n\x0bTxStartScan\x12\x33\n\x17TXTYPE_READ_BLOB_RANGES\x10\x0c\x1a\x16\x8a\xd6\x1b\x12\n\x10TxReadBlobRanges\x12!\n\rTXTYPE_EXPORT\x10\r\x1a\x0e\x8a\xd6\x1b\n\n\x08TxExport\x12!\n\rTXTYPE_FORGET\x10\x0e\x1a\x0e\x8a\xd6\x1b\n\n\x08TxForgetB\'\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x0b\x43olumnShard')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_columnshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\013ColumnShard'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLES"]._serialized_options = b'\202\326\033\010\n\006Tables'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_PRESETS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_PRESETS"]._serialized_options = b'\202\326\033\016\n\014TablePresets'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TTL_PRESETS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TTL_PRESETS"]._serialized_options = b'\202\326\033\014\n\nTtlPresets'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_TTLS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLE_TTLS"]._serialized_options = b'\202\326\033\013\n\tTableTtls'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEXES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEXES"]._serialized_options = b'\202\326\033\t\n\007Indexes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PREPARED_RECORDS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PREPARED_RECORDS"]._serialized_options = b'\202\326\033\021\n\017PreparedRecords'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PREPARED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PREPARED_BYTES"]._serialized_options = b'\202\326\033\017\n\rPreparedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMMITTED_RECORDS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMMITTED_RECORDS"]._serialized_options = b'\202\326\033\022\n\020CommittedRecords'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMMITTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMMITTED_BYTES"]._serialized_options = b'\202\326\033\020\n\016CommittedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_TABLES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_TABLES"]._serialized_options = b'\202\326\033\016\n\014Index/Tables'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_GRANULES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_GRANULES"]._serialized_options = b'\202\326\033\020\n\016Index/Granules'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_EMPTY_GRANULES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_EMPTY_GRANULES"]._serialized_options = b'\202\326\033\025\n\023Index/EmptyGranules'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_OVERLOADED_GRANULES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_OVERLOADED_GRANULES"]._serialized_options = b'\202\326\033\032\n\030Index/OverloadedGranules'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_COLUMN_RECORDS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_COLUMN_RECORDS"]._serialized_options = b'\202\326\033\025\n\023Index/ColumnRecords'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_COLUMN_METADATA_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INDEX_COLUMN_METADATA_BYTES"]._serialized_options = b'\202\326\033\033\n\031Index/ColumnMetadataBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_PORTIONS"]._serialized_options = b'\202\326\033\030\n\026Index/InsertedPortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_BLOBS"]._serialized_options = b'\202\326\033\025\n\023Index/InsertedBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_ROWS"]._serialized_options = b'\202\326\033\024\n\022Index/InsertedRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_BYTES"]._serialized_options = b'\202\326\033\025\n\023Index/InsertedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INSERTED_RAW_BYTES"]._serialized_options = b'\202\326\033\030\n\026Index/InsertedBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_PORTIONS"]._serialized_options = b'\202\326\033\031\n\027Index/CompactedPortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_BLOBS"]._serialized_options = b'\202\326\033\026\n\024Index/CompactedBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_ROWS"]._serialized_options = b'\202\326\033\025\n\023Index/CompactedRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_BYTES"]._serialized_options = b'\202\326\033\026\n\024Index/CompactedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_COMPACTED_RAW_BYTES"]._serialized_options = b'\202\326\033\031\n\027Index/CompactedBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_PORTIONS"]._serialized_options = b'\202\326\033\036\n\034Index/SplitCompactedPortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_BLOBS"]._serialized_options = b'\202\326\033\033\n\031Index/SplitCompactedBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_ROWS"]._serialized_options = b'\202\326\033\032\n\030Index/SplitCompactedRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_BYTES"]._serialized_options = b'\202\326\033\033\n\031Index/SplitCompactedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTED_RAW_BYTES"]._serialized_options = b'\202\326\033\036\n\034Index/SplitCompactedBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_PORTIONS"]._serialized_options = b'\202\326\033\030\n\026Index/InactivePortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_BLOBS"]._serialized_options = b'\202\326\033\025\n\023Index/InactiveBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_ROWS"]._serialized_options = b'\202\326\033\024\n\022Index/InactiveRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_BYTES"]._serialized_options = b'\202\326\033\025\n\023Index/InactiveBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_INACTIVE_RAW_BYTES"]._serialized_options = b'\202\326\033\030\n\026Index/InactiveBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SCAN_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SCAN_IN_FLY"]._serialized_options = b'\202\326\033\r\n\013ScanTxInFly'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_PORTIONS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_PORTIONS"]._serialized_options = b'\202\326\033\027\n\025Index/EvictedPortions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_BLOBS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_BLOBS"]._serialized_options = b'\202\326\033\024\n\022Index/EvictedBlobs'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_ROWS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_ROWS"]._serialized_options = b'\202\326\033\023\n\021Index/EvictedRows'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_BYTES"]._serialized_options = b'\202\326\033\024\n\022Index/EvictedBytes'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_RAW_BYTES"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_EVICTED_RAW_BYTES"]._serialized_options = b'\202\326\033\027\n\025Index/EvictedBytesRaw'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_WRITES_IN_FLY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_WRITES_IN_FLY"]._serialized_options = b'\202\326\033\r\n\013WritesInFly'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_SUCCESS"]._serialized_options = b'\202\326\033\016\n\014WriteSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_FAIL"]._serialized_options = b'\202\326\033\013\n\tWriteFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_SUCCESS"]._serialized_options = b'\202\326\033\r\n\013ReadSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_FAIL"]._serialized_options = b'\202\326\033\n\n\010ReadFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_REQUEST"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_REQUEST"]._serialized_options = b'\202\326\033\020\n\016PrepareRequest'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_ERROR"]._serialized_options = b'\202\326\033\016\n\014PrepareError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PREPARE_SUCCESS"]._serialized_options = b'\202\326\033\020\n\016PrepareSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_IGNORED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_IGNORED"]._serialized_options = b'\202\326\033\021\n\017PlanStepIgnored'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_ACCEPTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PLAN_STEP_ACCEPTED"]._serialized_options = b'\202\326\033\022\n\020PlanStepAccepted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_ROWS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_ROWS"]._serialized_options = b'\202\326\033\r\n\013ScannedRows'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCANNED_BYTES"]._serialized_options = b'\202\326\033\016\n\014ScannedBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPSERT_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPSERT_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\024\n\022UpsertBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPSERT_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPSERT_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\024\n\022UpsertBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\026\n\024IndexingBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\026\n\024IndexingBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\030\n\026CompactionBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\030\n\026CompactionBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_GC_REQUESTS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_GC_REQUESTS"]._serialized_options = b'\202\326\033\030\n\026BlobManager/GcRequests'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_KEEP_BLOBS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_KEEP_BLOBS"]._serialized_options = b'\202\326\033\027\n\025BlobManager/KeepBlobs'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_DONT_KEEP_BLOBS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_DONT_KEEP_BLOBS"]._serialized_options = b'\202\326\033\033\n\031BlobManager/DontKeepBlobs'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_SKIPPED_BLOBS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOB_MANAGER_SKIPPED_BLOBS"]._serialized_options = b'\202\326\033\032\n\030BlobManager/SkippedBlobs'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_UPSERTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_UPSERTED"]._serialized_options = b'\202\326\033\022\n\020RawBytesUpserted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_COMMITTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_COMMITTED"]._serialized_options = b'\202\326\033\020\n\016BlobsCommitted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_COMMITTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_COMMITTED"]._serialized_options = b'\202\326\033\020\n\016BytesCommitted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_COMMITTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_COMMITTED"]._serialized_options = b'\202\326\033\023\n\021RawBytesCommitted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_PORTIONS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_PORTIONS_WRITTEN"]._serialized_options = b'\202\326\033\031\n\027IndexingPortionsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_PORTIONS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_PORTIONS_WRITTEN"]._serialized_options = b'\202\326\033\033\n\031CompactionPortionsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_PORTIONS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_PORTIONS_WRITTEN"]._serialized_options = b'\202\326\033 \n\036SplitCompactionPortionsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\035\n\033SplitCompactionBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\035\n\033SplitCompactionBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PORTIONS_DEACTIVATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PORTIONS_DEACTIVATED"]._serialized_options = b'\202\326\033\025\n\023PortionsDeactivated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_DEACTIVATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_DEACTIVATED"]._serialized_options = b'\202\326\033\022\n\020BlobsDeactivated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_DEACTIVATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_DEACTIVATED"]._serialized_options = b'\202\326\033\022\n\020BytesDeactivated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_DEACTIVATED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_DEACTIVATED"]._serialized_options = b'\202\326\033\025\n\023RawBytesDeactivated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PORTIONS_ERASED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PORTIONS_ERASED"]._serialized_options = b'\202\326\033\020\n\016PortionsErased'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_ERASED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BLOBS_ERASED"]._serialized_options = b'\202\326\033\r\n\013BlobsErased'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_ERASED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BYTES_ERASED"]._serialized_options = b'\202\326\033\r\n\013BytesErased'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_ERASED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_RAW_BYTES_ERASED"]._serialized_options = b'\202\326\033\020\n\016RawBytesErased'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_SUCCESS"]._serialized_options = b'\202\326\033\021\n\017IndexingSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_FAIL"]._serialized_options = b'\202\326\033\016\n\014IndexingFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_SUCCESS"]._serialized_options = b'\202\326\033\023\n\021CompactionSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_FAIL"]._serialized_options = b'\202\326\033\020\n\016CompactionFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_SUCCESS"]._serialized_options = b'\202\326\033\030\n\026SplitCompactionSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SPLIT_COMPACTION_FAIL"]._serialized_options = b'\202\326\033\025\n\023SplitCompactionFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CLEANUP_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CLEANUP_SUCCESS"]._serialized_options = b'\202\326\033\020\n\016CleanupSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CLEANUP_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CLEANUP_FAIL"]._serialized_options = b'\202\326\033\r\n\013CleanupFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TTL_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TTL_SUCCESS"]._serialized_options = b'\202\326\033\014\n\nTtlSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TTL_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TTL_FAIL"]._serialized_options = b'\202\326\033\t\n\007TtlFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_OUT_OF_SPACE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_OUT_OF_SPACE"]._serialized_options = b'\202\326\033\014\n\nOutOfSpace'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCAN_RESTARTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCAN_RESTARTED"]._serialized_options = b'\202\326\033\017\n\rScanRestarted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_GRANULES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_GRANULES"]._serialized_options = b'\202\326\033\023\n\021ReadIndexGranules'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_PORTIONS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_PORTIONS"]._serialized_options = b'\202\326\033\023\n\021ReadIndexPortions'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_BLOBS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_BLOBS"]._serialized_options = b'\202\326\033\020\n\016ReadIndexBlobs'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_ROWS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_ROWS"]._serialized_options = b'\202\326\033\017\n\rReadIndexRows'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_READ_INDEX_BYTES"]._serialized_options = b'\202\326\033\020\n\016ReadIndexBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_DUPLICATE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_DUPLICATE"]._serialized_options = b'\202\326\033\020\n\016WriteDuplicate'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_WRITE_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_WRITE_COUNT"]._serialized_options = b'\202\326\033\025\n\023SmallBlobWriteCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_WRITE_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_WRITE_BYTES"]._serialized_options = b'\202\326\033\025\n\023SmallBlobWriteBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_SUCCESS"]._serialized_options = b'\202\326\033\026\n\024SmallBlobReadSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_ERROR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_ERROR"]._serialized_options = b'\202\326\033\024\n\022SmallBlobReadError'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_READ_BYTES"]._serialized_options = b'\202\326\033\024\n\022SmallBlobReadBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_DELETE_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_DELETE_COUNT"]._serialized_options = b'\202\326\033\026\n\024SmallBlobDeleteCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_DELETE_BYTES"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SMALL_BLOB_DELETE_BYTES"]._serialized_options = b'\202\326\033\026\n\024SmallBlobDeleteBytes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_PORTIONS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_PORTIONS_WRITTEN"]._serialized_options = b'\202\326\033\031\n\027EvictionPortionsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_BLOBS_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_BLOBS_WRITTEN"]._serialized_options = b'\202\326\033\026\n\024EvictionBlobsWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_BYTES_WRITTEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EVICTION_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\026\n\024EvictionBytesWritten'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EXPORT_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EXPORT_SUCCESS"]._serialized_options = b'\202\326\033\017\n\rExportSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EXPORT_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_EXPORT_FAIL"]._serialized_options = b'\202\326\033\014\n\nExportFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FORGET_SUCCESS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FORGET_SUCCESS"]._serialized_options = b'\202\326\033\017\n\rForgetSuccess'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FORGET_FAIL"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FORGET_FAIL"]._serialized_options = b'\202\326\033\014\n\nForgetFail'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_OVERLOAD"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_OVERLOAD"]._serialized_options = b'\202\326\033\017\n\rWriteOverload'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_OVERLOAD_SHARD"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_WRITE_OVERLOAD_SHARD"]._serialized_options = b'\202\326\033\024\n\022WriteOverloadShard'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_TIME"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_INDEXING_TIME"]._serialized_options = b'\202\326\033\016\n\014IndexingTime'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_TIME"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_COMPACTION_TIME"]._serialized_options = b'\202\326\033\020\n\016CompactionTime'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\274\001\022\007\010\220N\022\00210\022\010\010\240\234\001\022\00220\022\010\010\320\206\003\022\00250\022\t\010\240\215\006\022\003100\022\t\010\300\232\014\022\003200\022\t\010\240\302\036\022\003500\022\n\010\300\204=\022\0041000\022\n\010\200\211z\022\0042000\022\013\010\300\226\261\002\022\0045000\022\014\010\200\255\342\004\022\00510000\022\014\010\200\332\304\t\022\00520000\022\014\010\200\216\316\034\022\00560000\022\r\010\200\234\2349\022\006120000\022\016\010\200\306\206\217\001\022\006300000\022\016\010\200\214\215\236\002\022\006600000'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SCAN_LATENCY"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_SCAN_LATENCY"]._serialized_options = b'\202\326\033\r\n\013ScanLatency'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SCHEMA"]._serialized_options = b'\212\326\033\020\n\016TxUpdateSchema'
  _ETXTYPES.values_by_name["TXTYPE_WRITE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_WRITE"]._serialized_options = b'\212\326\033\t\n\007TxWrite'
  _ETXTYPES.values_by_name["TXTYPE_READ"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_READ"]._serialized_options = b'\212\326\033\010\n\006TxRead'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE"]._serialized_options = b'\212\326\033\013\n\tTxPropose'
  _ETXTYPES.values_by_name["TXTYPE_WRITE_INDEX"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_WRITE_INDEX"]._serialized_options = b'\212\326\033\016\n\014TxWriteIndex'
  _ETXTYPES.values_by_name["TXTYPE_PLANSTEP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PLANSTEP"]._serialized_options = b'\212\326\033\014\n\nTxPlanStep'
  _ETXTYPES.values_by_name["TXTYPE_NOTIFY_TX_COMPLETION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_NOTIFY_TX_COMPLETION"]._serialized_options = b'\212\326\033\026\n\024TxNotifyTxCompletion'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_CANCEL"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_CANCEL"]._serialized_options = b'\212\326\033\021\n\017TxProposeCancel'
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROGRESS"]._serialized_options = b'\212\326\033\014\n\nTxProgress'
  _ETXTYPES.values_by_name["TXTYPE_START_SCAN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_START_SCAN"]._serialized_options = b'\212\326\033\r\n\013TxStartScan'
  _ETXTYPES.values_by_name["TXTYPE_READ_BLOB_RANGES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_READ_BLOB_RANGES"]._serialized_options = b'\212\326\033\022\n\020TxReadBlobRanges'
  _ETXTYPES.values_by_name["TXTYPE_EXPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_EXPORT"]._serialized_options = b'\212\326\033\n\n\010TxExport'
  _ETXTYPES.values_by_name["TXTYPE_FORGET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_FORGET"]._serialized_options = b'\212\326\033\n\n\010TxForget'
  _ESIMPLECOUNTERS._serialized_start=101
  _ESIMPLECOUNTERS._serialized_end=2475
  _ECUMULATIVECOUNTERS._serialized_start=2478
  _ECUMULATIVECOUNTERS._serialized_end=6707
  _EPERCENTILECOUNTERS._serialized_start=6710
  _EPERCENTILECOUNTERS._serialized_end=6972
  _ETXTYPES._serialized_start=6975
  _ETXTYPES._serialized_end=7607
# @@protoc_insertion_point(module_scope)
