# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/fq_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.yq.libs.config.protos import audit_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_audit__pb2
from ydb.core.yq.libs.config.protos import checkpoint_coordinator_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_checkpoint__coordinator__pb2
from ydb.core.yq.libs.config.protos import common_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_common__pb2
from ydb.core.yq.libs.config.protos import control_plane_proxy_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_control__plane__proxy__pb2
from ydb.core.yq.libs.config.protos import control_plane_storage_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_control__plane__storage__pb2
from ydb.core.yq.libs.config.protos import db_pool_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_db__pool__pb2
from ydb.core.yq.libs.config.protos import gateways_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_gateways__pb2
from ydb.core.yq.libs.config.protos import health_config_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_health__config__pb2
from ydb.core.yq.libs.config.protos import nodes_manager_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_nodes__manager__pb2
from ydb.core.yq.libs.config.protos import pending_fetcher_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_pending__fetcher__pb2
from ydb.core.yq.libs.config.protos import pinger_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_pinger__pb2
from ydb.core.yq.libs.config.protos import private_api_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_private__api__pb2
from ydb.core.yq.libs.config.protos import private_proxy_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_private__proxy__pb2
from ydb.core.yq.libs.config.protos import quotas_manager_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_quotas__manager__pb2
from ydb.core.yq.libs.config.protos import rate_limiter_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_rate__limiter__pb2
from ydb.core.yq.libs.config.protos import read_actors_factory_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_read__actors__factory__pb2
from ydb.core.yq.libs.config.protos import resource_manager_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_resource__manager__pb2
from ydb.core.yq.libs.config.protos import test_connection_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_test__connection__pb2
from ydb.core.yq.libs.config.protos import token_accessor_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_token__accessor__pb2
from ydb.library.folder_service.proto import config_pb2 as ydb_dot_library_dot_folder__service_dot_proto_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ydb/core/yq/libs/config/protos/fq_config.proto\x12\x0bNYq.NConfig\x1a*ydb/core/yq/libs/config/protos/audit.proto\x1a;ydb/core/yq/libs/config/protos/checkpoint_coordinator.proto\x1a+ydb/core/yq/libs/config/protos/common.proto\x1a\x38ydb/core/yq/libs/config/protos/control_plane_proxy.proto\x1a:ydb/core/yq/libs/config/protos/control_plane_storage.proto\x1a,ydb/core/yq/libs/config/protos/db_pool.proto\x1a-ydb/core/yq/libs/config/protos/gateways.proto\x1a\x32ydb/core/yq/libs/config/protos/health_config.proto\x1a\x32ydb/core/yq/libs/config/protos/nodes_manager.proto\x1a\x34ydb/core/yq/libs/config/protos/pending_fetcher.proto\x1a+ydb/core/yq/libs/config/protos/pinger.proto\x1a\x30ydb/core/yq/libs/config/protos/private_api.proto\x1a\x32ydb/core/yq/libs/config/protos/private_proxy.proto\x1a\x33ydb/core/yq/libs/config/protos/quotas_manager.proto\x1a\x31ydb/core/yq/libs/config/protos/rate_limiter.proto\x1a\x38ydb/core/yq/libs/config/protos/read_actors_factory.proto\x1a\x35ydb/core/yq/libs/config/protos/resource_manager.proto\x1a\x34ydb/core/yq/libs/config/protos/test_connection.proto\x1a\x33ydb/core/yq/libs/config/protos/token_accessor.proto\x1a-ydb/library/folder_service/proto/config.proto\"\xca\t\n\x07TConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12*\n\x06\x43ommon\x18\x02 \x01(\x0b\x32\x1a.NYq.NConfig.TCommonConfig\x12\x44\n\x13\x43ontrolPlaneStorage\x18\x03 \x01(\x0b\x32\'.NYq.NConfig.TControlPlaneStorageConfig\x12@\n\x11\x43ontrolPlaneProxy\x18\x04 \x01(\x0b\x32%.NYq.NConfig.TControlPlaneProxyConfig\x12H\n\rFolderService\x18\x05 \x01(\x0b\x32\x31.NKikimrProto.NFolderService.TFolderServiceConfig\x12\x32\n\nPrivateApi\x18\x06 \x01(\x0b\x32\x1e.NYq.NConfig.TPrivateApiConfig\x12\x38\n\rTokenAccessor\x18\x07 \x01(\x0b\x32!.NYq.NConfig.TTokenAccessorConfig\x12*\n\x06\x44\x62Pool\x18\x08 \x01(\x0b\x32\x1a.NYq.NConfig.TDbPoolConfig\x12.\n\x08Gateways\x18\t \x01(\x0b\x32\x1c.NYq.NConfig.TGatewaysConfig\x12H\n\x15\x43heckpointCoordinator\x18\n \x01(\x0b\x32).NYq.NConfig.TCheckpointCoordinatorConfig\x12(\n\x05\x41udit\x18\x0b \x01(\x0b\x32\x19.NYq.NConfig.TAuditConfig\x12<\n\x0fResourceManager\x18\x0c \x01(\x0b\x32#.NYq.NConfig.TResourceManagerConfig\x12\x36\n\x0cPrivateProxy\x18\r \x01(\x0b\x32 .NYq.NConfig.TPrivateProxyConfig\x12\x36\n\x0cNodesManager\x18\x0e \x01(\x0b\x32 .NYq.NConfig.TNodesManagerConfig\x12:\n\x0ePendingFetcher\x18\x0f \x01(\x0b\x32\".NYq.NConfig.TPendingFetcherConfig\x12*\n\x06Pinger\x18\x10 \x01(\x0b\x32\x1a.NYq.NConfig.TPingerConfig\x12 \n\x18\x45nableDynamicNameservice\x18\x11 \x01(\x08\x12:\n\x0eTestConnection\x18\x12 \x01(\x0b\x32\".NYq.NConfig.TTestConnectionConfig\x12\x46\n\x17ReadActorsFactoryConfig\x18\x13 \x01(\x0b\x32%.NYq.NConfig.TReadActorsFactoryConfig\x12*\n\x06Health\x18\x14 \x01(\x0b\x32\x1a.NYq.NConfig.THealthConfig\x12\x38\n\rQuotasManager\x18\x15 \x01(\x0b\x32!.NYq.NConfig.TQuotasManagerConfig\x12\x34\n\x0bRateLimiter\x18\x16 \x01(\x0b\x32\x1f.NYq.NConfig.TRateLimiterConfig\x12\x1a\n\x12\x45nableTaskCounters\x18\x17 \x01(\x08\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.fq_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TCONFIG._serialized_start=1101
  _TCONFIG._serialized_end=2327
# @@protoc_insertion_point(module_scope)
