# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/ssa.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/ssa.proto\x12\nNKikimrSSA\"\xf0\x12\n\x08TProgram\x12.\n\x07\x43ommand\x18\x01 \x03(\x0b\x32\x1d.NKikimrSSA.TProgram.TCommand\x12\x0f\n\x07Version\x18\x02 \x01(\r\x1a#\n\x07TColumn\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x0c\n\x04Name\x18\x02 \x01(\t\x1a\xae\x01\n\tTConstant\x12\x0e\n\x04\x42ool\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05Int32\x18\x02 \x01(\x05H\x00\x12\x10\n\x06Uint32\x18\x03 \x01(\rH\x00\x12\x0f\n\x05Int64\x18\x04 \x01(\x03H\x00\x12\x10\n\x06Uint64\x18\x05 \x01(\x04H\x00\x12\x0f\n\x05\x46loat\x18\x06 \x01(\x02H\x00\x12\x10\n\x06\x44ouble\x18\x07 \x01(\x01H\x00\x12\x0f\n\x05\x42ytes\x18\x08 \x01(\x0cH\x00\x12\x0e\n\x04Text\x18\t \x01(\tH\x00\x42\x07\n\x05value\x1a\x1a\n\nTParameter\x12\x0c\n\x04Name\x18\x01 \x01(\t\x1a\xec\t\n\x0bTAssignment\x12,\n\x06\x43olumn\x18\x01 \x01(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x12>\n\x08\x46unction\x18\x02 \x01(\x0b\x32*.NKikimrSSA.TProgram.TAssignment.TFunctionH\x00\x12N\n\x10\x45xternalFunction\x18\x03 \x01(\x0b\x32\x32.NKikimrSSA.TProgram.TAssignment.TExternalFunctionH\x00\x12\x32\n\x08\x43onstant\x18\x04 \x01(\x0b\x32\x1e.NKikimrSSA.TProgram.TConstantH\x00\x12\x0e\n\x04Null\x18\x05 \x01(\x08H\x00\x12\x34\n\tParameter\x18\x06 \x01(\x0b\x32\x1f.NKikimrSSA.TProgram.TParameterH\x00\x1aH\n\tTFunction\x12\n\n\x02Id\x18\x01 \x01(\r\x12/\n\tArguments\x18\x02 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x1aR\n\x11TExternalFunction\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12/\n\tArguments\x18\x02 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\"\xf8\x05\n\tEFunction\x12\x14\n\x10\x46UNC_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x46UNC_CMP_EQUAL\x10\x01\x12\x16\n\x12\x46UNC_CMP_NOT_EQUAL\x10\x02\x12\x11\n\rFUNC_CMP_LESS\x10\x03\x12\x17\n\x13\x46UNC_CMP_LESS_EQUAL\x10\x04\x12\x14\n\x10\x46UNC_CMP_GREATER\x10\x05\x12\x1a\n\x16\x46UNC_CMP_GREATER_EQUAL\x10\x06\x12\x10\n\x0c\x46UNC_IS_NULL\x10\x07\x12\x13\n\x0f\x46UNC_STR_LENGTH\x10\x08\x12\x12\n\x0e\x46UNC_STR_MATCH\x10\t\x12\x13\n\x0f\x46UNC_BINARY_NOT\x10\n\x12\x13\n\x0f\x46UNC_BINARY_AND\x10\x0b\x12\x12\n\x0e\x46UNC_BINARY_OR\x10\x0c\x12\x13\n\x0f\x46UNC_BINARY_XOR\x10\r\x12\x11\n\rFUNC_MATH_ADD\x10\x0e\x12\x16\n\x12\x46UNC_MATH_SUBTRACT\x10\x0f\x12\x16\n\x12\x46UNC_MATH_MULTIPLY\x10\x10\x12\x14\n\x10\x46UNC_MATH_DIVIDE\x10\x11\x12\x18\n\x14\x46UNC_CAST_TO_BOOLEAN\x10\x12\x12\x15\n\x11\x46UNC_CAST_TO_INT8\x10\x13\x12\x16\n\x12\x46UNC_CAST_TO_INT16\x10\x14\x12\x16\n\x12\x46UNC_CAST_TO_INT32\x10\x15\x12\x16\n\x12\x46UNC_CAST_TO_INT64\x10\x16\x12\x16\n\x12\x46UNC_CAST_TO_UINT8\x10\x17\x12\x17\n\x13\x46UNC_CAST_TO_UINT16\x10\x18\x12\x17\n\x13\x46UNC_CAST_TO_UINT32\x10\x19\x12\x17\n\x13\x46UNC_CAST_TO_UINT64\x10\x1a\x12\x16\n\x12\x46UNC_CAST_TO_FLOAT\x10\x1b\x12\x17\n\x13\x46UNC_CAST_TO_DOUBLE\x10\x1c\x12\x17\n\x13\x46UNC_CAST_TO_BINARY\x10\x1d\x12\"\n\x1e\x46UNC_CAST_TO_FIXED_SIZE_BINARY\x10\x1e\x12\x1a\n\x16\x46UNC_CAST_TO_TIMESTAMP\x10\x1f\x42\x0c\n\nexpression\x1a\xe7\x02\n\x14TAggregateAssignment\x12,\n\x06\x43olumn\x18\x01 \x01(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x12N\n\x08\x46unction\x18\x02 \x01(\x0b\x32<.NKikimrSSA.TProgram.TAggregateAssignment.TAggregateFunction\x1a\x62\n\x12TAggregateFunction\x12\n\n\x02Id\x18\x01 \x01(\r\x12/\n\tArguments\x18\x02 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x12\x0f\n\x07Variant\x18\x03 \x01(\t\"m\n\x12\x45\x41ggregateFunction\x12\x13\n\x0f\x41GG_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x41GG_SOME\x10\x01\x12\r\n\tAGG_COUNT\x10\x02\x12\x0b\n\x07\x41GG_MIN\x10\x03\x12\x0b\n\x07\x41GG_MAX\x10\x04\x12\x0b\n\x07\x41GG_SUM\x10\x05\x1a<\n\x0bTProjection\x12-\n\x07\x43olumns\x18\x01 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x1a:\n\x07TFilter\x12/\n\tPredicate\x18\x01 \x01(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x1a{\n\x08TGroupBy\x12=\n\nAggregates\x18\x01 \x03(\x0b\x32).NKikimrSSA.TProgram.TAggregateAssignment\x12\x30\n\nKeyColumns\x18\x02 \x03(\x0b\x32\x1c.NKikimrSSA.TProgram.TColumn\x1a\xe0\x01\n\x08TCommand\x12\x32\n\x06\x41ssign\x18\x01 \x01(\x0b\x32 .NKikimrSSA.TProgram.TAssignmentH\x00\x12\x36\n\nProjection\x18\x02 \x01(\x0b\x32 .NKikimrSSA.TProgram.TProjectionH\x00\x12.\n\x06\x46ilter\x18\x03 \x01(\x0b\x32\x1c.NKikimrSSA.TProgram.TFilterH\x00\x12\x30\n\x07GroupBy\x18\x04 \x01(\x0b\x32\x1d.NKikimrSSA.TProgram.TGroupByH\x00\x42\x06\n\x04line\"M\n\x0cTOlapProgram\x12\x0f\n\x07Program\x18\x01 \x01(\x0c\x12\x18\n\x10ParametersSchema\x18\x02 \x01(\x0c\x12\x12\n\nParameters\x18\x03 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.ssa_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPROGRAM._serialized_start=42
  _TPROGRAM._serialized_end=2458
  _TPROGRAM_TCOLUMN._serialized_start=119
  _TPROGRAM_TCOLUMN._serialized_end=154
  _TPROGRAM_TCONSTANT._serialized_start=157
  _TPROGRAM_TCONSTANT._serialized_end=331
  _TPROGRAM_TPARAMETER._serialized_start=333
  _TPROGRAM_TPARAMETER._serialized_end=359
  _TPROGRAM_TASSIGNMENT._serialized_start=362
  _TPROGRAM_TASSIGNMENT._serialized_end=1622
  _TPROGRAM_TASSIGNMENT_TFUNCTION._serialized_start=689
  _TPROGRAM_TASSIGNMENT_TFUNCTION._serialized_end=761
  _TPROGRAM_TASSIGNMENT_TEXTERNALFUNCTION._serialized_start=763
  _TPROGRAM_TASSIGNMENT_TEXTERNALFUNCTION._serialized_end=845
  _TPROGRAM_TASSIGNMENT_EFUNCTION._serialized_start=848
  _TPROGRAM_TASSIGNMENT_EFUNCTION._serialized_end=1608
  _TPROGRAM_TAGGREGATEASSIGNMENT._serialized_start=1625
  _TPROGRAM_TAGGREGATEASSIGNMENT._serialized_end=1984
  _TPROGRAM_TAGGREGATEASSIGNMENT_TAGGREGATEFUNCTION._serialized_start=1775
  _TPROGRAM_TAGGREGATEASSIGNMENT_TAGGREGATEFUNCTION._serialized_end=1873
  _TPROGRAM_TAGGREGATEASSIGNMENT_EAGGREGATEFUNCTION._serialized_start=1875
  _TPROGRAM_TAGGREGATEASSIGNMENT_EAGGREGATEFUNCTION._serialized_end=1984
  _TPROGRAM_TPROJECTION._serialized_start=1986
  _TPROGRAM_TPROJECTION._serialized_end=2046
  _TPROGRAM_TFILTER._serialized_start=2048
  _TPROGRAM_TFILTER._serialized_end=2106
  _TPROGRAM_TGROUPBY._serialized_start=2108
  _TPROGRAM_TGROUPBY._serialized_end=2231
  _TPROGRAM_TCOMMAND._serialized_start=2234
  _TPROGRAM_TCOMMAND._serialized_end=2458
  _TOLAPPROGRAM._serialized_start=2460
  _TOLAPPROGRAM._serialized_end=2537
# @@protoc_insertion_point(module_scope)
