# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/bootstrapper.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/bootstrapper.proto\x12\x13NKikimrBootstrapper\"=\n\x08TEvWatch\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x10\n\x08SelfSeed\x18\x02 \x01(\x04\x12\r\n\x05Round\x18\x03 \x01(\x04\"\xd6\x01\n\x0eTEvWatchResult\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x39\n\x05State\x18\x02 \x01(\x0e\x32*.NKikimrBootstrapper.TEvWatchResult.EState\x12\x0c\n\x04Seed\x18\x03 \x01(\x04\x12\r\n\x05Round\x18\x04 \x01(\x04\"Z\n\x06\x45State\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x46REE\x10\x01\x12\t\n\x05OWNER\x10\x02\x12\x0b\n\x07WAITFOR\x10\x03\x12\x0f\n\x0bUNDELIVERED\x10\x04\x12\x10\n\x0c\x44ISCONNECTED\x10\x05\"z\n\tTEvNotify\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12.\n\x02Op\x18\x02 \x01(\x0e\x32\".NKikimrBootstrapper.TEvNotify.EOp\x12\r\n\x05Round\x18\x03 \x01(\x04\"\x1c\n\x03\x45Op\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04\x44ROP\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.bootstrapper_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVWATCH._serialized_start=59
  _TEVWATCH._serialized_end=120
  _TEVWATCHRESULT._serialized_start=123
  _TEVWATCHRESULT._serialized_end=337
  _TEVWATCHRESULT_ESTATE._serialized_start=247
  _TEVWATCHRESULT_ESTATE._serialized_end=337
  _TEVNOTIFY._serialized_start=339
  _TEVNOTIFY._serialized_end=461
  _TEVNOTIFY_EOP._serialized_start=433
  _TEVNOTIFY_EOP._serialized_end=461
# @@protoc_insertion_point(module_scope)
