# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/scheme_type_operation.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/core/protos/scheme_type_operation.proto\x12\x1aNKikimrSchemeTypeOperation\"\xc0\x02\n\tTMetadata\x12\x43\n\tOperation\x18\x01 \x03(\x0b\x32\x30.NKikimrSchemeTypeOperation.TMetadata.TOperation\x1a)\n\x04TArg\x12\x12\n\nSchemeType\x18\x01 \x01(\r\x12\r\n\x05\x46lags\x18\x02 \x01(\r\x1a^\n\x0cTDescription\x12\x37\n\x03\x41rg\x18\x01 \x03(\x0b\x32*.NKikimrSchemeTypeOperation.TMetadata.TArg\x12\x15\n\rDeterministic\x18\x02 \x01(\x08\x1a\x63\n\nTOperation\x12\x0c\n\x04Name\x18\x01 \x01(\x0c\x12G\n\x0b\x44\x65scription\x18\x02 \x03(\x0b\x32\x32.NKikimrSchemeTypeOperation.TMetadata.TDescriptionB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.scheme_type_operation_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TMETADATA._serialized_start=76
  _TMETADATA._serialized_end=396
  _TMETADATA_TARG._serialized_start=158
  _TMETADATA_TARG._serialized_end=199
  _TMETADATA_TDESCRIPTION._serialized_start=201
  _TMETADATA_TDESCRIPTION._serialized_end=295
  _TMETADATA_TOPERATION._serialized_start=297
  _TMETADATA_TOPERATION._serialized_end=396
# @@protoc_insertion_point(module_scope)
