# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_tx_allocator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/core/protos/counters_tx_allocator.proto\x12\x14NKikimr.NTxAllocator\x1a\x1eydb/core/protos/counters.proto*,\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00*4\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*N\n\x08\x45TxTypes\x12\x1d\n\x0bTXTYPE_INIT\x10\x00\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12#\n\x0eTXTYPE_RESERVE\x10\x01\x1a\x0f\x8a\xd6\x1b\x0b\n\tTxReserveB\'\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x0bTxAllocator')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_tx_allocator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\013TxAllocator'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_RESERVE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESERVE"]._serialized_options = b'\212\326\033\013\n\tTxReserve'
  _ESIMPLECOUNTERS._serialized_start=101
  _ESIMPLECOUNTERS._serialized_end=145
  _ECUMULATIVECOUNTERS._serialized_start=147
  _ECUMULATIVECOUNTERS._serialized_end=199
  _EPERCENTILECOUNTERS._serialized_start=201
  _EPERCENTILECOUNTERS._serialized_end=279
  _ETXTYPES._serialized_start=281
  _ETXTYPES._serialized_end=359
# @@protoc_insertion_point(module_scope)
