# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: library/cpp/actors/protos/services_common.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/library/cpp/actors/protos/services_common.proto\x12\x0fNActorsServices*\xbb\x01\n\x0e\x45ServiceCommon\x12\n\n\x06GLOBAL\x10\x00\x12\x10\n\x0cINTERCONNECT\x10\x01\x12\x08\n\x04TEST\x10\x02\x12\r\n\tPROTOCOLS\x10\x03\x12\x1b\n\x17INTERCONNECT_SPEED_TEST\x10\x04\x12\x17\n\x13INTERCONNECT_STATUS\x10\x05\x12\x18\n\x14INTERCONNECT_NETWORK\x10\x06\x12\x18\n\x14INTERCONNECT_SESSION\x10\x07\x12\x08\n\x04HTTP\x10\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'library.cpp.actors.protos.services_common_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ESERVICECOMMON._serialized_start=69
  _ESERVICECOMMON._serialized_end=256
# @@protoc_insertion_point(module_scope)
