# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/stream.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/stream.proto\x12\rNKikimrStream\"\xad\x03\n\x10TStreamingConfig\x12 \n\x12\x45nableInputStreams\x18\x01 \x01(\x08:\x04true\x12!\n\x13\x45nableOutputStreams\x18\x02 \x01(\x08:\x04true\x12O\n\x12OutputStreamConfig\x18\x03 \x01(\x0b\x32\x33.NKikimrStream.TStreamingConfig.TOutputStreamConfig\x1a\x82\x02\n\x13TOutputStreamConfig\x12\"\n\x10MessageSizeLimit\x18\x01 \x01(\x04:\x08\x32\x30\x39\x37\x31\x35\x32\x30\x12$\n\x11MessageBufferSize\x18\x02 \x01(\x04:\t536870912\x12\x17\n\x0cMinQuotaSize\x18\x03 \x01(\r:\x01\x31\x12\x17\n\x0cMaxQuotaSize\x18\x04 \x01(\r:\x01\x35\x12\x1d\n\x12MaxStreamingShards\x18\x05 \x01(\r:\x01\x35\x12\'\n\x15InactiveClientTimeout\x18\x06 \x01(\x04:\x08\x36\x30\x30\x30\x30\x30\x30\x30\x12\'\n\x15InactiveServerTimeout\x18\x07 \x01(\x04:\x08\x36\x30\x30\x30\x30\x30\x30\x30\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.stream_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSTREAMINGCONFIG._serialized_start=48
  _TSTREAMINGCONFIG._serialized_end=477
  _TSTREAMINGCONFIG_TOUTPUTSTREAMCONFIG._serialized_start=219
  _TSTREAMINGCONFIG_TOUTPUTSTREAMCONFIG._serialized_end=477
# @@protoc_insertion_point(module_scope)
