# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blockstore_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/core/protos/blockstore_config.proto\x12\x11NKikimrBlockStore\"\x97\x01\n\x0fTChannelProfile\x12\x10\n\x08PoolKind\x18\x01 \x01(\t\x12\x0c\n\x04Size\x18\x02 \x01(\x04\x12\x10\n\x08ReadIops\x18\x03 \x01(\x01\x12\x15\n\rReadBandwidth\x18\x04 \x01(\x01\x12\x11\n\tWriteIops\x18\x05 \x01(\x01\x12\x16\n\x0eWriteBandwidth\x18\x06 \x01(\x01\x12\x10\n\x08\x44\x61taKind\x18\x65 \x01(\r\"0\n\x0fTEncryptionDesc\x12\x0c\n\x04Mode\x18\x01 \x01(\r\x12\x0f\n\x07KeyHash\x18\x02 \x01(\x0c\"\xf7\n\n\rTVolumeConfig\x12\x11\n\tBlockSize\x18\x01 \x01(\r\x12\x12\n\nStripeSize\x18\x02 \x01(\r\x12?\n\nPartitions\x18\x03 \x03(\x0b\x32+.NKikimrBlockStore.TVolumeConfig.TPartition\x12\x13\n\x0bNumChannels\x18\x04 \x01(\r\x12\x18\n\x10\x43hannelProfileId\x18\x05 \x01(\r\x12\x0f\n\x07Version\x18\x06 \x01(\r\x12\x0e\n\x06\x44iskId\x18\x07 \x01(\t\x12\x11\n\tProjectId\x18\x08 \x01(\t\x12\x10\n\x08\x46olderId\x18\t \x01(\t\x12\x0f\n\x07\x43loudId\x18\n \x01(\t\x12\x15\n\rTabletVersion\x18\x0b \x01(\r\x12\x0e\n\x06Opaque\x18\x0c \x01(\x0c\x12\x18\n\x10StorageMediaKind\x18\r \x01(\r\x12*\n\"PerformanceProfileMaxReadBandwidth\x18\x0e \x01(\r\x12,\n$PerformanceProfileMaxPostponedWeight\x18\x10 \x01(\r\x12+\n#PerformanceProfileThrottlingEnabled\x18\x11 \x01(\x08\x12%\n\x1dPerformanceProfileMaxReadIops\x18\x12 \x01(\r\x12#\n\x1bPerformanceProfileBoostTime\x18\x14 \x01(\r\x12)\n!PerformanceProfileBoostRefillTime\x18\x15 \x01(\r\x12)\n!PerformanceProfileBoostPercentage\x18\x16 \x01(\r\x12+\n#PerformanceProfileMaxWriteBandwidth\x18\x17 \x01(\r\x12&\n\x1ePerformanceProfileMaxWriteIops\x18\x18 \x01(\r\x12)\n!PerformanceProfileBurstPercentage\x18\x19 \x01(\r\x12\x12\n\nBaseDiskId\x18\x1a \x01(\t\x12\x1c\n\x14\x42\x61seDiskCheckpointId\x18\x1b \x01(\t\x12\x1b\n\x13SizeDecreaseAllowed\x18\x1c \x01(\x08\x12\x43\n\x17\x45xplicitChannelProfiles\x18\x1d \x03(\x0b\x32\".NKikimrBlockStore.TChannelProfile\x12\x1d\n\x15PoolKindChangeAllowed\x18\x1e \x01(\x08\x12\x17\n\x0fMaxBlocksInBlob\x18\x1f \x01(\r\x12\x12\n\nCreationTs\x18  \x01(\x04\x12\x0f\n\x07\x41lterTs\x18! \x01(\x04\x12\x18\n\x10PlacementGroupId\x18\" \x01(\t\x12\x0f\n\x07TagsStr\x18# \x01(\t\x12\x0c\n\x04Tags\x18$ \x03(\t\x12\x17\n\x0f\x42locksPerStripe\x18% \x01(\r\x12\x16\n\x0eZoneBlockCount\x18& \x01(\r\x12\x10\n\x08IsSystem\x18( \x01(\x08\x12I\n\x1dVolumeExplicitChannelProfiles\x18) \x03(\x0b\x32\".NKikimrBlockStore.TChannelProfile\x12\x17\n\x0fStoragePoolName\x18* \x01(\t\x12\x10\n\x08\x41gentIds\x18+ \x03(\t\x12:\n\x0e\x45ncryptionDesc\x18, \x01(\x0b\x32\".NKikimrBlockStore.TEncryptionDesc\x12\x1c\n\x14PlacementPartitionId\x18- \x01(\t\x1aQ\n\nTPartition\x12\x12\n\nBlockCount\x18\x02 \x01(\x04\x12/\n\x04Type\x18\x03 \x01(\x0e\x32!.NKikimrBlockStore.EPartitionType\"\xd7\x01\n\x13TUpdateVolumeConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x0cVolumeConfig\x18\x02 \x01(\x0b\x32 .NKikimrBlockStore.TVolumeConfig\x12\x45\n\nPartitions\x18\x03 \x03(\x0b\x32\x31.NKikimrBlockStore.TUpdateVolumeConfig.TPartition\x1a\x33\n\nTPartition\x12\x13\n\x0bPartitionId\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\"g\n\x1bTUpdateVolumeConfigResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12*\n\x06Status\x18\x03 \x01(\x0e\x32\x1a.NKikimrBlockStore.EStatus*0\n\x0e\x45PartitionType\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\x11\n\rNonReplicated\x10\x01*Q\n\x07\x45Status\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x15\n\x11\x45RROR_BAD_VERSION\x10\x02\x12\x1c\n\x18\x45RROR_UPDATE_IN_PROGRESS\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blockstore_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EPARTITIONTYPE._serialized_start=1991
  _EPARTITIONTYPE._serialized_end=2039
  _ESTATUS._serialized_start=2041
  _ESTATUS._serialized_end=2122
  _TCHANNELPROFILE._serialized_start=63
  _TCHANNELPROFILE._serialized_end=214
  _TENCRYPTIONDESC._serialized_start=216
  _TENCRYPTIONDESC._serialized_end=264
  _TVOLUMECONFIG._serialized_start=267
  _TVOLUMECONFIG._serialized_end=1666
  _TVOLUMECONFIG_TPARTITION._serialized_start=1585
  _TVOLUMECONFIG_TPARTITION._serialized_end=1666
  _TUPDATEVOLUMECONFIG._serialized_start=1669
  _TUPDATEVOLUMECONFIG._serialized_end=1884
  _TUPDATEVOLUMECONFIG_TPARTITION._serialized_start=1833
  _TUPDATEVOLUMECONFIG_TPARTITION._serialized_end=1884
  _TUPDATEVOLUMECONFIGRESPONSE._serialized_start=1886
  _TUPDATEVOLUMECONFIGRESPONSE._serialized_end=1989
# @@protoc_insertion_point(module_scope)
