# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/ydb_table_impl.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/ydb_table_impl.proto\x12\x08Ydb.Impl\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\"\xc1\x01\n\x11ReadTableResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12-\n\x08snapshot\x18\x04 \x01(\x0b\x32\x1b.Ydb.Impl.ReadTableSnapshot\x12)\n\x06result\x18\x03 \x01(\x0b\x32\x19.Ydb.Impl.ReadTableResult\"5\n\x11ReadTableSnapshot\x12\x11\n\tplan_step\x18\x01 \x01(\x04\x12\r\n\x05tx_id\x18\x02 \x01(\x04\"%\n\x0fReadTableResult\x12\x12\n\nresult_set\x18\x01 \x01(\x0c\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.ydb_table_impl_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _READTABLERESPONSE._serialized_start=144
  _READTABLERESPONSE._serialized_end=337
  _READTABLESNAPSHOT._serialized_start=339
  _READTABLESNAPSHOT._serialized_end=392
  _READTABLERESULT._serialized_start=394
  _READTABLERESULT._serialized_end=431
# @@protoc_insertion_point(module_scope)
