# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/scheme_board_mon.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/core/protos/scheme_board_mon.proto\x12\x15NKikimrSchemeBoardMon\x1a&library/cpp/actors/protos/actors.proto\"3\n\x0eTEvInfoRequest\x12!\n\x13LimitRepeatedFields\x18\x01 \x01(\r:\x04\x31\x30\x30\x30\"\x91\x05\n\x0fTEvInfoResponse\x12$\n\x04Self\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x14\n\x0c\x41\x63tivityType\x18\x0b \x01(\t\x12\x18\n\tTruncated\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x42\n\x0fReplicaResponse\x18\x04 \x01(\x0b\x32\'.NKikimrSchemeBoardMon.TReplicaResponseH\x00\x12\x46\n\x11PopulatorResponse\x18\x05 \x01(\x0b\x32).NKikimrSchemeBoardMon.TPopulatorResponseH\x00\x12T\n\x18ReplicaPopulatorResponse\x18\x06 \x01(\x0b\x32\x30.NKikimrSchemeBoardMon.TReplicaPopulatorResponseH\x00\x12H\n\x12SubscriberResponse\x18\x07 \x01(\x0b\x32*.NKikimrSchemeBoardMon.TSubscriberResponseH\x00\x12R\n\x17SubscriberProxyResponse\x18\x08 \x01(\x0b\x32/.NKikimrSchemeBoardMon.TSubscriberProxyResponseH\x00\x12V\n\x19ReplicaSubscriberResponse\x18\t \x01(\x0b\x32\x31.NKikimrSchemeBoardMon.TReplicaSubscriberResponseH\x00\x12>\n\rCacheResponse\x18\n \x01(\x0b\x32%.NKikimrSchemeBoardMon.TCacheResponseH\x00\x42\n\n\x08ResponseJ\x04\x08\x02\x10\x03\"b\n\x12TEvDescribeRequest\x12\x0e\n\x04Path\x18\x01 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x02 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x42\n\n\x08PathKind\"#\n\x13TEvDescribeResponse\x12\x0c\n\x04Json\x18\x01 \x01(\t\"/\n\x07TPathId\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x13\n\x0bLocalPathId\x18\x02 \x01(\x04\"\xd6\x04\n\x10TReplicaResponse\x12J\n\nPopulators\x18\x01 \x03(\x0b\x32\x36.NKikimrSchemeBoardMon.TReplicaResponse.TPopulatorInfo\x12O\n\x0c\x44\x65scriptions\x18\x02 \x01(\x0b\x32\x39.NKikimrSchemeBoardMon.TReplicaResponse.TDescriptionsInfo\x12L\n\x0bSubscribers\x18\x03 \x03(\x0b\x32\x37.NKikimrSchemeBoardMon.TReplicaResponse.TSubscriberInfo\x1aw\n\x0eTPopulatorInfo\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x19\n\x11PendingGeneration\x18\x03 \x01(\x04\x12\'\n\x07\x41\x63torId\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1aS\n\x11TDescriptionsInfo\x12\x12\n\nTotalCount\x18\x01 \x01(\x04\x12\x13\n\x0b\x42yPathCount\x18\x02 \x01(\x04\x12\x15\n\rByPathIdCount\x18\x03 \x01(\x04\x1a\x88\x01\n\x0fTSubscriberInfo\x12\'\n\x07\x41\x63torId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x04Path\x18\x02 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x03 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x42\n\n\x08PathKind\"\xaa\x04\n\x12TPopulatorResponse\x12\r\n\x05Owner\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x19\n\x11\x44\x65scriptionsCount\x18\x03 \x01(\x04\x12\x31\n\tMaxPathId\x18\x04 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x1b\n\x13\x44\x65layedUpdatesCount\x18\x05 \x01(\x04\x12\x31\n\x11ReplicaPopulators\x18\x06 \x03(\x0b\x32\x16.NActorsProto.TActorId\x12L\n\nUpdateAcks\x18\x07 \x03(\x0b\x32\x38.NKikimrSchemeBoardMon.TPopulatorResponse.TUpdateAckInfo\x1a\x84\x02\n\x0eTUpdateAckInfo\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\x12%\n\x05\x41\x63kTo\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12W\n\x08PathAcks\x18\x03 \x03(\x0b\x32\x45.NKikimrSchemeBoardMon.TPopulatorResponse.TUpdateAckInfo.TPathAckInfo\x1a\x62\n\x0cTPathAckInfo\x12.\n\x06PathId\x18\x01 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x12\x11\n\tAcksCount\x18\x03 \x01(\r\"\xf1\x05\n\x19TReplicaPopulatorResponse\x12&\n\x06Parent\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\'\n\x07Replica\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\r\n\x05Owner\x18\x03 \x01(\x04\x12\x12\n\nGeneration\x18\x04 \x01(\x04\x12\x31\n\tCurPathId\x18\x05 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x37\n\x0fLastAckedPathId\x18\x06 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x11\n\tBatchSize\x18\x07 \x01(\r\x12\x16\n\x0e\x42\x61tchSizeLimit\x18\x08 \x01(\r\x12M\n\x07Updates\x18\t \x03(\x0b\x32<.NKikimrSchemeBoardMon.TReplicaPopulatorResponse.TUpdateInfo\x12V\n\x10UpdatesRequested\x18\n \x03(\x0b\x32<.NKikimrSchemeBoardMon.TReplicaPopulatorResponse.TUpdateInfo\x12U\n\x0fUpdatesInFlight\x18\x0b \x03(\x0b\x32<.NKikimrSchemeBoardMon.TReplicaPopulatorResponse.TUpdateInfo\x1a\xca\x01\n\x0bTUpdateInfo\x12.\n\x06PathId\x18\x01 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12[\n\x08Versions\x18\x02 \x03(\x0b\x32I.NKikimrSchemeBoardMon.TReplicaPopulatorResponse.TUpdateInfo.TVersionInfo\x1a.\n\x0cTVersionInfo\x12\x0f\n\x07Version\x18\x01 \x01(\x04\x12\r\n\x05TxIds\x18\x02 \x03(\x04\"\xb2\x05\n\x13TSubscriberResponse\x12%\n\x05Owner\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x15\n\rDomainOwnerId\x18\x02 \x01(\x04\x12O\n\x0bProxyStates\x18\x03 \x03(\x0b\x32:.NKikimrSchemeBoardMon.TSubscriberResponse.TProxyStateInfo\x12\x44\n\x05State\x18\x04 \x01(\x0b\x32\x35.NKikimrSchemeBoardMon.TSubscriberResponse.TStateInfo\x12\x1a\n\x12\x44\x65layedSyncRequest\x18\x05 \x01(\x04\x12\x1a\n\x12\x43urrentSyncRequest\x18\x06 \x01(\x04\x12\x0e\n\x04Path\x18\x07 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x08 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x1a\xbf\x01\n\nTStateInfo\x12\x0f\n\x07\x44\x65leted\x18\x01 \x01(\x08\x12\x0e\n\x06Strong\x18\x02 \x01(\x08\x12.\n\x06PathId\x18\x03 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x0f\n\x07Version\x18\x04 \x01(\x04\x12\x30\n\x08\x44omainId\x18\x05 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathId\x12\x1d\n\x15\x41\x62\x61ndonedSchemeShards\x18\x06 \x03(\x04\x1a~\n\x0fTProxyStateInfo\x12%\n\x05Proxy\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x44\n\x05State\x18\x02 \x01(\x0b\x32\x35.NKikimrSchemeBoardMon.TSubscriberResponse.TStateInfoB\n\n\x08PathKind\"\x9f\x02\n\x18TSubscriberProxyResponse\x12&\n\x06Parent\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\'\n\x07Replica\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x31\n\x11ReplicaSubscriber\x18\x03 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x15\n\rDomainOwnerId\x18\x04 \x01(\x04\x12\x1a\n\x12\x43urrentSyncRequest\x18\x05 \x01(\x04\x12\x0e\n\x04Path\x18\x06 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x07 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x42\n\n\x08PathKind\"\xee\x01\n\x1aTReplicaSubscriberResponse\x12&\n\x06Parent\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\'\n\x07Replica\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x15\n\rDomainOwnerId\x18\x03 \x01(\x04\x12\x1a\n\x12\x43urrentSyncRequest\x18\x04 \x01(\x04\x12\x0e\n\x04Path\x18\x05 \x01(\tH\x00\x12\x30\n\x06PathId\x18\x06 \x01(\x0b\x32\x1e.NKikimrSchemeBoardMon.TPathIdH\x00\x42\n\n\x08PathKind\"_\n\x0eTCacheResponse\x12\x17\n\x0fItemsTotalCount\x18\x01 \x01(\x04\x12\x18\n\x10ItemsByPathCount\x18\x02 \x01(\x04\x12\x1a\n\x12ItemsByPathIdCount\x18\x03 \x01(\x04\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.scheme_board_mon_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVINFOREQUEST._serialized_start=105
  _TEVINFOREQUEST._serialized_end=156
  _TEVINFORESPONSE._serialized_start=159
  _TEVINFORESPONSE._serialized_end=816
  _TEVDESCRIBEREQUEST._serialized_start=818
  _TEVDESCRIBEREQUEST._serialized_end=916
  _TEVDESCRIBERESPONSE._serialized_start=918
  _TEVDESCRIBERESPONSE._serialized_end=953
  _TPATHID._serialized_start=955
  _TPATHID._serialized_end=1002
  _TREPLICARESPONSE._serialized_start=1005
  _TREPLICARESPONSE._serialized_end=1603
  _TREPLICARESPONSE_TPOPULATORINFO._serialized_start=1260
  _TREPLICARESPONSE_TPOPULATORINFO._serialized_end=1379
  _TREPLICARESPONSE_TDESCRIPTIONSINFO._serialized_start=1381
  _TREPLICARESPONSE_TDESCRIPTIONSINFO._serialized_end=1464
  _TREPLICARESPONSE_TSUBSCRIBERINFO._serialized_start=1467
  _TREPLICARESPONSE_TSUBSCRIBERINFO._serialized_end=1603
  _TPOPULATORRESPONSE._serialized_start=1606
  _TPOPULATORRESPONSE._serialized_end=2160
  _TPOPULATORRESPONSE_TUPDATEACKINFO._serialized_start=1900
  _TPOPULATORRESPONSE_TUPDATEACKINFO._serialized_end=2160
  _TPOPULATORRESPONSE_TUPDATEACKINFO_TPATHACKINFO._serialized_start=2062
  _TPOPULATORRESPONSE_TUPDATEACKINFO_TPATHACKINFO._serialized_end=2160
  _TREPLICAPOPULATORRESPONSE._serialized_start=2163
  _TREPLICAPOPULATORRESPONSE._serialized_end=2916
  _TREPLICAPOPULATORRESPONSE_TUPDATEINFO._serialized_start=2714
  _TREPLICAPOPULATORRESPONSE_TUPDATEINFO._serialized_end=2916
  _TREPLICAPOPULATORRESPONSE_TUPDATEINFO_TVERSIONINFO._serialized_start=2870
  _TREPLICAPOPULATORRESPONSE_TUPDATEINFO_TVERSIONINFO._serialized_end=2916
  _TSUBSCRIBERRESPONSE._serialized_start=2919
  _TSUBSCRIBERRESPONSE._serialized_end=3609
  _TSUBSCRIBERRESPONSE_TSTATEINFO._serialized_start=3278
  _TSUBSCRIBERRESPONSE_TSTATEINFO._serialized_end=3469
  _TSUBSCRIBERRESPONSE_TPROXYSTATEINFO._serialized_start=3471
  _TSUBSCRIBERRESPONSE_TPROXYSTATEINFO._serialized_end=3597
  _TSUBSCRIBERPROXYRESPONSE._serialized_start=3612
  _TSUBSCRIBERPROXYRESPONSE._serialized_end=3899
  _TREPLICASUBSCRIBERRESPONSE._serialized_start=3902
  _TREPLICASUBSCRIBERRESPONSE._serialized_end=4140
  _TCACHERESPONSE._serialized_start=4142
  _TCACHERESPONSE._serialized_end=4237
# @@protoc_insertion_point(module_scope)
