# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/bind_channel_storage_pool.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ydb/core/protos/bind_channel_storage_pool.proto\x12\x12NKikimrStoragePool\"*\n\x0cTStoragePool\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Kind\x18\x02 \x01(\t\"s\n\x0cTChannelBind\x12\x17\n\x0fStoragePoolName\x18\x02 \x01(\t\x12\x0c\n\x04IOPS\x18\n \x01(\x02\x12\x12\n\nThroughput\x18\x0b \x01(\x04\x12\x0c\n\x04Size\x18\x0c \x01(\x04\x12\x1a\n\x12PhysicalGroupsOnly\x18\x14 \x01(\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.bind_channel_storage_pool_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSTORAGEPOOL._serialized_start=71
  _TSTORAGEPOOL._serialized_end=113
  _TCHANNELBIND._serialized_start=115
  _TCHANNELBIND._serialized_end=230
# @@protoc_insertion_point(module_scope)
