# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tenant_pool.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/tenant_pool.proto\x12\x11NKikimrTenantPool\x1a$ydb/core/protos/flat_scheme_op.proto\x1a ydb/core/protos/subdomains.proto\x1a\x1cydb/core/protos/tablet.proto\"\x96\x01\n\x0bTSlotConfig\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x12\n\nDomainName\x18\x02 \x01(\t\x12\x12\n\nTenantName\x18\x03 \x01(\t\x12\x11\n\tIsDynamic\x18\x04 \x01(\x08\x12\x0c\n\x04Type\x18\x05 \x01(\t\x12\x32\n\rResourceLimit\x18\x06 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\"m\n\x11TTenantPoolConfig\x12\x17\n\tIsEnabled\x18\x01 \x01(\x08:\x04true\x12-\n\x05Slots\x18\x02 \x03(\x0b\x32\x1e.NKikimrTenantPool.TSlotConfig\x12\x10\n\x08NodeType\x18\x03 \x01(\t\"\x99\x02\n\x0bTSlotStatus\x12\n\n\x02Id\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x16\n\x0e\x41ssignedTenant\x18\x03 \x01(\t\x12\x32\n\rResourceLimit\x18\x04 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\r\n\x05Label\x18\x05 \x01(\t\x12\x39\n\x10TenantAttributes\x18\x06 \x03(\x0b\x32\x1f.NKikimrSchemeOp.TUserAttribute\x12(\n\x05State\x18\x07 \x01(\x0e\x32\x19.NKikimrTenantPool.EState\x12\x30\n\tDomainKey\x18\x08 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\"%\n\nTGetStatus\x12\x17\n\x0fListStaticSlots\x18\x01 \x01(\x08\"T\n\x11TTenantPoolStatus\x12-\n\x05Slots\x18\x01 \x03(\x0b\x32\x1e.NKikimrTenantPool.TSlotStatus\x12\x10\n\x08NodeType\x18\x02 \x01(\t\"G\n\x0eTConfigureSlot\x12\x0e\n\x06SlotId\x18\x01 \x01(\t\x12\x16\n\x0e\x41ssignedTenant\x18\x02 \x01(\t\x12\r\n\x05Label\x18\x03 \x01(\t\"\x85\x01\n\x14TConfigureSlotResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrTenantPool.EStatus\x12\r\n\x05\x45rror\x18\x02 \x01(\t\x12\x32\n\nSlotStatus\x18\x03 \x01(\x0b\x32\x1e.NKikimrTenantPool.TSlotStatus\"3\n\x0eTTakeOwnership\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\"\x10\n\x0eTLostOwnership*S\n\x06\x45State\x12\x11\n\rSTATE_UNKNOWN\x10\x00\x12\x13\n\x0fTENANT_ASSIGNED\x10\x01\x12\r\n\tTENANT_OK\x10\x02\x12\x12\n\x0eTENANT_UNKNOWN\x10\x03*c\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x10\n\x0cUNKNOWN_SLOT\x10\x02\x12\x12\n\x0eUNKNOWN_TENANT\x10\x03\x12\r\n\tNOT_OWNER\x10\x04\x12\t\n\x05\x45RROR\x10\x05\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tenant_pool_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ESTATE._serialized_start=1111
  _ESTATE._serialized_end=1194
  _ESTATUS._serialized_start=1196
  _ESTATUS._serialized_end=1295
  _TSLOTCONFIG._serialized_start=159
  _TSLOTCONFIG._serialized_end=309
  _TTENANTPOOLCONFIG._serialized_start=311
  _TTENANTPOOLCONFIG._serialized_end=420
  _TSLOTSTATUS._serialized_start=423
  _TSLOTSTATUS._serialized_end=704
  _TGETSTATUS._serialized_start=706
  _TGETSTATUS._serialized_end=743
  _TTENANTPOOLSTATUS._serialized_start=745
  _TTENANTPOOLSTATUS._serialized_end=829
  _TCONFIGURESLOT._serialized_start=831
  _TCONFIGURESLOT._serialized_end=902
  _TCONFIGURESLOTRESULT._serialized_start=905
  _TCONFIGURESLOTRESULT._serialized_end=1038
  _TTAKEOWNERSHIP._serialized_start=1040
  _TTAKEOWNERSHIP._serialized_end=1091
  _TLOSTOWNERSHIP._serialized_start=1093
  _TLOSTOWNERSHIP._serialized_end=1109
# @@protoc_insertion_point(module_scope)
