# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/draft/ydb_long_tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/public/api/protos/draft/ydb_long_tx.proto\x12\nYdb.LongTx\x1a)ydb/public/api/protos/ydb_operation.proto\"\x7f\n\x04\x44\x61ta\x12\'\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\x17.Ydb.LongTx.Data.Format\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"@\n\x06\x46ormat\x12\x16\n\x12\x46ORMAT_UNSPECIFIED\x10\x00\x12\x0c\n\x08YDB_ROWS\x10\x01\x12\x10\n\x0c\x41PACHE_ARROW\x10\x03\"\xd0\x01\n\x17\x42\x65ginTransactionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12=\n\x07tx_type\x18\x02 \x01(\x0e\x32,.Ydb.LongTx.BeginTransactionRequest.TxTypeId\";\n\x08TxTypeId\x12\x1a\n\x16TX_TYPE_ID_UNSPECIFIED\x10\x00\x12\t\n\x05WRITE\x10\x01\x12\x08\n\x04READ\x10\x02\"\'\n\x16\x42\x65ginTransactionResult\x12\r\n\x05tx_id\x18\x01 \x01(\t\"H\n\x18\x42\x65ginTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"d\n\x18\x43ommitTransactionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\r\n\x05tx_id\x18\x02 \x01(\t\"(\n\x17\x43ommitTransactionResult\x12\r\n\x05tx_id\x18\x01 \x01(\t\"I\n\x19\x43ommitTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"f\n\x1aRollbackTransactionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\r\n\x05tx_id\x18\x02 \x01(\t\"*\n\x19RollbackTransactionResult\x12\r\n\x05tx_id\x18\x01 \x01(\t\"K\n\x1bRollbackTransactionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x98\x01\n\x0cWriteRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\x10\n\x08\x64\x65\x64up_id\x18\x04 \x01(\t\x12\x1e\n\x04\x64\x61ta\x18\x05 \x01(\x0b\x32\x10.Ydb.LongTx.Data\"<\n\x0bWriteResult\x12\r\n\x05tx_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x10\n\x08\x64\x65\x64up_id\x18\x03 \x01(\t\"=\n\rWriteResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"}\n\x0bReadRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\r\n\x05tx_id\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12\r\n\x03sql\x18\x0b \x01(\tH\x00\x42\x07\n\x05query\"j\n\nReadResult\x12\r\n\x05tx_id\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\r\n\x05\x63hunk\x18\x03 \x01(\x04\x12\x10\n\x08\x66inished\x18\x04 \x01(\x08\x12\x1e\n\x04\x64\x61ta\x18\x05 \x01(\x0b\x32\x10.Ydb.LongTx.Data\"<\n\x0cReadResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.OperationB)\n\x16\x63om.yandex.ydb.long_txB\x0cLongTxProtos\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.draft.ydb_long_tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026com.yandex.ydb.long_txB\014LongTxProtos\370\001\001'
  _DATA._serialized_start=104
  _DATA._serialized_end=231
  _DATA_FORMAT._serialized_start=167
  _DATA_FORMAT._serialized_end=231
  _BEGINTRANSACTIONREQUEST._serialized_start=234
  _BEGINTRANSACTIONREQUEST._serialized_end=442
  _BEGINTRANSACTIONREQUEST_TXTYPEID._serialized_start=383
  _BEGINTRANSACTIONREQUEST_TXTYPEID._serialized_end=442
  _BEGINTRANSACTIONRESULT._serialized_start=444
  _BEGINTRANSACTIONRESULT._serialized_end=483
  _BEGINTRANSACTIONRESPONSE._serialized_start=485
  _BEGINTRANSACTIONRESPONSE._serialized_end=557
  _COMMITTRANSACTIONREQUEST._serialized_start=559
  _COMMITTRANSACTIONREQUEST._serialized_end=659
  _COMMITTRANSACTIONRESULT._serialized_start=661
  _COMMITTRANSACTIONRESULT._serialized_end=701
  _COMMITTRANSACTIONRESPONSE._serialized_start=703
  _COMMITTRANSACTIONRESPONSE._serialized_end=776
  _ROLLBACKTRANSACTIONREQUEST._serialized_start=778
  _ROLLBACKTRANSACTIONREQUEST._serialized_end=880
  _ROLLBACKTRANSACTIONRESULT._serialized_start=882
  _ROLLBACKTRANSACTIONRESULT._serialized_end=924
  _ROLLBACKTRANSACTIONRESPONSE._serialized_start=926
  _ROLLBACKTRANSACTIONRESPONSE._serialized_end=1001
  _WRITEREQUEST._serialized_start=1004
  _WRITEREQUEST._serialized_end=1156
  _WRITERESULT._serialized_start=1158
  _WRITERESULT._serialized_end=1218
  _WRITERESPONSE._serialized_start=1220
  _WRITERESPONSE._serialized_end=1281
  _READREQUEST._serialized_start=1283
  _READREQUEST._serialized_end=1408
  _READRESULT._serialized_start=1410
  _READRESULT._serialized_end=1516
  _READRESPONSE._serialized_start=1518
  _READRESPONSE._serialized_end=1578
# @@protoc_insertion_point(module_scope)
