# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/msgbus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import console_pb2 as ydb_dot_core_dot_protos_dot_console__pb2
from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2
from ydb.core.protos import console_base_pb2 as ydb_dot_core_dot_protos_dot_console__base__pb2
from ydb.core.protos import console_config_pb2 as ydb_dot_core_dot_protos_dot_console__config__pb2
from ydb.core.protos import console_tenant_pb2 as ydb_dot_core_dot_protos_dot_console__tenant__pb2
from ydb.core.protos import datashard_load_pb2 as ydb_dot_core_dot_protos_dot_datashard__load__pb2
from ydb.core.protos import tablet_counters_pb2 as ydb_dot_core_dot_protos_dot_tablet__counters__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import tx_proxy_pb2 as ydb_dot_core_dot_protos_dot_tx__proxy__pb2
from ydb.core.protos import tx_scheme_pb2 as ydb_dot_core_dot_protos_dot_tx__scheme__pb2
from ydb.core.protos import node_whiteboard_pb2 as ydb_dot_core_dot_protos_dot_node__whiteboard__pb2
from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2
from ydb.core.protos import msgbus_kv_pb2 as ydb_dot_core_dot_protos_dot_msgbus__kv__pb2
from ydb.core.protos import msgbus_pq_pb2 as ydb_dot_core_dot_protos_dot_msgbus__pq__pb2
from ydb.core.protos import scheme_log_pb2 as ydb_dot_core_dot_protos_dot_scheme__log__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import blobstorage_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__config__pb2
from ydb.core.protos import node_broker_pb2 as ydb_dot_core_dot_protos_dot_node__broker__pb2
from ydb.core.protos import cms_pb2 as ydb_dot_core_dot_protos_dot_cms__pb2
from ydb.core.protos import sqs_pb2 as ydb_dot_core_dot_protos_dot_sqs__pb2
from ydb.core.protos import issue_id_pb2 as ydb_dot_core_dot_protos_dot_issue__id__pb2
from ydb.core.protos import query_stats_pb2 as ydb_dot_core_dot_protos_dot_query__stats__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import load_test_pb2 as ydb_dot_core_dot_protos_dot_load__test__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos.draft import persqueue_error_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_draft_dot_persqueue__error__codes__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.library.mkql_proto.protos import minikql_pb2 as ydb_dot_library_dot_mkql__proto_dot_protos_dot_minikql__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/msgbus.proto\x12\rNKikimrClient\x1a\x1dydb/core/protos/console.proto\x1a,library/cpp/actors/protos/interconnect.proto\x1a\"ydb/core/protos/console_base.proto\x1a$ydb/core/protos/console_config.proto\x1a$ydb/core/protos/console_tenant.proto\x1a$ydb/core/protos/datashard_load.proto\x1a%ydb/core/protos/tablet_counters.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a\x1eydb/core/protos/tx_proxy.proto\x1a\x1fydb/core/protos/tx_scheme.proto\x1a%ydb/core/protos/node_whiteboard.proto\x1a/ydb/core/protos/bind_channel_storage_pool.proto\x1a\x1fydb/core/protos/msgbus_kv.proto\x1a\x1fydb/core/protos/msgbus_pq.proto\x1a ydb/core/protos/scheme_log.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1cydb/core/protos/tablet.proto\x1a(ydb/core/protos/blobstorage_config.proto\x1a!ydb/core/protos/node_broker.proto\x1a\x19ydb/core/protos/cms.proto\x1a\x19ydb/core/protos/sqs.proto\x1a\x1eydb/core/protos/issue_id.proto\x1a!ydb/core/protos/query_stats.proto\x1a ydb/core/protos/subdomains.proto\x1a\x1fydb/core/protos/load_test.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a\x37ydb/public/api/protos/draft/persqueue_error_codes.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a+ydb/library/mkql_proto/protos/minikql.proto\x1a google/protobuf/descriptor.proto\"y\n\x0eTEnumValueHint\x12\x33\n\x05Hints\x18\x01 \x03(\x0b\x32$.NKikimrClient.TEnumValueHint.TEntry\x1a\x32\n\x06TEntry\x12\r\n\x05Value\x18\x01 \x01(\x04\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0b\n\x03Man\x18\x03 \x01(\t\"-\n\x12TMsgBusRequestBase\x12\x17\n\x0fServerTimeoutMs\x18\x01 \x01(\r\"\x87\x01\n\x08TRequest\x12\x35\n\x0bTransaction\x18\x01 \x01(\x0b\x32 .NKikimrTxUserProxy.TTransaction\x12\x12\n\nProxyFlags\x18\x02 \x01(\x04\x12\x19\n\x11\x45xecTimeoutPeriod\x18\x04 \x01(\x04\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\"F\n\tTFlatTxId\x12\x0c\n\x04TxId\x18\x01 \x01(\x06\x12\x1b\n\x13SchemeShardTabletId\x18\x02 \x01(\x06\x12\x0e\n\x06PathId\x18\x03 \x01(\x04\"4\n\x14TResolveNodeResponse\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\"\x93\x32\n\tTResponse\x12\xf9\x04\n\x06Status\x18\x01 \x01(\rB\xe8\x04\x92\x97\"\x15Generic msgbus status\x8a\x97\"\xca\x04\n5\x08\x00\x12\x0fMSTATUS_UNKNOWN\x1a Status unknown, must not be seen\n2\x08\x01\x12\nMSTATUS_OK\x1a\"Request complete with full success\n?\x08\x80\x01\x12\rMSTATUS_ERROR\x1a+Request failed because of client-side error\n9\x08\x81\x01\x12\x12MSTATUS_INPROGRESS\x1a Request accepted and in progress\nI\x08\x82\x01\x12\x0fMSTATUS_TIMEOUT\x1a\x33Request failed due to timeout, exact status unknown\nC\x08\x83\x01\x12\x10MSTATUS_NOTREADY\x1a,Not yet ready to process requests, try later\nL\x08\x84\x01\x12\x0fMSTATUS_ABORTED\x1a\x36Request aborted, particular meaning depends on context\nG\x08\x85\x01\x12\x15MSTATUS_INTERNALERROR\x1a+Something unexpected happend on server-side\n:\x08\x86\x01\x12\x10MSTATUS_REJECTED\x1a#Request rejected for now, try later\x12\x14\n\x0b\x45rrorReason\x18\x90\x03 \x01(\t\x12\x0c\n\x04TxId\x18\x02 \x01(\x06\x12\x0c\n\x04Step\x18\x03 \x01(\x06\x12\x10\n\x08TabletId\x18\x04 \x01(\x06\x12\xd4\x10\n\x0eProxyErrorCode\x18\x05 \x01(\rB\xbb\x10\x92\x97\"#Transaction proxy processing status\x8a\x97\"\x8f\x10\n-\x08\x00\x12\x07Unknown\x1a Status unknown, must not be seen\nh\x08\x01\x12\x0cWrongRequest\x1aVNot recognized or erroneous request, see error description fields for possible details\nL\x08\x02\x12\x10\x45mptyAffectedSet\x1a\x36Program must touch at least one shard but touches none\n9\x08\x03\x12\x0eNotImplemented\x1a%Not yet implemented feature requested\nH\x08\x04\x12\x0cResolveError\x1a\x36Some keys not resolved, see UnresolvedKeys for details\n+\x08\x05\x12\x0c\x41\x63\x63\x65ssDenied\x1a\x19\x41\x63\x63\x65ss denied for request\n@\x08\x06\x12\x13\x44omainLocalityError\x1a\'Cross database transactions not allowed\n|\x08\x10\x12\rProxyNotReady\x1aiTransaction proxy not ready for handling requests, try later. Most known case is temporary lack of txid-s\nA\x08\x11\x12\rProxyAccepted\x1a.Request accepted by proxy. Transitional status\nK\x08\x12\x12\rProxyResolved\x1a\x38Request keys resolved to datashards. Transitional status\nO\x08\x13\x12\rProxyPrepared\x1a<Request fragmets prepared on datashards. Transitional status\ni\x08\x14\x12\x16ProxyShardNotAvailable\x1aMOne or more of affected datashards not available, request execution cancelled\nR\x08\x15\x12\x12ProxyShardTryLater\x1a:One or more of affected datashards are starting, try again\nV\x08\x16\x12\x14ProxyShardOverloaded\x1a<One or more of affected datashards are overloaded, try again\nP\x08\x17\x12\x11ProxyShardUnknown\x1a\x39State of transaction on one or more datashards is unknown\nL\x08 \x12\x13\x43oordinatorDeclined\x1a\x33\x43oordinator declines to plan transaction, try again\nk\x08!\x12\x13\x43oordinatorOutdated\x1aRCoordinator was not able to plan transaction due to timing restrictions, try again\n:\x08\"\x12\x12\x43oordinatorAborted\x1a\"Transaction aborted by coordinator\n]\x08#\x12\x12\x43oordinatorPlanned\x1a\x45Transaction planned for execution by coordinator. Transitional status\n\x7f\x08$\x12\x12\x43oordinatorUnknown\x1agCould not reach coordinator or coordinator pipe dropped before confirmation. Transaction status unknown\n\x19\x08\x30\x12\x0c\x45xecComplete\x1a\x07Success\n4\x08\x31\x12\x0b\x45xecAlready\x1a#Requested operation already applied\nG\x08\x32\x12\x0b\x45xecAborted\x1a\x36Request aborted, particular meaning depends on context\n?\x08\x33\x12\x0b\x45xecTimeout\x1a.Proxy got no execution reply in timeout period\n\x1f\x08\x34\x12\tExecError\x1a\x10\x45xecution failed\n1\x08\x35\x12\x0e\x45xecInProgress\x1a\x1dRequest accepted and now runs\n8\x08\x37\x12\x15\x45xecResultUnavailable\x1a\x1d\x45xecution results unavailable\n*\x08\x38\x12\rExecCancelled\x1a\x17\x45xecution was cancelled\x12\x13\n\x0bProxyErrors\x18\x06 \x01(\x0c\x12\x39\n\nStatusCode\x18\x07 \x01(\x0e\x32%.NKikimrIssues.TStatusIds.EStatusCode\x12\'\n\x06Issues\x18\x08 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\xe4\x04\n\x15\x45xecutionEngineStatus\x18\x64 \x01(\rB\xc4\x04\x92\x97\"KMiniKQL engine processing status, if OK - see ExecutionEngineResponseStatus\x8a\x97\"\xf0\x03\n0\x08\x00\x12\x07Unknown\x1a#Status unknown, not filled probably\n\x0f\x08\x01\x12\x02Ok\x1a\x07Success\nU\x08\x02\x12\rSchemeChanged\x1a\x42Scheme or partitioning was changed b/w compilation and preparation\n7\x08\x03\x12\nIsReadonly\x1a\'Update requested in read-only operation\n*\x08\x04\x12\x08KeyError\x1a\x1cSomething wrong in data keys\n#\x08\x05\x12\x0cProgramError\x1a\x11Malformed program\n7\x08\x06\x12\rTooManyShards\x1a$Too much datashards affected program\n2\x08\x07\x12\x0bTooManyData\x1a!Too much data affected by program\n2\x08\x08\x12\x10SnapshotNotExist\x1a\x1cRequested snapshot not exist\n)\x08\t\x12\x10SnapshotNotReady\x1a\x13Snapshot not online\x12\xd9\x01\n\x1d\x45xecutionEngineResponseStatus\x18\x65 \x01(\rB\xb1\x01\x92\x97\"\x1fMiniKQL engine execution status\x8a\x97\"\x89\x01\n0\x08\x00\x12\x07Unknown\x1a#Status unknown, not filled probably\n\x10\x08\x01\x12\x05\x45rror\x1a\x05\x45rror\n#\x08\x02\x12\x08\x43omplete\x1a\x15\x43omplete with success\n\x1e\x08\x03\x12\x05\x41\x62ort\x1a\x13\x43omplete with abort\x12\x41\n ExecutionEngineEvaluatedResponse\x18g \x01(\x0b\x32\x17.NKikimrMiniKQL.TResult\x12\x15\n\rMiniKQLErrors\x18h \x01(\x0c\x12\x17\n\x0f\x44\x61taShardErrors\x18i \x01(\x0c\x12\x1d\n\x15\x43omplainingDataShards\x18j \x03(\x06\x12\x16\n\x0eUnresolvedKeys\x18k \x03(\x0c\x12,\n\x07TxStats\x18o \x01(\x0b\x32\x1b.NKikimrQueryStats.TTxStats\x12I\n\x15MiniKQLCompileResults\x18l \x01(\x0b\x32*.NKikimrTxUserProxy.TMiniKQLCompileResults\x12\x18\n\x10HadFollowerReads\x18m \x01(\x08\x12#\n\x1bSerializedReadTableResponse\x18n \x01(\x0c\x12\x14\n\x0c\x42SAssignedID\x18( \x01(\r\x12\x39\n\x0cProxyTimings\x18\x32 \x01(\x0b\x32#.NKikimrTxUserProxy.TTxProxyTimings\x12\x15\n\x0cSchemeStatus\x18\xac\x02 \x01(\x05\x12\x14\n\x0bSchemeTagId\x18\xad\x02 \x01(\r\x12\x15\n\x0cSchemePrefix\x18\xae\x02 \x01(\x0c\x12=\n\x0fTabletStateInfo\x18\xf4\x03 \x03(\x0b\x32#.NKikimrWhiteboard.TTabletStateInfo\x12;\n\x0fPathDescription\x18\xd8\x04 \x01(\x0b\x32!.NKikimrSchemeOp.TPathDescription\x12\r\n\x04Path\x18\xd9\x04 \x01(\t\x12+\n\x08\x46latTxId\x18\xbc\x05 \x01(\x0b\x32\x18.NKikimrClient.TFlatTxId\x12\x35\n\tErrorCode\x18\xa0\x06 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x46\n\x11PartitionResponse\x18\xa1\x06 \x01(\x0b\x32*.NKikimrClient.TPersQueuePartitionResponse\x12<\n\x0cMetaResponse\x18\xa2\x06 \x01(\x0b\x32%.NKikimrClient.TPersQueueMetaResponse\x12>\n\rFetchResponse\x18\xa3\x06 \x01(\x0b\x32&.NKikimrClient.TPersQueueFetchResponse\x12\x0f\n\x06\x43ookie\x18\x84\x07 \x01(\x04\x12O\n\x11\x44\x65leteRangeResult\x18\x85\x07 \x03(\x0b\x32\x33.NKikimrClient.TKeyValueResponse.TDeleteRangeResult\x12_\n\x19IncrementGenerationResult\x18\x86\x07 \x01(\x0b\x32;.NKikimrClient.TKeyValueResponse.TIncrementGenerationResult\x12\x41\n\nReadResult\x18\x87\x07 \x03(\x0b\x32,.NKikimrClient.TKeyValueResponse.TReadResult\x12K\n\x0fReadRangeResult\x18\x88\x07 \x03(\x0b\x32\x31.NKikimrClient.TKeyValueResponse.TReadRangeResult\x12\x43\n\x0bWriteResult\x18\x89\x07 \x03(\x0b\x32-.NKikimrClient.TKeyValueResponse.TWriteResult\x12\x45\n\x0cRenameResult\x18\x8a\x07 \x03(\x0b\x32..NKikimrClient.TKeyValueResponse.TRenameResult\x12K\n\x0f\x43opyRangeResult\x18\x8b\x07 \x03(\x0b\x32\x31.NKikimrClient.TKeyValueResponse.TCopyRangeResult\x12\x45\n\x0c\x43oncatResult\x18\x8c\x07 \x03(\x0b\x32..NKikimrClient.TKeyValueResponse.TConcatResult\x12K\n\x0fGetStatusResult\x18\x8d\x07 \x03(\x0b\x32\x31.NKikimrClient.TKeyValueResponse.TGetStatusResult\x12W\n\x15TrimLeakedBlobsResult\x18\x8e\x07 \x01(\x0b\x32\x37.NKikimrClient.TKeyValueResponse.TTrimLeakedBlobsResult\x12i\n\x1eSetExecutorFastLogPolicyResult\x18\x8f\x07 \x01(\x0b\x32@.NKikimrClient.TKeyValueResponse.TSetExecutorFastLogPolicyResult\x12I\n\x12\x43reateTabletResult\x18\xe8\x07 \x03(\x0b\x32,.NKikimrClient.TResponse.TCreateTabletResult\x12I\n\x12LookupTabletResult\x18\xea\x07 \x03(\x0b\x32,.NKikimrClient.TResponse.TLookupTabletResult\x12\x39\n\nTabletInfo\x18\xe9\x07 \x03(\x0b\x32$.NKikimrClient.TResponse.TTabletInfo\x12\x39\n\rLocalDbScheme\x18\xf2\x07 \x01(\x0b\x32!.NTabletFlatScheme.TSchemeChanges\x12;\n\x0eTabletCounters\x18\xfc\x07 \x01(\x0b\x32\".NKikimrTabletBase.TTabletCounters\x12G\n\x19\x42lobStorageConfigResponse\x18\x86\x08 \x01(\x0b\x32#.NKikimrBlobStorage.TConfigResponse\x12\x41\n\x13ResolveNodeResponse\x18\x90\x08 \x01(\x0b\x32#.NKikimrClient.TResolveNodeResponse\x12\x12\n\tProxyName\x18\x9a\x08 \x01(\t\x12\x14\n\x0bProxyCookie\x18\x9b\x08 \x01(\x04\x12\x11\n\x08UserName\x18\xcc\x08 \x01(\t\x12\x0f\n\x06Groups\x18\xcd\x08 \x03(\t\x12\x12\n\tUserToken\x18\xce\x08 \x01(\t\x1a\x37\n\x13TCreateTabletResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x1a\x37\n\x13TLookupTabletResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x1aZ\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x39\n\nTabletType\x18\x02 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\"\'\n\x10TFakeConfigDummy\x12\x13\n\x0b\x44\x61taShardID\x18\x01 \x01(\x04\"i\n\x16TTabletCountersRequest\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x19\n\x11\x43onnectToFollower\x18\x02 \x01(\x08\x12\x11\n\tWithRetry\x18\n \x01(\x08\x12\x0f\n\x07Timeout\x18\x0b \x01(\x04\"\xfb\x01\n\nTLocalMKQL\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x38\n\x07Program\x18\x02 \x01(\x0b\x32\'.NKikimrTxUserProxy.TMiniKQLTransaction\x12\x19\n\x11\x43onnectToFollower\x18\x03 \x01(\x08\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\x12\x11\n\tWithRetry\x18\n \x01(\x08\x12\x0f\n\x07Timeout\x18\x0b \x01(\x04\x1a%\n\x08TProgram\x12\x0b\n\x03\x42in\x18\x01 \x01(\x0c\x12\x0c\n\x04Text\x18\x02 \x01(\t\x1a$\n\x07TParams\x12\x0b\n\x03\x42in\x18\x01 \x01(\x0c\x12\x0c\n\x04Text\x18\x02 \x01(\t\"\xc2\x01\n\x0eTLocalSchemeTx\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\x12\x19\n\x11\x43onnectToFollower\x18\x02 \x01(\x08\x12\x38\n\rSchemeChanges\x18\x03 \x01(\x0b\x32!.NTabletFlatScheme.TSchemeChanges\x12\x0e\n\x06\x44ryRun\x18\x04 \x01(\x08\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\x12\x11\n\tWithRetry\x18\n \x01(\x08\x12\x0f\n\x07Timeout\x18\x0b \x01(\x04\"j\n\x0fTSchemeNavigate\x12\x0c\n\x04Path\x18\x01 \x01(\x0c\x12\x1e\n\x16ReadMaterializedFamily\x18\x02 \x01(\r\x12\x10\n\x08TextPath\x18\x03 \x01(\x0c\x12\x17\n\x0fSchemeShardHint\x18\x04 \x01(\x04\"\xc1\x01\n\x0fTSchemeInitRoot\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x12\r\n\x05TagId\x18\x02 \x01(\r\x12\x0f\n\x07TagName\x18\x03 \x01(\x0c\x12.\n\x0cGlobalConfig\x18\x04 \x01(\x0b\x32\x18.NKikimrTxScheme.TConfig\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\x12\x36\n\x0cStoragePools\x18\x06 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\"\x8f\x02\n\x06TBSAdm\x12\x0e\n\x06\x44omain\x18\x01 \x01(\r\x12I\n\x14GroupReconfigureWipe\x18\x06 \x01(\x0b\x32+.NKikimrClient.TBSAdm.TGroupReconfigureWipe\x12\x15\n\rSecurityToken\x18\x07 \x01(\t\x1a\x42\n\x0eTVDiskLocation\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07PDiskId\x18\x02 \x01(\r\x12\x0f\n\x07VSlotId\x18\x03 \x01(\r\x1aO\n\x15TGroupReconfigureWipe\x12\x36\n\x08Location\x18\x01 \x01(\x0b\x32$.NKikimrClient.TBSAdm.TVDiskLocation\"\x8a\x04\n\x11THiveCreateTablet\x12J\n\x0f\x43mdCreateTablet\x18\x01 \x03(\x0b\x32\x31.NKikimrClient.THiveCreateTablet.TCmdCreateTablet\x12J\n\x0f\x43mdLookupTablet\x18\x03 \x03(\x0b\x32\x31.NKikimrClient.THiveCreateTablet.TCmdLookupTablet\x12\x11\n\tDomainUid\x18\x02 \x01(\r\x1a\x92\x02\n\x10TCmdCreateTablet\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x10\n\x08OwnerIdx\x18\x02 \x01(\x04\x12\x39\n\nTabletType\x18\x03 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x17\n\x0f\x43hannelsProfile\x18\x04 \x01(\r\x12\x16\n\x0e\x41llowedNodeIDs\x18\x05 \x03(\r\x12\x35\n\x0e\x41llowedDomains\x18\x06 \x03(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x38\n\x0e\x42indedChannels\x18\x07 \x03(\x0b\x32 .NKikimrStoragePool.TChannelBind\x1a\x35\n\x10TCmdLookupTablet\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x04\x12\x10\n\x08OwnerIdx\x18\x02 \x01(\x04\"\xf8\x02\n\x17THiveCreateTabletResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x16\n\rProtobufError\x18\x90\x03 \x01(\x0c\x12V\n\x12\x43reateTabletResult\x18\x02 \x03(\x0b\x32:.NKikimrClient.THiveCreateTabletResult.TCreateTabletResult\x12V\n\x12LookupTabletResult\x18\x04 \x03(\x0b\x32:.NKikimrClient.THiveCreateTabletResult.TLookupTabletResult\x12\x13\n\x0b\x45rrorReason\x18\x03 \x01(\t\x1a\x37\n\x13TCreateTabletResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x1a\x37\n\x13TLookupTabletResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\"v\n\x16TLocalEnumerateTablets\x12\x11\n\tDomainUid\x18\x01 \x01(\x04\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x39\n\nTabletType\x18\x03 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\"\x84\x02\n\x1cTLocalEnumerateTabletsResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x16\n\rProtobufError\x18\x90\x03 \x01(\x0c\x12K\n\nTabletInfo\x18\x02 \x03(\x0b\x32\x37.NKikimrClient.TLocalEnumerateTabletsResult.TTabletInfo\x12\x13\n\x0b\x45rrorReason\x18\x03 \x01(\t\x1aZ\n\x0bTTabletInfo\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x39\n\nTabletType\x18\x02 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\"$\n\x14TTypeMetadataRequest\x12\x0c\n\x04\x45Tag\x18\x01 \x01(\x04\"}\n\x15TTypeMetadataResponse\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x16\n\rProtobufError\x18\x90\x03 \x01(\x0c\x12\x0c\n\x04\x45Tag\x18\x02 \x01(\x04\x12\x14\n\x0cTypeMetadata\x18\x03 \x01(\x0c\x12\x18\n\x10\x46unctionMetadata\x18\x04 \x01(\x0c\"\x8a\x01\n\x17TMessageBusTraceRequest\x12@\n\x07\x43ommand\x18\x01 \x01(\x0e\x32/.NKikimrClient.TMessageBusTraceRequest.ECommand\x12\x0c\n\x04Path\x18\x02 \x01(\x0c\"\x1f\n\x08\x45\x43ommand\x12\t\n\x05START\x10\x00\x12\x08\n\x04STOP\x10\x01\";\n\x16TMessageBusTraceStatus\x12\x13\n\x0bTraceActive\x18\x01 \x01(\x08\x12\x0c\n\x04Path\x18\x02 \x01(\x0c\"&\n\x12TTabletKillRequest\x12\x10\n\x08TabletID\x18\x01 \x01(\x04\"r\n\x13TTabletStateRequest\x12\x39\n\nTabletType\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\r\n\x05\x41live\x18\x02 \x01(\x08\x12\x11\n\tTabletIDs\x18\x03 \x03(\x06\"+\n\x12TFlatTxPollOptions\x12\x15\n\x07Timeout\x18\x01 \x01(\r:\x04\x31\x30\x30\x30\"\x98\x01\n\x10TSchemeOperation\x12\x35\n\x0bTransaction\x18\x01 \x01(\x0b\x32 .NKikimrTxUserProxy.TTransaction\x12\x36\n\x0bPollOptions\x18\n \x01(\x0b\x32!.NKikimrClient.TFlatTxPollOptions\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\"\x91\x01\n\x0fTSchemeDescribe\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x15\n\rSchemeshardId\x18\x03 \x01(\x04\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\x12\x32\n\x07Options\x18\x06 \x01(\x0b\x32!.NKikimrSchemeOp.TDescribeOptions\"\x84\x02\n\x15TFlatDescribeResponse\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0c\n\x04Path\x18\t \x01(\t\x12:\n\x0fPathDescription\x18\x02 \x01(\x0b\x32!.NKikimrSchemeOp.TPathDescription\x12\x13\n\x0b\x45rrorReason\x18\x03 \x01(\t\x12\x14\n\x0cSchemeStatus\x18\x04 \x01(\x05\x12\x39\n\nStatusCode\x18\x07 \x01(\x0e\x32%.NKikimrIssues.TStatusIds.EStatusCode\x12\'\n\x06Issues\x18\x08 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage:\x02\x18\x01\"|\n\x16TSchemeOperationStatus\x12*\n\x08\x46latTxId\x18\x01 \x01(\x0b\x32\x18.NKikimrClient.TFlatTxId\x12\x36\n\x0bPollOptions\x18\n \x01(\x0b\x32!.NKikimrClient.TFlatTxPollOptions\"a\n\x12TDsTestLoadRequest\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12;\n\x05\x45vent\x18\x02 \x01(\x0b\x32,.NKikimrDataShardLoad.TEvYCSBTestLoadRequest\"\x8c\x01\n\x13TDsTestLoadResponse\x12\x37\n\x05Items\x18\x01 \x03(\x0b\x32(.NKikimrClient.TDsTestLoadResponse.TItem\x1a<\n\x05TItem\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0e\n\x06Status\x18\x02 \x01(\r\x12\x13\n\x0b\x45rrorReason\x18\x03 \x01(\t\"P\n\x12TBsTestLoadRequest\x12\x0e\n\x06NodeId\x18\x01 \x03(\r\x12*\n\x05\x45vent\x18\x02 \x01(\x0b\x32\x1b.NKikimr.TEvLoadTestRequest\"\x8c\x01\n\x13TBsTestLoadResponse\x12\x37\n\x05Items\x18\x01 \x03(\x0b\x32(.NKikimrClient.TBsTestLoadResponse.TItem\x1a<\n\x05TItem\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0e\n\x06Status\x18\x02 \x01(\r\x12\x13\n\x0b\x45rrorReason\x18\x03 \x01(\t\"W\n\rTBsGetRequest\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12,\n\x07\x45xtreme\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobIDH\x00\x42\x07\n\x05Query\"f\n\x0eTBsGetResponse\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06\x42uffer\x18\x02 \x01(\x0c\x12\x18\n\x10\x45rrorDescription\x18\x03 \x01(\t\",\n\rTJsonSettings\x12\x1b\n\x0cUI64AsString\x18\x01 \x01(\x08:\x05\x66\x61lse\"`\n\x05TJSON\x12\x0c\n\x04JSON\x18\x01 \x01(\t\x12\x15\n\rSecurityToken\x18\x02 \x01(\t\x12\x32\n\x0cJsonSettings\x18\x03 \x01(\x0b\x32\x1c.NKikimrClient.TJsonSettings\"a\n\x13TChooseProxyRequest\x12\x15\n\rDataCenterNum\x18\x01 \x01(\r\x12\x12\n\nDataCenter\x18\x03 \x01(\t\x12\x1f\n\x10PreferLocalProxy\x18\x02 \x01(\x08:\x05\x66\x61lse\"6\n\x07TWhoAmI\x12\x14\n\x0cReturnGroups\x18\x01 \x01(\x08\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\"w\n\x19TBlobStorageConfigRequest\x12\x0e\n\x06\x44omain\x18\x01 \x01(\r\x12\x33\n\x07Request\x18\x02 \x01(\x0b\x32\".NKikimrBlobStorage.TConfigRequest\x12\x15\n\rSecurityToken\x18\x03 \x01(\t\":\n\x11TDrainNodeRequest\x12\x0e\n\x06NodeID\x18\x01 \x01(\r\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\"9\n\x10TFillNodeRequest\x12\x0e\n\x06NodeID\x18\x01 \x01(\r\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\"M\n\x13TResolveNodeRequest\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x18\n\x10ResolveLocalNode\x18\x03 \x01(\x08\"\xc9\x01\n\x18TNodeRegistrationRequest\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x13\n\x0bResolveHost\x18\x03 \x01(\t\x12\x0f\n\x07\x41\x64\x64ress\x18\x04 \x01(\t\x12\x34\n\x08Location\x18\x05 \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\x12\x12\n\nDomainPath\x18\x06 \x01(\t\x12\x13\n\x0b\x46ixedNodeId\x18\x07 \x01(\x08\x12\x0c\n\x04Path\x18\x08 \x01(\t\"\xd4\x01\n\x19TNodeRegistrationResponse\x12*\n\x06Status\x18\x01 \x01(\x0b\x32\x1a.NKikimrNodeBroker.TStatus\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x12\n\nDomainPath\x18\x03 \x01(\t\x12\x0e\n\x06\x45xpire\x18\x04 \x01(\x04\x12+\n\x05Nodes\x18\x05 \x03(\x0b\x32\x1c.NKikimrNodeBroker.TNodeInfo\x12\x15\n\rScopeTabletId\x18\x06 \x01(\x04\x12\x13\n\x0bScopePathId\x18\x07 \x01(\x04\"\x80\x07\n\x0bTCmsRequest\x12?\n\x13\x43lusterStateRequest\x18\x01 \x01(\x0b\x32 .NKikimrCms.TClusterStateRequestH\x00\x12;\n\x11PermissionRequest\x18\x02 \x01(\x0b\x32\x1e.NKikimrCms.TPermissionRequestH\x00\x12\x41\n\x14ManageRequestRequest\x18\x03 \x01(\x0b\x32!.NKikimrCms.TManageRequestRequestH\x00\x12\x31\n\x0c\x43heckRequest\x18\x04 \x01(\x0b\x32\x19.NKikimrCms.TCheckRequestH\x00\x12G\n\x17ManagePermissionRequest\x18\x05 \x01(\x0b\x32$.NKikimrCms.TManagePermissionRequestH\x00\x12Q\n\x1c\x43onditionalPermissionRequest\x18\x06 \x01(\x0b\x32).NKikimrCms.TConditionalPermissionRequestH\x00\x12\x31\n\x0cNotification\x18\x07 \x01(\x0b\x32\x19.NKikimrCms.TNotificationH\x00\x12K\n\x19ManageNotificationRequest\x18\x08 \x01(\x0b\x32&.NKikimrCms.TManageNotificationRequestH\x00\x12\x39\n\x10GetConfigRequest\x18\t \x01(\x0b\x32\x1d.NKikimrCms.TGetConfigRequestH\x00\x12\x39\n\x10SetConfigRequest\x18\n \x01(\x0b\x32\x1d.NKikimrCms.TSetConfigRequestH\x00\x12\x39\n\x10SetMarkerRequest\x18\x0b \x01(\x0b\x32\x1d.NKikimrCms.TSetMarkerRequestH\x00\x12=\n\x12ResetMarkerRequest\x18\x0c \x01(\x0b\x32\x1f.NKikimrCms.TResetMarkerRequestH\x00\x12;\n\x11GetLogTailRequest\x18\r \x01(\x0b\x32\x1e.NKikimrCms.TGetLogTailRequestH\x00\x12\x12\n\nDomainName\x18\x64 \x01(\t\x12\x15\n\rSecurityToken\x18\x65 \x01(\tB\t\n\x07Request\"\x9a\x06\n\x0cTCmsResponse\x12\x41\n\x14\x43lusterStateResponse\x18\x01 \x01(\x0b\x32!.NKikimrCms.TClusterStateResponseH\x00\x12=\n\x12PermissionResponse\x18\x02 \x01(\x0b\x32\x1f.NKikimrCms.TPermissionResponseH\x00\x12\x43\n\x15ManageRequestResponse\x18\x03 \x01(\x0b\x32\".NKikimrCms.TManageRequestResponseH\x00\x12I\n\x18ManagePermissionResponse\x18\x04 \x01(\x0b\x32%.NKikimrCms.TManagePermissionResponseH\x00\x12\x41\n\x14NotificationResponse\x18\x05 \x01(\x0b\x32!.NKikimrCms.TNotificationResponseH\x00\x12M\n\x1aManageNotificationResponse\x18\x06 \x01(\x0b\x32\'.NKikimrCms.TManageNotificationResponseH\x00\x12;\n\x11GetConfigResponse\x18\x07 \x01(\x0b\x32\x1e.NKikimrCms.TGetConfigResponseH\x00\x12;\n\x11SetConfigResponse\x18\x08 \x01(\x0b\x32\x1e.NKikimrCms.TSetConfigResponseH\x00\x12;\n\x11SetMarkerResponse\x18\t \x01(\x0b\x32\x1e.NKikimrCms.TSetMarkerResponseH\x00\x12?\n\x13ResetMarkerResponse\x18\n \x01(\x0b\x32 .NKikimrCms.TResetMarkerResponseH\x00\x12=\n\x12GetLogTailResponse\x18\x0b \x01(\x0b\x32\x1f.NKikimrCms.TGetLogTailResponseH\x00\x12#\n\x06Status\x18\x64 \x01(\x0b\x32\x13.NKikimrCms.TStatusB\n\n\x08Response\"\x83\r\n\x0bTSqsRequest\x12P\n\x17\x43hangeMessageVisibility\x18\x01 \x01(\x0b\x32-.NKikimr.NSQS.TChangeMessageVisibilityRequestH\x00\x12\x38\n\x0b\x43reateQueue\x18\x02 \x01(\x0b\x32!.NKikimr.NSQS.TCreateQueueRequestH\x00\x12\x46\n\x12GetQueueAttributes\x18\x03 \x01(\x0b\x32(.NKikimr.NSQS.TGetQueueAttributesRequestH\x00\x12<\n\rDeleteMessage\x18\x04 \x01(\x0b\x32#.NKikimr.NSQS.TDeleteMessageRequestH\x00\x12\x38\n\x0b\x44\x65leteQueue\x18\x05 \x01(\x0b\x32!.NKikimr.NSQS.TDeleteQueueRequestH\x00\x12\x36\n\nListQueues\x18\x06 \x01(\x0b\x32 .NKikimr.NSQS.TListQueuesRequestH\x00\x12\x36\n\nPurgeQueue\x18\x07 \x01(\x0b\x32 .NKikimr.NSQS.TPurgeQueueRequestH\x00\x12>\n\x0eReceiveMessage\x18\x08 \x01(\x0b\x32$.NKikimr.NSQS.TReceiveMessageRequestH\x00\x12\x38\n\x0bSendMessage\x18\t \x01(\x0b\x32!.NKikimr.NSQS.TSendMessageRequestH\x00\x12\x46\n\x12SetQueueAttributes\x18\n \x01(\x0b\x32(.NKikimr.NSQS.TSetQueueAttributesRequestH\x00\x12\x38\n\x0bGetQueueUrl\x18\x0b \x01(\x0b\x32!.NKikimr.NSQS.TGetQueueUrlRequestH\x00\x12Z\n\x1c\x43hangeMessageVisibilityBatch\x18\x0c \x01(\x0b\x32\x32.NKikimr.NSQS.TChangeMessageVisibilityBatchRequestH\x00\x12\x46\n\x12\x44\x65leteMessageBatch\x18\r \x01(\x0b\x32(.NKikimr.NSQS.TDeleteMessageBatchRequestH\x00\x12\x42\n\x10SendMessageBatch\x18\x0e \x01(\x0b\x32&.NKikimr.NSQS.TSendMessageBatchRequestH\x00\x12\x36\n\nCreateUser\x18\x0f \x01(\x0b\x32 .NKikimr.NSQS.TCreateUserRequestH\x00\x12\x36\n\nDeleteUser\x18\x10 \x01(\x0b\x32 .NKikimr.NSQS.TDeleteUserRequestH\x00\x12\x34\n\tListUsers\x18\x11 \x01(\x0b\x32\x1f.NKikimr.NSQS.TListUsersRequestH\x00\x12\x44\n\x11ModifyPermissions\x18\x12 \x01(\x0b\x32\'.NKikimr.NSQS.TModifyPermissionsRequestH\x00\x12@\n\x0fListPermissions\x18\x13 \x01(\x0b\x32%.NKikimr.NSQS.TListPermissionsRequestH\x00\x12\x42\n\x10\x44\x65leteQueueBatch\x18\x14 \x01(\x0b\x32&.NKikimr.NSQS.TDeleteQueueBatchRequestH\x00\x12@\n\x0fPurgeQueueBatch\x18\x15 \x01(\x0b\x32%.NKikimr.NSQS.TPurgeQueueBatchRequestH\x00\x12P\n\x17GetQueueAttributesBatch\x18\x16 \x01(\x0b\x32-.NKikimr.NSQS.TGetQueueAttributesBatchRequestH\x00\x12V\n\x1aListDeadLetterSourceQueues\x18\x17 \x01(\x0b\x32\x30.NKikimr.NSQS.TListDeadLetterSourceQueuesRequestH\x00\x12\x38\n\x0b\x43ountQueues\x18\x18 \x01(\x0b\x32!.NKikimr.NSQS.TCountQueuesRequestH\x00\x12\x11\n\tRequestId\x18\x1e \x01(\t\x12\x1e\n\x10RequestRateLimit\x18\x1f \x01(\x08:\x04trueB\t\n\x07Request\"\xb3\r\n\x0cTSqsResponse\x12Q\n\x17\x43hangeMessageVisibility\x18\x01 \x01(\x0b\x32..NKikimr.NSQS.TChangeMessageVisibilityResponseH\x00\x12\x39\n\x0b\x43reateQueue\x18\x02 \x01(\x0b\x32\".NKikimr.NSQS.TCreateQueueResponseH\x00\x12G\n\x12GetQueueAttributes\x18\x03 \x01(\x0b\x32).NKikimr.NSQS.TGetQueueAttributesResponseH\x00\x12=\n\rDeleteMessage\x18\x04 \x01(\x0b\x32$.NKikimr.NSQS.TDeleteMessageResponseH\x00\x12\x39\n\x0b\x44\x65leteQueue\x18\x05 \x01(\x0b\x32\".NKikimr.NSQS.TDeleteQueueResponseH\x00\x12\x37\n\nListQueues\x18\x06 \x01(\x0b\x32!.NKikimr.NSQS.TListQueuesResponseH\x00\x12\x37\n\nPurgeQueue\x18\x07 \x01(\x0b\x32!.NKikimr.NSQS.TPurgeQueueResponseH\x00\x12?\n\x0eReceiveMessage\x18\x08 \x01(\x0b\x32%.NKikimr.NSQS.TReceiveMessageResponseH\x00\x12\x39\n\x0bSendMessage\x18\t \x01(\x0b\x32\".NKikimr.NSQS.TSendMessageResponseH\x00\x12G\n\x12SetQueueAttributes\x18\n \x01(\x0b\x32).NKikimr.NSQS.TSetQueueAttributesResponseH\x00\x12\x39\n\x0bGetQueueUrl\x18\x0b \x01(\x0b\x32\".NKikimr.NSQS.TGetQueueUrlResponseH\x00\x12[\n\x1c\x43hangeMessageVisibilityBatch\x18\x0c \x01(\x0b\x32\x33.NKikimr.NSQS.TChangeMessageVisibilityBatchResponseH\x00\x12G\n\x12\x44\x65leteMessageBatch\x18\r \x01(\x0b\x32).NKikimr.NSQS.TDeleteMessageBatchResponseH\x00\x12\x43\n\x10SendMessageBatch\x18\x0e \x01(\x0b\x32\'.NKikimr.NSQS.TSendMessageBatchResponseH\x00\x12\x37\n\nCreateUser\x18\x0f \x01(\x0b\x32!.NKikimr.NSQS.TCreateUserResponseH\x00\x12\x37\n\nDeleteUser\x18\x10 \x01(\x0b\x32!.NKikimr.NSQS.TDeleteUserResponseH\x00\x12\x35\n\tListUsers\x18\x11 \x01(\x0b\x32 .NKikimr.NSQS.TListUsersResponseH\x00\x12\x45\n\x11ModifyPermissions\x18\x12 \x01(\x0b\x32(.NKikimr.NSQS.TModifyPermissionsResponseH\x00\x12\x41\n\x0fListPermissions\x18\x13 \x01(\x0b\x32&.NKikimr.NSQS.TListPermissionsResponseH\x00\x12\x43\n\x10\x44\x65leteQueueBatch\x18\x14 \x01(\x0b\x32\'.NKikimr.NSQS.TDeleteQueueBatchResponseH\x00\x12\x41\n\x0fPurgeQueueBatch\x18\x15 \x01(\x0b\x32&.NKikimr.NSQS.TPurgeQueueBatchResponseH\x00\x12Q\n\x17GetQueueAttributesBatch\x18\x16 \x01(\x0b\x32..NKikimr.NSQS.TGetQueueAttributesBatchResponseH\x00\x12W\n\x1aListDeadLetterSourceQueues\x18\x17 \x01(\x0b\x32\x31.NKikimr.NSQS.TListDeadLetterSourceQueuesResponseH\x00\x12\x39\n\x0b\x43ountQueues\x18\x18 \x01(\x0b\x32\".NKikimr.NSQS.TCountQueuesResponseH\x00\x12\x11\n\tRequestId\x18\x1e \x01(\t\x12\x10\n\x08\x46olderId\x18\x1f \x01(\t\x12\x12\n\nResourceId\x18  \x01(\t\x12\x0e\n\x06IsFifo\x18! \x01(\x08\x42\n\n\x08Response\"\xd8\x03\n\x12TInterconnectDebug\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43hannel\x18\x02 \x01(\r\x12\x0c\n\x04Hops\x18\x03 \x03(\r\x12\x0f\n\x07SizeMin\x18\x04 \x01(\r\x12\x0f\n\x07SizeMax\x18\x05 \x01(\r\x12\x10\n\x08InFlyMax\x18\x06 \x01(\r\x12\x13\n\x0bIntervalMin\x18\x07 \x01(\x04\x12\x13\n\x0bIntervalMax\x18\x08 \x01(\x04\x12\x10\n\x08SoftLoad\x18\t \x01(\x08\x12\x10\n\x08\x44uration\x18\n \x01(\x04\x12\x1e\n\x16UseProtobufWithPayload\x18\x0b \x01(\x08\x12\x13\n\x0bServicePool\x18\x0c \x01(\t\x12\x1d\n\x15\x43losePeerSocketNodeId\x18\x64 \x01(\r\x12\x1f\n\x17\x43loseInputSessionNodeId\x18\x65 \x01(\r\x12\x1b\n\x13PoisonSessionNodeId\x18\x66 \x01(\r\x12\x1a\n\x11NumSlowpokeActors\x18\xc8\x01 \x01(\r\x12\x0f\n\x06PoolId\x18\xc9\x01 \x01(\r\x12\x11\n\x08SleepMin\x18\xca\x01 \x01(\x04\x12\x11\n\x08SleepMax\x18\xcb\x01 \x01(\x04\x12\x16\n\rRescheduleMin\x18\xcc\x01 \x01(\x04\x12\x16\n\rRescheduleMax\x18\xcd\x01 \x01(\x04\"\xcc\t\n\x0fTConsoleRequest\x12\x43\n\x13\x43reateTenantRequest\x18\x01 \x01(\x0b\x32$.NKikimrConsole.TCreateTenantRequestH\x00\x12I\n\x16GetTenantStatusRequest\x18\x02 \x01(\x0b\x32\'.NKikimrConsole.TGetTenantStatusRequestH\x00\x12\x41\n\x12\x41lterTenantRequest\x18\x03 \x01(\x0b\x32#.NKikimrConsole.TAlterTenantRequestH\x00\x12\x41\n\x12ListTenantsRequest\x18\x04 \x01(\x0b\x32#.NKikimrConsole.TListTenantsRequestH\x00\x12=\n\x10GetConfigRequest\x18\x05 \x01(\x0b\x32!.NKikimrConsole.TGetConfigRequestH\x00\x12=\n\x10SetConfigRequest\x18\x06 \x01(\x0b\x32!.NKikimrConsole.TSetConfigRequestH\x00\x12=\n\x10\x43onfigureRequest\x18\x07 \x01(\x0b\x32!.NKikimrConsole.TConfigureRequestH\x00\x12G\n\x15GetConfigItemsRequest\x18\x08 \x01(\x0b\x32&.NKikimrConsole.TGetConfigItemsRequestH\x00\x12O\n\x19GetNodeConfigItemsRequest\x18\t \x01(\x0b\x32*.NKikimrConsole.TGetNodeConfigItemsRequestH\x00\x12\x45\n\x14GetNodeConfigRequest\x18\n \x01(\x0b\x32%.NKikimrConsole.TGetNodeConfigRequestH\x00\x12\x43\n\x13RemoveTenantRequest\x18\x0b \x01(\x0b\x32$.NKikimrConsole.TRemoveTenantRequestH\x00\x12\x42\n\x13GetOperationRequest\x18\x0c \x01(\x0b\x32#.Ydb.Operations.GetOperationRequestH\x00\x12O\n\x19\x43heckConfigUpdatesRequest\x18\r \x01(\x0b\x32*.NKikimrConsole.TCheckConfigUpdatesRequestH\x00\x12S\n\x1bListConfigValidatorsRequest\x18\x0e \x01(\x0b\x32,.NKikimrConsole.TListConfigValidatorsRequestH\x00\x12U\n\x1cToggleConfigValidatorRequest\x18\x0f \x01(\x0b\x32-.NKikimrConsole.TToggleConfigValidatorRequestH\x00\x12I\n\x16UpdateTenantPoolConfig\x18\x10 \x01(\x0b\x32\'.NKikimrConsole.TUpdateTenantPoolConfigH\x00\x12\x12\n\nDomainName\x18\x64 \x01(\t\x12\x15\n\rSecurityToken\x18\x65 \x01(\tB\t\n\x07Request\"\x9f\t\n\x10TConsoleResponse\x12\x45\n\x14\x43reateTenantResponse\x18\x01 \x01(\x0b\x32%.NKikimrConsole.TCreateTenantResponseH\x00\x12K\n\x17GetTenantStatusResponse\x18\x02 \x01(\x0b\x32(.NKikimrConsole.TGetTenantStatusResponseH\x00\x12\x43\n\x13\x41lterTenantResponse\x18\x03 \x01(\x0b\x32$.NKikimrConsole.TAlterTenantResponseH\x00\x12\x43\n\x13ListTenantsResponse\x18\x04 \x01(\x0b\x32$.NKikimrConsole.TListTenantsResponseH\x00\x12?\n\x11GetConfigResponse\x18\x05 \x01(\x0b\x32\".NKikimrConsole.TGetConfigResponseH\x00\x12?\n\x11SetConfigResponse\x18\x06 \x01(\x0b\x32\".NKikimrConsole.TSetConfigResponseH\x00\x12?\n\x11\x43onfigureResponse\x18\x07 \x01(\x0b\x32\".NKikimrConsole.TConfigureResponseH\x00\x12I\n\x16GetConfigItemsResponse\x18\x08 \x01(\x0b\x32\'.NKikimrConsole.TGetConfigItemsResponseH\x00\x12Q\n\x1aGetNodeConfigItemsResponse\x18\t \x01(\x0b\x32+.NKikimrConsole.TGetNodeConfigItemsResponseH\x00\x12G\n\x15GetNodeConfigResponse\x18\n \x01(\x0b\x32&.NKikimrConsole.TGetNodeConfigResponseH\x00\x12\x45\n\x14RemoveTenantResponse\x18\x0b \x01(\x0b\x32%.NKikimrConsole.TRemoveTenantResponseH\x00\x12\x44\n\x14GetOperationResponse\x18\x0c \x01(\x0b\x32$.Ydb.Operations.GetOperationResponseH\x00\x12Q\n\x1a\x43heckConfigUpdatesResponse\x18\r \x01(\x0b\x32+.NKikimrConsole.TCheckConfigUpdatesResponseH\x00\x12U\n\x1cListConfigValidatorsResponse\x18\x0e \x01(\x0b\x32-.NKikimrConsole.TListConfigValidatorsResponseH\x00\x12W\n\x1dToggleConfigValidatorResponse\x18\x0f \x01(\x0b\x32..NKikimrConsole.TToggleConfigValidatorResponseH\x00\x12\'\n\x06Status\x18\x64 \x01(\x0b\x32\x17.NKikimrConsole.TStatusB\n\n\x08Response\"\xa3\x05\n\x18TTestShardControlRequest\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12L\n\nInitialize\x18\x02 \x01(\x0b\x32\x36.NKikimrClient.TTestShardControlRequest.TCmdInitializeH\x00\x1aI\n\rTSizeInterval\x12\x0e\n\x06Weight\x18\x01 \x01(\x04\x12\x0b\n\x03Min\x18\x02 \x01(\r\x12\x0b\n\x03Max\x18\x03 \x01(\r\x12\x0e\n\x06Inline\x18\x04 \x01(\x08\x1aI\n\rTTimeInterval\x12\x0e\n\x06Weight\x18\x01 \x01(\x04\x12\x11\n\tFrequency\x18\x02 \x01(\x01\x12\x15\n\rMaxIntervalMs\x18\x03 \x01(\r\x1a\x85\x03\n\x0eTCmdInitialize\x12\x19\n\x11StorageServerHost\x18\x01 \x01(\t\x12\x19\n\x11StorageServerPort\x18\x02 \x01(\x05\x12\x14\n\x0cMaxDataBytes\x18\x03 \x01(\x04\x12\x14\n\x0cMinDataBytes\x18\x04 \x01(\x04\x12\x13\n\x0bMaxInFlight\x18\x05 \x01(\r\x12\x1a\n\x12ValidateAfterBytes\x18\t \x01(\x04\x12\x44\n\x05Sizes\x18\x06 \x03(\x0b\x32\x35.NKikimrClient.TTestShardControlRequest.TSizeInterval\x12K\n\x0cWritePeriods\x18\x07 \x03(\x0b\x32\x35.NKikimrClient.TTestShardControlRequest.TTimeInterval\x12M\n\x0eRestartPeriods\x18\x08 \x03(\x0b\x32\x35.NKikimrClient.TTestShardControlRequest.TTimeIntervalB\t\n\x07\x43ommand\"\x1b\n\x19TTestShardControlResponse\"A\n\rTLoginRequest\x12\x10\n\x08\x44\x61tabase\x18\x01 \x01(\t\x12\x0c\n\x04User\x18\x02 \x01(\t\x12\x10\n\x08Password\x18\x03 \x01(\t:U\n\rEnumValueHint\x12\x1d.google.protobuf.FieldOptions\x18\xf1\xa2\x04 \x01(\x0b\x32\x1d.NKikimrClient.TEnumValueHint::\n\x11\x43ommonDescription\x12\x1d.google.protobuf.FieldOptions\x18\xf2\xa2\x04 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.msgbus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(EnumValueHint)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(CommonDescription)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TRESPONSE.fields_by_name['Status']._options = None
  _TRESPONSE.fields_by_name['Status']._serialized_options = b'\222\227\"\025Generic msgbus status\212\227\"\312\004\n5\010\000\022\017MSTATUS_UNKNOWN\032 Status unknown, must not be seen\n2\010\001\022\nMSTATUS_OK\032\"Request complete with full success\n?\010\200\001\022\rMSTATUS_ERROR\032+Request failed because of client-side error\n9\010\201\001\022\022MSTATUS_INPROGRESS\032 Request accepted and in progress\nI\010\202\001\022\017MSTATUS_TIMEOUT\0323Request failed due to timeout, exact status unknown\nC\010\203\001\022\020MSTATUS_NOTREADY\032,Not yet ready to process requests, try later\nL\010\204\001\022\017MSTATUS_ABORTED\0326Request aborted, particular meaning depends on context\nG\010\205\001\022\025MSTATUS_INTERNALERROR\032+Something unexpected happend on server-side\n:\010\206\001\022\020MSTATUS_REJECTED\032#Request rejected for now, try later'
  _TRESPONSE.fields_by_name['ProxyErrorCode']._options = None
  _TRESPONSE.fields_by_name['ProxyErrorCode']._serialized_options = b'\222\227\"#Transaction proxy processing status\212\227\"\217\020\n-\010\000\022\007Unknown\032 Status unknown, must not be seen\nh\010\001\022\014WrongRequest\032VNot recognized or erroneous request, see error description fields for possible details\nL\010\002\022\020EmptyAffectedSet\0326Program must touch at least one shard but touches none\n9\010\003\022\016NotImplemented\032%Not yet implemented feature requested\nH\010\004\022\014ResolveError\0326Some keys not resolved, see UnresolvedKeys for details\n+\010\005\022\014AccessDenied\032\031Access denied for request\n@\010\006\022\023DomainLocalityError\032\'Cross database transactions not allowed\n|\010\020\022\rProxyNotReady\032iTransaction proxy not ready for handling requests, try later. Most known case is temporary lack of txid-s\nA\010\021\022\rProxyAccepted\032.Request accepted by proxy. Transitional status\nK\010\022\022\rProxyResolved\0328Request keys resolved to datashards. Transitional status\nO\010\023\022\rProxyPrepared\032<Request fragmets prepared on datashards. Transitional status\ni\010\024\022\026ProxyShardNotAvailable\032MOne or more of affected datashards not available, request execution cancelled\nR\010\025\022\022ProxyShardTryLater\032:One or more of affected datashards are starting, try again\nV\010\026\022\024ProxyShardOverloaded\032<One or more of affected datashards are overloaded, try again\nP\010\027\022\021ProxyShardUnknown\0329State of transaction on one or more datashards is unknown\nL\010 \022\023CoordinatorDeclined\0323Coordinator declines to plan transaction, try again\nk\010!\022\023CoordinatorOutdated\032RCoordinator was not able to plan transaction due to timing restrictions, try again\n:\010\"\022\022CoordinatorAborted\032\"Transaction aborted by coordinator\n]\010#\022\022CoordinatorPlanned\032ETransaction planned for execution by coordinator. Transitional status\n\177\010$\022\022CoordinatorUnknown\032gCould not reach coordinator or coordinator pipe dropped before confirmation. Transaction status unknown\n\031\0100\022\014ExecComplete\032\007Success\n4\0101\022\013ExecAlready\032#Requested operation already applied\nG\0102\022\013ExecAborted\0326Request aborted, particular meaning depends on context\n?\0103\022\013ExecTimeout\032.Proxy got no execution reply in timeout period\n\037\0104\022\tExecError\032\020Execution failed\n1\0105\022\016ExecInProgress\032\035Request accepted and now runs\n8\0107\022\025ExecResultUnavailable\032\035Execution results unavailable\n*\0108\022\rExecCancelled\032\027Execution was cancelled'
  _TRESPONSE.fields_by_name['ExecutionEngineStatus']._options = None
  _TRESPONSE.fields_by_name['ExecutionEngineStatus']._serialized_options = b'\222\227\"KMiniKQL engine processing status, if OK - see ExecutionEngineResponseStatus\212\227\"\360\003\n0\010\000\022\007Unknown\032#Status unknown, not filled probably\n\017\010\001\022\002Ok\032\007Success\nU\010\002\022\rSchemeChanged\032BScheme or partitioning was changed b/w compilation and preparation\n7\010\003\022\nIsReadonly\032\'Update requested in read-only operation\n*\010\004\022\010KeyError\032\034Something wrong in data keys\n#\010\005\022\014ProgramError\032\021Malformed program\n7\010\006\022\rTooManyShards\032$Too much datashards affected program\n2\010\007\022\013TooManyData\032!Too much data affected by program\n2\010\010\022\020SnapshotNotExist\032\034Requested snapshot not exist\n)\010\t\022\020SnapshotNotReady\032\023Snapshot not online'
  _TRESPONSE.fields_by_name['ExecutionEngineResponseStatus']._options = None
  _TRESPONSE.fields_by_name['ExecutionEngineResponseStatus']._serialized_options = b'\222\227\"\037MiniKQL engine execution status\212\227\"\211\001\n0\010\000\022\007Unknown\032#Status unknown, not filled probably\n\020\010\001\022\005Error\032\005Error\n#\010\002\022\010Complete\032\025Complete with success\n\036\010\003\022\005Abort\032\023Complete with abort'
  _TFLATDESCRIBERESPONSE._options = None
  _TFLATDESCRIBERESPONSE._serialized_options = b'\030\001'
  _TENUMVALUEHINT._serialized_start=1153
  _TENUMVALUEHINT._serialized_end=1274
  _TENUMVALUEHINT_TENTRY._serialized_start=1224
  _TENUMVALUEHINT_TENTRY._serialized_end=1274
  _TMSGBUSREQUESTBASE._serialized_start=1276
  _TMSGBUSREQUESTBASE._serialized_end=1321
  _TREQUEST._serialized_start=1324
  _TREQUEST._serialized_end=1459
  _TFLATTXID._serialized_start=1461
  _TFLATTXID._serialized_end=1531
  _TRESOLVENODERESPONSE._serialized_start=1533
  _TRESOLVENODERESPONSE._serialized_end=1585
  _TRESPONSE._serialized_start=1588
  _TRESPONSE._serialized_end=8007
  _TRESPONSE_TCREATETABLETRESULT._serialized_start=7803
  _TRESPONSE_TCREATETABLETRESULT._serialized_end=7858
  _TRESPONSE_TLOOKUPTABLETRESULT._serialized_start=7860
  _TRESPONSE_TLOOKUPTABLETRESULT._serialized_end=7915
  _TRESPONSE_TTABLETINFO._serialized_start=7917
  _TRESPONSE_TTABLETINFO._serialized_end=8007
  _TFAKECONFIGDUMMY._serialized_start=8009
  _TFAKECONFIGDUMMY._serialized_end=8048
  _TTABLETCOUNTERSREQUEST._serialized_start=8050
  _TTABLETCOUNTERSREQUEST._serialized_end=8155
  _TLOCALMKQL._serialized_start=8158
  _TLOCALMKQL._serialized_end=8409
  _TLOCALMKQL_TPROGRAM._serialized_start=8334
  _TLOCALMKQL_TPROGRAM._serialized_end=8371
  _TLOCALMKQL_TPARAMS._serialized_start=8373
  _TLOCALMKQL_TPARAMS._serialized_end=8409
  _TLOCALSCHEMETX._serialized_start=8412
  _TLOCALSCHEMETX._serialized_end=8606
  _TSCHEMENAVIGATE._serialized_start=8608
  _TSCHEMENAVIGATE._serialized_end=8714
  _TSCHEMEINITROOT._serialized_start=8717
  _TSCHEMEINITROOT._serialized_end=8910
  _TBSADM._serialized_start=8913
  _TBSADM._serialized_end=9184
  _TBSADM_TVDISKLOCATION._serialized_start=9037
  _TBSADM_TVDISKLOCATION._serialized_end=9103
  _TBSADM_TGROUPRECONFIGUREWIPE._serialized_start=9105
  _TBSADM_TGROUPRECONFIGUREWIPE._serialized_end=9184
  _THIVECREATETABLET._serialized_start=9187
  _THIVECREATETABLET._serialized_end=9709
  _THIVECREATETABLET_TCMDCREATETABLET._serialized_start=9380
  _THIVECREATETABLET_TCMDCREATETABLET._serialized_end=9654
  _THIVECREATETABLET_TCMDLOOKUPTABLET._serialized_start=9656
  _THIVECREATETABLET_TCMDLOOKUPTABLET._serialized_end=9709
  _THIVECREATETABLETRESULT._serialized_start=9712
  _THIVECREATETABLETRESULT._serialized_end=10088
  _THIVECREATETABLETRESULT_TCREATETABLETRESULT._serialized_start=7803
  _THIVECREATETABLETRESULT_TCREATETABLETRESULT._serialized_end=7858
  _THIVECREATETABLETRESULT_TLOOKUPTABLETRESULT._serialized_start=7860
  _THIVECREATETABLETRESULT_TLOOKUPTABLETRESULT._serialized_end=7915
  _TLOCALENUMERATETABLETS._serialized_start=10090
  _TLOCALENUMERATETABLETS._serialized_end=10208
  _TLOCALENUMERATETABLETSRESULT._serialized_start=10211
  _TLOCALENUMERATETABLETSRESULT._serialized_end=10471
  _TLOCALENUMERATETABLETSRESULT_TTABLETINFO._serialized_start=7917
  _TLOCALENUMERATETABLETSRESULT_TTABLETINFO._serialized_end=8007
  _TTYPEMETADATAREQUEST._serialized_start=10473
  _TTYPEMETADATAREQUEST._serialized_end=10509
  _TTYPEMETADATARESPONSE._serialized_start=10511
  _TTYPEMETADATARESPONSE._serialized_end=10636
  _TMESSAGEBUSTRACEREQUEST._serialized_start=10639
  _TMESSAGEBUSTRACEREQUEST._serialized_end=10777
  _TMESSAGEBUSTRACEREQUEST_ECOMMAND._serialized_start=10746
  _TMESSAGEBUSTRACEREQUEST_ECOMMAND._serialized_end=10777
  _TMESSAGEBUSTRACESTATUS._serialized_start=10779
  _TMESSAGEBUSTRACESTATUS._serialized_end=10838
  _TTABLETKILLREQUEST._serialized_start=10840
  _TTABLETKILLREQUEST._serialized_end=10878
  _TTABLETSTATEREQUEST._serialized_start=10880
  _TTABLETSTATEREQUEST._serialized_end=10994
  _TFLATTXPOLLOPTIONS._serialized_start=10996
  _TFLATTXPOLLOPTIONS._serialized_end=11039
  _TSCHEMEOPERATION._serialized_start=11042
  _TSCHEMEOPERATION._serialized_end=11194
  _TSCHEMEDESCRIBE._serialized_start=11197
  _TSCHEMEDESCRIBE._serialized_end=11342
  _TFLATDESCRIBERESPONSE._serialized_start=11345
  _TFLATDESCRIBERESPONSE._serialized_end=11605
  _TSCHEMEOPERATIONSTATUS._serialized_start=11607
  _TSCHEMEOPERATIONSTATUS._serialized_end=11731
  _TDSTESTLOADREQUEST._serialized_start=11733
  _TDSTESTLOADREQUEST._serialized_end=11830
  _TDSTESTLOADRESPONSE._serialized_start=11833
  _TDSTESTLOADRESPONSE._serialized_end=11973
  _TDSTESTLOADRESPONSE_TITEM._serialized_start=11913
  _TDSTESTLOADRESPONSE_TITEM._serialized_end=11973
  _TBSTESTLOADREQUEST._serialized_start=11975
  _TBSTESTLOADREQUEST._serialized_end=12055
  _TBSTESTLOADRESPONSE._serialized_start=12058
  _TBSTESTLOADRESPONSE._serialized_end=12198
  _TBSTESTLOADRESPONSE_TITEM._serialized_start=11913
  _TBSTESTLOADRESPONSE_TITEM._serialized_end=11973
  _TBSGETREQUEST._serialized_start=12200
  _TBSGETREQUEST._serialized_end=12287
  _TBSGETRESPONSE._serialized_start=12289
  _TBSGETRESPONSE._serialized_end=12391
  _TJSONSETTINGS._serialized_start=12393
  _TJSONSETTINGS._serialized_end=12437
  _TJSON._serialized_start=12439
  _TJSON._serialized_end=12535
  _TCHOOSEPROXYREQUEST._serialized_start=12537
  _TCHOOSEPROXYREQUEST._serialized_end=12634
  _TWHOAMI._serialized_start=12636
  _TWHOAMI._serialized_end=12690
  _TBLOBSTORAGECONFIGREQUEST._serialized_start=12692
  _TBLOBSTORAGECONFIGREQUEST._serialized_end=12811
  _TDRAINNODEREQUEST._serialized_start=12813
  _TDRAINNODEREQUEST._serialized_end=12871
  _TFILLNODEREQUEST._serialized_start=12873
  _TFILLNODEREQUEST._serialized_end=12930
  _TRESOLVENODEREQUEST._serialized_start=12932
  _TRESOLVENODEREQUEST._serialized_end=13009
  _TNODEREGISTRATIONREQUEST._serialized_start=13012
  _TNODEREGISTRATIONREQUEST._serialized_end=13213
  _TNODEREGISTRATIONRESPONSE._serialized_start=13216
  _TNODEREGISTRATIONRESPONSE._serialized_end=13428
  _TCMSREQUEST._serialized_start=13431
  _TCMSREQUEST._serialized_end=14327
  _TCMSRESPONSE._serialized_start=14330
  _TCMSRESPONSE._serialized_end=15124
  _TSQSREQUEST._serialized_start=15127
  _TSQSREQUEST._serialized_end=16794
  _TSQSRESPONSE._serialized_start=16797
  _TSQSRESPONSE._serialized_end=18512
  _TINTERCONNECTDEBUG._serialized_start=18515
  _TINTERCONNECTDEBUG._serialized_end=18987
  _TCONSOLEREQUEST._serialized_start=18990
  _TCONSOLEREQUEST._serialized_end=20218
  _TCONSOLERESPONSE._serialized_start=20221
  _TCONSOLERESPONSE._serialized_end=21404
  _TTESTSHARDCONTROLREQUEST._serialized_start=21407
  _TTESTSHARDCONTROLREQUEST._serialized_end=22082
  _TTESTSHARDCONTROLREQUEST_TSIZEINTERVAL._serialized_start=21531
  _TTESTSHARDCONTROLREQUEST_TSIZEINTERVAL._serialized_end=21604
  _TTESTSHARDCONTROLREQUEST_TTIMEINTERVAL._serialized_start=21606
  _TTESTSHARDCONTROLREQUEST_TTIMEINTERVAL._serialized_end=21679
  _TTESTSHARDCONTROLREQUEST_TCMDINITIALIZE._serialized_start=21682
  _TTESTSHARDCONTROLREQUEST_TCMDINITIALIZE._serialized_end=22071
  _TTESTSHARDCONTROLRESPONSE._serialized_start=22084
  _TTESTSHARDCONTROLRESPONSE._serialized_end=22111
  _TLOGINREQUEST._serialized_start=22113
  _TLOGINREQUEST._serialized_end=22178
# @@protoc_insertion_point(module_scope)
