# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/cms.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blobstorage_config_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__config__pb2
from ydb.core.protos import blobstorage_disk_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__pb2
from library.cpp.actors.protos import interconnect_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_interconnect__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/cms.proto\x12\nNKikimrCms\x1a(ydb/core/protos/blobstorage_config.proto\x1a&ydb/core/protos/blobstorage_disk.proto\x1a,library/cpp/actors/protos/interconnect.proto\"\x9b\x02\n\x07TStatus\x12\'\n\x04\x43ode\x18\x01 \x01(\x0e\x32\x19.NKikimrCms.TStatus.ECode\x12\x0e\n\x06Reason\x18\x02 \x01(\t\"\xd6\x01\n\x05\x45\x43ode\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02OK\x10\x01\x12\t\n\x05\x41LLOW\x10\x02\x12\x11\n\rALLOW_PARTIAL\x10\x03\x12\x0c\n\x08\x44ISALLOW\x10\x04\x12\x11\n\rDISALLOW_TEMP\x10\x05\x12\x11\n\rWRONG_REQUEST\x10\x06\x12\t\n\x05\x45RROR\x10\x07\x12\x0e\n\nERROR_TEMP\x10\x08\x12\x10\n\x0cUNAUTHORIZED\x10\t\x12\x10\n\x0cNO_SUCH_HOST\x10\n\x12\x12\n\x0eNO_SUCH_DEVICE\x10\x0b\x12\x13\n\x0fNO_SUCH_SERVICE\x10\x0c\"d\n\rTServiceState\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12!\n\x05State\x18\x02 \x01(\x0e\x32\x12.NKikimrCms.EState\x12\x0f\n\x07Version\x18\x03 \x01(\t\x12\x11\n\tTimestamp\x18\x04 \x01(\x04\"x\n\x0cTDeviceState\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12!\n\x05State\x18\x02 \x01(\x0e\x32\x12.NKikimrCms.EState\x12\x11\n\tTimestamp\x18\x03 \x01(\x04\x12$\n\x07Markers\x18\x04 \x03(\x0e\x32\x13.NKikimrCms.EMarker\"\xae\x02\n\nTHostState\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12!\n\x05State\x18\x02 \x01(\x0e\x32\x12.NKikimrCms.EState\x12+\n\x08Services\x18\x03 \x03(\x0b\x32\x19.NKikimrCms.TServiceState\x12)\n\x07\x44\x65vices\x18\x04 \x03(\x0b\x32\x18.NKikimrCms.TDeviceState\x12\x11\n\tTimestamp\x18\x05 \x01(\x04\x12\x0e\n\x06NodeId\x18\x06 \x01(\r\x12\x18\n\x10InterconnectPort\x18\x07 \x01(\r\x12$\n\x07Markers\x18\x08 \x03(\x0e\x32\x13.NKikimrCms.EMarker\x12\x34\n\x08Location\x18\t \x01(\x0b\x32\".NActorsInterconnect.TNodeLocation\"W\n\rTClusterState\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12%\n\x05Hosts\x18\x02 \x03(\x0b\x32\x16.NKikimrCms.THostState\x12\x11\n\tTimestamp\x18\x03 \x01(\x04\"%\n\x14TClusterStateRequest\x12\r\n\x05Hosts\x18\x01 \x03(\t\"f\n\x15TClusterStateResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12(\n\x05State\x18\x02 \x01(\x0b\x32\x19.NKikimrCms.TClusterState\"\xcb\x02\n\x07TAction\x12\'\n\x04Type\x18\x01 \x01(\x0e\x32\x19.NKikimrCms.TAction.EType\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x10\n\x08Services\x18\x03 \x03(\t\x12\x0f\n\x07\x44\x65vices\x18\x04 \x03(\t\x12\x10\n\x08\x44uration\x18\x05 \x01(\x04\x12\x0e\n\x06Tenant\x18\x06 \x01(\t\"\xc3\x01\n\x05\x45Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x12\n\x0eSTART_SERVICES\x10\x01\x12\x14\n\x10RESTART_SERVICES\x10\x02\x12\x11\n\rSTOP_SERVICES\x10\x03\x12\x0c\n\x08\x41\x44\x44_HOST\x10\x04\x12\x11\n\rSHUTDOWN_HOST\x10\x05\x12\x15\n\x11\x44\x45\x43OMMISSION_HOST\x10\x06\x12\x0f\n\x0b\x41\x44\x44_DEVICES\x10\x07\x12\x13\n\x0fREPLACE_DEVICES\x10\x08\x12\x12\n\x0eREMOVE_DEVICES\x10\t\"\xbf\x02\n\x12TPermissionRequest\x12\x0c\n\x04User\x18\x01 \x01(\t\x12$\n\x07\x41\x63tions\x18\x02 \x03(\x0b\x32\x13.NKikimrCms.TAction\x12\'\n\x18PartialPermissionAllowed\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x10\n\x08Schedule\x18\x04 \x01(\x08\x12\x0e\n\x06\x44ryRun\x18\x05 \x01(\x08\x12\x0e\n\x06Reason\x18\x06 \x01(\t\x12\x10\n\x08\x44uration\x18\x07 \x01(\x04\x12\x38\n\x0cTenantPolicy\x18\x08 \x01(\x0e\x32\x19.NKikimrCms.ETenantPolicy:\x07\x44\x45\x46\x41ULT\x12N\n\x10\x41vailabilityMode\x18\t \x01(\x0e\x32\x1d.NKikimrCms.EAvailabilityMode:\x15MODE_MAX_AVAILABILITY\"g\n\x14TPermissionExtension\x12(\n\x04Type\x18\x01 \x01(\x0e\x32\x1a.NKikimrCms.EExtensionType\x12%\n\x05Hosts\x18\x02 \x03(\x0b\x32\x16.NKikimrCms.THostState\"\x86\x01\n\x0bTPermission\x12\n\n\x02Id\x18\x01 \x01(\t\x12#\n\x06\x41\x63tion\x18\x02 \x01(\x0b\x32\x13.NKikimrCms.TAction\x12\x10\n\x08\x44\x65\x61\x64line\x18\x03 \x01(\x04\x12\x34\n\nExtentions\x18\x04 \x03(\x0b\x32 .NKikimrCms.TPermissionExtension\"\x8d\x01\n\x13TPermissionResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12,\n\x0bPermissions\x18\x03 \x03(\x0b\x32\x17.NKikimrCms.TPermission\x12\x10\n\x08\x44\x65\x61\x64line\x18\x04 \x01(\x04\"\xbd\x01\n\x15TManageRequestRequest\x12\x0c\n\x04User\x18\x01 \x01(\t\x12;\n\x07\x43ommand\x18\x02 \x01(\x0e\x32*.NKikimrCms.TManageRequestRequest.ECommand\x12\x11\n\tRequestId\x18\x03 \x01(\t\x12\x0e\n\x06\x44ryRun\x18\x04 \x01(\x08\"6\n\x08\x45\x43ommand\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04LIST\x10\x01\x12\x07\n\x03GET\x10\x02\x12\n\n\x06REJECT\x10\x03\"\x95\x02\n\x16TManageRequestResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12\x46\n\x08Requests\x18\x02 \x03(\x0b\x32\x34.NKikimrCms.TManageRequestResponse.TScheduledRequest\x1a\x8d\x01\n\x11TScheduledRequest\x12\x11\n\tRequestId\x18\x01 \x01(\t\x12\r\n\x05Owner\x18\x02 \x01(\t\x12$\n\x07\x41\x63tions\x18\x03 \x03(\x0b\x32\x13.NKikimrCms.TAction\x12 \n\x18PartialPermissionAllowed\x18\x04 \x01(\x08\x12\x0e\n\x06Reason\x18\x05 \x01(\t\"\x90\x01\n\rTCheckRequest\x12\x0c\n\x04User\x18\x01 \x01(\t\x12\x11\n\tRequestId\x18\x02 \x01(\t\x12\x0e\n\x06\x44ryRun\x18\x03 \x01(\x08\x12N\n\x10\x41vailabilityMode\x18\x04 \x01(\x0e\x32\x1d.NKikimrCms.EAvailabilityMode:\x15MODE_MAX_AVAILABILITY\"\xed\x01\n\x18TManagePermissionRequest\x12\x0c\n\x04User\x18\x01 \x01(\t\x12>\n\x07\x43ommand\x18\x02 \x01(\x0e\x32-.NKikimrCms.TManagePermissionRequest.ECommand\x12\x13\n\x0bPermissions\x18\x03 \x03(\t\x12\x10\n\x08\x44\x65\x61\x64line\x18\x04 \x01(\x04\x12\x0e\n\x06\x44ryRun\x18\x05 \x01(\x08\"L\n\x08\x45\x43ommand\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04LIST\x10\x01\x12\x07\n\x03GET\x10\x02\x12\x08\n\x04\x44ONE\x10\x03\x12\n\n\x06\x45XTEND\x10\x04\x12\n\n\x06REJECT\x10\x05\"n\n\x19TManagePermissionResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12,\n\x0bPermissions\x18\x02 \x03(\x0b\x32\x17.NKikimrCms.TPermission\"\x98\x01\n\x0eTVersionFilter\x12.\n\x04Type\x18\x01 \x01(\x0e\x32 .NKikimrCms.TVersionFilter.EType\x12\x0f\n\x07Version\x18\x02 \x01(\t\"E\n\x05\x45Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\t\n\x05MATCH\x10\x01\x12\x0c\n\x08MISMATCH\x10\x02\x12\t\n\x05LOWER\x10\x03\x12\x0b\n\x07GREATER\x10\x04\"w\n\x0bTNameFilter\x12+\n\x04Type\x18\x01 \x01(\x0e\x32\x1d.NKikimrCms.TNameFilter.EType\x12\r\n\x05Names\x18\x02 \x03(\t\",\n\x05\x45Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06ONE_OF\x10\x01\x12\n\n\x06NOT_IN\x10\x02\"p\n\x0eTServiceFilter\x12+\n\nNameFilter\x18\x01 \x01(\x0b\x32\x17.NKikimrCms.TNameFilter\x12\x31\n\rVersionFilter\x18\x02 \x01(\x0b\x32\x1a.NKikimrCms.TVersionFilter\":\n\x0bTHostFilter\x12+\n\nNameFilter\x18\x01 \x01(\x0b\x32\x17.NKikimrCms.TNameFilter\"\x98\x02\n\x1dTConditionalPermissionRequest\x12\x0c\n\x04User\x18\x01 \x01(\t\x12#\n\x06\x41\x63tion\x18\x02 \x01(\x0b\x32\x13.NKikimrCms.TAction\x12\x31\n\rServiceFilter\x18\x03 \x01(\x0b\x32\x1a.NKikimrCms.TServiceFilter\x12+\n\nHostFilter\x18\x04 \x01(\x0b\x32\x17.NKikimrCms.THostFilter\x12 \n\x18PartialPermissionAllowed\x18\x05 \x01(\x08\x12\x10\n\x08Schedule\x18\x06 \x01(\x08\x12\x0e\n\x06\x44ryRun\x18\x07 \x01(\x08\x12\x0e\n\x06Reason\x18\x08 \x01(\t\x12\x10\n\x08\x44uration\x18\t \x01(\x04\"a\n\rTNotification\x12\x0c\n\x04User\x18\x01 \x01(\t\x12$\n\x07\x41\x63tions\x18\x02 \x03(\x0b\x32\x13.NKikimrCms.TAction\x12\x0c\n\x04Time\x18\x03 \x01(\x04\x12\x0e\n\x06Reason\x18\x04 \x01(\t\"T\n\x15TNotificationResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12\x16\n\x0eNotificationId\x18\x02 \x01(\t\"\xcc\x01\n\x1aTManageNotificationRequest\x12\x0c\n\x04User\x18\x01 \x01(\t\x12@\n\x07\x43ommand\x18\x02 \x01(\x0e\x32/.NKikimrCms.TManageNotificationRequest.ECommand\x12\x16\n\x0eNotificationId\x18\x03 \x01(\t\x12\x0e\n\x06\x44ryRun\x18\x04 \x01(\x08\"6\n\x08\x45\x43ommand\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04LIST\x10\x01\x12\x07\n\x03GET\x10\x02\x12\n\n\x06REJECT\x10\x03\"\x99\x02\n\x1bTManageNotificationResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12R\n\rNotifications\x18\x02 \x03(\x0b\x32;.NKikimrCms.TManageNotificationResponse.TStoredNotification\x1a\x80\x01\n\x13TStoredNotification\x12\x16\n\x0eNotificationId\x18\x01 \x01(\t\x12\r\n\x05Owner\x18\x02 \x01(\t\x12$\n\x07\x41\x63tions\x18\x03 \x03(\x0b\x32\x13.NKikimrCms.TAction\x12\x0c\n\x04Time\x18\x04 \x01(\x04\x12\x0e\n\x06Reason\x18\x05 \x01(\t\"v\n\x17TWalleCreateTaskRequest\x12\x0e\n\x06TaskId\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\t\x12\x0e\n\x06Issuer\x18\x03 \x01(\t\x12\x0e\n\x06\x41\x63tion\x18\x04 \x01(\t\x12\r\n\x05Hosts\x18\x05 \x03(\t\x12\x0e\n\x06\x44ryRun\x18\x06 \x01(\x08\"^\n\x18TWalleCreateTaskResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12\x0e\n\x06TaskId\x18\x02 \x01(\t\x12\r\n\x05Hosts\x18\x03 \x03(\t\"\x18\n\x16TWalleListTasksRequest\"?\n\x0eTWalleTaskInfo\x12\x0e\n\x06TaskId\x18\x01 \x01(\t\x12\r\n\x05Hosts\x18\x02 \x03(\t\x12\x0e\n\x06Status\x18\x03 \x01(\t\"D\n\x17TWalleListTasksResponse\x12)\n\x05Tasks\x18\x01 \x03(\x0b\x32\x1a.NKikimrCms.TWalleTaskInfo\"(\n\x16TWalleCheckTaskRequest\x12\x0e\n\x06TaskId\x18\x01 \x01(\t\"h\n\x17TWalleCheckTaskResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12(\n\x04Task\x18\x02 \x01(\x0b\x32\x1a.NKikimrCms.TWalleTaskInfo\")\n\x17TWalleRemoveTaskRequest\x12\x0e\n\x06TaskId\x18\x01 \x01(\t\"?\n\x18TWalleRemoveTaskResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\"J\n\x07TLimits\x12\x1a\n\x12\x44isabledNodesLimit\x18\x01 \x01(\r\x12#\n\x17\x44isabledNodesRatioLimit\x18\x02 \x01(\r:\x02\x31\x30\"\xc3\x0b\n\nTCmsConfig\x12#\n\x10\x44\x65\x66\x61ultRetryTime\x18\x01 \x01(\x04:\t300000000\x12,\n\x19\x44\x65\x66\x61ultPermissionDuration\x18\x02 \x01(\x04:\t300000000\x12<\n\rMonitorConfig\x18\x03 \x01(\x0b\x32%.NKikimrCms.TCmsConfig.TMonitorConfig\x12)\n\x0cTenantLimits\x18\x04 \x01(\x0b\x32\x13.NKikimrCms.TLimits\x12*\n\rClusterLimits\x18\x05 \x01(\x0b\x32\x13.NKikimrCms.TLimits\x12\'\n\x15InfoCollectionTimeout\x18\x06 \x01(\x04:\x08\x31\x35\x30\x30\x30\x30\x30\x30\x12\x34\n\tLogConfig\x18\x07 \x01(\x0b\x32!.NKikimrCms.TCmsConfig.TLogConfig\x12>\n\x0eSentinelConfig\x18\x08 \x01(\x0b\x32&.NKikimrCms.TCmsConfig.TSentinelConfig\x1a\xe4\x01\n\x0eTMonitorConfig\x12\x19\n\x11\x45nableAutoUpdates\x18\x01 \x01(\x08\x12 \n\x0eUpdateInterval\x18\x02 \x01(\x04:\x08\x36\x30\x30\x30\x30\x30\x30\x30\x12%\n\x12IgnoredDowntimeGap\x18\x03 \x01(\x04:\t600000000\x12!\n\rBrokenTimeout\x18\x04 \x01(\x04:\n7200000000\x12$\n\x11\x42rokenPrepTimeout\x18\x05 \x01(\x04:\t600000000\x12%\n\x11\x46\x61ultyPrepTimeout\x18\x06 \x01(\x04:\n3600000000\x1a\x8b\x04\n\x0fTSentinelConfig\x12\x0e\n\x06\x45nable\x18\x01 \x01(\x08\x12(\n\x14UpdateConfigInterval\x18\x02 \x01(\x04:\n3600000000\x12#\n\x11RetryUpdateConfig\x18\x03 \x01(\x04:\x08\x36\x30\x30\x30\x30\x30\x30\x30\x12%\n\x13UpdateStateInterval\x18\x04 \x01(\x04:\x08\x36\x30\x30\x30\x30\x30\x30\x30\x12$\n\x12UpdateStateTimeout\x18\x05 \x01(\x04:\x08\x34\x35\x30\x30\x30\x30\x30\x30\x12#\n\x11RetryChangeStatus\x18\x06 \x01(\x04:\x08\x31\x30\x30\x30\x30\x30\x30\x30\x12\x1e\n\x13\x43hangeStatusRetries\x18\x07 \x01(\r:\x01\x35\x12\x1d\n\x11\x44\x65\x66\x61ultStateLimit\x18\x08 \x01(\r:\x02\x36\x30\x12\x17\n\x0b\x42rokenLimit\x18\t \x01(\r:\x02\x36\x30\x12\x1b\n\x0f\x44\x61taCenterRatio\x18\n \x01(\r:\x02\x35\x30\x12\x15\n\tRoomRatio\x18\x0b \x01(\r:\x02\x37\x30\x12\x15\n\tRackRatio\x18\x0c \x01(\r:\x02\x39\x30\x12\x0e\n\x06\x44ryRun\x18\r \x01(\x08\x12G\n\x0bStateLimits\x18\x0e \x03(\x0b\x32\x32.NKikimrCms.TCmsConfig.TSentinelConfig.TStateLimit\x1a+\n\x0bTStateLimit\x12\r\n\x05State\x18\x01 \x01(\r\x12\r\n\x05Limit\x18\x02 \x01(\r\x1a\xb8\x02\n\nTLogConfig\x12G\n\x0c\x44\x65\x66\x61ultLevel\x18\x01 \x01(\x0e\x32(.NKikimrCms.TCmsConfig.TLogConfig.ELevel:\x07\x45NABLED\x12\x45\n\x0f\x43omponentLevels\x18\x02 \x03(\x0b\x32,.NKikimrCms.TCmsConfig.TLogConfig.TComponent\x12\x1a\n\x03TTL\x18\x03 \x01(\x04:\r1209600000000\x1aY\n\nTComponent\x12\x12\n\nRecordType\x18\x01 \x01(\r\x12\x37\n\x05Level\x18\x02 \x01(\x0e\x32(.NKikimrCms.TCmsConfig.TLogConfig.ELevel\"#\n\x06\x45Level\x12\x0b\n\x07\x45NABLED\x10\x00\x12\x0c\n\x08\x44ISABLED\x10\x01\"*\n\x08TPDiskID\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0e\n\x06\x44iskId\x18\x02 \x01(\r\"z\n\x06TItems\x12\r\n\x05Hosts\x18\x01 \x03(\t\x12\r\n\x05Nodes\x18\x02 \x03(\r\x12$\n\x06PDisks\x18\x03 \x03(\x0b\x32\x14.NKikimrCms.TPDiskID\x12,\n\x06VDisks\x18\x04 \x03(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskID\"n\n\x11TSetMarkerRequest\x12#\n\x06Marker\x18\x01 \x01(\x0e\x32\x13.NKikimrCms.EMarker\x12!\n\x05Items\x18\x02 \x01(\x0b\x32\x12.NKikimrCms.TItems\x12\x11\n\tUserToken\x18\n \x01(\t\"9\n\x12TSetMarkerResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\"p\n\x13TResetMarkerRequest\x12#\n\x06Marker\x18\x01 \x01(\x0e\x32\x13.NKikimrCms.EMarker\x12!\n\x05Items\x18\x02 \x01(\x0b\x32\x12.NKikimrCms.TItems\x12\x11\n\tUserToken\x18\n \x01(\t\";\n\x14TResetMarkerResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\"\x13\n\x11TGetConfigRequest\"a\n\x12TGetConfigResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12&\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x16.NKikimrCms.TCmsConfig\";\n\x11TSetConfigRequest\x12&\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x16.NKikimrCms.TCmsConfig\"9\n\x12TSetConfigResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\"\xab\x01\n\x12TAvailabilityStats\x12;\n\tDowntimes\x18\x01 \x03(\x0b\x32(.NKikimrCms.TAvailabilityStats.TDowntime\x12\x1a\n\x12IgnoredDowntimeGap\x18\x02 \x01(\x04\x1a<\n\tTDowntime\x12\r\n\x05Start\x18\x01 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x02 \x01(\x04\x12\x13\n\x0b\x45xplanation\x18\x03 \x01(\t\"\xbc\x08\n\x0eTLogRecordData\x12\x12\n\nRecordType\x18\x01 \x01(\r\x12:\n\tCmsLoaded\x18\x0b \x01(\x0b\x32%.NKikimrCms.TLogRecordData.TCmsLoadedH\x00\x12L\n\x12PDiskMonitorAction\x18\x0c \x01(\x0b\x32..NKikimrCms.TLogRecordData.TPDiskMonitorActionH\x00\x12N\n\x13MarkersModification\x18\r \x01(\x0b\x32/.NKikimrCms.TLogRecordData.TMarkersModificationH\x00\x1a;\n\nTCmsLoaded\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x0f\n\x07Version\x18\x03 \x01(\t\x1a\xa0\x03\n\x13TPDiskMonitorAction\x12%\n\x07PDiskId\x18\x01 \x01(\x0b\x32\x14.NKikimrCms.TPDiskID\x12\x37\n\rCurrentStatus\x18\x02 \x01(\x0e\x32 .NKikimrBlobStorage.EDriveStatus\x12\x38\n\x0eRequiredStatus\x18\x03 \x01(\x0e\x32 .NKikimrBlobStorage.EDriveStatus\x12)\n\x0cPDiskMarkers\x18\x04 \x03(\x0e\x32\x13.NKikimrCms.EMarker\x12(\n\x0bNodeMarkers\x18\x05 \x03(\x0e\x32\x13.NKikimrCms.EMarker\x12=\n\x15\x44iskAvailabilityStats\x18\x06 \x01(\x0b\x32\x1e.NKikimrCms.TAvailabilityStats\x12=\n\x15NodeAvailabilityStats\x18\x07 \x01(\x0b\x32\x1e.NKikimrCms.TAvailabilityStats\x12\x0c\n\x04Host\x18\x08 \x01(\t\x12\x0e\n\x06Reason\x18\t \x01(\t\x1a\xf9\x01\n\x14TMarkersModification\x12\x0e\n\x04Host\x18\x01 \x01(\tH\x00\x12\x0e\n\x04Node\x18\x02 \x01(\rH\x00\x12%\n\x05PDisk\x18\x03 \x01(\x0b\x32\x14.NKikimrCms.TPDiskIDH\x00\x12-\n\x05VDisk\x18\x04 \x01(\x0b\x32\x1c.NKikimrBlobStorage.TVDiskIDH\x00\x12\'\n\nOldMarkers\x18\x05 \x03(\x0e\x32\x13.NKikimrCms.EMarker\x12\'\n\nNewMarkers\x18\x06 \x03(\x0e\x32\x13.NKikimrCms.EMarker\x12\x11\n\tUserToken\x18\x07 \x01(\tB\x06\n\x04Item\"X\n\x05\x45Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0e\n\nCMS_LOADED\x10\x01\x12\x18\n\x14PDISK_MONITOR_ACTION\x10\x02\x12\x18\n\x14MARKERS_MODIFICATION\x10\x03\x42\x06\n\x04\x44\x61ta\"n\n\nTLogRecord\x12\x11\n\tTimestamp\x18\x01 \x01(\x04\x12\x12\n\nRecordType\x18\x02 \x01(\r\x12(\n\x04\x44\x61ta\x18\x03 \x01(\x0b\x32\x1a.NKikimrCms.TLogRecordData\x12\x0f\n\x07Message\x18\x04 \x01(\t\"p\n\nTLogFilter\x12\x12\n\nRecordType\x18\x01 \x01(\r\x12\x14\n\x0cMinTimestamp\x18\x02 \x01(\x04\x12\x14\n\x0cMaxTimestamp\x18\x03 \x01(\x04\x12\x12\n\x05Limit\x18\x04 \x01(\r:\x03\x31\x30\x30\x12\x0e\n\x06Offset\x18\x05 \x01(\r\"\x9b\x01\n\x12TGetLogTailRequest\x12)\n\tLogFilter\x18\x01 \x01(\x0b\x32\x16.NKikimrCms.TLogFilter\x12\x1a\n\x0bIncludeData\x18\x02 \x01(\x08:\x05\x66\x61lse\x12>\n\nTextFormat\x18\x03 \x01(\x0e\x32\x17.NKikimrCms.ETextFormat:\x11TEXT_FORMAT_SHORT\"f\n\x13TGetLogTailResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12*\n\nLogRecords\x18\x02 \x03(\x0b\x32\x16.NKikimrCms.TLogRecord\"*\n\x0cTFilterRange\x12\r\n\x05\x42\x65gin\x18\x01 \x01(\r\x12\x0b\n\x03\x45nd\x18\x02 \x01(\r\"\xaf\x01\n\x18TGetSentinelStateRequest\x12\x38\n\x04Show\x18\x01 \x01(\x0e\x32*.NKikimrCms.TGetSentinelStateRequest.EShow\x12(\n\x06Ranges\x18\x02 \x03(\x0b\x32\x18.NKikimrCms.TFilterRange\"/\n\x05\x45Show\x12\r\n\tUNHEALTHY\x10\x01\x12\x0e\n\nSUSPICIOUS\x10\x02\x12\x07\n\x03\x41LL\x10\x03\"\xd5\x03\n\nTPDiskInfo\x12\r\n\x05State\x18\x01 \x01(\r\x12\x11\n\tPrevState\x18\x02 \x01(\r\x12\x14\n\x0cStateCounter\x18\x03 \x01(\x04\x12\x0e\n\x06Status\x18\x04 \x01(\r\x12\x17\n\x0f\x43hangingAllowed\x18\x05 \x01(\x08\x12\x0f\n\x07Touched\x18\x06 \x01(\x08\x12\x15\n\rDesiredStatus\x18\x07 \x01(\r\x12\x1c\n\x14StatusChangeAttempts\x18\x08 \x01(\r\x12\x19\n\x11PrevDesiredStatus\x18\t \x01(\r\x12 \n\x18PrevStatusChangeAttempts\x18\n \x01(\r\x12\x18\n\x10LastStatusChange\x18\x0b \x01(\t\x12:\n\x0cIgnoreReason\x18\x0c \x01(\x0e\x32$.NKikimrCms.TPDiskInfo.EIgnoreReason\x12\x1a\n\x12StatusChangeFailed\x18\r \x01(\x08\"q\n\rEIgnoreReason\x12\x0f\n\x0bNOT_IGNORED\x10\x01\x12\x10\n\x0cMISSING_NODE\x10\x02\x12\x17\n\x13RATIO_BY_DATACENTER\x10\x03\x12\x11\n\rRATIO_BY_ROOM\x10\x04\x12\x11\n\rRATIO_BY_RACK\x10\x05\"P\n\x06TPDisk\x12 \n\x02Id\x18\x01 \x01(\x0b\x32\x14.NKikimrCms.TPDiskID\x12$\n\x04Info\x18\x02 \x01(\x0b\x32\x16.NKikimrCms.TPDiskInfo\"C\n\x0cTUpdaterInfo\x12\x0f\n\x07\x41\x63torId\x18\x01 \x01(\t\x12\x11\n\tStartedAt\x18\x02 \x01(\t\x12\x0f\n\x07\x44\x65layed\x18\x03 \x01(\x08\"\x89\x01\n\x12TStateUpdaterState\x12-\n\x0bUpdaterInfo\x18\x01 \x01(\x0b\x32\x18.NKikimrCms.TUpdaterInfo\x12\x31\n\x0fPrevUpdaterInfo\x18\x02 \x01(\x0b\x32\x18.NKikimrCms.TUpdaterInfo\x12\x11\n\tWaitNodes\x18\x03 \x03(\r\"\xcf\x01\n\x13TConfigUpdaterState\x12-\n\x0bUpdaterInfo\x18\x01 \x01(\x0b\x32\x18.NKikimrCms.TUpdaterInfo\x12\x31\n\x0fPrevUpdaterInfo\x18\x02 \x01(\x0b\x32\x18.NKikimrCms.TUpdaterInfo\x12\x12\n\nBSCAttempt\x18\x03 \x01(\r\x12\x16\n\x0ePrevBSCAttempt\x18\x04 \x01(\r\x12\x12\n\nCMSAttempt\x18\x05 \x01(\r\x12\x16\n\x0ePrevCMSAttempt\x18\x06 \x01(\r\"\x92\x02\n\x19TGetSentinelStateResponse\x12#\n\x06Status\x18\x01 \x01(\x0b\x32\x13.NKikimrCms.TStatus\x12>\n\x0eSentinelConfig\x18\x02 \x01(\x0b\x32&.NKikimrCms.TCmsConfig.TSentinelConfig\x12\"\n\x06PDisks\x18\x03 \x03(\x0b\x32\x12.NKikimrCms.TPDisk\x12\x34\n\x0cStateUpdater\x18\x04 \x01(\x0b\x32\x1e.NKikimrCms.TStateUpdaterState\x12\x36\n\rConfigUpdater\x18\x05 \x01(\x0b\x32\x1f.NKikimrCms.TConfigUpdaterState*4\n\x06\x45State\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x06\n\x02UP\x10\x01\x12\x0b\n\x07RESTART\x10\x02\x12\x08\n\x04\x44OWN\x10\x03*\x7f\n\x07\x45Marker\x12\x12\n\x0eMARKER_UNKNOWN\x10\x00\x12\x16\n\x12MARKER_DISK_BROKEN\x10\x01\x12\x16\n\x12MARKER_DISK_FAULTY\x10\x02\x12\x16\n\x12MARKER_DISK_ACTIVE\x10\x03\x12\x18\n\x14MARKER_DISK_INACTIVE\x10\x04*&\n\rETenantPolicy\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x44\x45\x46\x41ULT\x10\x01*_\n\x11\x45\x41vailabilityMode\x12\x19\n\x15MODE_MAX_AVAILABILITY\x10\x00\x12\x17\n\x13MODE_KEEP_AVAILABLE\x10\x01\x12\x16\n\x12MODE_FORCE_RESTART\x10\x02*\x1e\n\x0e\x45\x45xtensionType\x12\x0c\n\x08HostInfo\x10\x01*T\n\x0b\x45TextFormat\x12\x14\n\x10TEXT_FORMAT_NONE\x10\x00\x12\x15\n\x11TEXT_FORMAT_SHORT\x10\x01\x12\x18\n\x14TEXT_FORMAT_DETAILED\x10\x02\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.cms_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ESTATE._serialized_start=10800
  _ESTATE._serialized_end=10852
  _EMARKER._serialized_start=10854
  _EMARKER._serialized_end=10981
  _ETENANTPOLICY._serialized_start=10983
  _ETENANTPOLICY._serialized_end=11021
  _EAVAILABILITYMODE._serialized_start=11023
  _EAVAILABILITYMODE._serialized_end=11118
  _EEXTENSIONTYPE._serialized_start=11120
  _EEXTENSIONTYPE._serialized_end=11150
  _ETEXTFORMAT._serialized_start=11152
  _ETEXTFORMAT._serialized_end=11236
  _TSTATUS._serialized_start=170
  _TSTATUS._serialized_end=453
  _TSTATUS_ECODE._serialized_start=239
  _TSTATUS_ECODE._serialized_end=453
  _TSERVICESTATE._serialized_start=455
  _TSERVICESTATE._serialized_end=555
  _TDEVICESTATE._serialized_start=557
  _TDEVICESTATE._serialized_end=677
  _THOSTSTATE._serialized_start=680
  _THOSTSTATE._serialized_end=982
  _TCLUSTERSTATE._serialized_start=984
  _TCLUSTERSTATE._serialized_end=1071
  _TCLUSTERSTATEREQUEST._serialized_start=1073
  _TCLUSTERSTATEREQUEST._serialized_end=1110
  _TCLUSTERSTATERESPONSE._serialized_start=1112
  _TCLUSTERSTATERESPONSE._serialized_end=1214
  _TACTION._serialized_start=1217
  _TACTION._serialized_end=1548
  _TACTION_ETYPE._serialized_start=1353
  _TACTION_ETYPE._serialized_end=1548
  _TPERMISSIONREQUEST._serialized_start=1551
  _TPERMISSIONREQUEST._serialized_end=1870
  _TPERMISSIONEXTENSION._serialized_start=1872
  _TPERMISSIONEXTENSION._serialized_end=1975
  _TPERMISSION._serialized_start=1978
  _TPERMISSION._serialized_end=2112
  _TPERMISSIONRESPONSE._serialized_start=2115
  _TPERMISSIONRESPONSE._serialized_end=2256
  _TMANAGEREQUESTREQUEST._serialized_start=2259
  _TMANAGEREQUESTREQUEST._serialized_end=2448
  _TMANAGEREQUESTREQUEST_ECOMMAND._serialized_start=2394
  _TMANAGEREQUESTREQUEST_ECOMMAND._serialized_end=2448
  _TMANAGEREQUESTRESPONSE._serialized_start=2451
  _TMANAGEREQUESTRESPONSE._serialized_end=2728
  _TMANAGEREQUESTRESPONSE_TSCHEDULEDREQUEST._serialized_start=2587
  _TMANAGEREQUESTRESPONSE_TSCHEDULEDREQUEST._serialized_end=2728
  _TCHECKREQUEST._serialized_start=2731
  _TCHECKREQUEST._serialized_end=2875
  _TMANAGEPERMISSIONREQUEST._serialized_start=2878
  _TMANAGEPERMISSIONREQUEST._serialized_end=3115
  _TMANAGEPERMISSIONREQUEST_ECOMMAND._serialized_start=3039
  _TMANAGEPERMISSIONREQUEST_ECOMMAND._serialized_end=3115
  _TMANAGEPERMISSIONRESPONSE._serialized_start=3117
  _TMANAGEPERMISSIONRESPONSE._serialized_end=3227
  _TVERSIONFILTER._serialized_start=3230
  _TVERSIONFILTER._serialized_end=3382
  _TVERSIONFILTER_ETYPE._serialized_start=3313
  _TVERSIONFILTER_ETYPE._serialized_end=3382
  _TNAMEFILTER._serialized_start=3384
  _TNAMEFILTER._serialized_end=3503
  _TNAMEFILTER_ETYPE._serialized_start=3459
  _TNAMEFILTER_ETYPE._serialized_end=3503
  _TSERVICEFILTER._serialized_start=3505
  _TSERVICEFILTER._serialized_end=3617
  _THOSTFILTER._serialized_start=3619
  _THOSTFILTER._serialized_end=3677
  _TCONDITIONALPERMISSIONREQUEST._serialized_start=3680
  _TCONDITIONALPERMISSIONREQUEST._serialized_end=3960
  _TNOTIFICATION._serialized_start=3962
  _TNOTIFICATION._serialized_end=4059
  _TNOTIFICATIONRESPONSE._serialized_start=4061
  _TNOTIFICATIONRESPONSE._serialized_end=4145
  _TMANAGENOTIFICATIONREQUEST._serialized_start=4148
  _TMANAGENOTIFICATIONREQUEST._serialized_end=4352
  _TMANAGENOTIFICATIONREQUEST_ECOMMAND._serialized_start=2394
  _TMANAGENOTIFICATIONREQUEST_ECOMMAND._serialized_end=2448
  _TMANAGENOTIFICATIONRESPONSE._serialized_start=4355
  _TMANAGENOTIFICATIONRESPONSE._serialized_end=4636
  _TMANAGENOTIFICATIONRESPONSE_TSTOREDNOTIFICATION._serialized_start=4508
  _TMANAGENOTIFICATIONRESPONSE_TSTOREDNOTIFICATION._serialized_end=4636
  _TWALLECREATETASKREQUEST._serialized_start=4638
  _TWALLECREATETASKREQUEST._serialized_end=4756
  _TWALLECREATETASKRESPONSE._serialized_start=4758
  _TWALLECREATETASKRESPONSE._serialized_end=4852
  _TWALLELISTTASKSREQUEST._serialized_start=4854
  _TWALLELISTTASKSREQUEST._serialized_end=4878
  _TWALLETASKINFO._serialized_start=4880
  _TWALLETASKINFO._serialized_end=4943
  _TWALLELISTTASKSRESPONSE._serialized_start=4945
  _TWALLELISTTASKSRESPONSE._serialized_end=5013
  _TWALLECHECKTASKREQUEST._serialized_start=5015
  _TWALLECHECKTASKREQUEST._serialized_end=5055
  _TWALLECHECKTASKRESPONSE._serialized_start=5057
  _TWALLECHECKTASKRESPONSE._serialized_end=5161
  _TWALLEREMOVETASKREQUEST._serialized_start=5163
  _TWALLEREMOVETASKREQUEST._serialized_end=5204
  _TWALLEREMOVETASKRESPONSE._serialized_start=5206
  _TWALLEREMOVETASKRESPONSE._serialized_end=5269
  _TLIMITS._serialized_start=5271
  _TLIMITS._serialized_end=5345
  _TCMSCONFIG._serialized_start=5348
  _TCMSCONFIG._serialized_end=6823
  _TCMSCONFIG_TMONITORCONFIG._serialized_start=5754
  _TCMSCONFIG_TMONITORCONFIG._serialized_end=5982
  _TCMSCONFIG_TSENTINELCONFIG._serialized_start=5985
  _TCMSCONFIG_TSENTINELCONFIG._serialized_end=6508
  _TCMSCONFIG_TSENTINELCONFIG_TSTATELIMIT._serialized_start=6465
  _TCMSCONFIG_TSENTINELCONFIG_TSTATELIMIT._serialized_end=6508
  _TCMSCONFIG_TLOGCONFIG._serialized_start=6511
  _TCMSCONFIG_TLOGCONFIG._serialized_end=6823
  _TCMSCONFIG_TLOGCONFIG_TCOMPONENT._serialized_start=6697
  _TCMSCONFIG_TLOGCONFIG_TCOMPONENT._serialized_end=6786
  _TCMSCONFIG_TLOGCONFIG_ELEVEL._serialized_start=6788
  _TCMSCONFIG_TLOGCONFIG_ELEVEL._serialized_end=6823
  _TPDISKID._serialized_start=6825
  _TPDISKID._serialized_end=6867
  _TITEMS._serialized_start=6869
  _TITEMS._serialized_end=6991
  _TSETMARKERREQUEST._serialized_start=6993
  _TSETMARKERREQUEST._serialized_end=7103
  _TSETMARKERRESPONSE._serialized_start=7105
  _TSETMARKERRESPONSE._serialized_end=7162
  _TRESETMARKERREQUEST._serialized_start=7164
  _TRESETMARKERREQUEST._serialized_end=7276
  _TRESETMARKERRESPONSE._serialized_start=7278
  _TRESETMARKERRESPONSE._serialized_end=7337
  _TGETCONFIGREQUEST._serialized_start=7339
  _TGETCONFIGREQUEST._serialized_end=7358
  _TGETCONFIGRESPONSE._serialized_start=7360
  _TGETCONFIGRESPONSE._serialized_end=7457
  _TSETCONFIGREQUEST._serialized_start=7459
  _TSETCONFIGREQUEST._serialized_end=7518
  _TSETCONFIGRESPONSE._serialized_start=7520
  _TSETCONFIGRESPONSE._serialized_end=7577
  _TAVAILABILITYSTATS._serialized_start=7580
  _TAVAILABILITYSTATS._serialized_end=7751
  _TAVAILABILITYSTATS_TDOWNTIME._serialized_start=7691
  _TAVAILABILITYSTATS_TDOWNTIME._serialized_end=7751
  _TLOGRECORDDATA._serialized_start=7754
  _TLOGRECORDDATA._serialized_end=8838
  _TLOGRECORDDATA_TCMSLOADED._serialized_start=8010
  _TLOGRECORDDATA_TCMSLOADED._serialized_end=8069
  _TLOGRECORDDATA_TPDISKMONITORACTION._serialized_start=8072
  _TLOGRECORDDATA_TPDISKMONITORACTION._serialized_end=8488
  _TLOGRECORDDATA_TMARKERSMODIFICATION._serialized_start=8491
  _TLOGRECORDDATA_TMARKERSMODIFICATION._serialized_end=8740
  _TLOGRECORDDATA_ETYPE._serialized_start=8742
  _TLOGRECORDDATA_ETYPE._serialized_end=8830
  _TLOGRECORD._serialized_start=8840
  _TLOGRECORD._serialized_end=8950
  _TLOGFILTER._serialized_start=8952
  _TLOGFILTER._serialized_end=9064
  _TGETLOGTAILREQUEST._serialized_start=9067
  _TGETLOGTAILREQUEST._serialized_end=9222
  _TGETLOGTAILRESPONSE._serialized_start=9224
  _TGETLOGTAILRESPONSE._serialized_end=9326
  _TFILTERRANGE._serialized_start=9328
  _TFILTERRANGE._serialized_end=9370
  _TGETSENTINELSTATEREQUEST._serialized_start=9373
  _TGETSENTINELSTATEREQUEST._serialized_end=9548
  _TGETSENTINELSTATEREQUEST_ESHOW._serialized_start=9501
  _TGETSENTINELSTATEREQUEST_ESHOW._serialized_end=9548
  _TPDISKINFO._serialized_start=9551
  _TPDISKINFO._serialized_end=10020
  _TPDISKINFO_EIGNOREREASON._serialized_start=9907
  _TPDISKINFO_EIGNOREREASON._serialized_end=10020
  _TPDISK._serialized_start=10022
  _TPDISK._serialized_end=10102
  _TUPDATERINFO._serialized_start=10104
  _TUPDATERINFO._serialized_end=10171
  _TSTATEUPDATERSTATE._serialized_start=10174
  _TSTATEUPDATERSTATE._serialized_end=10311
  _TCONFIGUPDATERSTATE._serialized_start=10314
  _TCONFIGUPDATERSTATE._serialized_end=10521
  _TGETSENTINELSTATERESPONSE._serialized_start=10524
  _TGETSENTINELSTATERESPONSE._serialized_end=10798
# @@protoc_insertion_point(module_scope)
