# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aydb/core/protos/base.proto\x12\x0cNKikimrProto\":\n\x0bTLogoBlobID\x12\r\n\x05RawX1\x18\x01 \x01(\x06\x12\r\n\x05RawX2\x18\x02 \x01(\x06\x12\r\n\x05RawX3\x18\x03 \x01(\x06\")\n\x0bTRowVersion\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"+\n\x07TPathID\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x06\x12\x0f\n\x07LocalId\x18\x02 \x01(\x04*\xde\x02\n\x0c\x45ReplyStatus\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x0b\n\x07\x41LREADY\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x08\n\x04RACE\x10\x04\x12\n\n\x06NODATA\x10\x05\x12\x0b\n\x07\x42LOCKED\x10\x06\x12\x0c\n\x08NOTREADY\x10\x07\x12\x0b\n\x07OVERRUN\x10\x08\x12\x0c\n\x08TRYLATER\x10\t\x12\x11\n\rTRYLATER_TIME\x10\n\x12\x11\n\rTRYLATER_SIZE\x10\x0b\x12\x0c\n\x08\x44\x45\x41\x44LINE\x10\x0c\x12\r\n\tCORRUPTED\x10\r\x12\r\n\tSCHEDULED\x10\x0e\x12\x10\n\x0cOUT_OF_SPACE\x10\x0f\x12\x15\n\x11VDISK_ERROR_STATE\x10\x10\x12\x11\n\rINVALID_OWNER\x10\x11\x12\x11\n\rINVALID_ROUND\x10\x12\x12\x0b\n\x07RESTART\x10\x13\x12\x0b\n\x07NOT_YET\x10\x14\x12\x0c\n\x08NO_GROUP\x10\x15\x12\x0c\n\x07UNKNOWN\x10\xff\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EREPLYSTATUS._serialized_start=193
  _EREPLYSTATUS._serialized_end=543
  _TLOGOBLOBID._serialized_start=44
  _TLOGOBLOBID._serialized_end=102
  _TROWVERSION._serialized_start=104
  _TROWVERSION._serialized_end=145
  _TPATHID._serialized_start=147
  _TPATHID._serialized_end=190
# @@protoc_insertion_point(module_scope)
