# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/folder_service/proto/config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/library/folder_service/proto/config.proto\x12\x1bNKikimrProto.NFolderService\"N\n\x14TFolderServiceConfig\x12\x0e\n\x06\x45nable\x18\x01 \x01(\x08\x12\x10\n\x08\x45ndpoint\x18\x02 \x01(\t\x12\x14\n\x0cPathToRootCA\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.folder_service.proto.config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TFOLDERSERVICECONFIG._serialized_start=78
  _TFOLDERSERVICECONFIG._serialized_end=156
# @@protoc_insertion_point(module_scope)
