# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_bs_controller.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/protos/counters_bs_controller.proto\x12\x1eNKikimr.NBlobStorageController\x1a\x1eydb/core/protos/counters.proto*\xae\x0b\n\x0f\x45SimpleCounters\x12:\n\x1a\x43OUNTER_RESPONSE_TIME_USEC\x10\x00\x1a\x1a\x82\xd6\x1b\x16\n\x14ResponseTimeMicrosec\x12Q\n)COUNTER_GROUPS_WITH_SLOTS_ON_FAULTY_DISKS\x10\x01\x1a\"\x82\xd6\x1b\x1e\n\x1cGroupsWithSlotsOnFaultyDisks\x12;\n\x1d\x43OUNTER_SLOTS_ON_FAULTY_DISKS\x10\x02\x1a\x18\x82\xd6\x1b\x14\n\x12SlotsOnFaultyDisks\x12;\n\x1d\x43OUNTER_BYTES_ON_FAULTY_DISKS\x10\x03\x1a\x18\x82\xd6\x1b\x14\n\x12\x42ytesOnFaultyDisks\x12T\n*COUNTER_PDISKS_WITHOUT_EXPECTED_SLOT_COUNT\x10\x04\x1a$\x82\xd6\x1b \n\x1ePDisksWithoutExpectedSlotCount\x12\x37\n\x1b\x43OUNTER_TO_BE_REMOVED_DISKS\x10\x05\x1a\x16\x82\xd6\x1b\x12\n\x10ToBeRemovedDisks\x12]\n0COUNTER_GROUPS_WITH_SLOTS_ON_TO_BE_REMOVED_DISKS\x10\x06\x1a\'\x82\xd6\x1b#\n!GroupsWithSlotsOnToBeRemovedDisks\x12G\n$COUNTER_SLOTS_ON_TO_BE_REMOVED_DISKS\x10\x07\x1a\x1d\x82\xd6\x1b\x19\n\x17SlotsOnToBeRemovedDisks\x12G\n$COUNTER_BYTES_ON_TO_BE_REMOVED_DISKS\x10\x08\x1a\x1d\x82\xd6\x1b\x19\n\x17\x42ytesOnToBeRemovedDisks\x12M\n&COUNTER_PDISKS_WITHOUT_EXPECTED_SERIAL\x10\t\x1a!\x82\xd6\x1b\x1d\n\x1bPDisksWithoutExpectedSerial\x12;\n\x1d\x43OUNTER_DRIVE_SERIAL_NOT_SEEN\x10\n\x1a\x18\x82\xd6\x1b\x14\n\x12\x44riveSerialNotSeen\x12:\n\x1c\x43OUNTER_DRIVE_SERIAL_REMOVED\x10\x0b\x1a\x18\x82\xd6\x1b\x14\n\x12\x44riveSerialRemoved\x12\x36\n\x1a\x43OUNTER_DRIVE_SERIAL_ERROR\x10\x0c\x1a\x16\x82\xd6\x1b\x12\n\x10\x44riveSerialError\x12H\n$COUNTER_DISK_SCRUB_WAITING_FOR_START\x10\r\x1a\x1e\x82\xd6\x1b\x1a\n\x18\x44iskScrubWaitingForStart\x12\x36\n\x1a\x43OUNTER_DISK_SCRUB_RUNNING\x10\x0e\x1a\x16\x82\xd6\x1b\x12\n\x10\x44iskScrubRunning\x12=\n\x1e\x43OUNTER_DISK_SCRUB_IN_PROGRESS\x10\x0f\x1a\x19\x82\xd6\x1b\x15\n\x13\x44iskScrubInProgress\x12=\n\x1e\x43OUNTER_DISK_SCRUB_FINISHED_OK\x10\x10\x1a\x19\x82\xd6\x1b\x15\n\x13\x44iskScrubFinishedOk\x12?\n\x1f\x43OUNTER_DISK_SCRUB_FINISHED_ERR\x10\x11\x1a\x1a\x82\xd6\x1b\x16\n\x14\x44iskScrubFinishedErr\x12>\n\x1c\x43OUNTER_DISK_SCRUB_CUR_DISKS\x10\x12\x1a\x1c\x82\xd6\x1b\x18\n\x16\x43urrentlyScrubbedDisks\x12@\n\x1d\x43OUNTER_DISK_SCRUB_CUR_GROUPS\x10\x13\x1a\x1d\x82\xd6\x1b\x19\n\x17\x43urrentlyScrubbedGroups\x12O\n\'COUNTER_SELF_HEAL_UNREASSIGNABLE_GROUPS\x10\x14\x1a\"\x82\xd6\x1b\x1e\n\x1cSelfHealUnreassignableGroups*\xfc\x13\n\x13\x45\x43umulativeCounters\x12\x38\n\x1b\x43OUNTER_REGISTER_NODE_COUNT\x10\x00\x1a\x17\x82\xd6\x1b\x13\n\x11RegisterNodeCount\x12:\n\x1a\x43OUNTER_REGISTER_NODE_USEC\x10\x01\x1a\x1a\x82\xd6\x1b\x16\n\x14RegisterNodeMicrosec\x12\x30\n\x17\x43OUNTER_GET_GROUP_COUNT\x10\x02\x1a\x13\x82\xd6\x1b\x0f\n\rGetGroupCount\x12\x32\n\x16\x43OUNTER_GET_GROUP_USEC\x10\x03\x1a\x16\x82\xd6\x1b\x12\n\x10GetGroupMicrosec\x12\x38\n\x1b\x43OUNTER_SELECT_GROUPS_COUNT\x10\x04\x1a\x17\x82\xd6\x1b\x13\n\x11SelectGroupsCount\x12:\n\x1a\x43OUNTER_SELECT_GROUPS_USEC\x10\x05\x1a\x1a\x82\xd6\x1b\x16\n\x14SelectGroupsMicrosec\x12\x43\n!COUNTER_UPDATE_DISK_METRICS_COUNT\x10\x06\x1a\x1c\x82\xd6\x1b\x18\n\x16UpdateDiskMetricsCount\x12\x45\n COUNTER_UPDATE_DISK_METRICS_USEC\x10\x07\x1a\x1f\x82\xd6\x1b\x1b\n\x19UpdateDiskMetricsMicrosec\x12\x34\n\x19\x43OUNTER_NODE_REPORT_COUNT\x10\x08\x1a\x15\x82\xd6\x1b\x11\n\x0fNodeReportCount\x12\x36\n\x18\x43OUNTER_NODE_REPORT_USEC\x10\t\x1a\x18\x82\xd6\x1b\x14\n\x12NodeReportMicrosec\x12+\n\x14\x43OUNTER_CONFIG_COUNT\x10\n\x1a\x11\x82\xd6\x1b\r\n\x0b\x43onfigCount\x12-\n\x13\x43OUNTER_CONFIG_USEC\x10\x0b\x1a\x14\x82\xd6\x1b\x10\n\x0e\x43onfigMicrosec\x12\x36\n\x1a\x43OUNTER_REQUEST_INFO_COUNT\x10\x0c\x1a\x16\x82\xd6\x1b\x12\n\x10RequestInfoCount\x12\x38\n\x19\x43OUNTER_REQUEST_INFO_USEC\x10\r\x1a\x19\x82\xd6\x1b\x15\n\x13RequestInfoMicrosec\x12M\n&COUNTER_SELFHEAL_REASSIGN_BSC_REQUESTS\x10\x0e\x1a!\x82\xd6\x1b\x1d\n\x1bSelfHealReassignBscRequests\x12\x41\n COUNTER_SELFHEAL_REASSIGN_BSC_OK\x10\x0f\x1a\x1b\x82\xd6\x1b\x17\n\x15SelfHealReassignBscOk\x12\x43\n!COUNTER_SELFHEAL_REASSIGN_BSC_ERR\x10\x10\x1a\x1c\x82\xd6\x1b\x18\n\x16SelfHealReassignBscErr\x12\x45\n)COUNTER_CONFIGCMD_DEFINE_HOST_CONFIG_USEC\x10\x11\x1a\x16\x82\xd6\x1b\x12\n\x10\x44\x65\x66ineHostConfig\x12\x41\n\'COUNTER_CONFIGCMD_READ_HOST_CONFIG_USEC\x10\x12\x1a\x14\x82\xd6\x1b\x10\n\x0eReadHostConfig\x12\x45\n)COUNTER_CONFIGCMD_DELETE_HOST_CONFIG_USEC\x10\x13\x1a\x16\x82\xd6\x1b\x12\n\x10\x44\x65leteHostConfig\x12\x36\n!COUNTER_CONFIGCMD_DEFINE_BOX_USEC\x10\x14\x1a\x0f\x82\xd6\x1b\x0b\n\tDefineBox\x12\x32\n\x1f\x43OUNTER_CONFIGCMD_READ_BOX_USEC\x10\x15\x1a\r\x82\xd6\x1b\t\n\x07ReadBox\x12\x36\n!COUNTER_CONFIGCMD_DELETE_BOX_USEC\x10\x16\x1a\x0f\x82\xd6\x1b\x0b\n\tDeleteBox\x12G\n*COUNTER_CONFIGCMD_DEFINE_STORAGE_POOL_USEC\x10\x17\x1a\x17\x82\xd6\x1b\x13\n\x11\x44\x65\x66ineStoragePool\x12\x43\n(COUNTER_CONFIGCMD_READ_STORAGE_POOL_USEC\x10\x18\x1a\x15\x82\xd6\x1b\x11\n\x0fReadStoragePool\x12G\n*COUNTER_CONFIGCMD_DELETE_STORAGE_POOL_USEC\x10\x19\x1a\x17\x82\xd6\x1b\x13\n\x11\x44\x65leteStoragePool\x12G\n*COUNTER_CONFIGCMD_UPDATE_DRIVE_STATUS_USEC\x10\x1a\x1a\x17\x82\xd6\x1b\x13\n\x11UpdateDriveStatus\x12\x43\n(COUNTER_CONFIGCMD_READ_DRIVE_STATUS_USEC\x10\x1b\x1a\x15\x82\xd6\x1b\x11\n\x0fReadDriveStatus\x12K\n,COUNTER_CONFIGCMD_PROPOSE_STORAGE_POOLS_USEC\x10\x1c\x1a\x19\x82\xd6\x1b\x15\n\x13ProposeStoragePools\x12\x43\n(COUNTER_CONFIGCMD_QUERY_BASE_CONFIG_USEC\x10\x1d\x1a\x15\x82\xd6\x1b\x11\n\x0fQueryBaseConfig\x12\x38\n\"COUNTER_CONFIGCMD_MERGE_BOXES_USEC\x10\x1e\x1a\x10\x82\xd6\x1b\x0c\n\nMergeBoxes\x12\x38\n\"COUNTER_CONFIGCMD_MOVE_GROUPS_USEC\x10\x1f\x1a\x10\x82\xd6\x1b\x0c\n\nMoveGroups\x12\x45\n)COUNTER_CONFIGCMD_ADD_MIGRATION_PLAN_USEC\x10 \x1a\x16\x82\xd6\x1b\x12\n\x10\x41\x64\x64MigrationPlan\x12K\n,COUNTER_CONFIGCMD_DELETE_MIGRATION_PLAN_USEC\x10!\x1a\x19\x82\xd6\x1b\x15\n\x13\x44\x65leteMigrationPlan\x12>\n%COUNTER_CONFIGCMD_DECLARE_INTENT_USEC\x10\"\x1a\x13\x82\xd6\x1b\x0f\n\rDeclareIntent\x12\x38\n\"COUNTER_CONFIGCMD_READ_INTENT_USEC\x10#\x1a\x10\x82\xd6\x1b\x0c\n\nReadIntent\x12?\n&COUNTER_CONFIGCMD_DROP_DONOR_DISK_USEC\x10$\x1a\x13\x82\xd6\x1b\x0f\n\rDropDonorDisk\x12G\n*COUNTER_CONFIGCMD_REASSIGN_GROUP_DISK_USEC\x10%\x1a\x17\x82\xd6\x1b\x13\n\x11ReassignGroupDisk\x12>\n#COUNTER_DISK_SCRUB_QUANTUM_FINISHED\x10&\x1a\x15\x82\xd6\x1b\x11\n\x0fQuantumFinished\x12<\n$COUNTER_CONFIGCMD_READ_SETTINGS_USEC\x10\'\x1a\x12\x82\xd6\x1b\x0e\n\x0cReadSettings*\xe6\n\n\x13\x45PercentileCounters\x12\x38\n COUNTER_PERCENTILE_SELECT_GROUPS\x10\x00\x1a\x12\x82\xd6\x1b\x0e\n\x0cSelectGroups\x12\xdd\x02\n\x1e\x43OUNTER_FAULTY_USETTLED_PDISKS\x10\x01\x1a\xb8\x02\x82\xd6\x1b\xb3\x02\n\x15\x46\x61ultyUnsettledPDisks\x12\x05\x08\x00\x12\x01\x30\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x14\x12\x02\x32\x30\x12\x06\x08\x1e\x12\x02\x33\x30\x12\x06\x08(\x12\x02\x34\x30\x12\x06\x08\x32\x12\x02\x35\x30\x12\x06\x08<\x12\x02\x36\x30\x12\x07\x08x\x12\x03\x31\x32\x30\x12\x08\x08\xb4\x01\x12\x03\x31\x38\x30\x12\x08\x08\xf0\x01\x12\x03\x32\x34\x30\x12\x08\x08\xac\x02\x12\x03\x33\x30\x30\x12\x08\x08\xe8\x02\x12\x03\x33\x36\x30\x12\x08\x08\xa4\x03\x12\x03\x34\x32\x30\x12\x08\x08\xe0\x03\x12\x03\x34\x38\x30\x12\x08\x08\x9c\x04\x12\x03\x35\x34\x30\x12\x08\x08\xd8\x04\x12\x03\x36\x30\x30\x12\t\x08\xb0\t\x12\x04\x31\x32\x30\x30\x12\t\x08\x88\x0e\x12\x04\x31\x38\x30\x30\x12\t\x08\xe0\x12\x12\x04\x32\x34\x30\x30\x12\t\x08\xb8\x17\x12\x04\x33\x30\x30\x30\x12\t\x08\x90\x1c\x12\x04\x33\x36\x30\x30\x12\t\x08\x98*\x12\x04\x35\x34\x30\x30\x12\t\x08\xa0\x38\x12\x04\x37\x32\x30\x30\x12\t\x08\xa8\x46\x12\x04\x39\x30\x30\x30\x12\n\x08\xb0T\x12\x05\x31\x30\x38\x30\x30\x12\n\x08\xc0p\x12\x05\x31\x34\x34\x30\x30\x12\x0b\x08\xd0\x8c\x01\x12\x05\x31\x38\x30\x30\x30\x12\x0b\x08\xe0\xa8\x01\x12\x05\x32\x31\x36\x30\x30\x18\x01\x12\xe9\x02\n%COUNTER_TO_BE_REMOVED_USETTLED_PDISKS\x10\x02\x1a\xbd\x02\x82\xd6\x1b\xb8\x02\n\x1aToBeRemovedUnsettledPDisks\x12\x05\x08\x00\x12\x01\x30\x12\x06\x08\n\x12\x02\x31\x30\x12\x06\x08\x14\x12\x02\x32\x30\x12\x06\x08\x1e\x12\x02\x33\x30\x12\x06\x08(\x12\x02\x34\x30\x12\x06\x08\x32\x12\x02\x35\x30\x12\x06\x08<\x12\x02\x36\x30\x12\x07\x08x\x12\x03\x31\x32\x30\x12\x08\x08\xb4\x01\x12\x03\x31\x38\x30\x12\x08\x08\xf0\x01\x12\x03\x32\x34\x30\x12\x08\x08\xac\x02\x12\x03\x33\x30\x30\x12\x08\x08\xe8\x02\x12\x03\x33\x36\x30\x12\x08\x08\xa4\x03\x12\x03\x34\x32\x30\x12\x08\x08\xe0\x03\x12\x03\x34\x38\x30\x12\x08\x08\x9c\x04\x12\x03\x35\x34\x30\x12\x08\x08\xd8\x04\x12\x03\x36\x30\x30\x12\t\x08\xb0\t\x12\x04\x31\x32\x30\x30\x12\t\x08\x88\x0e\x12\x04\x31\x38\x30\x30\x12\t\x08\xe0\x12\x12\x04\x32\x34\x30\x30\x12\t\x08\xb8\x17\x12\x04\x33\x30\x30\x30\x12\t\x08\x90\x1c\x12\x04\x33\x36\x30\x30\x12\t\x08\x98*\x12\x04\x35\x34\x30\x30\x12\t\x08\xa0\x38\x12\x04\x37\x32\x30\x30\x12\t\x08\xa8\x46\x12\x04\x39\x30\x30\x30\x12\n\x08\xb0T\x12\x05\x31\x30\x38\x30\x30\x12\n\x08\xc0p\x12\x05\x31\x34\x34\x30\x30\x12\x0b\x08\xd0\x8c\x01\x12\x05\x31\x38\x30\x30\x30\x12\x0b\x08\xe0\xa8\x01\x12\x05\x32\x31\x36\x30\x30\x18\x01\x12\xea\x01\n\x1c\x43OUNTER_NUM_NOT_READY_VDISKS\x10\x03\x1a\xc7\x01\x82\xd6\x1b\xc2\x01\n\x11NumNotReadyVDisks\x12\x05\x08\x00\x12\x01\x30\x12\x06\x08<\x12\x02\x36\x30\x12\x08\x08\xac\x02\x12\x03\x33\x30\x30\x12\x08\x08\xd8\x04\x12\x03\x36\x30\x30\x12\t\x08\xb0\t\x12\x04\x31\x32\x30\x30\x12\t\x08\x88\x0e\x12\x04\x31\x38\x30\x30\x12\t\x08\xe0\x12\x12\x04\x32\x34\x30\x30\x12\t\x08\xb8\x17\x12\x04\x33\x30\x30\x30\x12\t\x08\x90\x1c\x12\x04\x33\x36\x30\x30\x12\t\x08\x98*\x12\x04\x35\x34\x30\x30\x12\t\x08\xa0\x38\x12\x04\x37\x32\x30\x30\x12\t\x08\xa8\x46\x12\x04\x39\x30\x30\x30\x12\n\x08\xb0T\x12\x05\x31\x30\x38\x30\x30\x12\n\x08\xc0p\x12\x05\x31\x34\x34\x30\x30\x12\x0b\x08\xd0\x8c\x01\x12\x05\x31\x38\x30\x30\x30\x12\x0b\x08\xe0\xa8\x01\x12\x05\x32\x31\x36\x30\x30\x18\x01\x1a\xdb\x02\x92\xd6\x1b\xd6\x02\x12\x11\x08\xf4\x03\x12\x0c(1) < 500 us\x12\x11\x08\xe8\x07\x12\x0c(2) 0.5-1 ms\x12\x0f\x08\xd0\x0f\x12\n(3) 1-2 ms\x12\x0f\x08\xa0\x1f\x12\n(4) 2-4 ms\x12\x0f\x08\xc0>\x12\n(5) 4-8 ms\x12\x10\x08\x80}\x12\x0b(6) 8-16 ms\x12\x12\x08\x80\xfa\x01\x12\x0c(7) 16-32 ms\x12\x12\x08\x80\xf4\x03\x12\x0c(8) 32-64 ms\x12\x13\x08\x80\xe8\x07\x12\r(9) 64-128 ms\x12\x15\x08\x80\xd0\x0f\x12\x0f(10) 128-256 ms\x12\x15\x08\x80\xa0\x1f\x12\x0f(11) 256-512 ms\x12\x16\x08\x80\xc0>\x12\x10(12) 512-1024 ms\x12\x17\x08\x80\x89z\x12\x11(13) 1024-2000 ms\x12\x11\x08\x80\x92\xf4\x01\x12\n(14) 2-4 s\x12\x11\x08\x80\xa4\xe8\x03\x12\n(15) 4-8 s\x12\x12\x08\x80\xc8\xd0\x07\x12\x0b(16) 8-16 s\x12\x13\x08\x80\x90\xa1\x0f\x12\x0c(17) 16-32 s*\xec\x0b\n\x08\x45TxTypes\x12+\n\x12TXTYPE_INIT_SCHEME\x10\x00\x1a\x13\x8a\xd6\x1b\x0f\n\rTTxInitScheme\x12$\n\x0eTXTYPE_MIGRATE\x10\x01\x1a\x10\x8a\xd6\x1b\x0c\n\nTTxMigrate\x12\x33\n\x16TXTYPE_LOAD_EVERYTHING\x10\x02\x1a\x17\x8a\xd6\x1b\x13\n\x11TTxLoadEverything\x12\x42\n\x1eTXTYPE_MON_EVENT_OPERATION_LOG\x10\x03\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxMonEvent_OperationLog\x12\x38\n\x19TXTYPE_MON_EVENT_SET_DOWN\x10\x04\x1a\x19\x8a\xd6\x1b\x15\n\x13TTxMonEvent_SetDown\x12\x38\n\x19TXTYPE_MON_EVENT_GET_DOWN\x10\x05\x1a\x19\x8a\xd6\x1b\x15\n\x13TTxMonEvent_GetDown\x12:\n\x1aTXTYPE_UPDATE_DISK_METRICS\x10\x06\x1a\x1a\x8a\xd6\x1b\x16\n\x14TTxUpdateDiskMetrics\x12@\n\x1dTXTYPE_UPDATE_GROUP_LATENCIES\x10\x07\x1a\x1d\x8a\xd6\x1b\x19\n\x17TTxUpdateGroupLatencies\x12@\n\x1dTXTYPE_GROUP_RECONFIGURE_WIPE\x10\x08\x1a\x1d\x8a\xd6\x1b\x19\n\x17TTxGroupReconfigureWipe\x12+\n\x12TXTYPE_NODE_REPORT\x10\t\x1a\x13\x8a\xd6\x1b\x0f\n\rTTxNodeReport\x12\x42\n\x1eTXTYPE_UPDATE_SEEN_OPERATIONAL\x10\n\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxUpdateSeenOperational\x12)\n\x11TXTYPE_CONFIG_CMD\x10\x0b\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTTxConfigCmd\x12\x36\n\x18TXTYPE_PROPOSE_GROUP_KEY\x10\x0c\x1a\x18\x8a\xd6\x1b\x14\n\x12TTxProposeGroupKey\x12/\n\x14TXTYPE_REGISTER_NODE\x10\r\x1a\x15\x8a\xd6\x1b\x11\n\x0fTTxRegisterNode\x12\'\n\x10TXTYPE_GET_GROUP\x10\x0e\x1a\x11\x8a\xd6\x1b\r\n\x0bTTxGetGroup\x12\x42\n\x1eTXTYPE_REQUEST_CONTROLLER_INFO\x10\x0f\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxRequestControllerInfo\x12/\n\x14TXTYPE_SELECT_GROUPS\x10\x10\x1a\x15\x8a\xd6\x1b\x11\n\x0fTTxSelectGroups\x12\x42\n\x1eTXTYPE_MON_EVENT_HEALTH_EVENTS\x10\x11\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TTxMonEvent_HealthEvents\x12)\n\x11TXTYPE_DROP_DONOR\x10\x12\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTTxDropDonor\x12+\n\x12TXTYPE_SCRUB_START\x10\x13\x1a\x13\x8a\xd6\x1b\x0f\n\rTTxScrubStart\x12@\n\x1dTXTYPE_SCRUB_QUANTUM_FINISHED\x10\x14\x1a\x1d\x8a\xd6\x1b\x19\n\x17TTxScrubQuantumFinished\x12?\n\x1dTXTYPE_UPDATE_LAST_SEEN_READY\x10\x15\x1a\x1c\x8a\xd6\x1b\x18\n\x16TTxUpdateLastSeenReady\x12\x38\n\x19TXTYPE_UPDATE_NODE_DRIVES\x10\x16\x1a\x19\x8a\xd6\x1b\x15\n\x13TTxUpdateNodeDrives\x12M\n$TXTYPE_MON_EVENT_OPERATION_LOG_ENTRY\x10\x17\x1a#\x8a\xd6\x1b\x1f\n\x1dTTxMonEvent_OperationLogEntry\x12S\n\'TXTYPE_UPDATE_NODE_DISCONNECT_TIMESTAMP\x10\x18\x1a&\x8a\xd6\x1b\"\n TTxUpdateNodeDisconnectTimestamp\x12@\n\x1dTXTYPE_GROUP_METRICS_EXCHANGE\x10\x19\x1a\x1d\x8a\xd6\x1b\x19\n\x17TTxGroupMetricsExchangeB(\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x0c\x42SController')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_bs_controller_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\014BSController'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._serialized_options = b'\202\326\033\026\n\024ResponseTimeMicrosec'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_GROUPS_WITH_SLOTS_ON_FAULTY_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_GROUPS_WITH_SLOTS_ON_FAULTY_DISKS"]._serialized_options = b'\202\326\033\036\n\034GroupsWithSlotsOnFaultyDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SLOTS_ON_FAULTY_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SLOTS_ON_FAULTY_DISKS"]._serialized_options = b'\202\326\033\024\n\022SlotsOnFaultyDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_ON_FAULTY_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_ON_FAULTY_DISKS"]._serialized_options = b'\202\326\033\024\n\022BytesOnFaultyDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PDISKS_WITHOUT_EXPECTED_SLOT_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PDISKS_WITHOUT_EXPECTED_SLOT_COUNT"]._serialized_options = b'\202\326\033 \n\036PDisksWithoutExpectedSlotCount'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TO_BE_REMOVED_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TO_BE_REMOVED_DISKS"]._serialized_options = b'\202\326\033\022\n\020ToBeRemovedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_GROUPS_WITH_SLOTS_ON_TO_BE_REMOVED_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_GROUPS_WITH_SLOTS_ON_TO_BE_REMOVED_DISKS"]._serialized_options = b'\202\326\033#\n!GroupsWithSlotsOnToBeRemovedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SLOTS_ON_TO_BE_REMOVED_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SLOTS_ON_TO_BE_REMOVED_DISKS"]._serialized_options = b'\202\326\033\031\n\027SlotsOnToBeRemovedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_ON_TO_BE_REMOVED_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BYTES_ON_TO_BE_REMOVED_DISKS"]._serialized_options = b'\202\326\033\031\n\027BytesOnToBeRemovedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PDISKS_WITHOUT_EXPECTED_SERIAL"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PDISKS_WITHOUT_EXPECTED_SERIAL"]._serialized_options = b'\202\326\033\035\n\033PDisksWithoutExpectedSerial'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_NOT_SEEN"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_NOT_SEEN"]._serialized_options = b'\202\326\033\024\n\022DriveSerialNotSeen'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_REMOVED"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_REMOVED"]._serialized_options = b'\202\326\033\024\n\022DriveSerialRemoved'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_ERROR"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DRIVE_SERIAL_ERROR"]._serialized_options = b'\202\326\033\022\n\020DriveSerialError'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_WAITING_FOR_START"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_WAITING_FOR_START"]._serialized_options = b'\202\326\033\032\n\030DiskScrubWaitingForStart'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_RUNNING"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_RUNNING"]._serialized_options = b'\202\326\033\022\n\020DiskScrubRunning'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_IN_PROGRESS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_IN_PROGRESS"]._serialized_options = b'\202\326\033\025\n\023DiskScrubInProgress'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_FINISHED_OK"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_FINISHED_OK"]._serialized_options = b'\202\326\033\025\n\023DiskScrubFinishedOk'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_FINISHED_ERR"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_FINISHED_ERR"]._serialized_options = b'\202\326\033\026\n\024DiskScrubFinishedErr'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_CUR_DISKS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_CUR_DISKS"]._serialized_options = b'\202\326\033\030\n\026CurrentlyScrubbedDisks'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_CUR_GROUPS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_CUR_GROUPS"]._serialized_options = b'\202\326\033\031\n\027CurrentlyScrubbedGroups'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SELF_HEAL_UNREASSIGNABLE_GROUPS"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SELF_HEAL_UNREASSIGNABLE_GROUPS"]._serialized_options = b'\202\326\033\036\n\034SelfHealUnreassignableGroups'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REGISTER_NODE_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REGISTER_NODE_COUNT"]._serialized_options = b'\202\326\033\023\n\021RegisterNodeCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REGISTER_NODE_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REGISTER_NODE_USEC"]._serialized_options = b'\202\326\033\026\n\024RegisterNodeMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_GET_GROUP_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_GET_GROUP_COUNT"]._serialized_options = b'\202\326\033\017\n\rGetGroupCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_GET_GROUP_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_GET_GROUP_USEC"]._serialized_options = b'\202\326\033\022\n\020GetGroupMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELECT_GROUPS_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELECT_GROUPS_COUNT"]._serialized_options = b'\202\326\033\023\n\021SelectGroupsCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELECT_GROUPS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELECT_GROUPS_USEC"]._serialized_options = b'\202\326\033\026\n\024SelectGroupsMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPDATE_DISK_METRICS_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPDATE_DISK_METRICS_COUNT"]._serialized_options = b'\202\326\033\030\n\026UpdateDiskMetricsCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPDATE_DISK_METRICS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_UPDATE_DISK_METRICS_USEC"]._serialized_options = b'\202\326\033\033\n\031UpdateDiskMetricsMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_NODE_REPORT_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_NODE_REPORT_COUNT"]._serialized_options = b'\202\326\033\021\n\017NodeReportCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_NODE_REPORT_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_NODE_REPORT_USEC"]._serialized_options = b'\202\326\033\024\n\022NodeReportMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIG_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIG_COUNT"]._serialized_options = b'\202\326\033\r\n\013ConfigCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIG_USEC"]._serialized_options = b'\202\326\033\020\n\016ConfigMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQUEST_INFO_COUNT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQUEST_INFO_COUNT"]._serialized_options = b'\202\326\033\022\n\020RequestInfoCount'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQUEST_INFO_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQUEST_INFO_USEC"]._serialized_options = b'\202\326\033\025\n\023RequestInfoMicrosec'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_REQUESTS"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_REQUESTS"]._serialized_options = b'\202\326\033\035\n\033SelfHealReassignBscRequests'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_OK"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_OK"]._serialized_options = b'\202\326\033\027\n\025SelfHealReassignBscOk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_ERR"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SELFHEAL_REASSIGN_BSC_ERR"]._serialized_options = b'\202\326\033\030\n\026SelfHealReassignBscErr'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_HOST_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_HOST_CONFIG_USEC"]._serialized_options = b'\202\326\033\022\n\020DefineHostConfig'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_HOST_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_HOST_CONFIG_USEC"]._serialized_options = b'\202\326\033\020\n\016ReadHostConfig'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_HOST_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_HOST_CONFIG_USEC"]._serialized_options = b'\202\326\033\022\n\020DeleteHostConfig'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_BOX_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_BOX_USEC"]._serialized_options = b'\202\326\033\013\n\tDefineBox'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_BOX_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_BOX_USEC"]._serialized_options = b'\202\326\033\t\n\007ReadBox'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_BOX_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_BOX_USEC"]._serialized_options = b'\202\326\033\013\n\tDeleteBox'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_STORAGE_POOL_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DEFINE_STORAGE_POOL_USEC"]._serialized_options = b'\202\326\033\023\n\021DefineStoragePool'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_STORAGE_POOL_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_STORAGE_POOL_USEC"]._serialized_options = b'\202\326\033\021\n\017ReadStoragePool'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_STORAGE_POOL_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_STORAGE_POOL_USEC"]._serialized_options = b'\202\326\033\023\n\021DeleteStoragePool'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_UPDATE_DRIVE_STATUS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_UPDATE_DRIVE_STATUS_USEC"]._serialized_options = b'\202\326\033\023\n\021UpdateDriveStatus'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_DRIVE_STATUS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_DRIVE_STATUS_USEC"]._serialized_options = b'\202\326\033\021\n\017ReadDriveStatus'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_PROPOSE_STORAGE_POOLS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_PROPOSE_STORAGE_POOLS_USEC"]._serialized_options = b'\202\326\033\025\n\023ProposeStoragePools'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_QUERY_BASE_CONFIG_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_QUERY_BASE_CONFIG_USEC"]._serialized_options = b'\202\326\033\021\n\017QueryBaseConfig'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_MERGE_BOXES_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_MERGE_BOXES_USEC"]._serialized_options = b'\202\326\033\014\n\nMergeBoxes'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_MOVE_GROUPS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_MOVE_GROUPS_USEC"]._serialized_options = b'\202\326\033\014\n\nMoveGroups'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_ADD_MIGRATION_PLAN_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_ADD_MIGRATION_PLAN_USEC"]._serialized_options = b'\202\326\033\022\n\020AddMigrationPlan'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_MIGRATION_PLAN_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DELETE_MIGRATION_PLAN_USEC"]._serialized_options = b'\202\326\033\025\n\023DeleteMigrationPlan'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DECLARE_INTENT_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DECLARE_INTENT_USEC"]._serialized_options = b'\202\326\033\017\n\rDeclareIntent'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_INTENT_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_INTENT_USEC"]._serialized_options = b'\202\326\033\014\n\nReadIntent'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DROP_DONOR_DISK_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_DROP_DONOR_DISK_USEC"]._serialized_options = b'\202\326\033\017\n\rDropDonorDisk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_REASSIGN_GROUP_DISK_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_REASSIGN_GROUP_DISK_USEC"]._serialized_options = b'\202\326\033\023\n\021ReassignGroupDisk'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_QUANTUM_FINISHED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DISK_SCRUB_QUANTUM_FINISHED"]._serialized_options = b'\202\326\033\021\n\017QuantumFinished'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_SETTINGS_USEC"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_CONFIGCMD_READ_SETTINGS_USEC"]._serialized_options = b'\202\326\033\016\n\014ReadSettings'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\326\002\022\021\010\364\003\022\014(1) < 500 us\022\021\010\350\007\022\014(2) 0.5-1 ms\022\017\010\320\017\022\n(3) 1-2 ms\022\017\010\240\037\022\n(4) 2-4 ms\022\017\010\300>\022\n(5) 4-8 ms\022\020\010\200}\022\013(6) 8-16 ms\022\022\010\200\372\001\022\014(7) 16-32 ms\022\022\010\200\364\003\022\014(8) 32-64 ms\022\023\010\200\350\007\022\r(9) 64-128 ms\022\025\010\200\320\017\022\017(10) 128-256 ms\022\025\010\200\240\037\022\017(11) 256-512 ms\022\026\010\200\300>\022\020(12) 512-1024 ms\022\027\010\200\211z\022\021(13) 1024-2000 ms\022\021\010\200\222\364\001\022\n(14) 2-4 s\022\021\010\200\244\350\003\022\n(15) 4-8 s\022\022\010\200\310\320\007\022\013(16) 8-16 s\022\023\010\200\220\241\017\022\014(17) 16-32 s'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PERCENTILE_SELECT_GROUPS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_PERCENTILE_SELECT_GROUPS"]._serialized_options = b'\202\326\033\016\n\014SelectGroups'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_FAULTY_USETTLED_PDISKS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_FAULTY_USETTLED_PDISKS"]._serialized_options = b'\202\326\033\263\002\n\025FaultyUnsettledPDisks\022\005\010\000\022\0010\022\006\010\n\022\00210\022\006\010\024\022\00220\022\006\010\036\022\00230\022\006\010(\022\00240\022\006\0102\022\00250\022\006\010<\022\00260\022\007\010x\022\003120\022\010\010\264\001\022\003180\022\010\010\360\001\022\003240\022\010\010\254\002\022\003300\022\010\010\350\002\022\003360\022\010\010\244\003\022\003420\022\010\010\340\003\022\003480\022\010\010\234\004\022\003540\022\010\010\330\004\022\003600\022\t\010\260\t\022\0041200\022\t\010\210\016\022\0041800\022\t\010\340\022\022\0042400\022\t\010\270\027\022\0043000\022\t\010\220\034\022\0043600\022\t\010\230*\022\0045400\022\t\010\2408\022\0047200\022\t\010\250F\022\0049000\022\n\010\260T\022\00510800\022\n\010\300p\022\00514400\022\013\010\320\214\001\022\00518000\022\013\010\340\250\001\022\00521600\030\001'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_TO_BE_REMOVED_USETTLED_PDISKS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_TO_BE_REMOVED_USETTLED_PDISKS"]._serialized_options = b'\202\326\033\270\002\n\032ToBeRemovedUnsettledPDisks\022\005\010\000\022\0010\022\006\010\n\022\00210\022\006\010\024\022\00220\022\006\010\036\022\00230\022\006\010(\022\00240\022\006\0102\022\00250\022\006\010<\022\00260\022\007\010x\022\003120\022\010\010\264\001\022\003180\022\010\010\360\001\022\003240\022\010\010\254\002\022\003300\022\010\010\350\002\022\003360\022\010\010\244\003\022\003420\022\010\010\340\003\022\003480\022\010\010\234\004\022\003540\022\010\010\330\004\022\003600\022\t\010\260\t\022\0041200\022\t\010\210\016\022\0041800\022\t\010\340\022\022\0042400\022\t\010\270\027\022\0043000\022\t\010\220\034\022\0043600\022\t\010\230*\022\0045400\022\t\010\2408\022\0047200\022\t\010\250F\022\0049000\022\n\010\260T\022\00510800\022\n\010\300p\022\00514400\022\013\010\320\214\001\022\00518000\022\013\010\340\250\001\022\00521600\030\001'
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_NUM_NOT_READY_VDISKS"]._options = None
  _EPERCENTILECOUNTERS.values_by_name["COUNTER_NUM_NOT_READY_VDISKS"]._serialized_options = b'\202\326\033\302\001\n\021NumNotReadyVDisks\022\005\010\000\022\0010\022\006\010<\022\00260\022\010\010\254\002\022\003300\022\010\010\330\004\022\003600\022\t\010\260\t\022\0041200\022\t\010\210\016\022\0041800\022\t\010\340\022\022\0042400\022\t\010\270\027\022\0043000\022\t\010\220\034\022\0043600\022\t\010\230*\022\0045400\022\t\010\2408\022\0047200\022\t\010\250F\022\0049000\022\n\010\260T\022\00510800\022\n\010\300p\022\00514400\022\013\010\320\214\001\022\00518000\022\013\010\340\250\001\022\00521600\030\001'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEME"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEME"]._serialized_options = b'\212\326\033\017\n\rTTxInitScheme'
  _ETXTYPES.values_by_name["TXTYPE_MIGRATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MIGRATE"]._serialized_options = b'\212\326\033\014\n\nTTxMigrate'
  _ETXTYPES.values_by_name["TXTYPE_LOAD_EVERYTHING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOAD_EVERYTHING"]._serialized_options = b'\212\326\033\023\n\021TTxLoadEverything'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_OPERATION_LOG"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_OPERATION_LOG"]._serialized_options = b'\212\326\033\032\n\030TTxMonEvent_OperationLog'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_SET_DOWN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_SET_DOWN"]._serialized_options = b'\212\326\033\025\n\023TTxMonEvent_SetDown'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_GET_DOWN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_GET_DOWN"]._serialized_options = b'\212\326\033\025\n\023TTxMonEvent_GetDown'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DISK_METRICS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DISK_METRICS"]._serialized_options = b'\212\326\033\026\n\024TTxUpdateDiskMetrics'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_GROUP_LATENCIES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_GROUP_LATENCIES"]._serialized_options = b'\212\326\033\031\n\027TTxUpdateGroupLatencies'
  _ETXTYPES.values_by_name["TXTYPE_GROUP_RECONFIGURE_WIPE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GROUP_RECONFIGURE_WIPE"]._serialized_options = b'\212\326\033\031\n\027TTxGroupReconfigureWipe'
  _ETXTYPES.values_by_name["TXTYPE_NODE_REPORT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_NODE_REPORT"]._serialized_options = b'\212\326\033\017\n\rTTxNodeReport'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SEEN_OPERATIONAL"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_SEEN_OPERATIONAL"]._serialized_options = b'\212\326\033\032\n\030TTxUpdateSeenOperational'
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_CMD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_CMD"]._serialized_options = b'\212\326\033\016\n\014TTxConfigCmd'
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_GROUP_KEY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROPOSE_GROUP_KEY"]._serialized_options = b'\212\326\033\024\n\022TTxProposeGroupKey'
  _ETXTYPES.values_by_name["TXTYPE_REGISTER_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REGISTER_NODE"]._serialized_options = b'\212\326\033\021\n\017TTxRegisterNode'
  _ETXTYPES.values_by_name["TXTYPE_GET_GROUP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GET_GROUP"]._serialized_options = b'\212\326\033\r\n\013TTxGetGroup'
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_CONTROLLER_INFO"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_CONTROLLER_INFO"]._serialized_options = b'\212\326\033\032\n\030TTxRequestControllerInfo'
  _ETXTYPES.values_by_name["TXTYPE_SELECT_GROUPS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SELECT_GROUPS"]._serialized_options = b'\212\326\033\021\n\017TTxSelectGroups'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_HEALTH_EVENTS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_HEALTH_EVENTS"]._serialized_options = b'\212\326\033\032\n\030TTxMonEvent_HealthEvents'
  _ETXTYPES.values_by_name["TXTYPE_DROP_DONOR"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DROP_DONOR"]._serialized_options = b'\212\326\033\016\n\014TTxDropDonor'
  _ETXTYPES.values_by_name["TXTYPE_SCRUB_START"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SCRUB_START"]._serialized_options = b'\212\326\033\017\n\rTTxScrubStart'
  _ETXTYPES.values_by_name["TXTYPE_SCRUB_QUANTUM_FINISHED"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SCRUB_QUANTUM_FINISHED"]._serialized_options = b'\212\326\033\031\n\027TTxScrubQuantumFinished'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_LAST_SEEN_READY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_LAST_SEEN_READY"]._serialized_options = b'\212\326\033\030\n\026TTxUpdateLastSeenReady'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_NODE_DRIVES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_NODE_DRIVES"]._serialized_options = b'\212\326\033\025\n\023TTxUpdateNodeDrives'
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_OPERATION_LOG_ENTRY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_EVENT_OPERATION_LOG_ENTRY"]._serialized_options = b'\212\326\033\037\n\035TTxMonEvent_OperationLogEntry'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_NODE_DISCONNECT_TIMESTAMP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_NODE_DISCONNECT_TIMESTAMP"]._serialized_options = b'\212\326\033\"\n TTxUpdateNodeDisconnectTimestamp'
  _ETXTYPES.values_by_name["TXTYPE_GROUP_METRICS_EXCHANGE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_GROUP_METRICS_EXCHANGE"]._serialized_options = b'\212\326\033\031\n\027TTxGroupMetricsExchange'
  _ESIMPLECOUNTERS._serialized_start=113
  _ESIMPLECOUNTERS._serialized_end=1567
  _ECUMULATIVECOUNTERS._serialized_start=1570
  _ECUMULATIVECOUNTERS._serialized_end=4126
  _EPERCENTILECOUNTERS._serialized_start=4129
  _EPERCENTILECOUNTERS._serialized_end=5511
  _ETXTYPES._serialized_start=5514
  _ETXTYPES._serialized_end=7030
# @@protoc_insertion_point(module_scope)
