# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_replication.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ydb/core/protos/counters_replication.proto\x12\x14NKikimr.NReplication\x1a\x1eydb/core/protos/counters.proto*,\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00*4\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\xa8\x03\n\x08\x45TxTypes\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x00\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12\x1d\n\x0bTXTYPE_INIT\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12\x38\n\x19TXTYPE_CREATE_REPLICATION\x10\x02\x1a\x19\x8a\xd6\x1b\x15\n\x13TxCreateReplication\x12\x34\n\x17TXTYPE_DROP_REPLICATION\x10\x03\x1a\x17\x8a\xd6\x1b\x13\n\x11TxDropReplication\x12\x34\n\x17TXTYPE_DISCOVERY_RESULT\x10\x04\x1a\x17\x8a\xd6\x1b\x13\n\x11TxDiscoveryResult\x12\x37\n\x19TXTYPE_ASSIGN_STREAM_NAME\x10\x05\x1a\x18\x8a\xd6\x1b\x14\n\x12TxAssignStreamName\x12;\n\x1bTXTYPE_CREATE_STREAM_RESULT\x10\x06\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxCreateStreamResult\x12\x35\n\x18TXTYPE_CREATE_DST_RESULT\x10\x07\x1a\x17\x8a\xd6\x1b\x13\n\x11TxCreateDstResultB1\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x15ReplicationController')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_replication_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\025ReplicationController'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_REPLICATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_REPLICATION"]._serialized_options = b'\212\326\033\025\n\023TxCreateReplication'
  _ETXTYPES.values_by_name["TXTYPE_DROP_REPLICATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DROP_REPLICATION"]._serialized_options = b'\212\326\033\023\n\021TxDropReplication'
  _ETXTYPES.values_by_name["TXTYPE_DISCOVERY_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DISCOVERY_RESULT"]._serialized_options = b'\212\326\033\023\n\021TxDiscoveryResult'
  _ETXTYPES.values_by_name["TXTYPE_ASSIGN_STREAM_NAME"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ASSIGN_STREAM_NAME"]._serialized_options = b'\212\326\033\024\n\022TxAssignStreamName'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_STREAM_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_STREAM_RESULT"]._serialized_options = b'\212\326\033\026\n\024TxCreateStreamResult'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_DST_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_DST_RESULT"]._serialized_options = b'\212\326\033\023\n\021TxCreateDstResult'
  _ESIMPLECOUNTERS._serialized_start=100
  _ESIMPLECOUNTERS._serialized_end=144
  _ECUMULATIVECOUNTERS._serialized_start=146
  _ECUMULATIVECOUNTERS._serialized_end=198
  _EPERCENTILECOUNTERS._serialized_start=200
  _EPERCENTILECOUNTERS._serialized_end=278
  _ETXTYPES._serialized_start=281
  _ETXTYPES._serialized_end=705
# @@protoc_insertion_point(module_scope)
