# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/kqp.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import type_info_pb2 as ydb_dot_core_dot_protos_dot_type__info__pb2
from ydb.core.protos import kqp_physical_pb2 as ydb_dot_core_dot_protos_dot_kqp__physical__pb2
from ydb.core.protos import kqp_stats_pb2 as ydb_dot_core_dot_protos_dot_kqp__stats__pb2
from ydb.core.protos import query_stats_pb2 as ydb_dot_core_dot_protos_dot_query__stats__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_table_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__table__pb2
from ydb.public.api.protos import ydb_value_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__value__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_topic_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__topic__pb2
from ydb.library.mkql_proto.protos import minikql_pb2 as ydb_dot_library_dot_mkql__proto_dot_protos_dot_minikql__pb2
from ydb.library.yql.dq.actors.protos import dq_events_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__events__pb2
from ydb.library.yql.dq.actors.protos import dq_stats_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_actors_dot_protos_dot_dq__stats__pb2
from ydb.library.yql.dq.proto import dq_tasks_pb2 as ydb_dot_library_dot_yql_dot_dq_dot_proto_dot_dq__tasks__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19ydb/core/protos/kqp.proto\x12\nNKikimrKqp\x1a&library/cpp/actors/protos/actors.proto\x1a\x1fydb/core/protos/type_info.proto\x1a\"ydb/core/protos/kqp_physical.proto\x1a\x1fydb/core/protos/kqp_stats.proto\x1a!ydb/core/protos/query_stats.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a%ydb/public/api/protos/ydb_table.proto\x1a%ydb/public/api/protos/ydb_value.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a%ydb/public/api/protos/ydb_topic.proto\x1a+ydb/library/mkql_proto/protos/minikql.proto\x1a\x30ydb/library/yql/dq/actors/protos/dq_events.proto\x1a/ydb/library/yql/dq/actors/protos/dq_stats.proto\x1a\'ydb/library/yql/dq/proto/dq_tasks.proto\"l\n\x10TTopicOperations\x12\x10\n\x08\x43onsumer\x18\x01 \x01(\t\x12\x46\n\x06Topics\x18\x02 \x03(\x0b\x32\x36.Ydb.Topic.AddOffsetsToTransactionRequest.TopicOffsets\"\x8e\x06\n\rTQueryRequest\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\x12\r\n\x05Query\x18\x02 \x01(\t\x12$\n\x04Type\x18\x03 \x01(\x0e\x32\x16.NKikimrKqp.EQueryType\x12\x13\n\x0bKeepSession\x18\x05 \x01(\x08\x12+\n\nParameters\x18\x07 \x01(\x0b\x32\x17.NKikimrMiniKQL.TParams\x12(\n\x06\x41\x63tion\x18\t \x01(\x0e\x32\x18.NKikimrKqp.EQueryAction\x12\x15\n\rPreparedQuery\x18\x0b \x01(\x0c\x12\x15\n\nReplyFlags\x18\x0c \x01(\r:\x01\x31\x12\x30\n\tTxControl\x18\r \x01(\x0b\x32\x1d.Ydb.Table.TransactionControl\x12\x10\n\x08\x44\x61tabase\x18\x0e \x01(\t\x12\x35\n\x10QueryCachePolicy\x18\x0f \x01(\x0b\x32\x1b.Ydb.Table.QueryCachePolicy\x12\x15\n\rCancelAfterMs\x18\x10 \x01(\x04\x12\x11\n\tTimeoutMs\x18\x11 \x01(\x04\x12.\n\tStatsMode\x18\x14 \x01(\x0e\x32\x1b.NYql.NDqProto.EDqStatsMode\x12:\n\x0c\x43ollectStats\x18\x15 \x01(\x0e\x32$.Ydb.Table.QueryStatsCollection.Mode\x12\x35\n\x0fTopicOperations\x18\x16 \x01(\x0b\x32\x1c.NKikimrKqp.TTopicOperations\x12#\n\x1bUsePublicResponseDataFormat\x18\x17 \x01(\x08\x12\x43\n\rYdbParameters\x18\x18 \x03(\x0b\x32,.NKikimrKqp.TQueryRequest.YdbParametersEntry\x1a\x45\n\x12YdbParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01J\x04\x08\x04\x10\x05J\x04\x08\x06\x10\x07J\x04\x08\x08\x10\tJ\x04\x08\n\x10\x0bJ\x04\x08\x12\x10\x13J\x04\x08\x13\x10\x14\"3\n\x0fTKqpPathIdProto\x12\x0f\n\x07OwnerId\x18\x01 \x01(\r\x12\x0f\n\x07TableId\x18\x02 \x01(\r\"\xad\x01\n\x16TIndexDescriptionProto\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\r\n\x05State\x18\x03 \x01(\r\x12\x15\n\rSchemaVersion\x18\x04 \x01(\r\x12\x13\n\x0bLocalPathId\x18\x05 \x01(\r\x12\x13\n\x0bPathOwnerId\x18\x06 \x01(\r\x12\x12\n\nKeyColumns\x18\x07 \x03(\t\x12\x13\n\x0b\x44\x61taColumns\x18\x08 \x03(\t\"\xa4\x01\n\x17TKqpColumnMetadataProto\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\n\n\x02Id\x18\x02 \x01(\r\x12\x0c\n\x04Type\x18\x03 \x01(\t\x12\x0e\n\x06TypeId\x18\x04 \x01(\r\x12)\n\x08TypeInfo\x18\x07 \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x12\x0e\n\x06\x46\x61mily\x18\x05 \x03(\t\x12\x16\n\x07NotNull\x18\x06 \x01(\x08:\x05\x66\x61lse\"\xf1\x03\n\x16TKqpTableMetadataProto\x12\x11\n\tDoesExist\x18\x01 \x01(\x08\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x0f\n\x07SysView\x18\x04 \x01(\t\x12+\n\x06PathId\x18\x05 \x01(\x0b\x32\x1b.NKikimrKqp.TKqpPathIdProto\x12\x15\n\rSchemaVersion\x18\x06 \x01(\r\x12\x0c\n\x04Kind\x18\x07 \x01(\r\x12\x46\n\nAttributes\x18\x08 \x03(\x0b\x32\x32.NKikimrKqp.TKqpTableMetadataProto.TAttributeProto\x12\x34\n\x07\x43olumns\x18\t \x03(\x0b\x32#.NKikimrKqp.TKqpColumnMetadataProto\x12\x16\n\x0eKeyColunmNames\x18\n \x03(\t\x12\x33\n\x07Indexes\x18\x0b \x03(\x0b\x32\".NKikimrKqp.TIndexDescriptionProto\x12H\n\x1cSecondaryGlobalIndexMetadata\x18\x0c \x03(\x0b\x32\".NKikimrKqp.TKqpTableMetadataProto\x1a-\n\x0fTAttributeProto\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"9\n\x07TRlPath\x12\x18\n\x10\x43oordinationNode\x18\x01 \x01(\t\x12\x14\n\x0cResourcePath\x18\x02 \x01(\t\"\xd9\x02\n\x0fTEvQueryRequest\x12*\n\x07Request\x18\x01 \x01(\x0b\x32\x19.NKikimrKqp.TQueryRequest\x12\x0f\n\x07TraceId\x18\x02 \x01(\t\x12\x11\n\tUserToken\x18\x03 \x01(\t\x12.\n\x0eRequestActorId\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x13\n\x0bRequestType\x18\x05 \x01(\t\x12#\n\x06RlPath\x18\x06 \x01(\x0b\x32\x13.NKikimrKqp.TRlPath\x12,\n\x0bQueryIssues\x18\x07 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12,\n\tYdbStatus\x18\x08 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x30\n\x10\x43\x61ncelationActor\x18\t \x01(\x0b\x32\x16.NActorsProto.TActorId\"K\n\x0cTMkqlProfile\x12\r\n\x05Query\x18\x01 \x01(\t\x12,\n\x07TxStats\x18\x02 \x01(\x0b\x32\x1b.NKikimrQueryStats.TTxStats\"\xd4\x01\n\x11TTransformProfile\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x1b\n\x13TransformDurationUs\x18\x02 \x01(\x04\x12\x16\n\x0eWaitDurationUs\x18\x03 \x01(\x04\x12\x14\n\x0cNewExprNodes\x18\x04 \x01(\x05\x12\x14\n\x0cNewTypeNodes\x18\x05 \x01(\x05\x12\x0f\n\x07Repeats\x18\x06 \x01(\r\x12\x10\n\x08Restarts\x18\x07 \x01(\r\x12-\n\x06Stages\x18\x64 \x03(\x0b\x32\x1d.NKikimrKqp.TTransformProfile\"\xc1\x01\n\x0bTKqlProfile\x12\r\n\x05Query\x18\x01 \x01(\t\x12.\n\x0cMkqlProfiles\x18\x02 \x03(\x0b\x32\x18.NKikimrKqp.TMkqlProfile\x12<\n\x17\x45\x66\x66\x65\x63tiveIsolationLevel\x18\x03 \x01(\x0e\x32\x1b.NKikimrKqp.EIsolationLevel\x12\x35\n\x0eTransformStats\x18\x04 \x01(\x0b\x32\x1d.NKikimrKqp.TTransformProfile\"t\n\rTQueryProfile\x12,\n\x0bKqlProfiles\x18\x01 \x03(\x0b\x32\x17.NKikimrKqp.TKqlProfile\x12\x35\n\x0eTransformStats\x18\x02 \x01(\x0b\x32\x1d.NKikimrKqp.TTransformProfile\"I\n\x11TParameterBinding\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x11\n\tMkqlIndex\x18\x02 \x01(\r\x12\x13\n\x0bResultIndex\x18\x03 \x01(\r\"`\n\x0fTPreparedResult\x12\x10\n\x08KqlIndex\x18\x01 \x01(\r\x12\x13\n\x0bResultIndex\x18\x02 \x01(\r\x12\x13\n\x0b\x43olumnHints\x18\x03 \x03(\t\x12\x11\n\tRowsLimit\x18\x04 \x01(\x04\"J\n\x15TParameterDescription\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12#\n\x04Type\x18\x02 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\"\xa3\x02\n\x0eTPreparedQuery\x12\x0f\n\x07Version\x18\x01 \x01(\r\x12,\n\x07Results\x18\x03 \x03(\x0b\x32\x1b.NKikimrKqp.TPreparedResult\x12\x35\n\nParameters\x18\x04 \x03(\x0b\x32!.NKikimrKqp.TParameterDescription\x12\x0c\n\x04Text\x18\x05 \x01(\t\x12.\n\rPhysicalQuery\x18\x06 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyQuery\"W\n\x08\x45Version\x12\x17\n\x13VERSION_UNSPECIFIED\x10\x00\x12\x19\n\x15VERSION_V1_DEPRECATED\x10\x01\x12\x17\n\x13VERSION_PHYSICAL_V1\x10\x0bJ\x04\x08\x02\x10\x03\"\x84\x03\n\x0eTQueryResponse\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\x12(\n\x07Results\x18\x03 \x03(\x0b\x32\x17.NKikimrMiniKQL.TResult\x12\x15\n\rPreparedQuery\x18\x05 \x01(\x0c\x12\x10\n\x08QueryAst\x18\x06 \x01(\t\x12,\n\x0bQueryIssues\x18\x08 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x11\n\tQueryPlan\x18\t \x01(\x0c\x12:\n\x0fQueryParameters\x18\n \x03(\x0b\x32!.NKikimrKqp.TParameterDescription\x12*\n\x06TxMeta\x18\x0b \x01(\x0b\x32\x1a.Ydb.Table.TransactionMeta\x12-\n\nQueryStats\x18\x0c \x01(\x0b\x32\x19.NKqpProto.TKqpStatsQuery\x12\"\n\nYdbResults\x18\r \x03(\x0b\x32\x0e.Ydb.ResultSetJ\x04\x08\x02\x10\x03J\x04\x08\x04\x10\x05J\x04\x08\x07\x10\x08\"\xb4\x01\n\x10TEvQueryResponse\x12,\n\x08Response\x18\x03 \x01(\x0b\x32\x1a.NKikimrKqp.TQueryResponse\x12,\n\tYdbStatus\x18\x04 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x12\n\nConsumedRu\x18\x06 \x01(\x04\x12\x1e\n\x0fWorkerIsClosing\x18\x07 \x01(\x08:\x05\x66\x61lseJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06\")\n\x14TCloseSessionRequest\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\"\\\n\x16TEvCloseSessionRequest\x12\x31\n\x07Request\x18\x01 \x01(\x0b\x32 .NKikimrKqp.TCloseSessionRequest\x12\x0f\n\x07TraceId\x18\x02 \x01(\t\":\n\x15TCloseSessionResponse\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\x12\x0e\n\x06\x43losed\x18\x02 \x01(\x08\"\xa2\x01\n\x17TEvCloseSessionResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x33\n\x08Response\x18\x03 \x01(\x0b\x32!.NKikimrKqp.TCloseSessionResponse\"w\n\x12TEvProcessResponse\x12\r\n\x05\x45rror\x18\x02 \x01(\x0c\x12,\n\tYdbStatus\x18\x03 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x1e\n\x0fWorkerIsClosing\x18\x04 \x01(\x08:\x05\x66\x61lseJ\x04\x08\x01\x10\x02\"*\n\x0bTKqpSetting\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\r\n\x05Value\x18\x02 \x02(\t\"G\n\x13TKqpDefaultSettings\x12\x30\n\x0f\x44\x65\x66\x61ultSettings\x18\x01 \x03(\x0b\x32\x17.NKikimrKqp.TKqpSetting\")\n\x15TCreateSessionRequest\x12\x10\n\x08\x44\x61tabase\x18\x01 \x01(\t\"\xbb\x01\n\x17TEvCreateSessionRequest\x12\x32\n\x07Request\x18\x01 \x01(\x0b\x32!.NKikimrKqp.TCreateSessionRequest\x12\x0f\n\x07TraceId\x18\x02 \x01(\t\x12\x12\n\nDeadlineUs\x18\x03 \x01(\x04\x12%\n\x16\x43\x61nCreateRemoteSession\x18\x04 \x01(\x08:\x05\x66\x61lse\x12 \n\x11SupportsBalancing\x18\x05 \x01(\x08:\x05\x66\x61lse\"+\n\x16TCreateSessionResponse\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\"\xb5\x01\n\x18TEvCreateSessionResponse\x12\r\n\x05\x45rror\x18\x02 \x01(\x0c\x12\x34\n\x08Response\x18\x03 \x01(\x0b\x32\".NKikimrKqp.TCreateSessionResponse\x12,\n\tYdbStatus\x18\x04 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12 \n\x11ResourceExhausted\x18\x05 \x01(\x08:\x05\x66\x61lseJ\x04\x08\x01\x10\x02\"A\n\x13TPingSessionRequest\x12\x11\n\tSessionId\x18\x01 \x01(\x0c\x12\x17\n\tTimeoutMs\x18\x02 \x01(\r:\x04\x35\x30\x30\x30\"Z\n\x15TEvPingSessionRequest\x12\x30\n\x07Request\x18\x01 \x01(\x0b\x32\x1f.NKikimrKqp.TPingSessionRequest\x12\x0f\n\x07TraceId\x18\x02 \x01(\t\"w\n\x14TPingSessionResponse\x12?\n\rSessionStatus\x18\x01 \x01(\x0e\x32(.Ydb.Table.KeepAliveResult.SessionStatus\x12\x1e\n\x0fWorkerIsClosing\x18\x02 \x01(\x08:\x05\x66\x61lse\"\xc0\x01\n\x16TEvPingSessionResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x32\n\x08Response\x18\x03 \x01(\x0b\x32 .NKikimrKqp.TPingSessionResponse\x12\x1e\n\x0fWorkerIsClosing\x18\x04 \x01(\x08:\x05\x66\x61lse\"r\n\x16TEvDataQueryStreamPart\x12.\n\x0eGatewayActorId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x07Results\x18\x02 \x03(\x0b\x32\x17.NKikimrMiniKQL.TResult\"\"\n\x12TExecuterTxRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\x93\x01\n\x14TEvExecuterTxRequest\x12/\n\x07Request\x18\x01 \x01(\x0b\x32\x1e.NKikimrKqp.TExecuterTxRequest\x12&\n\x06Target\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0f\n\x07TraceId\x18\x03 \x01(\t\x12\x11\n\tUserToken\x18\x04 \x01(\t\"~\n\x11TExecuterTxResult\x12&\n\x05Locks\x18\x04 \x01(\x0b\x32\x17.NKikimrMiniKQL.TResult\x12/\n\x05Stats\x18\x06 \x01(\x0b\x32 .NYql.NDqProto.TDqExecutionStatsJ\x04\x08\x03\x10\x04J\x04\x08\x05\x10\x06J\x04\x08\x07\x10\x08\"\x98\x01\n\x13TExecuterTxResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12-\n\x06Result\x18\x03 \x01(\x0b\x32\x1d.NKikimrKqp.TExecuterTxResult\"J\n\x15TEvExecuterTxResponse\x12\x31\n\x08Response\x18\x01 \x01(\x0b\x32\x1f.NKikimrKqp.TExecuterTxResponse\"I\n\x15TEvExecuterStreamData\x12!\n\tResultSet\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\"S\n\x18TEvExecuterStreamDataAck\x12\r\n\x05SeqNo\x18\x01 \x01(\x04\x12\x11\n\tFreeSpace\x18\x02 \x01(\x03\x12\x15\n\x06\x45nough\x18\x03 \x01(\x08:\x05\x66\x61lse\"S\n\x18TEvExecuterStreamProfile\x12\x31\n\x07Profile\x18\x02 \x01(\x0b\x32 .NYql.NDqProto.TDqExecutionStatsJ\x04\x08\x01\x10\x02\"F\n\x13TEvExecuterProgress\x12/\n\x0f\x45xecuterActorId\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\"\x96\x01\n\x16TKqpProxyNodeResources\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x17\n\x0f\x44\x61taCenterNumId\x18\x02 \x01(\x04\x12\x1a\n\x12\x41\x63tiveWorkersCount\x18\x03 \x01(\r\x12\x14\n\x0c\x44\x61taCenterId\x18\x04 \x01(\t\x12\x10\n\x08\x43puUsage\x18\x05 \x01(\x01\x12\x0f\n\x07Threads\x18\x06 \x01(\r\"*\n\x0cTKqpSnapshot\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"\xef\x01\n\x14TEvStartComputeTasks\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12%\n\x05Tasks\x18\x02 \x03(\x0b\x32\x16.NYql.NDqProto.TDqTask\x12?\n\x0fRuntimeSettings\x18\x04 \x01(\x0b\x32&.NYql.NDqProto.TComputeRuntimeSettings\x12/\n\x0f\x45xecuterActorId\x18\x05 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12*\n\x08Snapshot\x18\x08 \x01(\x0b\x32\x18.NKikimrKqp.TKqpSnapshotJ\x04\x08\x03\x10\x04\"\xa8\x02\n\x1bTEvStartComputeTasksFailure\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12?\n\x06Reason\x18\x02 \x01(\x0e\x32/.NKikimrKqp.TEvStartComputeTasksFailure.EReason\x12\x0f\n\x07Message\x18\x03 \x01(\t\"\xa8\x01\n\x07\x45Reason\x12\x19\n\x15MEMORY_LIMIT_EXCEEDED\x10\x01\x12\x15\n\x11NOT_ENOUGH_MEMORY\x10\x02\x12!\n\x1d\x43OMPUTE_ACTORS_LIMIT_EXCEEDED\x10\x03\x12\x1d\n\x19NOT_ENOUGH_COMPUTE_ACTORS\x10\x04\x12\x1a\n\x16REQUEST_ALREADY_EXISTS\x10\x05\x12\r\n\tNOT_READY\x10\x06\"\xb6\x01\n\x16TEvStartedComputeTasks\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x45\n\x0cStartedTasks\x18\x02 \x03(\x0b\x32/.NKikimrKqp.TEvStartedComputeTasks.TStartedTask\x1aG\n\x0cTStartedTask\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12\'\n\x07\x41\x63torId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\"N\n\x15TEvCancelComputeTasks\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"\x8a\x02\n\x17TEvStartKqpTasksRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12%\n\x05Tasks\x18\x02 \x03(\x0b\x32\x16.NYql.NDqProto.TDqTask\x12?\n\x0fRuntimeSettings\x18\x03 \x01(\x0b\x32&.NYql.NDqProto.TComputeRuntimeSettings\x12/\n\x0f\x45xecuterActorId\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12*\n\x08Snapshot\x18\x05 \x01(\x0b\x32\x18.NKikimrKqp.TKqpSnapshot\x12\x1c\n\x0eStartAllOrFail\x18\x06 \x01(\x08:\x04true\"\xb9\x04\n\x18TEvStartKqpTasksResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12G\n\x0cStartedTasks\x18\x02 \x03(\x0b\x32\x31.NKikimrKqp.TEvStartKqpTasksResponse.TStartedTask\x12M\n\x0fNotStartedTasks\x18\x03 \x03(\x0b\x32\x34.NKikimrKqp.TEvStartKqpTasksResponse.TNotStartedTask\x1aG\n\x0cTStartedTask\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12\'\n\x07\x41\x63torId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x1a~\n\x0fTNotStartedTask\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12J\n\x06Reason\x18\x02 \x01(\x0e\x32:.NKikimrKqp.TEvStartKqpTasksResponse.ENotStartedTaskReason\x12\x0f\n\x07Message\x18\x03 \x01(\t\"\xad\x01\n\x15\x45NotStartedTaskReason\x12\x15\n\x11NOT_ENOUGH_MEMORY\x10\x01\x12\x1e\n\x1aNOT_ENOUGH_EXECUTION_UNITS\x10\x02\x12\x1f\n\x1bQUERY_MEMORY_LIMIT_EXCEEDED\x10\x03\x12(\n$QUERY_EXECUTION_UNITS_LIMIT_EXCEEDED\x10\x04\x12\x12\n\x0eINTERNAL_ERROR\x10\x05\"8\n\x18TEvCancelKqpTasksRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06Reason\x18\x02 \x01(\t\"\x1b\n\x19TEvCancelKqpTasksResponse\"\xd1\x03\n\x11TKqpNodeResources\x12\x36\n\x16ResourceManagerActorId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x1e\n\x16\x41vailableComputeActors\x18\x04 \x01(\r\x12\x12\n\nUsedMemory\x18\x05 \x01(\x04\x12\x13\n\x0bTotalMemory\x18\x07 \x01(\x04\x12@\n\x0cTransactions\x18\x06 \x03(\x0b\x32*.NKikimrKqp.TKqpNodeResources.TTxResources\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x11\n\tTimestamp\x18\x03 \x01(\r\x12\x35\n\x06Memory\x18\x08 \x03(\x0b\x32%.NKikimrKqp.TKqpNodeResources.TMemory\x12\x16\n\x0e\x45xecutionUnits\x18\t \x01(\r\x1a[\n\x0cTTxResources\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x15\n\rComputeActors\x18\x02 \x01(\r\x12\x0e\n\x06Memory\x18\x03 \x01(\x04\x12\x16\n\x0eStartTimestamp\x18\x04 \x01(\r\x1a*\n\x07TMemory\x12\x0c\n\x04Pool\x18\x01 \x01(\r\x12\x11\n\tAvailable\x18\x02 \x01(\x04\"c\n\x10TEvScanInitActor\x12\x0e\n\x06ScanId\x18\x01 \x01(\x04\x12+\n\x0bScanActorId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x12\n\nGeneration\x18\x03 \x01(\r\"v\n\x0cTEvScanError\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x12\n\nGeneration\x18\x03 \x01(\r\"\xa3\x02\n\x11TEvRemoteScanData\x12\x0e\n\x06ScanId\x18\x01 \x01(\r\x12\x11\n\tCpuTimeUs\x18\x02 \x01(\x04\x12\x12\n\nWaitTimeMs\x18\x03 \x01(\x04\x12\x12\n\nPageFaults\x18\x04 \x01(\r\x12\x11\n\tPageFault\x18\x05 \x01(\x08\x12\x10\n\x08\x46inished\x18\x06 \x01(\x08\x12\x0f\n\x07LastKey\x18\x07 \x01(\x0c\x12\x12\n\nGeneration\x18\t \x01(\r\x12\x0c\n\x04Rows\x18\x08 \x03(\x0c\x12=\n\nArrowBatch\x18\n \x01(\x0b\x32).NKikimrKqp.TEvRemoteScanData.TArrowBatch\x1a,\n\x0bTArrowBatch\x12\x0e\n\x06Schema\x18\x01 \x01(\x0c\x12\r\n\x05\x42\x61tch\x18\x02 \x01(\x0c\"=\n\x14TEvRemoteScanDataAck\x12\x11\n\tFreeSpace\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\"\xc2\x02\n\x11TEvRemoteCostData\x12\x0e\n\x06ScanId\x18\x01 \x01(\r\x12\x39\n\x08\x43ostInfo\x18\x02 \x01(\x0b\x32\'.NKikimrKqp.TEvRemoteCostData.TCostInfo\x1aK\n\rTIntervalMeta\x12\x1e\n\x0fIntervalSkipped\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1a\n\x0cMarkIncluded\x18\x02 \x01(\x08:\x04true\x1a\x94\x01\n\tTCostInfo\x12\x41\n\x0cIntervalMeta\x18\x01 \x03(\x0b\x32+.NKikimrKqp.TEvRemoteCostData.TIntervalMeta\x12\x18\n\x10LeftBorderOpened\x18\x02 \x01(\x08\x12\x13\n\x0b\x43olumnsData\x18\x03 \x01(\x0c\x12\x15\n\rColumnsSchema\x18\x04 \x01(\x0c\"\x13\n\x11TEvKillScanTablet\"\xba\x01\n\x18TKqpStreamLookupSettings\x12&\n\x05Table\x18\x01 \x01(\x0b\x32\x17.NKqpProto.TKqpPhyTable\x12\x12\n\nKeyColumns\x18\x02 \x03(\t\x12\x0f\n\x07\x43olumns\x18\x03 \x03(\t\x12*\n\x08Snapshot\x18\x04 \x01(\x0b\x32\x18.NKikimrKqp.TKqpSnapshot\x12\x10\n\x08LockTxId\x18\x05 \x01(\x04\x12\x13\n\x0bImmediateTx\x18\x06 \x01(\x08*o\n\x0c\x45RequestType\x12\x1e\n\x1aREQUEST_TYPE_PROCESS_QUERY\x10\x01\x12\x1e\n\x1aREQUEST_TYPE_CLOSE_SESSION\x10\x02\x12\x1f\n\x1bREQUEST_TYPE_CREATE_SESSION\x10\x03*\xa9\x02\n\nEQueryType\x12\x18\n\x14QUERY_TYPE_UNDEFINED\x10\x00\x12\x16\n\x12QUERY_TYPE_SQL_DML\x10\x04\x12\x16\n\x12QUERY_TYPE_SQL_DDL\x10\x05\x12\x1b\n\x17QUERY_TYPE_PREPARED_DML\x10\x06\x12\x16\n\x12QUERY_TYPE_AST_DML\x10\x07\x12\x19\n\x15QUERY_TYPE_SQL_SCRIPT\x10\x08\x12\x17\n\x13QUERY_TYPE_SQL_SCAN\x10\t\x12\x17\n\x13QUERY_TYPE_AST_SCAN\x10\n\x12#\n\x1fQUERY_TYPE_SQL_SCRIPT_STREAMING\x10\x0b\x12\x18\n\x14QUERY_TYPE_SQL_QUERY\x10\x0c\"\x04\x08\x01\x10\x01\"\x04\x08\x02\x10\x02\"\x04\x08\x03\x10\x03*\x9f\x02\n\x0c\x45QueryAction\x12\x18\n\x14QUERY_ACTION_EXECUTE\x10\x01\x12\x18\n\x14QUERY_ACTION_EXPLAIN\x10\x02\x12\x19\n\x15QUERY_ACTION_VALIDATE\x10\x03\x12\x18\n\x14QUERY_ACTION_PREPARE\x10\x04\x12!\n\x1dQUERY_ACTION_EXECUTE_PREPARED\x10\x05\x12\x19\n\x15QUERY_ACTION_BEGIN_TX\x10\x06\x12\x1a\n\x16QUERY_ACTION_COMMIT_TX\x10\x07\x12\x1c\n\x18QUERY_ACTION_ROLLBACK_TX\x10\x08\x12\x16\n\x12QUERY_ACTION_PARSE\x10\t\x12\x16\n\x12QUERY_ACTION_TOPIC\x10\n*\xbc\x01\n\x0f\x45IsolationLevel\x12\x1d\n\x19ISOLATION_LEVEL_UNDEFINED\x10\x00\x12 \n\x1cISOLATION_LEVEL_SERIALIZABLE\x10\x01\x12\"\n\x1eISOLATION_LEVEL_READ_COMMITTED\x10\x02\x12$\n ISOLATION_LEVEL_READ_UNCOMMITTED\x10\x03\x12\x1e\n\x1aISOLATION_LEVEL_READ_STALE\x10\x04*e\n\x10\x45QueryReplyFlags\x12\x1c\n\x18QUERY_REPLY_FLAG_RESULTS\x10\x01\x12\x19\n\x15QUERY_REPLY_FLAG_PLAN\x10\x02\x12\x18\n\x14QUERY_REPLY_FLAG_AST\x10\x04\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.kqp_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TQUERYREQUEST_YDBPARAMETERSENTRY._options = None
  _TQUERYREQUEST_YDBPARAMETERSENTRY._serialized_options = b'8\001'
  _EREQUESTTYPE._serialized_start=10561
  _EREQUESTTYPE._serialized_end=10672
  _EQUERYTYPE._serialized_start=10675
  _EQUERYTYPE._serialized_end=10972
  _EQUERYACTION._serialized_start=10975
  _EQUERYACTION._serialized_end=11262
  _EISOLATIONLEVEL._serialized_start=11265
  _EISOLATIONLEVEL._serialized_end=11453
  _EQUERYREPLYFLAGS._serialized_start=11455
  _EQUERYREPLYFLAGS._serialized_end=11556
  _TTOPICOPERATIONS._serialized_start=613
  _TTOPICOPERATIONS._serialized_end=721
  _TQUERYREQUEST._serialized_start=724
  _TQUERYREQUEST._serialized_end=1506
  _TQUERYREQUEST_YDBPARAMETERSENTRY._serialized_start=1401
  _TQUERYREQUEST_YDBPARAMETERSENTRY._serialized_end=1470
  _TKQPPATHIDPROTO._serialized_start=1508
  _TKQPPATHIDPROTO._serialized_end=1559
  _TINDEXDESCRIPTIONPROTO._serialized_start=1562
  _TINDEXDESCRIPTIONPROTO._serialized_end=1735
  _TKQPCOLUMNMETADATAPROTO._serialized_start=1738
  _TKQPCOLUMNMETADATAPROTO._serialized_end=1902
  _TKQPTABLEMETADATAPROTO._serialized_start=1905
  _TKQPTABLEMETADATAPROTO._serialized_end=2402
  _TKQPTABLEMETADATAPROTO_TATTRIBUTEPROTO._serialized_start=2357
  _TKQPTABLEMETADATAPROTO_TATTRIBUTEPROTO._serialized_end=2402
  _TRLPATH._serialized_start=2404
  _TRLPATH._serialized_end=2461
  _TEVQUERYREQUEST._serialized_start=2464
  _TEVQUERYREQUEST._serialized_end=2809
  _TMKQLPROFILE._serialized_start=2811
  _TMKQLPROFILE._serialized_end=2886
  _TTRANSFORMPROFILE._serialized_start=2889
  _TTRANSFORMPROFILE._serialized_end=3101
  _TKQLPROFILE._serialized_start=3104
  _TKQLPROFILE._serialized_end=3297
  _TQUERYPROFILE._serialized_start=3299
  _TQUERYPROFILE._serialized_end=3415
  _TPARAMETERBINDING._serialized_start=3417
  _TPARAMETERBINDING._serialized_end=3490
  _TPREPAREDRESULT._serialized_start=3492
  _TPREPAREDRESULT._serialized_end=3588
  _TPARAMETERDESCRIPTION._serialized_start=3590
  _TPARAMETERDESCRIPTION._serialized_end=3664
  _TPREPAREDQUERY._serialized_start=3667
  _TPREPAREDQUERY._serialized_end=3958
  _TPREPAREDQUERY_EVERSION._serialized_start=3865
  _TPREPAREDQUERY_EVERSION._serialized_end=3952
  _TQUERYRESPONSE._serialized_start=3961
  _TQUERYRESPONSE._serialized_end=4349
  _TEVQUERYRESPONSE._serialized_start=4352
  _TEVQUERYRESPONSE._serialized_end=4532
  _TCLOSESESSIONREQUEST._serialized_start=4534
  _TCLOSESESSIONREQUEST._serialized_end=4575
  _TEVCLOSESESSIONREQUEST._serialized_start=4577
  _TEVCLOSESESSIONREQUEST._serialized_end=4669
  _TCLOSESESSIONRESPONSE._serialized_start=4671
  _TCLOSESESSIONRESPONSE._serialized_end=4729
  _TEVCLOSESESSIONRESPONSE._serialized_start=4732
  _TEVCLOSESESSIONRESPONSE._serialized_end=4894
  _TEVPROCESSRESPONSE._serialized_start=4896
  _TEVPROCESSRESPONSE._serialized_end=5015
  _TKQPSETTING._serialized_start=5017
  _TKQPSETTING._serialized_end=5059
  _TKQPDEFAULTSETTINGS._serialized_start=5061
  _TKQPDEFAULTSETTINGS._serialized_end=5132
  _TCREATESESSIONREQUEST._serialized_start=5134
  _TCREATESESSIONREQUEST._serialized_end=5175
  _TEVCREATESESSIONREQUEST._serialized_start=5178
  _TEVCREATESESSIONREQUEST._serialized_end=5365
  _TCREATESESSIONRESPONSE._serialized_start=5367
  _TCREATESESSIONRESPONSE._serialized_end=5410
  _TEVCREATESESSIONRESPONSE._serialized_start=5413
  _TEVCREATESESSIONRESPONSE._serialized_end=5594
  _TPINGSESSIONREQUEST._serialized_start=5596
  _TPINGSESSIONREQUEST._serialized_end=5661
  _TEVPINGSESSIONREQUEST._serialized_start=5663
  _TEVPINGSESSIONREQUEST._serialized_end=5753
  _TPINGSESSIONRESPONSE._serialized_start=5755
  _TPINGSESSIONRESPONSE._serialized_end=5874
  _TEVPINGSESSIONRESPONSE._serialized_start=5877
  _TEVPINGSESSIONRESPONSE._serialized_end=6069
  _TEVDATAQUERYSTREAMPART._serialized_start=6071
  _TEVDATAQUERYSTREAMPART._serialized_end=6185
  _TEXECUTERTXREQUEST._serialized_start=6187
  _TEXECUTERTXREQUEST._serialized_end=6221
  _TEVEXECUTERTXREQUEST._serialized_start=6224
  _TEVEXECUTERTXREQUEST._serialized_end=6371
  _TEXECUTERTXRESULT._serialized_start=6373
  _TEXECUTERTXRESULT._serialized_end=6499
  _TEXECUTERTXRESPONSE._serialized_start=6502
  _TEXECUTERTXRESPONSE._serialized_end=6654
  _TEVEXECUTERTXRESPONSE._serialized_start=6656
  _TEVEXECUTERTXRESPONSE._serialized_end=6730
  _TEVEXECUTERSTREAMDATA._serialized_start=6732
  _TEVEXECUTERSTREAMDATA._serialized_end=6805
  _TEVEXECUTERSTREAMDATAACK._serialized_start=6807
  _TEVEXECUTERSTREAMDATAACK._serialized_end=6890
  _TEVEXECUTERSTREAMPROFILE._serialized_start=6892
  _TEVEXECUTERSTREAMPROFILE._serialized_end=6975
  _TEVEXECUTERPROGRESS._serialized_start=6977
  _TEVEXECUTERPROGRESS._serialized_end=7047
  _TKQPPROXYNODERESOURCES._serialized_start=7050
  _TKQPPROXYNODERESOURCES._serialized_end=7200
  _TKQPSNAPSHOT._serialized_start=7202
  _TKQPSNAPSHOT._serialized_end=7244
  _TEVSTARTCOMPUTETASKS._serialized_start=7247
  _TEVSTARTCOMPUTETASKS._serialized_end=7486
  _TEVSTARTCOMPUTETASKSFAILURE._serialized_start=7489
  _TEVSTARTCOMPUTETASKSFAILURE._serialized_end=7785
  _TEVSTARTCOMPUTETASKSFAILURE_EREASON._serialized_start=7617
  _TEVSTARTCOMPUTETASKSFAILURE_EREASON._serialized_end=7785
  _TEVSTARTEDCOMPUTETASKS._serialized_start=7788
  _TEVSTARTEDCOMPUTETASKS._serialized_end=7970
  _TEVSTARTEDCOMPUTETASKS_TSTARTEDTASK._serialized_start=7899
  _TEVSTARTEDCOMPUTETASKS_TSTARTEDTASK._serialized_end=7970
  _TEVCANCELCOMPUTETASKS._serialized_start=7972
  _TEVCANCELCOMPUTETASKS._serialized_end=8050
  _TEVSTARTKQPTASKSREQUEST._serialized_start=8053
  _TEVSTARTKQPTASKSREQUEST._serialized_end=8319
  _TEVSTARTKQPTASKSRESPONSE._serialized_start=8322
  _TEVSTARTKQPTASKSRESPONSE._serialized_end=8891
  _TEVSTARTKQPTASKSRESPONSE_TSTARTEDTASK._serialized_start=7899
  _TEVSTARTKQPTASKSRESPONSE_TSTARTEDTASK._serialized_end=7970
  _TEVSTARTKQPTASKSRESPONSE_TNOTSTARTEDTASK._serialized_start=8589
  _TEVSTARTKQPTASKSRESPONSE_TNOTSTARTEDTASK._serialized_end=8715
  _TEVSTARTKQPTASKSRESPONSE_ENOTSTARTEDTASKREASON._serialized_start=8718
  _TEVSTARTKQPTASKSRESPONSE_ENOTSTARTEDTASKREASON._serialized_end=8891
  _TEVCANCELKQPTASKSREQUEST._serialized_start=8893
  _TEVCANCELKQPTASKSREQUEST._serialized_end=8949
  _TEVCANCELKQPTASKSRESPONSE._serialized_start=8951
  _TEVCANCELKQPTASKSRESPONSE._serialized_end=8978
  _TKQPNODERESOURCES._serialized_start=8981
  _TKQPNODERESOURCES._serialized_end=9446
  _TKQPNODERESOURCES_TTXRESOURCES._serialized_start=9311
  _TKQPNODERESOURCES_TTXRESOURCES._serialized_end=9402
  _TKQPNODERESOURCES_TMEMORY._serialized_start=9404
  _TKQPNODERESOURCES_TMEMORY._serialized_end=9446
  _TEVSCANINITACTOR._serialized_start=9448
  _TEVSCANINITACTOR._serialized_end=9547
  _TEVSCANERROR._serialized_start=9549
  _TEVSCANERROR._serialized_end=9667
  _TEVREMOTESCANDATA._serialized_start=9670
  _TEVREMOTESCANDATA._serialized_end=9961
  _TEVREMOTESCANDATA_TARROWBATCH._serialized_start=9917
  _TEVREMOTESCANDATA_TARROWBATCH._serialized_end=9961
  _TEVREMOTESCANDATAACK._serialized_start=9963
  _TEVREMOTESCANDATAACK._serialized_end=10024
  _TEVREMOTECOSTDATA._serialized_start=10027
  _TEVREMOTECOSTDATA._serialized_end=10349
  _TEVREMOTECOSTDATA_TINTERVALMETA._serialized_start=10123
  _TEVREMOTECOSTDATA_TINTERVALMETA._serialized_end=10198
  _TEVREMOTECOSTDATA_TCOSTINFO._serialized_start=10201
  _TEVREMOTECOSTDATA_TCOSTINFO._serialized_end=10349
  _TEVKILLSCANTABLET._serialized_start=10351
  _TEVKILLSCANTABLET._serialized_end=10370
  _TKQPSTREAMLOOKUPSETTINGS._serialized_start=10373
  _TKQPSTREAMLOOKUPSETTINGS._serialized_end=10559
# @@protoc_insertion_point(module_scope)
