# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blob_depot_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ydb/core/protos/blob_depot_config.proto\x12\x10NKikimrBlobDepot\"2\n\x0cTChannelKind\"\"\n\x01\x45\x12\n\n\x06System\x10\x00\x12\x08\n\x04\x44\x61ta\x10\x01\x12\x07\n\x03Log\x10\x02\"\x89\x01\n\x0fTChannelProfile\x12\x17\n\x0fStoragePoolName\x18\x01 \x01(\t\x12\x17\n\x0fStoragePoolKind\x18\x02 \x01(\t\x12\r\n\x05\x43ount\x18\x03 \x01(\r\x12\x35\n\x0b\x43hannelKind\x18\x04 \x01(\x0e\x32 .NKikimrBlobDepot.TChannelKind.E\"\x83\x01\n\x10TBlobDepotConfig\x12:\n\x0f\x43hannelProfiles\x18\x01 \x03(\x0b\x32!.NKikimrBlobDepot.TChannelProfile\x12\x16\n\x0eVirtualGroupId\x18\x02 \x01(\r\x12\x1b\n\x13IsDecommittingGroup\x18\x03 \x01(\x08')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blob_depot_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TCHANNELKIND._serialized_start=61
  _TCHANNELKIND._serialized_end=111
  _TCHANNELKIND_E._serialized_start=77
  _TCHANNELKIND_E._serialized_end=111
  _TCHANNELPROFILE._serialized_start=114
  _TCHANNELPROFILE._serialized_end=251
  _TBLOBDEPOTCONFIG._serialized_start=254
  _TBLOBDEPOTCONFIG._serialized_end=385
# @@protoc_insertion_point(module_scope)
