# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_sequenceshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/core/protos/tx_sequenceshard.proto\x12\x16NKikimrTxSequenceShard\x1a\x1aydb/core/protos/base.proto\"R\n\x16TEvMarkSchemeShardPipe\x12\x15\n\rSchemeShardId\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\r\n\x05Round\x18\x03 \x01(\x04\"\xc4\x02\n\x11TEvCreateSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\x12\x12\n\x08MinValue\x18\x04 \x01(\x12H\x00\x12\x12\n\x08MaxValue\x18\x05 \x01(\x12H\x01\x12\x14\n\nStartValue\x18\x06 \x01(\x12H\x02\x12\x0f\n\x05\x43\x61\x63he\x18\x07 \x01(\x04H\x03\x12\x13\n\tIncrement\x18\x08 \x01(\x12H\x04\x12\x0f\n\x05\x43ycle\x18\t \x01(\x08H\x05\x42\x12\n\x10OptionalMinValueB\x12\n\x10OptionalMaxValueB\x14\n\x12OptionalStartValueB\x0f\n\rOptionalCacheB\x13\n\x11OptionalIncrementB\x0f\n\rOptionalCycle\"\xe7\x01\n\x17TEvCreateSequenceResult\x12G\n\x06Status\x18\x01 \x01(\x0e\x32\x37.NKikimrTxSequenceShard.TEvCreateSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\"S\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x1b\n\x17SEQUENCE_ALREADY_EXISTS\x10\x03\"K\n\x13TEvAllocateSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\r\n\x05\x43\x61\x63he\x18\x02 \x01(\x04\"\xe7\x02\n\x19TEvAllocateSequenceResult\x12I\n\x06Status\x18\x01 \x01(\x0e\x32\x39.NKikimrTxSequenceShard.TEvAllocateSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x17\n\x0f\x41llocationStart\x18\x03 \x01(\x12\x12\x17\n\x0f\x41llocationCount\x18\x04 \x01(\x04\x12\x1b\n\x13\x41llocationIncrement\x18\x05 \x01(\x12\x12\x0f\n\x07MovedTo\x18\x06 \x01(\x04\"\x8e\x01\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\x12\x13\n\x0fSEQUENCE_FROZEN\x10\x04\x12\x12\n\x0eSEQUENCE_MOVED\x10\x05\x12\x15\n\x11SEQUENCE_OVERFLOW\x10\x06\"X\n\x0fTEvDropSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\"\xde\x01\n\x15TEvDropSequenceResult\x12\x45\n\x06Status\x18\x01 \x01(\x0e\x32\x35.NKikimrTxSequenceShard.TEvDropSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\"N\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\"\x86\x03\n\x11TEvUpdateSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\x12\x12\n\x08MinValue\x18\x04 \x01(\x12H\x00\x12\x12\n\x08MaxValue\x18\x05 \x01(\x12H\x01\x12\x14\n\nStartValue\x18\x06 \x01(\x12H\x02\x12\x13\n\tNextValue\x18\x07 \x01(\x12H\x03\x12\x12\n\x08NextUsed\x18\x08 \x01(\x08H\x04\x12\x0f\n\x05\x43\x61\x63he\x18\t \x01(\x04H\x05\x12\x13\n\tIncrement\x18\n \x01(\x12H\x06\x12\x0f\n\x05\x43ycle\x18\x0b \x01(\x08H\x07\x42\x10\n\x0e\x43hangeMinValueB\x10\n\x0e\x43hangeMaxValueB\x12\n\x10\x43hangeStartValueB\x11\n\x0f\x43hangeNextValueB\x10\n\x0e\x43hangeNextUsedB\r\n\x0b\x43hangeCacheB\x11\n\x0f\x43hangeIncrementB\r\n\x0b\x43hangeCycle\"\x9c\x02\n\x17TEvUpdateSequenceResult\x12G\n\x06Status\x18\x01 \x01(\x0e\x32\x37.NKikimrTxSequenceShard.TEvUpdateSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\x12\x0f\n\x07MovedTo\x18\x05 \x01(\x04\"w\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\x12\x13\n\x0fSEQUENCE_FROZEN\x10\x04\x12\x12\n\x0eSEQUENCE_MOVED\x10\x05\"Z\n\x11TEvFreezeSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\"\x95\x03\n\x17TEvFreezeSequenceResult\x12G\n\x06Status\x18\x01 \x01(\x0e\x32\x37.NKikimrTxSequenceShard.TEvFreezeSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\x12\x0f\n\x07MovedTo\x18\x05 \x01(\x04\x12\x10\n\x08MinValue\x18\x06 \x01(\x12\x12\x10\n\x08MaxValue\x18\x07 \x01(\x12\x12\x12\n\nStartValue\x18\x08 \x01(\x12\x12\x11\n\tNextValue\x18\t \x01(\x12\x12\x10\n\x08NextUsed\x18\n \x01(\x08\x12\r\n\x05\x43\x61\x63he\x18\x0b \x01(\x04\x12\x11\n\tIncrement\x18\x0c \x01(\x12\x12\r\n\x05\x43ycle\x18\r \x01(\x08\"b\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\x12\x12\n\x0eSEQUENCE_MOVED\x10\x04\"\xe9\x01\n\x12TEvRestoreSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\x12\x10\n\x08MinValue\x18\x04 \x01(\x12\x12\x10\n\x08MaxValue\x18\x05 \x01(\x12\x12\x12\n\nStartValue\x18\x06 \x01(\x12\x12\x11\n\tNextValue\x18\x07 \x01(\x12\x12\x10\n\x08NextUsed\x18\x08 \x01(\x08\x12\r\n\x05\x43\x61\x63he\x18\t \x01(\x04\x12\x11\n\tIncrement\x18\n \x01(\x12\x12\r\n\x05\x43ycle\x18\x0b \x01(\x08\"\xe9\x01\n\x18TEvRestoreSequenceResult\x12H\n\x06Status\x18\x01 \x01(\x0e\x32\x38.NKikimrTxSequenceShard.TEvRestoreSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\"S\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x1b\n\x17SEQUENCE_ALREADY_ACTIVE\x10\x03\"p\n\x13TEvRedirectSequence\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TxPartId\x18\x03 \x01(\x04\x12\x12\n\nRedirectTo\x18\x04 \x01(\x04\"\xe6\x01\n\x19TEvRedirectSequenceResult\x12I\n\x06Status\x18\x01 \x01(\x0e\x32\x39.NKikimrTxSequenceShard.TEvRedirectSequenceResult.EStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x10\n\x08TxPartId\x18\x04 \x01(\x04\"N\n\x07\x45Status\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x11\n\rPIPE_OUTDATED\x10\x02\x12\x16\n\x12SEQUENCE_NOT_FOUND\x10\x03\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_sequenceshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TEVMARKSCHEMESHARDPIPE._serialized_start=94
  _TEVMARKSCHEMESHARDPIPE._serialized_end=176
  _TEVCREATESEQUENCE._serialized_start=179
  _TEVCREATESEQUENCE._serialized_end=503
  _TEVCREATESEQUENCERESULT._serialized_start=506
  _TEVCREATESEQUENCERESULT._serialized_end=737
  _TEVCREATESEQUENCERESULT_ESTATUS._serialized_start=654
  _TEVCREATESEQUENCERESULT_ESTATUS._serialized_end=737
  _TEVALLOCATESEQUENCE._serialized_start=739
  _TEVALLOCATESEQUENCE._serialized_end=814
  _TEVALLOCATESEQUENCERESULT._serialized_start=817
  _TEVALLOCATESEQUENCERESULT._serialized_end=1176
  _TEVALLOCATESEQUENCERESULT_ESTATUS._serialized_start=1034
  _TEVALLOCATESEQUENCERESULT_ESTATUS._serialized_end=1176
  _TEVDROPSEQUENCE._serialized_start=1178
  _TEVDROPSEQUENCE._serialized_end=1266
  _TEVDROPSEQUENCERESULT._serialized_start=1269
  _TEVDROPSEQUENCERESULT._serialized_end=1491
  _TEVDROPSEQUENCERESULT_ESTATUS._serialized_start=1034
  _TEVDROPSEQUENCERESULT_ESTATUS._serialized_end=1112
  _TEVUPDATESEQUENCE._serialized_start=1494
  _TEVUPDATESEQUENCE._serialized_end=1884
  _TEVUPDATESEQUENCERESULT._serialized_start=1887
  _TEVUPDATESEQUENCERESULT._serialized_end=2171
  _TEVUPDATESEQUENCERESULT_ESTATUS._serialized_start=1034
  _TEVUPDATESEQUENCERESULT_ESTATUS._serialized_end=1153
  _TEVFREEZESEQUENCE._serialized_start=2173
  _TEVFREEZESEQUENCE._serialized_end=2263
  _TEVFREEZESEQUENCERESULT._serialized_start=2266
  _TEVFREEZESEQUENCERESULT._serialized_end=2671
  _TEVFREEZESEQUENCERESULT_ESTATUS._serialized_start=2573
  _TEVFREEZESEQUENCERESULT_ESTATUS._serialized_end=2671
  _TEVRESTORESEQUENCE._serialized_start=2674
  _TEVRESTORESEQUENCE._serialized_end=2907
  _TEVRESTORESEQUENCERESULT._serialized_start=2910
  _TEVRESTORESEQUENCERESULT._serialized_end=3143
  _TEVRESTORESEQUENCERESULT_ESTATUS._serialized_start=3060
  _TEVRESTORESEQUENCERESULT_ESTATUS._serialized_end=3143
  _TEVREDIRECTSEQUENCE._serialized_start=3145
  _TEVREDIRECTSEQUENCE._serialized_end=3257
  _TEVREDIRECTSEQUENCERESULT._serialized_start=3260
  _TEVREDIRECTSEQUENCERESULT._serialized_end=3490
  _TEVREDIRECTSEQUENCERESULT_ESTATUS._serialized_start=1034
  _TEVREDIRECTSEQUENCERESULT_ESTATUS._serialized_end=1112
# @@protoc_insertion_point(module_scope)
