# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tablet_counters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/tablet_counters.proto\x12\x11NKikimrTabletBase\"3\n\x14TTabletSimpleCounter\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x04\"7\n\x18TTabletCumulativeCounter\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\x04\"H\n\x18TTabletPercentileCounter\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06Ranges\x18\x02 \x03(\t\x12\x0e\n\x06Values\x18\x03 \x03(\x04\"\xe8\x01\n\x13TTabletCountersBase\x12?\n\x0eSimpleCounters\x18\x01 \x03(\x0b\x32\'.NKikimrTabletBase.TTabletSimpleCounter\x12G\n\x12\x43umulativeCounters\x18\x02 \x03(\x0b\x32+.NKikimrTabletBase.TTabletCumulativeCounter\x12G\n\x12PercentileCounters\x18\x03 \x03(\x0b\x32+.NKikimrTabletBase.TTabletPercentileCounter\"\x90\x01\n\x0fTTabletCounters\x12@\n\x10\x45xecutorCounters\x18\x01 \x01(\x0b\x32&.NKikimrTabletBase.TTabletCountersBase\x12;\n\x0b\x41ppCounters\x18\x02 \x01(\x0b\x32&.NKikimrTabletBase.TTabletCountersBaseB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tablet_counters_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TTABLETSIMPLECOUNTER._serialized_start=60
  _TTABLETSIMPLECOUNTER._serialized_end=111
  _TTABLETCUMULATIVECOUNTER._serialized_start=113
  _TTABLETCUMULATIVECOUNTER._serialized_end=168
  _TTABLETPERCENTILECOUNTER._serialized_start=170
  _TTABLETPERCENTILECOUNTER._serialized_end=242
  _TTABLETCOUNTERSBASE._serialized_start=245
  _TTABLETCOUNTERSBASE._serialized_end=477
  _TTABLETCOUNTERS._serialized_start=480
  _TTABLETCOUNTERS._serialized_end=624
# @@protoc_insertion_point(module_scope)
