# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: library/cpp/actors/protos/interconnect.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,library/cpp/actors/protos/interconnect.proto\x12\x13NActorsInterconnect\x1a&library/cpp/actors/protos/actors.proto\x1a google/protobuf/descriptor.proto\"2\n\x0eTEvResolveNode\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x10\n\x08\x44\x65\x61\x64line\x18\x02 \x01(\x04\"<\n\x0bTEvNodeInfo\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0f\n\x07\x41\x64\x64ress\x18\x02 \x01(\t\x12\x0c\n\x04Port\x18\x03 \x01(\r\"\xda\x01\n\rTNodeLocation\x12\x19\n\rDataCenterNum\x18\x01 \x01(\rB\x02\x18\x01\x12\x13\n\x07RoomNum\x18\x02 \x01(\rB\x02\x18\x01\x12\x13\n\x07RackNum\x18\x03 \x01(\rB\x02\x18\x01\x12\x13\n\x07\x42odyNum\x18\x04 \x01(\rB\x02\x18\x01\x12\x12\n\x04\x42ody\x18\x94\x91\x06 \x01(\rB\x02\x18\x01\x12\x1a\n\nDataCenter\x18\n \x01(\tB\x06\xc2\xcc\x18\x02\x44\x43\x12\x15\n\x06Module\x18\x14 \x01(\tB\x05\xc2\xcc\x18\x01M\x12\x13\n\x04Rack\x18\x1e \x01(\tB\x05\xc2\xcc\x18\x01R\x12\x13\n\x04Unit\x18( \x01(\tB\x05\xc2\xcc\x18\x01U\"8\n\rTClusterUUIDs\x12\x13\n\x0b\x43lusterUUID\x18\x01 \x01(\t\x12\x12\n\nAcceptUUID\x18\x02 \x03(\t\"\"\n\x08TScopeId\x12\n\n\x02X1\x18\x01 \x01(\x06\x12\n\n\x02X2\x18\x02 \x01(\x06\"\x9c\x04\n\x11THandshakeRequest\x12\x10\n\x08Protocol\x18\x01 \x02(\x04\x12\x12\n\nProgramPID\x18\x02 \x02(\x04\x12\x18\n\x10ProgramStartTime\x18\x03 \x02(\x04\x12\x0e\n\x06Serial\x18\x04 \x02(\x04\x12\x16\n\x0eReceiverNodeId\x18\x05 \x02(\r\x12\x15\n\rSenderActorId\x18\x06 \x02(\t\x12\x16\n\x0eSenderHostName\x18\x07 \x01(\t\x12\x18\n\x10ReceiverHostName\x18\x08 \x01(\t\x12\x0c\n\x04UUID\x18\t \x01(\t\x12\x38\n\x0c\x43lusterUUIDs\x18\r \x01(\x0b\x32\".NActorsInterconnect.TClusterUUIDs\x12\x0f\n\x07\x42\x61llast\x18\n \x01(\x0c\x12\x12\n\nVersionTag\x18\x0b \x01(\t\x12\x1b\n\x13\x41\x63\x63\x65ptedVersionTags\x18\x0c \x03(\t\x12\x19\n\x11RequireEncryption\x18\x0e \x01(\x08\x12\x34\n\rClientScopeId\x18\x0f \x01(\x0b\x32\x1d.NActorsInterconnect.TScopeId\x12\x0e\n\x06\x43ookie\x18\x10 \x01(\t\x12\x15\n\rDoCheckCookie\x18\x11 \x01(\x08\x12\x1a\n\x12RequestModernFrame\x18\x12 \x01(\x08\x12\x17\n\x0fRequestAuthOnly\x18\x13 \x01(\x08\x12\x1f\n\x17RequestExtendedTraceFmt\x18\x14 \x01(\x08\"\xfb\x02\n\x11THandshakeSuccess\x12\x10\n\x08Protocol\x18\x01 \x02(\x04\x12\x12\n\nProgramPID\x18\x02 \x02(\x04\x12\x18\n\x10ProgramStartTime\x18\x03 \x02(\x04\x12\x0e\n\x06Serial\x18\x04 \x02(\x04\x12\x15\n\rSenderActorId\x18\x05 \x02(\t\x12\x12\n\nVersionTag\x18\x06 \x01(\t\x12\x1b\n\x13\x41\x63\x63\x65ptedVersionTags\x18\x07 \x03(\t\x12\x38\n\x0c\x43lusterUUIDs\x18\x08 \x01(\x0b\x32\".NActorsInterconnect.TClusterUUIDs\x12\x17\n\x0fStartEncryption\x18\t \x01(\x08\x12\x34\n\rServerScopeId\x18\n \x01(\x0b\x32\x1d.NActorsInterconnect.TScopeId\x12\x16\n\x0eUseModernFrame\x18\x0b \x01(\x08\x12\x10\n\x08\x41uthOnly\x18\x0c \x01(\x08\x12\x1b\n\x13UseExtendedTraceFmt\x18\r \x01(\x08\"\x80\x01\n\x0fTHandshakeReply\x12\x37\n\x07Success\x18\x01 \x01(\x0b\x32&.NActorsInterconnect.THandshakeSuccess\x12\x19\n\x11\x45rrorExplaination\x18\x02 \x01(\t\x12\x19\n\x11\x43ookieCheckResult\x18\x03 \x01(\x08\"\x96\x01\n\x0eTEvLoadMessage\x12\x36\n\x04Hops\x18\x01 \x03(\x0b\x32(.NActorsInterconnect.TEvLoadMessage.THop\x12\n\n\x02Id\x18\x03 \x01(\t\x12\x0f\n\x07Payload\x18\x04 \x01(\x0c\x1a/\n\x04THop\x12\'\n\x07NextHop\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId:2\n\tPrintName\x12\x1d.google.protobuf.FieldOptions\x18\xc8\x89\x03 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'library.cpp.actors.protos.interconnect_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(PrintName)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TNODELOCATION.fields_by_name['DataCenterNum']._options = None
  _TNODELOCATION.fields_by_name['DataCenterNum']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['RoomNum']._options = None
  _TNODELOCATION.fields_by_name['RoomNum']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['RackNum']._options = None
  _TNODELOCATION.fields_by_name['RackNum']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['BodyNum']._options = None
  _TNODELOCATION.fields_by_name['BodyNum']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['Body']._options = None
  _TNODELOCATION.fields_by_name['Body']._serialized_options = b'\030\001'
  _TNODELOCATION.fields_by_name['DataCenter']._options = None
  _TNODELOCATION.fields_by_name['DataCenter']._serialized_options = b'\302\314\030\002DC'
  _TNODELOCATION.fields_by_name['Module']._options = None
  _TNODELOCATION.fields_by_name['Module']._serialized_options = b'\302\314\030\001M'
  _TNODELOCATION.fields_by_name['Rack']._options = None
  _TNODELOCATION.fields_by_name['Rack']._serialized_options = b'\302\314\030\001R'
  _TNODELOCATION.fields_by_name['Unit']._options = None
  _TNODELOCATION.fields_by_name['Unit']._serialized_options = b'\302\314\030\001U'
  _TEVRESOLVENODE._serialized_start=143
  _TEVRESOLVENODE._serialized_end=193
  _TEVNODEINFO._serialized_start=195
  _TEVNODEINFO._serialized_end=255
  _TNODELOCATION._serialized_start=258
  _TNODELOCATION._serialized_end=476
  _TCLUSTERUUIDS._serialized_start=478
  _TCLUSTERUUIDS._serialized_end=534
  _TSCOPEID._serialized_start=536
  _TSCOPEID._serialized_end=570
  _THANDSHAKEREQUEST._serialized_start=573
  _THANDSHAKEREQUEST._serialized_end=1113
  _THANDSHAKESUCCESS._serialized_start=1116
  _THANDSHAKESUCCESS._serialized_end=1495
  _THANDSHAKEREPLY._serialized_start=1498
  _THANDSHAKEREPLY._serialized_end=1626
  _TEVLOADMESSAGE._serialized_start=1629
  _TEVLOADMESSAGE._serialized_end=1779
  _TEVLOADMESSAGE_THOP._serialized_start=1732
  _TEVLOADMESSAGE_THOP._serialized_end=1779
# @@protoc_insertion_point(module_scope)
