# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/health.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/health.proto\x12\rNKikimrHealth\"\"\n\x04TRaw\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x04\"\x7f\n\tTPathLeaf\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\r\n\x05SetAt\x18\x02 \x01(\x04\x12/\n\rPreviousValue\x18\x03 \x01(\x0b\x32\x18.NKikimrHealth.TPathLeaf\x12$\n\x05\x43olor\x18\x04 \x01(\x0e\x32\x15.NKikimrHealth.EColor\"\x81\x01\n\tTPathNode\x12 \n\x03Raw\x18\x01 \x01(\x0b\x32\x13.NKikimrHealth.TRaw\x12*\n\x08\x43hildren\x18\x02 \x03(\x0b\x32\x18.NKikimrHealth.TPathNode\x12&\n\x04Leaf\x18\x03 \x01(\x0b\x32\x18.NKikimrHealth.TPathLeaf\"5\n\x0bTHealthTree\x12&\n\x04Root\x18\x01 \x01(\x0b\x32\x18.NKikimrHealth.TPathNode\"R\n\x0bTNodeGossip\x12\x19\n\x11\x43reationInstantMs\x18\x01 \x01(\x04\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x18\n\x10StartupInstantMs\x18\x03 \x01(\x04\"\xa0\x01\n\rTEvPushStatus\x12\x19\n\x11\x43reationInstantMs\x18\x01 \x01(\x04\x12\x14\n\x0cSenderNodeId\x18\x02 \x01(\r\x12.\n\nNodeGossip\x18\x03 \x03(\x0b\x32\x1a.NKikimrHealth.TNodeGossip\x12.\n\nHealthTree\x18\x04 \x01(\x0b\x32\x1a.NKikimrHealth.THealthTree*\x1c\n\x06\x45\x43olor\x12\x07\n\x03Red\x10\x00\x12\t\n\x05Green\x10\x01\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.health_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ECOLOR._serialized_start=646
  _ECOLOR._serialized_end=674
  _TRAW._serialized_start=47
  _TRAW._serialized_end=81
  _TPATHLEAF._serialized_start=83
  _TPATHLEAF._serialized_end=210
  _TPATHNODE._serialized_start=213
  _TPATHNODE._serialized_end=342
  _THEALTHTREE._serialized_start=344
  _THEALTHTREE._serialized_end=397
  _TNODEGOSSIP._serialized_start=399
  _TNODEGOSSIP._serialized_end=481
  _TEVPUSHSTATUS._serialized_start=484
  _TEVPUSHSTATUS._serialized_end=644
# @@protoc_insertion_point(module_scope)
