# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/grpc_pq_old.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/grpc_pq_old.proto\x12\x0fNKikimrPQClient\"\'\n\tTKeyValue\x12\x0b\n\x03Key\x18\x01 \x01(\t\x12\r\n\x05Value\x18\x02 \x01(\t\"5\n\x08TMapType\x12)\n\x05Items\x18\x01 \x03(\x0b\x32\x1a.NKikimrPQClient.TKeyValue\"\xfb\x02\n\nTDataChunk\x12\x38\n\x04Meta\x18| \x01(\x0b\x32*.NKikimrPQClient.TDataChunk.TSessionHeader\x12\r\n\x05SeqNo\x18\x01 \x01(\x04\x12\x12\n\nCreateTime\x18\x03 \x01(\x04\x12\n\n\x02Ip\x18\x08 \x01(\x0c\x12\x42\n\tChunkType\x18\t \x01(\x0e\x32&.NKikimrPQClient.TDataChunk.EChunkType:\x07REGULAR\x12\r\n\x05\x43odec\x18\n \x01(\x03\x12.\n\x0b\x45xtraFields\x18~ \x01(\x0b\x32\x19.NKikimrPQClient.TMapType\x12\x0c\n\x04\x44\x61ta\x18\x7f \x01(\x0c\x1aN\n\x0eTSessionHeader\x12\x0e\n\x06Server\x18\x01 \x01(\t\x12\x0c\n\x04\x46ile\x18\x02 \x01(\t\x12\r\n\x05Ident\x18\x03 \x01(\t\x12\x0f\n\x07LogType\x18\x04 \x01(\t\"#\n\nEChunkType\x12\x0b\n\x07REGULAR\x10\x00\x12\x08\n\x04GROW\x10\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.grpc_pq_old_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TKEYVALUE._serialized_start=54
  _TKEYVALUE._serialized_end=93
  _TMAPTYPE._serialized_start=95
  _TMAPTYPE._serialized_end=148
  _TDATACHUNK._serialized_start=151
  _TDATACHUNK._serialized_end=530
  _TDATACHUNK_TSESSIONHEADER._serialized_start=415
  _TDATACHUNK_TSESSIONHEADER._serialized_end=493
  _TDATACHUNK_ECHUNKTYPE._serialized_start=495
  _TDATACHUNK_ECHUNKTYPE._serialized_end=530
# @@protoc_insertion_point(module_scope)
