# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/labeled_counters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&ydb/core/protos/labeled_counters.proto\x12\x16NKikimrLabeledCounters\x1a\x1eydb/core/protos/counters.proto\x1a\x1cydb/core/protos/tablet.proto\"\x99\x01\n\x1fTEvTabletLabeledCountersRequest\x12\x39\n\nTabletType\x18\x01 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\r\n\x05Group\x18\x02 \x01(\t\x12\x18\n\x10LabeledCounterId\x18\x03 \x01(\x04\x12\x12\n\x07Version\x18\x04 \x01(\r:\x01\x31\"\xd3\x01\n\x15TTabletLabeledCounter\x12\r\n\x05Value\x18\x01 \x01(\x04\x12\n\n\x02Id\x18\x02 \x01(\x04\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x45\n\rAggregateFunc\x18\x04 \x01(\x0e\x32..NKikimr.TLabeledCounterOptions.EAggregateFunc\x12:\n\x04Type\x18\x05 \x01(\x0e\x32,.NKikimr.TLabeledCounterOptions.ECounterType\x12\x0e\n\x06NameId\x18\x06 \x01(\r\"\x95\x01\n\x16TTabletLabeledCounters\x12\r\n\x05Group\x18\x01 \x01(\t\x12\x12\n\nGroupNames\x18\x02 \x01(\t\x12\x45\n\x0eLabeledCounter\x18\x03 \x03(\x0b\x32-.NKikimrLabeledCounters.TTabletLabeledCounter\x12\x11\n\tDelimiter\x18\x04 \x01(\t\"\x97\x01\n TEvTabletLabeledCountersResponse\x12N\n\x16LabeledCountersByGroup\x18\x01 \x03(\x0b\x32..NKikimrLabeledCounters.TTabletLabeledCounters\x12\r\n\x05Nodes\x18\x02 \x03(\r\x12\x14\n\x0c\x43ounterNames\x18\x03 \x03(\tB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.labeled_counters_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TEVTABLETLABELEDCOUNTERSREQUEST._serialized_start=129
  _TEVTABLETLABELEDCOUNTERSREQUEST._serialized_end=282
  _TTABLETLABELEDCOUNTER._serialized_start=285
  _TTABLETLABELEDCOUNTER._serialized_end=496
  _TTABLETLABELEDCOUNTERS._serialized_start=499
  _TTABLETLABELEDCOUNTERS._serialized_end=648
  _TEVTABLETLABELEDCOUNTERSRESPONSE._serialized_start=651
  _TEVTABLETLABELEDCOUNTERSRESPONSE._serialized_end=802
# @@protoc_insertion_point(module_scope)
