# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/flat_tx_scheme.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import type_info_pb2 as ydb_dot_core_dot_protos_dot_type__info__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.public.api.protos import ydb_cms_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__cms__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/flat_tx_scheme.proto\x12\rNKikimrScheme\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1fydb/core/protos/type_info.proto\x1a ydb/core/protos/subdomains.proto\x1a/ydb/core/protos/bind_channel_storage_pool.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a#ydb/public/api/protos/ydb_cms.proto\"1\n\rTSchemeConfig\x12 \n\x18PipeClientCachePoolLimit\x18\x01 \x01(\x04\"x\n\x07TConfig\x12-\n\x07\x43urrent\x18\x01 \x01(\x0b\x32\x1c.NKikimrScheme.TSchemeConfig\x12>\n\x18\x44\x65\x66\x61ultSchemeShardConfig\x18\x03 \x01(\x0b\x32\x1c.NKikimrScheme.TSchemeConfig\"\xa8\x01\n\x1aTEvModifySchemeTransaction\x12\x33\n\x0bTransaction\x18\x01 \x03(\x0b\x32\x1e.NKikimrSchemeOp.TModifyScheme\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\x12\r\n\x05Owner\x18\x05 \x01(\t\x12\x13\n\x0b\x46\x61ilOnExist\x18\x06 \x01(\x08\x12\x11\n\tUserToken\x18\x07 \x01(\t\"W\n)TFetcherCheckUserTieringPermissionsResult\x12\x16\n\x0eOperationAllow\x18\x01 \x01(\x08\x12\x12\n\nDenyReason\x18\x02 \x01(\t\"f\n#TFetcherCheckUserTieringPermissions\x12\x11\n\tUserToken\x18\x01 \x01(\x0c\x12\x16\n\x0eTieringRuleIds\x18\x02 \x03(\t\x12\x14\n\x0c\x41\x63tivityType\x18\x03 \x01(\t\"7\n\x14TEvProcessingRequest\x12\x11\n\tClassName\x18\x01 \x01(\t\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\"\xdb\x01\n\x15TEvProcessingResponse\x12@\n\x07\x43ontent\x18\x01 \x01(\x0b\x32-.NKikimrScheme.TEvProcessingResponse.TContentH\x00\x12<\n\x05\x45rror\x18\x02 \x01(\x0b\x32+.NKikimrScheme.TEvProcessingResponse.TErrorH\x00\x1a\x18\n\x08TContent\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x1a\x1e\n\x06TError\x12\x14\n\x0c\x45rrorMessage\x18\x01 \x01(\tB\x08\n\x06Result\"\xbd\x01\n TEvModifySchemeTransactionResult\x12&\n\x06Status\x18\x01 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\x12\x0e\n\x06Reason\x18\x02 \x01(\t\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x15\n\rSchemeshardId\x18\x04 \x01(\x04\x12\x0e\n\x06PathId\x18\x05 \x01(\x04\x12\x16\n\x0ePathCreateTxId\x18\x06 \x01(\x04\x12\x14\n\x0cPathDropTxId\x18\x07 \x01(\x04\"\xdc\x02\n\x17TEvDescribeSchemeResult\x12&\n\x06Status\x18\x01 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\x12\x0e\n\x06Reason\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12:\n\x0fPathDescription\x18\x04 \x01(\x0b\x32!.NKikimrSchemeOp.TPathDescription\x12\x11\n\tPathOwner\x18\x05 \x01(\x06\x12\x0e\n\x06PathId\x18\x06 \x01(\x06\x12\x1d\n\x15LastExistedPrefixPath\x18\x07 \x01(\t\x12\x1f\n\x17LastExistedPrefixPathId\x18\x08 \x01(\x06\x12G\n\x1cLastExistedPrefixDescription\x18\t \x01(\x0b\x32!.NKikimrSchemeOp.TPathDescription\x12\x13\n\x0bPathOwnerId\x18\n \x01(\x06\"T\n\x0bTEvCancelTx\x12\x12\n\nTargetTxId\x18\x01 \x01(\x04\x12\x0c\n\x04Path\x18\x02 \x01(\t\x12\x15\n\rSecurityToken\x18\x03 \x01(\t\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\"m\n\x11TEvCancelTxResult\x12&\n\x06Status\x18\x01 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\x12\x0e\n\x06Result\x18\x02 \x01(\t\x12\x12\n\nTargetTxId\x18\x03 \x01(\x04\x12\x0c\n\x04TxId\x18\x04 \x01(\x04\"a\n\x0fTEvUpdateConfig\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12&\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x16.NKikimrScheme.TConfig\"c\n\x15TEvUpdateConfigResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Reason\x18\x03 \x01(\t\"*\n\x08TEvLogin\x12\x0c\n\x04User\x18\x01 \x01(\t\x12\x10\n\x08Password\x18\x02 \x01(\t\".\n\x0eTEvLoginResult\x12\r\n\x05\x45rror\x18\x01 \x01(\t\x12\r\n\x05Token\x18\x02 \x01(\t\"%\n\x15TEvNotifyTxCompletion\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"/\n\x1fTEvNotifyTxCompletionRegistered\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"+\n\x1bTEvNotifyTxCompletionResult\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\x98\x03\n\rTSchemeLimits\x12\x10\n\x08MaxDepth\x18\x01 \x01(\x04\x12\x10\n\x08MaxPaths\x18\x02 \x01(\x04\x12\x18\n\x10MaxChildrenInDir\x18\x03 \x01(\x04\x12\x17\n\x0fMaxAclBytesSize\x18\x04 \x01(\x04\x12\x17\n\x0fMaxTableColumns\x18\x05 \x01(\x04\x12 \n\x18MaxTableColumnNameLength\x18\x06 \x01(\x04\x12\x1a\n\x12MaxTableKeyColumns\x18\x07 \x01(\x04\x12\x17\n\x0fMaxTableIndices\x18\x08 \x01(\x04\x12\x11\n\tMaxShards\x18\t \x01(\x04\x12\x17\n\x0fMaxShardsInPath\x18\n \x01(\x04\x12 \n\x18MaxConsistentCopyTargets\x18\x0b \x01(\x04\x12\x1c\n\x14MaxPathElementLength\x18\x0c \x01(\x04\x12\x1f\n\x17\x45xtraPathSymbolsAllowed\x18\r \x01(\t\x12\x17\n\x0fMaxPQPartitions\x18\x0e \x01(\x04\x12\x1a\n\x12MaxTableCdcStreams\x18\x0f \x01(\x04\"\x82\x05\n\x18TEvInitTenantSchemeShard\x12\x19\n\x11\x44omainSchemeShard\x18\x01 \x01(\x06\x12\x14\n\x0c\x44omainPathId\x18\x02 \x01(\x06\x12\x10\n\x08RootPath\x18\x03 \x01(\t\x12\r\n\x05Owner\x18\x04 \x01(\t\x12\x14\n\x0c\x45\x66\x66\x65\x63tiveACL\x18\x05 \x01(\x0c\x12\x1b\n\x13\x45\x66\x66\x65\x63tiveACLVersion\x18\x06 \x01(\x04\x12>\n\x10ProcessingParams\x18\x07 \x01(\x0b\x32$.NKikimrSubDomains.TProcessingParams\x12\x36\n\x0cStoragePools\x18\x08 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\x12\x37\n\x0eUserAttributes\x18\t \x03(\x0b\x32\x1f.NKikimrSchemeOp.TUserAttribute\x12\x1d\n\x15UserAttributesVersion\x18\n \x01(\x04\x12\x32\n\x0cSchemeLimits\x18\x0b \x01(\x0b\x32\x1c.NKikimrScheme.TSchemeLimits\x12\x19\n\x11InitiateMigration\x18\x0c \x01(\x08\x12\x1e\n\x16ResourcesDomainOwnerId\x18\r \x01(\x06\x12\x1d\n\x15ResourcesDomainPathId\x18\x0e \x01(\x06\x12\x12\n\nSharedHive\x18\x0f \x01(\x06\x12>\n\x14\x44\x65\x63laredSchemeQuotas\x18\x10 \x01(\x0b\x32 .NKikimrSubDomains.TSchemeQuotas\x12/\n\x0e\x44\x61tabaseQuotas\x18\x11 \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\"c\n\x1eTEvInitTenantSchemeShardResult\x12\x19\n\x11TenantSchemeShard\x18\x01 \x01(\x04\x12&\n\x06Status\x18\x02 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\",\n\x08TShardID\x12\x0f\n\x07OwnerId\x18\x01 \x01(\x06\x12\x0f\n\x07LocalId\x18\x02 \x01(\x04\"\x97\x01\n\rTMigrateShard\x12)\n\x08ShardIdx\x18\x01 \x01(\x0b\x32\x17.NKikimrScheme.TShardID\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\x10\n\x08TabletId\x18\x03 \x01(\x06\x12;\n\x11\x42indedStoragePool\x18\x04 \x03(\x0b\x32 .NKikimrStoragePool.TChannelBind\"\xcc\x02\n\x0cTMigratePath\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12+\n\x0cParentPathId\x18\x02 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0c\n\x04Name\x18\x03 \x01(\t\x12\x10\n\x08PathType\x18\x04 \x01(\r\x12\x13\n\x0bStepCreated\x18\x05 \x01(\x04\x12\x12\n\nCreateTxId\x18\x06 \x01(\x06\x12\r\n\x05Owner\x18\x07 \x01(\t\x12\x0b\n\x03\x41\x43L\x18\x08 \x01(\t\x12\x17\n\x0f\x44irAlterVersion\x18\t \x01(\x04\x12\x1d\n\x15UserAttrsAlterVersion\x18\n \x01(\x04\x12\x12\n\nACLVersion\x18\x0b \x01(\x04\x12\x37\n\x0eUserAttributes\x18\x0c \x03(\x0b\x32\x1f.NKikimrSchemeOp.TUserAttribute\"\xf8\x01\n\x0eTMigrateColumn\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x0f\n\x07\x43olType\x18\x03 \x01(\r\x12,\n\x0b\x43olTypeInfo\x18\x0b \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x12\x13\n\x0b\x43olKeyOrder\x18\x04 \x01(\r\x12\x15\n\rCreateVersion\x18\x05 \x01(\x04\x12\x15\n\rDeleteVersion\x18\x06 \x01(\x04\x12\x0e\n\x06\x46\x61mily\x18\x07 \x01(\r\x12\x13\n\x0b\x44\x65\x66\x61ultKind\x18\x08 \x01(\r\x12\x14\n\x0c\x44\x65\x66\x61ultValue\x18\t \x01(\x0c\x12\x0f\n\x07NotNull\x18\n \x01(\x08\"u\n\x11TMigratePartition\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x10\n\x08RangeEnd\x18\x02 \x01(\t\x12)\n\x08ShardIdx\x18\x03 \x01(\x0b\x32\x17.NKikimrScheme.TShardID\x12\x17\n\x0fPartitionConfig\x18\x04 \x01(\t\"\xfb\x01\n\rTMigrateTable\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x11\n\tNextColId\x18\x02 \x01(\r\x12\x17\n\x0fPartitionConfig\x18\x03 \x01(\t\x12\x14\n\x0c\x41lterVersion\x18\x04 \x01(\r\x12\x1b\n\x13PartitioningVersion\x18\x05 \x01(\r\x12.\n\x07\x43olumns\x18\x06 \x03(\x0b\x32\x1d.NKikimrScheme.TMigrateColumn\x12\x34\n\nPartitions\x18\x07 \x03(\x0b\x32 .NKikimrScheme.TMigratePartition\"|\n\x12TMigrateTableIndex\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x14\n\x0c\x41lterVersion\x18\x02 \x01(\x04\x12\x0c\n\x04Type\x18\x03 \x01(\r\x12\r\n\x05State\x18\x04 \x01(\r\x12\x0c\n\x04Keys\x18\x05 \x03(\t\"W\n\rTMigrateKesus\x12%\n\x06PathId\x18\x01 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12\x0f\n\x07Version\x18\x02 \x01(\x04\x12\x0e\n\x06\x43onfig\x18\x03 \x01(\t\"\xc9\x02\n\nTEvMigrate\x12\x1d\n\x15SchemeShardGeneration\x18\x01 \x01(\x04\x12)\n\x04Path\x18\x02 \x01(\x0b\x32\x1b.NKikimrScheme.TMigratePath\x12\x32\n\x0bPathVersion\x18\x03 \x01(\x0b\x32\x1d.NKikimrSchemeOp.TPathVersion\x12,\n\x06Shards\x18\x04 \x03(\x0b\x32\x1c.NKikimrScheme.TMigrateShard\x12+\n\x05Table\x18\x05 \x01(\x0b\x32\x1c.NKikimrScheme.TMigrateTable\x12\x35\n\nTableIndex\x18\x06 \x01(\x0b\x32!.NKikimrScheme.TMigrateTableIndex\x12+\n\x05Kesus\x18\x07 \x01(\x0b\x32\x1c.NKikimrScheme.TMigrateKesus\"\x9e\x01\n\x10TEvMigrateResult\x12\x19\n\x11TenantSchemeShard\x18\x01 \x01(\x06\x12\x1d\n\x15SchemeShardGeneration\x18\x02 \x01(\x04\x12%\n\x06PathId\x18\x03 \x01(\x0b\x32\x15.NKikimrProto.TPathID\x12)\n\x08ShardIds\x18\x04 \x03(\x0b\x32\x17.NKikimrScheme.TShardID\"7\n\x1aTEvPublishTenantAsReadOnly\x12\x19\n\x11\x44omainSchemeShard\x18\x01 \x01(\x06\"e\n TEvPublishTenantAsReadOnlyResult\x12\x19\n\x11TenantSchemeShard\x18\x01 \x01(\x06\x12&\n\x06Status\x18\x02 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\"Y\n\x0fTEvRewriteOwner\x12\x11\n\tPrevOwner\x18\x01 \x01(\x06\x12\x10\n\x08NewOwner\x18\x02 \x01(\x06\x12\x12\n\nGeneration\x18\x03 \x01(\x04\x12\r\n\x05Round\x18\x04 \x01(\x04\"?\n\x15TEvRewriteOwnerResult\x12&\n\x06Status\x18\x01 \x01(\x0e\x32\x16.NKikimrScheme.EStatus\"-\n\x10TEvPublishTenant\x12\x19\n\x11\x44omainSchemeShard\x18\x01 \x01(\x06\"3\n\x16TEvPublishTenantResult\x12\x19\n\x11TenantSchemeShard\x18\x01 \x01(\x06\"\x92\x02\n\x18TEvSyncTenantSchemeShard\x12\x19\n\x11\x44omainSchemeShard\x18\x01 \x01(\x06\x12\x14\n\x0c\x44omainPathId\x18\x02 \x01(\x06\x12\x10\n\x08TabletID\x18\x03 \x01(\x06\x12\x12\n\nGeneration\x18\x04 \x01(\x04\x12\x1b\n\x13\x45\x66\x66\x65\x63tiveACLVersion\x18\x05 \x01(\x04\x12\x18\n\x10SubdomainVersion\x18\x06 \x01(\x04\x12\x1d\n\x15UserAttributesVersion\x18\x07 \x01(\x04\x12\x12\n\nTenantHive\x18\x08 \x01(\x04\x12\x1e\n\x16TenantSysViewProcessor\x18\t \x01(\x04\x12\x15\n\rTenantRootACL\x18\n \x01(\t\"\xf0\x03\n\x1aTEvUpdateTenantSchemeShard\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\r\n\x05Owner\x18\x03 \x01(\t\x12\x14\n\x0c\x45\x66\x66\x65\x63tiveACL\x18\x04 \x01(\x0c\x12\x1b\n\x13\x45\x66\x66\x65\x63tiveACLVersion\x18\x05 \x01(\x04\x12\x36\n\x0cStoragePools\x18\x06 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\x12\x18\n\x10SubdomainVersion\x18\x07 \x01(\x04\x12\x37\n\x0eUserAttributes\x18\x08 \x03(\x0b\x32\x1f.NKikimrSchemeOp.TUserAttribute\x12\x1d\n\x15UserAttributesVersion\x18\t \x01(\x04\x12\x12\n\nTenantHive\x18\n \x01(\x04\x12\x1e\n\x16TenantSysViewProcessor\x18\x0b \x01(\x04\x12>\n\x14\x44\x65\x63laredSchemeQuotas\x18\x0c \x01(\x0b\x32 .NKikimrSubDomains.TSchemeQuotas\x12/\n\x0e\x44\x61tabaseQuotas\x18\x0e \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x12\x1b\n\x13UpdateTenantRootACL\x18\r \x01(\t\"0\n\x1cTEvFindTabletSubDomainPathId\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\"\x83\x02\n\"TEvFindTabletSubDomainPathIdResult\x12I\n\x06Status\x18\x01 \x01(\x0e\x32\x39.NKikimrScheme.TEvFindTabletSubDomainPathIdResult.EStatus\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\x15\n\rSchemeShardId\x18\x03 \x01(\x04\x12\x17\n\x0fSubDomainPathId\x18\x04 \x01(\x04\"P\n\x07\x45Status\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x13\n\x0fSHARD_NOT_FOUND\x10\x02\x12\x12\n\x0ePATH_NOT_FOUND\x10\x03*\x84\x04\n\x07\x45Status\x12\x11\n\rStatusSuccess\x10\x00\x12\x12\n\x0eStatusAccepted\x10\x01\x12\x1a\n\x16StatusPathDoesNotExist\x10\x02\x12\x1c\n\x18StatusPathIsNotDirectory\x10\x03\x12\x17\n\x13StatusAlreadyExists\x10\x04\x12\x15\n\x11StatusSchemeError\x10\x05\x12\x16\n\x12StatusNameConflict\x10\x06\x12\x1a\n\x16StatusInvalidParameter\x10\x07\x12\x1f\n\x1bStatusMultipleModifications\x10\x08\x12\x12\n\x0eStatusReadOnly\x10\t\x12\x17\n\x13StatusTxIdNotExists\x10\n\x12\x1c\n\x18StatusTxIsNotCancellable\x10\x0b\x12\x16\n\x12StatusAccessDenied\x10\x0c\x12\x16\n\x12StatusNotAvailable\x10\r\x12\x1c\n\x18StatusPreconditionFailed\x10\x0e\x12\x18\n\x14StatusRedirectDomain\x10\x0f\x12\x17\n\x13StatusQuotaExceeded\x10\x10\x12\x1b\n\x17StatusResourceExhausted\x10\x11\x12\x14\n\x10StatusReserved18\x10\x12\x12\x14\n\x10StatusReserved19\x10\x13\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.flat_tx_scheme_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ESTATUS._serialized_start=6824
  _ESTATUS._serialized_end=7340
  _TSCHEMECONFIG._serialized_start=314
  _TSCHEMECONFIG._serialized_end=363
  _TCONFIG._serialized_start=365
  _TCONFIG._serialized_end=485
  _TEVMODIFYSCHEMETRANSACTION._serialized_start=488
  _TEVMODIFYSCHEMETRANSACTION._serialized_end=656
  _TFETCHERCHECKUSERTIERINGPERMISSIONSRESULT._serialized_start=658
  _TFETCHERCHECKUSERTIERINGPERMISSIONSRESULT._serialized_end=745
  _TFETCHERCHECKUSERTIERINGPERMISSIONS._serialized_start=747
  _TFETCHERCHECKUSERTIERINGPERMISSIONS._serialized_end=849
  _TEVPROCESSINGREQUEST._serialized_start=851
  _TEVPROCESSINGREQUEST._serialized_end=906
  _TEVPROCESSINGRESPONSE._serialized_start=909
  _TEVPROCESSINGRESPONSE._serialized_end=1128
  _TEVPROCESSINGRESPONSE_TCONTENT._serialized_start=1062
  _TEVPROCESSINGRESPONSE_TCONTENT._serialized_end=1086
  _TEVPROCESSINGRESPONSE_TERROR._serialized_start=1088
  _TEVPROCESSINGRESPONSE_TERROR._serialized_end=1118
  _TEVMODIFYSCHEMETRANSACTIONRESULT._serialized_start=1131
  _TEVMODIFYSCHEMETRANSACTIONRESULT._serialized_end=1320
  _TEVDESCRIBESCHEMERESULT._serialized_start=1323
  _TEVDESCRIBESCHEMERESULT._serialized_end=1671
  _TEVCANCELTX._serialized_start=1673
  _TEVCANCELTX._serialized_end=1757
  _TEVCANCELTXRESULT._serialized_start=1759
  _TEVCANCELTXRESULT._serialized_end=1868
  _TEVUPDATECONFIG._serialized_start=1870
  _TEVUPDATECONFIG._serialized_end=1967
  _TEVUPDATECONFIGRESULT._serialized_start=1969
  _TEVUPDATECONFIGRESULT._serialized_end=2068
  _TEVLOGIN._serialized_start=2070
  _TEVLOGIN._serialized_end=2112
  _TEVLOGINRESULT._serialized_start=2114
  _TEVLOGINRESULT._serialized_end=2160
  _TEVNOTIFYTXCOMPLETION._serialized_start=2162
  _TEVNOTIFYTXCOMPLETION._serialized_end=2199
  _TEVNOTIFYTXCOMPLETIONREGISTERED._serialized_start=2201
  _TEVNOTIFYTXCOMPLETIONREGISTERED._serialized_end=2248
  _TEVNOTIFYTXCOMPLETIONRESULT._serialized_start=2250
  _TEVNOTIFYTXCOMPLETIONRESULT._serialized_end=2293
  _TSCHEMELIMITS._serialized_start=2296
  _TSCHEMELIMITS._serialized_end=2704
  _TEVINITTENANTSCHEMESHARD._serialized_start=2707
  _TEVINITTENANTSCHEMESHARD._serialized_end=3349
  _TEVINITTENANTSCHEMESHARDRESULT._serialized_start=3351
  _TEVINITTENANTSCHEMESHARDRESULT._serialized_end=3450
  _TSHARDID._serialized_start=3452
  _TSHARDID._serialized_end=3496
  _TMIGRATESHARD._serialized_start=3499
  _TMIGRATESHARD._serialized_end=3650
  _TMIGRATEPATH._serialized_start=3653
  _TMIGRATEPATH._serialized_end=3985
  _TMIGRATECOLUMN._serialized_start=3988
  _TMIGRATECOLUMN._serialized_end=4236
  _TMIGRATEPARTITION._serialized_start=4238
  _TMIGRATEPARTITION._serialized_end=4355
  _TMIGRATETABLE._serialized_start=4358
  _TMIGRATETABLE._serialized_end=4609
  _TMIGRATETABLEINDEX._serialized_start=4611
  _TMIGRATETABLEINDEX._serialized_end=4735
  _TMIGRATEKESUS._serialized_start=4737
  _TMIGRATEKESUS._serialized_end=4824
  _TEVMIGRATE._serialized_start=4827
  _TEVMIGRATE._serialized_end=5156
  _TEVMIGRATERESULT._serialized_start=5159
  _TEVMIGRATERESULT._serialized_end=5317
  _TEVPUBLISHTENANTASREADONLY._serialized_start=5319
  _TEVPUBLISHTENANTASREADONLY._serialized_end=5374
  _TEVPUBLISHTENANTASREADONLYRESULT._serialized_start=5376
  _TEVPUBLISHTENANTASREADONLYRESULT._serialized_end=5477
  _TEVREWRITEOWNER._serialized_start=5479
  _TEVREWRITEOWNER._serialized_end=5568
  _TEVREWRITEOWNERRESULT._serialized_start=5570
  _TEVREWRITEOWNERRESULT._serialized_end=5633
  _TEVPUBLISHTENANT._serialized_start=5635
  _TEVPUBLISHTENANT._serialized_end=5680
  _TEVPUBLISHTENANTRESULT._serialized_start=5682
  _TEVPUBLISHTENANTRESULT._serialized_end=5733
  _TEVSYNCTENANTSCHEMESHARD._serialized_start=5736
  _TEVSYNCTENANTSCHEMESHARD._serialized_end=6010
  _TEVUPDATETENANTSCHEMESHARD._serialized_start=6013
  _TEVUPDATETENANTSCHEMESHARD._serialized_end=6509
  _TEVFINDTABLETSUBDOMAINPATHID._serialized_start=6511
  _TEVFINDTABLETSUBDOMAINPATHID._serialized_end=6559
  _TEVFINDTABLETSUBDOMAINPATHIDRESULT._serialized_start=6562
  _TEVFINDTABLETSUBDOMAINPATHIDRESULT._serialized_end=6821
  _TEVFINDTABLETSUBDOMAINPATHIDRESULT_ESTATUS._serialized_start=6741
  _TEVFINDTABLETSUBDOMAINPATHIDRESULT_ESTATUS._serialized_end=6821
# @@protoc_insertion_point(module_scope)
