# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/s3/proto/range.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ydb/library/yql/providers/s3/proto/range.proto\x12\x08NYql.NS3\"\xbc\x01\n\x06TRange\x12\x16\n\x0e\x44\x65precatedPath\x18\x02 \x03(\t\x12\x16\n\x0eStartPathIndex\x18\x03 \x01(\x04\x12%\n\x05Paths\x18\x04 \x03(\x0b\x32\x16.NYql.NS3.TRange.TPath\x1a[\n\x05TPath\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12(\n\x08\x43hildren\x18\x02 \x03(\x0b\x32\x16.NYql.NS3.TRange.TPath\x12\x0c\n\x04Size\x18\x03 \x01(\x04\x12\x0c\n\x04Read\x18\x04 \x01(\x08\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.s3.proto.range_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TRANGE._serialized_start=61
  _TRANGE._serialized_end=249
  _TRANGE_TPATH._serialized_start=158
  _TRANGE_TPATH._serialized_end=249
# @@protoc_insertion_point(module_scope)
