# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blob_depot.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import blob_depot_config_pb2 as ydb_dot_core_dot_protos_dot_blob__depot__config__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import blobstorage_disk_color_pb2 as ydb_dot_core_dot_protos_dot_blobstorage__disk__color__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ydb/core/protos/blob_depot.proto\x12\x10NKikimrBlobDepot\x1a\'ydb/core/protos/blob_depot_config.proto\x1a\x1aydb/core/protos/base.proto\x1a,ydb/core/protos/blobstorage_disk_color.proto\"N\n\nTBlobSeqId\x12\x0f\n\x07\x43hannel\x18\x01 \x01(\r\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0c\n\x04Step\x18\x03 \x01(\r\x12\r\n\x05Index\x18\x04 \x01(\r\"\x8b\x01\n\x0cTBlobLocator\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12/\n\tBlobSeqId\x18\x02 \x01(\x0b\x32\x1c.NKikimrBlobDepot.TBlobSeqId\x12\x10\n\x08\x43hecksum\x18\x03 \x01(\r\x12\x14\n\x0cTotalDataLen\x18\x04 \x01(\x04\x12\x11\n\tFooterLen\x18\x05 \x01(\r\"j\n\x0bTValueChain\x12/\n\x07Locator\x18\x01 \x01(\x0b\x32\x1e.NKikimrBlobDepot.TBlobLocator\x12\x15\n\rSubrangeBegin\x18\x02 \x01(\x04\x12\x13\n\x0bSubrangeEnd\x18\x03 \x01(\x04\"\xa5\x01\n\x06TValue\x12\x0c\n\x04Meta\x18\x01 \x01(\x0c\x12\x31\n\nValueChain\x18\x02 \x03(\x0b\x32\x1d.NKikimrBlobDepot.TValueChain\x12/\n\tKeepState\x18\x03 \x01(\x0e\x32\x1c.NKikimrBlobDepot.EKeepState\x12\x0e\n\x06Public\x18\x04 \x01(\x08\x12\x19\n\x11GoingToAssimilate\x18\x05 \x01(\x08\"\x93\x01\n\rTGivenIdRange\x12\x44\n\rChannelRanges\x18\x01 \x03(\x0b\x32-.NKikimrBlobDepot.TGivenIdRange.TChannelRange\x1a<\n\rTChannelRange\x12\x0f\n\x07\x43hannel\x18\x01 \x01(\r\x12\r\n\x05\x42\x65gin\x18\x02 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x03 \x01(\x04\"}\n\x13TResolvedValueChain\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\x12)\n\x06\x42lobId\x18\x02 \x01(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x15\n\rSubrangeBegin\x18\x03 \x01(\r\x12\x13\n\x0bSubrangeEnd\x18\x04 \x01(\r\"R\n\x0eTEvApplyConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x32\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\".NKikimrBlobDepot.TBlobDepotConfig\"6\n\x14TEvApplyConfigResult\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"C\n\x10TEvRegisterAgent\x12\x16\n\x0eVirtualGroupId\x18\x01 \x01(\r\x12\x17\n\x0f\x41gentInstanceId\x18\x02 \x01(\x06\"\xbf\x03\n\x16TEvRegisterAgentResult\x12\x12\n\nGeneration\x18\x01 \x01(\r\x12K\n\x0c\x43hannelKinds\x18\x02 \x03(\x0b\x32\x35.NKikimrBlobDepot.TEvRegisterAgentResult.TChannelKind\x12\x17\n\x0f\x44\x65\x63ommitGroupId\x18\x03 \x01(\r\x12:\n\nSpaceColor\x18\x04 \x01(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\x12!\n\x19\x41pproximateFreeSpaceShare\x18\x05 \x01(\x02\x1a\x33\n\x0fTChannelGroupId\x12\x0f\n\x07\x43hannel\x18\x01 \x01(\r\x12\x0f\n\x07GroupId\x18\x02 \x01(\r\x1a\x96\x01\n\x0cTChannelKind\x12\x35\n\x0b\x43hannelKind\x18\x01 \x01(\x0e\x32 .NKikimrBlobDepot.TChannelKind.E\x12O\n\rChannelGroups\x18\x02 \x03(\x0b\x32\x38.NKikimrBlobDepot.TEvRegisterAgentResult.TChannelGroupId\"V\n\x0eTEvAllocateIds\x12\x35\n\x0b\x43hannelKind\x18\x01 \x01(\x0e\x32 .NKikimrBlobDepot.TChannelKind.E\x12\r\n\x05\x43ount\x18\x02 \x01(\r\"\x98\x01\n\x14TEvAllocateIdsResult\x12\x35\n\x0b\x43hannelKind\x18\x01 \x01(\x0e\x32 .NKikimrBlobDepot.TChannelKind.E\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x35\n\x0cGivenIdRange\x18\x03 \x01(\x0b\x32\x1f.NKikimrBlobDepot.TGivenIdRange\"K\n\x08TEvBlock\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x19\n\x11\x42lockedGeneration\x18\x02 \x01(\r\x12\x12\n\nIssuerGuid\x18\x03 \x01(\x04\"g\n\x0eTEvBlockResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12\x14\n\x0cTimeToLiveMs\x18\x03 \x01(\r\"\xa7\x03\n\rTEvPushNotify\x12\x46\n\x0e\x42lockedTablets\x18\x01 \x03(\x0b\x32..NKikimrBlobDepot.TEvPushNotify.TBlockedTablet\x12J\n\x10InvalidatedSteps\x18\x02 \x03(\x0b\x32\x30.NKikimrBlobDepot.TEvPushNotify.TInvalidatedStep\x12:\n\nSpaceColor\x18\x03 \x01(\x0e\x32&.NKikimrBlobStorage.TPDiskSpaceColor.E\x12!\n\x19\x41pproximateFreeSpaceShare\x18\x04 \x01(\x02\x1aQ\n\x0eTBlockedTablet\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x19\n\x11\x42lockedGeneration\x18\x02 \x01(\r\x12\x12\n\nIssuerGuid\x18\x03 \x01(\x04\x1aP\n\x10TInvalidatedStep\x12\x0f\n\x07\x43hannel\x18\x01 \x01(\r\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x17\n\x0fInvalidatedStep\x18\x03 \x01(\r\"W\n\x13TEvPushNotifyResult\x12\x34\n\x0eWritesInFlight\x18\x01 \x03(\x0b\x32\x1c.NKikimrBlobDepot.TBlobSeqId\x12\n\n\x02Id\x18\x02 \x01(\x04\"#\n\x0eTEvQueryBlocks\x12\x11\n\tTabletIds\x18\x01 \x03(\x06\"H\n\x14TEvQueryBlocksResult\x12\x1a\n\x12\x42lockedGenerations\x18\x01 \x03(\r\x12\x14\n\x0cTimeToLiveMs\x18\x02 \x01(\r\"\xfd\x01\n\x11TEvCollectGarbage\x12\'\n\x04Keep\x18\x01 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12,\n\tDoNotKeep\x18\x02 \x03(\x0b\x32\x19.NKikimrProto.TLogoBlobID\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\x12\x12\n\nGeneration\x18\x04 \x01(\r\x12\x1c\n\x14PerGenerationCounter\x18\x05 \x01(\r\x12\x0f\n\x07\x43hannel\x18\x06 \x01(\r\x12\x0c\n\x04Hard\x18\x07 \x01(\x08\x12\x19\n\x11\x43ollectGeneration\x18\x08 \x01(\r\x12\x13\n\x0b\x43ollectStep\x18\t \x01(\x04\"Z\n\x17TEvCollectGarbageResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\"\xd3\x01\n\x10TEvCommitBlobSeq\x12\x37\n\x05Items\x18\x01 \x03(\x0b\x32(.NKikimrBlobDepot.TEvCommitBlobSeq.TItem\x1a\x85\x01\n\x05TItem\x12\x33\n\x0b\x42lobLocator\x18\x01 \x01(\x0b\x32\x1e.NKikimrBlobDepot.TBlobLocator\x12\x0b\n\x03Key\x18\x02 \x01(\x0c\x12\x0c\n\x04Meta\x18\x03 \x01(\x0c\x12\x16\n\x0eUncertainWrite\x18\x04 \x01(\x08\x12\x14\n\x0c\x43ommitNotify\x18\x05 \x01(\x08\"\xa1\x01\n\x16TEvCommitBlobSeqResult\x12=\n\x05Items\x18\x01 \x03(\x0b\x32..NKikimrBlobDepot.TEvCommitBlobSeqResult.TItem\x1aH\n\x05TItem\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\"G\n\x18TEvDiscardSpoiledBlobSeq\x12+\n\x05Items\x18\x01 \x03(\x0b\x32\x1c.NKikimrBlobDepot.TBlobSeqId\"\xbf\x03\n\nTEvResolve\x12\x31\n\x05Items\x18\x01 \x03(\x0b\x32\".NKikimrBlobDepot.TEvResolve.TItem\x1a\x9e\x01\n\tTKeyRange\x12\x14\n\x0c\x42\x65ginningKey\x18\x01 \x01(\x0c\x12\x1e\n\x10IncludeBeginning\x18\x02 \x01(\x08:\x04true\x12\x11\n\tEndingKey\x18\x03 \x01(\x0c\x12\x1c\n\rIncludeEnding\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x12\n\x07MaxKeys\x18\x05 \x01(\r:\x01\x30\x12\x16\n\x07Reverse\x18\x06 \x01(\x08:\x05\x66\x61lse\x1a\xdc\x01\n\x05TItem\x12:\n\x08KeyRange\x18\x01 \x01(\x0b\x32&.NKikimrBlobDepot.TEvResolve.TKeyRangeH\x00\x12\x12\n\x08\x45xactKey\x18\x02 \x01(\x0cH\x00\x12\x19\n\nReturnMeta\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x0cReturnOwners\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x10\n\x08TabletId\x18\x06 \x01(\x06\x12\x18\n\x10MustRestoreFirst\x18\x07 \x01(\x08\x42\x0f\n\rKeyDesignator\"\xb6\x02\n\x10TEvResolveResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x13\n\x0b\x45rrorReason\x18\x02 \x01(\t\x12\x45\n\x0cResolvedKeys\x18\x03 \x03(\x0b\x32/.NKikimrBlobDepot.TEvResolveResult.TResolvedKey\x1a\x99\x01\n\x0cTResolvedKey\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\x12\x0b\n\x03Key\x18\x02 \x01(\x0c\x12\x39\n\nValueChain\x18\x03 \x03(\x0b\x32%.NKikimrBlobDepot.TResolvedValueChain\x12\x0c\n\x04Meta\x18\x04 \x01(\x0c\x12\x0e\n\x06Owners\x18\x05 \x03(\x04\x12\x13\n\x0b\x45rrorReason\x18\x06 \x01(\t*2\n\nEKeepState\x12\x0b\n\x07\x44\x65\x66\x61ult\x10\x00\x12\x08\n\x04Keep\x10\x01\x12\r\n\tDoNotKeep\x10\x02')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blob_depot_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _EKEEPSTATE._serialized_start=4216
  _EKEEPSTATE._serialized_end=4266
  _TBLOBSEQID._serialized_start=169
  _TBLOBSEQID._serialized_end=247
  _TBLOBLOCATOR._serialized_start=250
  _TBLOBLOCATOR._serialized_end=389
  _TVALUECHAIN._serialized_start=391
  _TVALUECHAIN._serialized_end=497
  _TVALUE._serialized_start=500
  _TVALUE._serialized_end=665
  _TGIVENIDRANGE._serialized_start=668
  _TGIVENIDRANGE._serialized_end=815
  _TGIVENIDRANGE_TCHANNELRANGE._serialized_start=755
  _TGIVENIDRANGE_TCHANNELRANGE._serialized_end=815
  _TRESOLVEDVALUECHAIN._serialized_start=817
  _TRESOLVEDVALUECHAIN._serialized_end=942
  _TEVAPPLYCONFIG._serialized_start=944
  _TEVAPPLYCONFIG._serialized_end=1026
  _TEVAPPLYCONFIGRESULT._serialized_start=1028
  _TEVAPPLYCONFIGRESULT._serialized_end=1082
  _TEVREGISTERAGENT._serialized_start=1084
  _TEVREGISTERAGENT._serialized_end=1151
  _TEVREGISTERAGENTRESULT._serialized_start=1154
  _TEVREGISTERAGENTRESULT._serialized_end=1601
  _TEVREGISTERAGENTRESULT_TCHANNELGROUPID._serialized_start=1397
  _TEVREGISTERAGENTRESULT_TCHANNELGROUPID._serialized_end=1448
  _TEVREGISTERAGENTRESULT_TCHANNELKIND._serialized_start=1451
  _TEVREGISTERAGENTRESULT_TCHANNELKIND._serialized_end=1601
  _TEVALLOCATEIDS._serialized_start=1603
  _TEVALLOCATEIDS._serialized_end=1689
  _TEVALLOCATEIDSRESULT._serialized_start=1692
  _TEVALLOCATEIDSRESULT._serialized_end=1844
  _TEVBLOCK._serialized_start=1846
  _TEVBLOCK._serialized_end=1921
  _TEVBLOCKRESULT._serialized_start=1923
  _TEVBLOCKRESULT._serialized_end=2026
  _TEVPUSHNOTIFY._serialized_start=2029
  _TEVPUSHNOTIFY._serialized_end=2452
  _TEVPUSHNOTIFY_TBLOCKEDTABLET._serialized_start=2289
  _TEVPUSHNOTIFY_TBLOCKEDTABLET._serialized_end=2370
  _TEVPUSHNOTIFY_TINVALIDATEDSTEP._serialized_start=2372
  _TEVPUSHNOTIFY_TINVALIDATEDSTEP._serialized_end=2452
  _TEVPUSHNOTIFYRESULT._serialized_start=2454
  _TEVPUSHNOTIFYRESULT._serialized_end=2541
  _TEVQUERYBLOCKS._serialized_start=2543
  _TEVQUERYBLOCKS._serialized_end=2578
  _TEVQUERYBLOCKSRESULT._serialized_start=2580
  _TEVQUERYBLOCKSRESULT._serialized_end=2652
  _TEVCOLLECTGARBAGE._serialized_start=2655
  _TEVCOLLECTGARBAGE._serialized_end=2908
  _TEVCOLLECTGARBAGERESULT._serialized_start=2910
  _TEVCOLLECTGARBAGERESULT._serialized_end=3000
  _TEVCOMMITBLOBSEQ._serialized_start=3003
  _TEVCOMMITBLOBSEQ._serialized_end=3214
  _TEVCOMMITBLOBSEQ_TITEM._serialized_start=3081
  _TEVCOMMITBLOBSEQ_TITEM._serialized_end=3214
  _TEVCOMMITBLOBSEQRESULT._serialized_start=3217
  _TEVCOMMITBLOBSEQRESULT._serialized_end=3378
  _TEVCOMMITBLOBSEQRESULT_TITEM._serialized_start=3306
  _TEVCOMMITBLOBSEQRESULT_TITEM._serialized_end=3378
  _TEVDISCARDSPOILEDBLOBSEQ._serialized_start=3380
  _TEVDISCARDSPOILEDBLOBSEQ._serialized_end=3451
  _TEVRESOLVE._serialized_start=3454
  _TEVRESOLVE._serialized_end=3901
  _TEVRESOLVE_TKEYRANGE._serialized_start=3520
  _TEVRESOLVE_TKEYRANGE._serialized_end=3678
  _TEVRESOLVE_TITEM._serialized_start=3681
  _TEVRESOLVE_TITEM._serialized_end=3901
  _TEVRESOLVERESULT._serialized_start=3904
  _TEVRESOLVERESULT._serialized_end=4214
  _TEVRESOLVERESULT_TRESOLVEDKEY._serialized_start=4061
  _TEVRESOLVERESULT_TRESOLVEDKEY._serialized_end=4214
# @@protoc_insertion_point(module_scope)
