# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/s3/proto/sink.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/library/yql/providers/s3/proto/sink.proto\x12\x08NYql.NS3\"\x9f\x02\n\x05TSink\x12\x0b\n\x03Url\x18\x01 \x01(\t\x12\r\n\x05Token\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12\x0c\n\x04Keys\x18\x04 \x03(\t\x12\x18\n\x0b\x43ompression\x18\x05 \x01(\tH\x00\x88\x01\x01\x12\x18\n\x0bMemoryLimit\x18\x06 \x01(\x04H\x01\x88\x01\x01\x12#\n\x16MaxFileSize_deprecated\x18\x07 \x01(\x04H\x02\x88\x01\x01\x12\x16\n\tExtension\x18\x08 \x01(\tH\x03\x88\x01\x01\x12\x16\n\tMultipart\x18\t \x01(\x08H\x04\x88\x01\x01\x42\x0e\n\x0c_CompressionB\x0e\n\x0c_MemoryLimitB\x19\n\x17_MaxFileSize_deprecatedB\x0c\n\n_ExtensionB\x0c\n\n_MultipartB\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.s3.proto.sink_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TSINK._serialized_start=60
  _TSINK._serialized_end=347
# @@protoc_insertion_point(module_scope)
