# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/s3/proto/retry_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ydb/library/yql/providers/s3/proto/retry_config.proto\x12\x08NYql.NS3\"j\n\x0cTRetryConfig\x12\x16\n\x0eInitialDelayMs\x18\x01 \x01(\x04\x12\x19\n\x11MaxRetriesPerPath\x18\x02 \x01(\r\x12\x0f\n\x07\x45psilon\x18\x03 \x01(\x01\x12\x16\n\x0eMaxRetryTimeMs\x18\x04 \x01(\x04\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.s3.proto.retry_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TRETRYCONFIG._serialized_start=67
  _TRETRYCONFIG._serialized_end=173
# @@protoc_insertion_point(module_scope)
