# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/drivemodel.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ydb/core/protos/drivemodel.proto\x12\x12NKikimrBlobStorage\"\x8a\x07\n\x0bTDriveModel\x12\x17\n\x0cSeekTimeNsec\x18\n \x01(\x04:\x01\x30\x12!\n\x16\x42ulkReadBlockSizeBytes\x18\x1e \x01(\x04:\x01\x30\x12\"\n\x17\x42ulkWriteBlockSizeBytes\x18( \x01(\x04:\x01\x30\x12\x17\n\x0cTrimSpeedBps\x18\x32 \x01(\x04:\x01\x30\x12\x1b\n\x10TotalChunksCount\x18< \x01(\x04:\x01\x30\x12\x17\n\x0cSpeedBpsRead\x18\x46 \x01(\x04:\x01\x30\x12\x18\n\rSpeedBpsWrite\x18P \x01(\x04:\x01\x30\x12\x1a\n\x0fSpeedBpsMinRead\x18Z \x01(\x04:\x01\x30\x12\x1b\n\x10SpeedBpsMinWrite\x18\x64 \x01(\x04:\x01\x30\x12\x1a\n\x0fSpeedBpsMaxRead\x18n \x01(\x04:\x01\x30\x12\x1b\n\x10SpeedBpsMaxWrite\x18x \x01(\x04:\x01\x30\x12!\n\x15OptimalQueueDepthRead\x18\x82\x01 \x01(\x04:\x01\x30\x12\"\n\x16OptimalQueueDepthWrite\x18\x8c\x01 \x01(\x04:\x01\x30\x12\x1f\n\x13GlueingDeadlineRead\x18\x96\x01 \x01(\x04:\x01\x30\x12 \n\x14GlueingDeadlineWrite\x18\xa0\x01 \x01(\x04:\x01\x30\x12O\n\x0bModelSource\x18\xf2\x07 \x01(\x0e\x32,.NKikimrBlobStorage.TDriveModel.EModelSource:\x0bSourceClear\x12\x1c\n\x11SourceModelNumber\x18\xfc\x07 \x01(\t:\x00\x12!\n\x16SourceFirmwareRevision\x18\x86\x08 \x01(\t:\x00\x12\x1d\n\x12SourceSerialNumber\x18\x90\x08 \x01(\t:\x00\x12)\n\x19IsSourceWriteCacheEnabled\x18\x9a\x08 \x01(\x08:\x05\x66\x61lse\x12$\n\x14IsSourceSharedWithOs\x18\xa4\x08 \x01(\x08:\x05\x66\x61lse\x12\"\n\x12IsSourceSolidState\x18\xae\x08 \x01(\x08:\x05\x66\x61lse\"\x8f\x01\n\x0c\x45ModelSource\x12\x0f\n\x0bSourceClear\x10\x00\x12\x19\n\x15SourceGenericHardcode\x10\x01\x12\x1c\n\x18SourceMatchingIdHardcode\x10\x02\x12\x16\n\x12SourceLocalMeasure\x10\x03\x12\x1d\n\x19SourceConfigForMatchingId\x10\x04\"F\n\x0fTDriveModelList\x12\x33\n\nDriveModel\x18\n \x03(\x0b\x32\x1f.NKikimrBlobStorage.TDriveModelB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.drivemodel_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TDRIVEMODEL._serialized_start=57
  _TDRIVEMODEL._serialized_end=963
  _TDRIVEMODEL_EMODELSOURCE._serialized_start=820
  _TDRIVEMODEL_EMODELSOURCE._serialized_end=963
  _TDRIVEMODELLIST._serialized_start=965
  _TDRIVEMODELLIST._serialized_end=1035
# @@protoc_insertion_point(module_scope)
