# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_hive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#ydb/core/protos/counters_hive.proto\x12\rNKikimr.NHive\x1a\x1eydb/core/protos/counters.proto*\xff\x05\n\x0f\x45SimpleCounters\x12-\n\x15\x43OUNTER_TABLETS_TOTAL\x10\x00\x1a\x12\x82\xd6\x1b\x0e\n\x0cTabletsTotal\x12-\n\x15\x43OUNTER_TABLETS_ALIVE\x10\x01\x1a\x12\x82\xd6\x1b\x0e\n\x0cTabletsAlive\x12/\n\x16\x43OUNTER_BOOTQUEUE_SIZE\x10\x02\x1a\x13\x82\xd6\x1b\x0f\n\rBootQueueSize\x12\'\n\x12\x43OUNTER_STATE_DONE\x10\x03\x1a\x0f\x82\xd6\x1b\x0b\n\tStateDone\x12:\n\x1a\x43OUNTER_RESPONSE_TIME_USEC\x10\x04\x1a\x1a\x82\xd6\x1b\x16\n\x14ResponseTimeMicrosec\x12\x31\n\x17\x43OUNTER_METRICS_COUNTER\x10\x05\x1a\x14\x82\xd6\x1b\x10\n\x0eMetricsCounter\x12)\n\x13\x43OUNTER_METRICS_CPU\x10\x06\x1a\x10\x82\xd6\x1b\x0c\n\nMetricsCPU\x12/\n\x16\x43OUNTER_METRICS_MEMORY\x10\x07\x1a\x13\x82\xd6\x1b\x0f\n\rMetricsMemory\x12\x31\n\x17\x43OUNTER_METRICS_NETWORK\x10\x08\x1a\x14\x82\xd6\x1b\x10\n\x0eMetricsNetwork\x12\x31\n\x17\x43OUNTER_BALANCE_SCATTER\x10\t\x1a\x14\x82\xd6\x1b\x10\n\x0e\x42\x61lanceScatter\x12/\n\x16\x43OUNTER_WAITQUEUE_SIZE\x10\n\x1a\x13\x82\xd6\x1b\x0f\n\rWaitQueueSize\x12\x34\n\x19\x43OUNTER_BALANCE_USAGE_MIN\x10\x0b\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42\x61lanceUsageMin\x12\x34\n\x19\x43OUNTER_BALANCE_USAGE_MAX\x10\x0c\x1a\x15\x82\xd6\x1b\x11\n\x0f\x42\x61lanceUsageMax\x12-\n\x15\x43OUNTER_SEQUENCE_FREE\x10\r\x1a\x12\x82\xd6\x1b\x0e\n\x0cSequenceFree\x12\x37\n\x1a\x43OUNTER_SEQUENCE_ALLOCATED\x10\x0e\x1a\x17\x82\xd6\x1b\x13\n\x11SequenceAllocated*\x85\x05\n\x13\x45\x43umulativeCounters\x12\x39\n\x1b\x43OUNTER_BOOTQUEUE_PROCESSED\x10\x00\x1a\x18\x82\xd6\x1b\x14\n\x12\x42ootQueueProcessed\x12/\n\x16\x43OUNTER_BOOTQUEUE_TIME\x10\x01\x1a\x13\x82\xd6\x1b\x0f\n\rBootQueueTime\x12\x35\n\x19\x43OUNTER_AUTOKICK_EXECUTED\x10\x02\x1a\x16\x82\xd6\x1b\x12\n\x10\x41utokickExecuted\x12\x31\n\x17\x43OUNTER_AUTOKICK_FAILED\x10\x03\x1a\x14\x82\xd6\x1b\x10\n\x0e\x41utokickFailed\x12\x35\n\x19\x43OUNTER_BALANCER_EXECUTED\x10\x04\x1a\x16\x82\xd6\x1b\x12\n\x10\x42\x61lancerExecuted\x12\x31\n\x17\x43OUNTER_BALANCER_FAILED\x10\x05\x1a\x14\x82\xd6\x1b\x10\n\x0e\x42\x61lancerFailed\x12/\n\x16\x43OUNTER_DRAIN_EXECUTED\x10\x06\x1a\x13\x82\xd6\x1b\x0f\n\rDrainExecuted\x12+\n\x14\x43OUNTER_DRAIN_FAILED\x10\x07\x1a\x11\x82\xd6\x1b\r\n\x0b\x44rainFailed\x12-\n\x15\x43OUNTER_FILL_EXECUTED\x10\x08\x1a\x12\x82\xd6\x1b\x0e\n\x0c\x46illExecuted\x12-\n\x15\x43OUNTER_TABLETS_MOVED\x10\t\x1a\x12\x82\xd6\x1b\x0e\n\x0cTabletsMoved\x12\x36\n\x1a\x43OUNTER_SUGGESTED_SCALE_UP\x10\n\x1a\x16\x82\xd6\x1b\x12\n\x10SuggestedScaleUp\x12:\n\x1c\x43OUNTER_SUGGESTED_SCALE_DOWN\x10\x0b\x1a\x18\x82\xd6\x1b\x14\n\x12SuggestedScaleDown*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\xa5\x19\n\x08\x45TxTypes\x12.\n\x14TXTYPE_CREATE_TABLET\x10\x00\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxCreateTablet\x12,\n\x13TXTYPE_SYNC_TABLETS\x10\x01\x1a\x13\x8a\xd6\x1b\x0f\n\rTxSyncTablets\x12*\n\x12TXTYPE_KILL_TABLET\x10\x02\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxKillTablet\x12\x39\n\x1aTXTYPE_UPDATE_TABLET_GROUP\x10\x03\x1a\x19\x8a\xd6\x1b\x15\n\x13TxUpdateTabletGroup\x12;\n\x1bTXTYPE_UPDATE_TABLET_STATUS\x10\x04\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxUpdateTabletStatus\x12.\n\x14TXTYPE_REGISTER_NODE\x10\x05\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxRegisterNode\x12&\n\x10TXTYPE_KILL_NODE\x10\x06\x1a\x10\x8a\xd6\x1b\x0c\n\nTxKillNode\x12,\n\x13TXTYPE_ADOPT_TABLET\x10\x07\x1a\x13\x8a\xd6\x1b\x0f\n\rTxAdoptTablet\x12;\n\x1bTXTYPE_UPDATE_TABLET_METRIC\x10\x08\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxUpdateTabletMetric\x12;\n\x1bTXTYPE_UPDATE_TABLET_GROUPS\x10\t\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxUpdateTabletGroups\x12\x41\n\x1eTXTYPE_UNLOCK_TABLET_EXECUTION\x10\n\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxUnlockTabletExecution\x12\x32\n\x16TXTYPE_REASSIGN_GROUPS\x10\x0b\x1a\x16\x8a\xd6\x1b\x12\n\x10TxReassignGroups\x12=\n\x1cTXTYPE_LOCK_TABLET_EXECUTION\x10\x0c\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxLockTabletExecution\x12\x32\n\x16TXTYPE_LOAD_EVERYTHING\x10\r\x1a\x16\x8a\xd6\x1b\x12\n\x10TxLoadEverything\x12*\n\x12TXTYPE_INIT_SCHEME\x10\x0e\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitScheme\x12;\n\x1bTXTYPE_DELETE_TABLET_RESULT\x10\x0f\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxDeleteTabletResult\x12.\n\x14TXTYPE_DELETE_TABLET\x10\x10\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxDeleteTablet\x12\x37\n\x19TXTYPE_CUT_TABLET_HISTORY\x10\x11\x1a\x18\x8a\xd6\x1b\x14\n\x12TxCutTabletHistory\x12;\n\x1bTXTYPE_BLOCK_STORAGE_RESULT\x10\x12\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxBlockStorageResult\x12\x41\n\x1eTXTYPE_REQUEST_TABLET_SEQUENCE\x10\x13\x1a\x1d\x8a\xd6\x1b\x19\n\x17TxRequestTabletSequence\x12\x43\n\x1fTXTYPE_RESPONSE_TABLET_SEQUENCE\x10\x14\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxResponseTabletSequence\x12G\n!TXTYPE_PROCESS_PENDING_OPERATIONS\x10\x15\x1a \x8a\xd6\x1b\x1c\n\x1aTxProcessPendingOperations\x12+\n\x13TXTYPE_MON_DB_STATE\x10\x16\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonDbState\x12-\n\x14TXTYPE_MON_MEM_STATE\x10\x17\x1a\x13\x8a\xd6\x1b\x0f\n\rTxMonMemState\x12.\n\x14TXTYPE_MON_RESOURCES\x10\x18\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxMonResources\x12,\n\x13TXTYPE_MON_SETTINGS\x10\x19\x1a\x13\x8a\xd6\x1b\x0f\n\rTxMonSettings\x12*\n\x12TXTYPE_MON_LANDING\x10\x1a\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonLanding\x12\x33\n\x17TXTYPE_MON_LANDING_DATA\x10\x1b\x1a\x16\x8a\xd6\x1b\x12\n\x10TxMonLandingData\x12+\n\x13TXTYPE_MON_SET_DOWN\x10\x1c\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonSetDown\x12/\n\x15TXTYPE_MON_SET_FREEZE\x10\x1d\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxMonSetFreeze\x12-\n\x14TXTYPE_MON_KICK_NODE\x10\x1e\x1a\x13\x8a\xd6\x1b\x0f\n\rTxMonKickNode\x12.\n\x14TXTYPE_MON_REBALANCE\x10\x1f\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxMonRebalance\x12\x39\n\x1aTXTYPE_MON_REASSIGN_TABLET\x10 \x1a\x19\x8a\xd6\x1b\x15\n\x13TxMonReassignTablet\x12\x33\n\x17TXTYPE_MON_RESET_TABLET\x10!\x1a\x16\x8a\xd6\x1b\x12\n\x10TxMonResetTablet\x12(\n\x11TXTYPE_MON_GROUPS\x10\"\x1a\x11\x8a\xd6\x1b\r\n\x0bTxMonGroups\x12-\n\x14TXTYPE_MON_NOT_READY\x10#\x1a\x13\x8a\xd6\x1b\x0f\n\rTxMonNotReady\x12*\n\x12TXTYPE_MON_STORAGE\x10$\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxMonStorage\x12\x37\n\x19TXTYPE_PROCESS_BOOT_QUEUE\x10%\x1a\x18\x8a\xd6\x1b\x14\n\x12TxProcessBootQueue\x12!\n\rTXTYPE_STATUS\x10&\x1a\x0e\x8a\xd6\x1b\n\n\x08TxStatus\x12\x32\n\x16TXTYPE_DISCONNECT_NODE\x10\'\x1a\x16\x8a\xd6\x1b\x12\n\x10TxDisconnectNode\x12\x31\n\x16TXTYPE_MON_FIND_TABLET\x10(\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxMonFindTablet\x12.\n\x14TXTYPE_UPDATE_DOMAIN\x10)\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxUpdateDomain\x12\x31\n\x16TXTYPE_MON_STOP_TABLET\x10*\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxMonStopTablet\x12\x35\n\x18TXTYPE_MON_RESUME_TABLET\x10+\x1a\x17\x8a\xd6\x1b\x13\n\x11TxMonResumeTablet\x12:\n\x1aTXTYPE_CONFIGURE_SUBDOMAIN\x10,\x1a\x1a\x8a\xd6\x1b\x16\n\x14TxConfigureSubdomain\x12\x37\n\x19TXTYPE_MON_INIT_MIGRATION\x10-\x1a\x18\x8a\xd6\x1b\x14\n\x12TxMonInitMigration\x12\x39\n\x1aTXTYPE_MON_QUERY_MIGRATION\x10.\x1a\x19\x8a\xd6\x1b\x15\n\x13TxMonQueryMigration\x12.\n\x14TXTYPE_SEIZE_TABLETS\x10/\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxSeizeTablets\x12\x39\n\x1aTXTYPE_SEIZE_TABLETS_REPLY\x10\x30\x1a\x19\x8a\xd6\x1b\x15\n\x13TxSeizeTabletsReply\x12\x32\n\x16TXTYPE_RELEASE_TABLETS\x10\x31\x1a\x16\x8a\xd6\x1b\x12\n\x10TxReleaseTablets\x12=\n\x1cTXTYPE_RELEASE_TABLETS_REPLY\x10\x32\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxReleaseTabletsReply\x12/\n\x15TXTYPE_MON_DRAIN_NODE\x10\x33\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxMonDrainNode\x12\x31\n\x16TXTYPE_MON_TABLET_INFO\x10\x34\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxMonTabletInfo\x12,\n\x13TXTYPE_START_TABLET\x10\x35\x1a\x13\x8a\xd6\x1b\x0f\n\rTxStartTablet\x12*\n\x12TXTYPE_STOP_TABLET\x10\x36\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxStopTablet\x12.\n\x14TXTYPE_RESUME_TABLET\x10\x37\x1a\x14\x8a\xd6\x1b\x10\n\x0eTxResumeTablet\x12\x30\n\x15TXTYPE_RESTART_TABLET\x10\x38\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxRestartTablet\x12\x31\n\x16TXTYPE_MON_MOVE_TABLET\x10\x39\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxMonMoveTablet\x12\x39\n\x1aTXTYPE_TABLET_OWNERS_REPLY\x10:\x1a\x19\x8a\xd6\x1b\x15\n\x13TxTabletOwnersReply\x12=\n\x1cTXTYPE_REQUEST_TABLET_OWNERS\x10;\x1a\x1b\x8a\xd6\x1b\x17\n\x15TxRequestTabletOwners\x12H\n\"TXTYPE_REASSIGN_GROUPS_ON_DECOMMIT\x10<\x1a \x8a\xd6\x1b\x1c\n\x1aTxReassignGroupsOnDecommitB \n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x04Hive')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_hive_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\004Hive'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLETS_TOTAL"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLETS_TOTAL"]._serialized_options = b'\202\326\033\016\n\014TabletsTotal'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLETS_ALIVE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_TABLETS_ALIVE"]._serialized_options = b'\202\326\033\016\n\014TabletsAlive'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_SIZE"]._serialized_options = b'\202\326\033\017\n\rBootQueueSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STATE_DONE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_STATE_DONE"]._serialized_options = b'\202\326\033\013\n\tStateDone'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_RESPONSE_TIME_USEC"]._serialized_options = b'\202\326\033\026\n\024ResponseTimeMicrosec'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_COUNTER"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_COUNTER"]._serialized_options = b'\202\326\033\020\n\016MetricsCounter'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_CPU"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_CPU"]._serialized_options = b'\202\326\033\014\n\nMetricsCPU'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_MEMORY"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_MEMORY"]._serialized_options = b'\202\326\033\017\n\rMetricsMemory'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_NETWORK"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_METRICS_NETWORK"]._serialized_options = b'\202\326\033\020\n\016MetricsNetwork'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_SCATTER"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_SCATTER"]._serialized_options = b'\202\326\033\020\n\016BalanceScatter'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_WAITQUEUE_SIZE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_WAITQUEUE_SIZE"]._serialized_options = b'\202\326\033\017\n\rWaitQueueSize'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_USAGE_MIN"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_USAGE_MIN"]._serialized_options = b'\202\326\033\021\n\017BalanceUsageMin'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_USAGE_MAX"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_BALANCE_USAGE_MAX"]._serialized_options = b'\202\326\033\021\n\017BalanceUsageMax'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_FREE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_FREE"]._serialized_options = b'\202\326\033\016\n\014SequenceFree'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_ALLOCATED"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEQUENCE_ALLOCATED"]._serialized_options = b'\202\326\033\023\n\021SequenceAllocated'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_PROCESSED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_PROCESSED"]._serialized_options = b'\202\326\033\024\n\022BootQueueProcessed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_TIME"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BOOTQUEUE_TIME"]._serialized_options = b'\202\326\033\017\n\rBootQueueTime'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_AUTOKICK_EXECUTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_AUTOKICK_EXECUTED"]._serialized_options = b'\202\326\033\022\n\020AutokickExecuted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_AUTOKICK_FAILED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_AUTOKICK_FAILED"]._serialized_options = b'\202\326\033\020\n\016AutokickFailed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BALANCER_EXECUTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BALANCER_EXECUTED"]._serialized_options = b'\202\326\033\022\n\020BalancerExecuted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BALANCER_FAILED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_BALANCER_FAILED"]._serialized_options = b'\202\326\033\020\n\016BalancerFailed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DRAIN_EXECUTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DRAIN_EXECUTED"]._serialized_options = b'\202\326\033\017\n\rDrainExecuted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DRAIN_FAILED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_DRAIN_FAILED"]._serialized_options = b'\202\326\033\r\n\013DrainFailed'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FILL_EXECUTED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_FILL_EXECUTED"]._serialized_options = b'\202\326\033\016\n\014FillExecuted'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TABLETS_MOVED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_TABLETS_MOVED"]._serialized_options = b'\202\326\033\016\n\014TabletsMoved'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SUGGESTED_SCALE_UP"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SUGGESTED_SCALE_UP"]._serialized_options = b'\202\326\033\022\n\020SuggestedScaleUp'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SUGGESTED_SCALE_DOWN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SUGGESTED_SCALE_DOWN"]._serialized_options = b'\202\326\033\024\n\022SuggestedScaleDown'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_CREATE_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CREATE_TABLET"]._serialized_options = b'\212\326\033\020\n\016TxCreateTablet'
  _ETXTYPES.values_by_name["TXTYPE_SYNC_TABLETS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SYNC_TABLETS"]._serialized_options = b'\212\326\033\017\n\rTxSyncTablets'
  _ETXTYPES.values_by_name["TXTYPE_KILL_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_KILL_TABLET"]._serialized_options = b'\212\326\033\016\n\014TxKillTablet'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_GROUP"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_GROUP"]._serialized_options = b'\212\326\033\025\n\023TxUpdateTabletGroup'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_STATUS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_STATUS"]._serialized_options = b'\212\326\033\026\n\024TxUpdateTabletStatus'
  _ETXTYPES.values_by_name["TXTYPE_REGISTER_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REGISTER_NODE"]._serialized_options = b'\212\326\033\020\n\016TxRegisterNode'
  _ETXTYPES.values_by_name["TXTYPE_KILL_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_KILL_NODE"]._serialized_options = b'\212\326\033\014\n\nTxKillNode'
  _ETXTYPES.values_by_name["TXTYPE_ADOPT_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_ADOPT_TABLET"]._serialized_options = b'\212\326\033\017\n\rTxAdoptTablet'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_METRIC"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_METRIC"]._serialized_options = b'\212\326\033\026\n\024TxUpdateTabletMetric'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_GROUPS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_TABLET_GROUPS"]._serialized_options = b'\212\326\033\026\n\024TxUpdateTabletGroups'
  _ETXTYPES.values_by_name["TXTYPE_UNLOCK_TABLET_EXECUTION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UNLOCK_TABLET_EXECUTION"]._serialized_options = b'\212\326\033\031\n\027TxUnlockTabletExecution'
  _ETXTYPES.values_by_name["TXTYPE_REASSIGN_GROUPS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REASSIGN_GROUPS"]._serialized_options = b'\212\326\033\022\n\020TxReassignGroups'
  _ETXTYPES.values_by_name["TXTYPE_LOCK_TABLET_EXECUTION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOCK_TABLET_EXECUTION"]._serialized_options = b'\212\326\033\027\n\025TxLockTabletExecution'
  _ETXTYPES.values_by_name["TXTYPE_LOAD_EVERYTHING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_LOAD_EVERYTHING"]._serialized_options = b'\212\326\033\022\n\020TxLoadEverything'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEME"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEME"]._serialized_options = b'\212\326\033\016\n\014TxInitScheme'
  _ETXTYPES.values_by_name["TXTYPE_DELETE_TABLET_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DELETE_TABLET_RESULT"]._serialized_options = b'\212\326\033\026\n\024TxDeleteTabletResult'
  _ETXTYPES.values_by_name["TXTYPE_DELETE_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DELETE_TABLET"]._serialized_options = b'\212\326\033\020\n\016TxDeleteTablet'
  _ETXTYPES.values_by_name["TXTYPE_CUT_TABLET_HISTORY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CUT_TABLET_HISTORY"]._serialized_options = b'\212\326\033\024\n\022TxCutTabletHistory'
  _ETXTYPES.values_by_name["TXTYPE_BLOCK_STORAGE_RESULT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_BLOCK_STORAGE_RESULT"]._serialized_options = b'\212\326\033\026\n\024TxBlockStorageResult'
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_TABLET_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_TABLET_SEQUENCE"]._serialized_options = b'\212\326\033\031\n\027TxRequestTabletSequence'
  _ETXTYPES.values_by_name["TXTYPE_RESPONSE_TABLET_SEQUENCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESPONSE_TABLET_SEQUENCE"]._serialized_options = b'\212\326\033\032\n\030TxResponseTabletSequence'
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_PENDING_OPERATIONS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_PENDING_OPERATIONS"]._serialized_options = b'\212\326\033\034\n\032TxProcessPendingOperations'
  _ETXTYPES.values_by_name["TXTYPE_MON_DB_STATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_DB_STATE"]._serialized_options = b'\212\326\033\016\n\014TxMonDbState'
  _ETXTYPES.values_by_name["TXTYPE_MON_MEM_STATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_MEM_STATE"]._serialized_options = b'\212\326\033\017\n\rTxMonMemState'
  _ETXTYPES.values_by_name["TXTYPE_MON_RESOURCES"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_RESOURCES"]._serialized_options = b'\212\326\033\020\n\016TxMonResources'
  _ETXTYPES.values_by_name["TXTYPE_MON_SETTINGS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_SETTINGS"]._serialized_options = b'\212\326\033\017\n\rTxMonSettings'
  _ETXTYPES.values_by_name["TXTYPE_MON_LANDING"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_LANDING"]._serialized_options = b'\212\326\033\016\n\014TxMonLanding'
  _ETXTYPES.values_by_name["TXTYPE_MON_LANDING_DATA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_LANDING_DATA"]._serialized_options = b'\212\326\033\022\n\020TxMonLandingData'
  _ETXTYPES.values_by_name["TXTYPE_MON_SET_DOWN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_SET_DOWN"]._serialized_options = b'\212\326\033\016\n\014TxMonSetDown'
  _ETXTYPES.values_by_name["TXTYPE_MON_SET_FREEZE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_SET_FREEZE"]._serialized_options = b'\212\326\033\020\n\016TxMonSetFreeze'
  _ETXTYPES.values_by_name["TXTYPE_MON_KICK_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_KICK_NODE"]._serialized_options = b'\212\326\033\017\n\rTxMonKickNode'
  _ETXTYPES.values_by_name["TXTYPE_MON_REBALANCE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_REBALANCE"]._serialized_options = b'\212\326\033\020\n\016TxMonRebalance'
  _ETXTYPES.values_by_name["TXTYPE_MON_REASSIGN_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_REASSIGN_TABLET"]._serialized_options = b'\212\326\033\025\n\023TxMonReassignTablet'
  _ETXTYPES.values_by_name["TXTYPE_MON_RESET_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_RESET_TABLET"]._serialized_options = b'\212\326\033\022\n\020TxMonResetTablet'
  _ETXTYPES.values_by_name["TXTYPE_MON_GROUPS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_GROUPS"]._serialized_options = b'\212\326\033\r\n\013TxMonGroups'
  _ETXTYPES.values_by_name["TXTYPE_MON_NOT_READY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_NOT_READY"]._serialized_options = b'\212\326\033\017\n\rTxMonNotReady'
  _ETXTYPES.values_by_name["TXTYPE_MON_STORAGE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_STORAGE"]._serialized_options = b'\212\326\033\016\n\014TxMonStorage'
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_BOOT_QUEUE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_PROCESS_BOOT_QUEUE"]._serialized_options = b'\212\326\033\024\n\022TxProcessBootQueue'
  _ETXTYPES.values_by_name["TXTYPE_STATUS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STATUS"]._serialized_options = b'\212\326\033\n\n\010TxStatus'
  _ETXTYPES.values_by_name["TXTYPE_DISCONNECT_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DISCONNECT_NODE"]._serialized_options = b'\212\326\033\022\n\020TxDisconnectNode'
  _ETXTYPES.values_by_name["TXTYPE_MON_FIND_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_FIND_TABLET"]._serialized_options = b'\212\326\033\021\n\017TxMonFindTablet'
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DOMAIN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_UPDATE_DOMAIN"]._serialized_options = b'\212\326\033\020\n\016TxUpdateDomain'
  _ETXTYPES.values_by_name["TXTYPE_MON_STOP_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_STOP_TABLET"]._serialized_options = b'\212\326\033\021\n\017TxMonStopTablet'
  _ETXTYPES.values_by_name["TXTYPE_MON_RESUME_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_RESUME_TABLET"]._serialized_options = b'\212\326\033\023\n\021TxMonResumeTablet'
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE_SUBDOMAIN"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIGURE_SUBDOMAIN"]._serialized_options = b'\212\326\033\026\n\024TxConfigureSubdomain'
  _ETXTYPES.values_by_name["TXTYPE_MON_INIT_MIGRATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_INIT_MIGRATION"]._serialized_options = b'\212\326\033\024\n\022TxMonInitMigration'
  _ETXTYPES.values_by_name["TXTYPE_MON_QUERY_MIGRATION"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_QUERY_MIGRATION"]._serialized_options = b'\212\326\033\025\n\023TxMonQueryMigration'
  _ETXTYPES.values_by_name["TXTYPE_SEIZE_TABLETS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEIZE_TABLETS"]._serialized_options = b'\212\326\033\020\n\016TxSeizeTablets'
  _ETXTYPES.values_by_name["TXTYPE_SEIZE_TABLETS_REPLY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEIZE_TABLETS_REPLY"]._serialized_options = b'\212\326\033\025\n\023TxSeizeTabletsReply'
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_TABLETS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_TABLETS"]._serialized_options = b'\212\326\033\022\n\020TxReleaseTablets'
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_TABLETS_REPLY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RELEASE_TABLETS_REPLY"]._serialized_options = b'\212\326\033\027\n\025TxReleaseTabletsReply'
  _ETXTYPES.values_by_name["TXTYPE_MON_DRAIN_NODE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_DRAIN_NODE"]._serialized_options = b'\212\326\033\020\n\016TxMonDrainNode'
  _ETXTYPES.values_by_name["TXTYPE_MON_TABLET_INFO"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_TABLET_INFO"]._serialized_options = b'\212\326\033\021\n\017TxMonTabletInfo'
  _ETXTYPES.values_by_name["TXTYPE_START_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_START_TABLET"]._serialized_options = b'\212\326\033\017\n\rTxStartTablet'
  _ETXTYPES.values_by_name["TXTYPE_STOP_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_STOP_TABLET"]._serialized_options = b'\212\326\033\016\n\014TxStopTablet'
  _ETXTYPES.values_by_name["TXTYPE_RESUME_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESUME_TABLET"]._serialized_options = b'\212\326\033\020\n\016TxResumeTablet'
  _ETXTYPES.values_by_name["TXTYPE_RESTART_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_RESTART_TABLET"]._serialized_options = b'\212\326\033\021\n\017TxRestartTablet'
  _ETXTYPES.values_by_name["TXTYPE_MON_MOVE_TABLET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_MON_MOVE_TABLET"]._serialized_options = b'\212\326\033\021\n\017TxMonMoveTablet'
  _ETXTYPES.values_by_name["TXTYPE_TABLET_OWNERS_REPLY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_TABLET_OWNERS_REPLY"]._serialized_options = b'\212\326\033\025\n\023TxTabletOwnersReply'
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_TABLET_OWNERS"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REQUEST_TABLET_OWNERS"]._serialized_options = b'\212\326\033\027\n\025TxRequestTabletOwners'
  _ETXTYPES.values_by_name["TXTYPE_REASSIGN_GROUPS_ON_DECOMMIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_REASSIGN_GROUPS_ON_DECOMMIT"]._serialized_options = b'\212\326\033\034\n\032TxReassignGroupsOnDecommit'
  _ESIMPLECOUNTERS._serialized_start=87
  _ESIMPLECOUNTERS._serialized_end=854
  _ECUMULATIVECOUNTERS._serialized_start=857
  _ECUMULATIVECOUNTERS._serialized_end=1502
  _EPERCENTILECOUNTERS._serialized_start=1504
  _EPERCENTILECOUNTERS._serialized_end=1582
  _ETXTYPES._serialized_start=1585
  _ETXTYPES._serialized_end=4822
# @@protoc_insertion_point(module_scope)
