# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/common/proto/udf_resolver.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9ydb/library/yql/providers/common/proto/udf_resolver.proto\x12\x04NYql\"?\n\tTFunction\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\x12\n\nTypeConfig\x18\x02 \x02(\t\x12\x10\n\x08UserType\x18\x03 \x01(\t\"D\n\nTArgResult\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\x0c\n\x04Type\x18\x02 \x02(\t\x12\x0b\n\x03\x44oc\x18\x03 \x02(\t\x12\r\n\x05\x46lags\x18\x04 \x02(\r\"\x90\x02\n\x0fTFunctionResult\x12\x1a\n\x12NormalizedUserType\x18\x01 \x01(\t\x12\x15\n\rRunConfigType\x18\x02 \x01(\t\x12\x14\n\x0c\x43\x61llableType\x18\x03 \x01(\t\x12\r\n\x05\x45rror\x18\x04 \x01(\t\x12\x0c\n\x04Name\x18\x05 \x01(\t\x12\x0b\n\x03\x44oc\x18\x07 \x01(\t\x12\x17\n\x0fIsTypeAwareness\x18\x08 \x01(\x08\x12\x10\n\x08\x41rgCount\x18\t \x01(\r\x12\x18\n\x10OptionalArgCount\x18\n \x01(\r\x12\x1e\n\x04\x41rgs\x18\x0b \x03(\x0b\x32\x10.NYql.TArgResult\x12\x12\n\nReturnType\x18\x0c \x01(\t\x12\x11\n\tReturnDoc\x18\r \x01(\t\"Z\n\x07TImport\x12\x11\n\tFileAlias\x18\x01 \x02(\t\x12\x0c\n\x04Path\x18\x02 \x02(\t\x12\x15\n\x06System\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x17\n\x0f\x43ustomUdfPrefix\x18\x04 \x01(\t\"z\n\rTImportResult\x12\x11\n\tFileAlias\x18\x01 \x02(\t\x12\x0f\n\x07Modules\x18\x02 \x03(\t\x12\r\n\x05\x45rror\x18\x03 \x01(\t\x12\x10\n\x08\x46ileSize\x18\x04 \x01(\x04\x12\x0b\n\x03Md5\x18\x05 \x01(\t\x12\x17\n\x0f\x43ustomUdfPrefix\x18\x06 \x01(\t\"I\n\x08TResolve\x12\x1e\n\x07Imports\x18\x01 \x03(\x0b\x32\r.NYql.TImport\x12\x1d\n\x04Udfs\x18\x02 \x03(\x0b\x32\x0f.NYql.TFunction\"[\n\x0eTResolveResult\x12$\n\x07Imports\x18\x01 \x03(\x0b\x32\x13.NYql.TImportResult\x12#\n\x04Udfs\x18\x02 \x03(\x0b\x32\x15.NYql.TFunctionResultB\x15\n\x13ru.yandex.yql.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.common.proto.udf_resolver_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023ru.yandex.yql.proto'
  _TFUNCTION._serialized_start=67
  _TFUNCTION._serialized_end=130
  _TARGRESULT._serialized_start=132
  _TARGRESULT._serialized_end=200
  _TFUNCTIONRESULT._serialized_start=203
  _TFUNCTIONRESULT._serialized_end=475
  _TIMPORT._serialized_start=477
  _TIMPORT._serialized_end=567
  _TIMPORTRESULT._serialized_start=569
  _TIMPORTRESULT._serialized_end=691
  _TRESOLVE._serialized_start=693
  _TRESOLVE._serialized_end=766
  _TRESOLVERESULT._serialized_start=768
  _TRESOLVERESULT._serialized_end=859
# @@protoc_insertion_point(module_scope)
