# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/hive.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import tablet_pb2 as ydb_dot_core_dot_protos_dot_tablet__pb2
from ydb.core.protos import subdomains_pb2 as ydb_dot_core_dot_protos_dot_subdomains__pb2
from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2
from ydb.core.protos import follower_group_pb2 as ydb_dot_core_dot_protos_dot_follower__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1aydb/core/protos/hive.proto\x12\x0bNKikimrHive\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1cydb/core/protos/tablet.proto\x1a ydb/core/protos/subdomains.proto\x1a/ydb/core/protos/bind_channel_storage_pool.proto\x1a$ydb/core/protos/follower_group.proto\"\xad\x01\n\x0cTChannelInfo\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\x37\n\x07History\x18\x03 \x03(\x0b\x32&.NKikimrHive.TChannelInfo.THistorySlot\x1aJ\n\x0cTHistorySlot\x12\x16\n\x0e\x46romGeneration\x18\x01 \x01(\r\x12\x0f\n\x07GroupID\x18\x02 \x01(\r\x12\x11\n\tTimestamp\x18\x03 \x01(\x04\"!\n\rTEvBootTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\"S\n\x12TEvBootTabletReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x11\n\tStatusMsg\x18\x02 \x01(\t\"d\n\x0fTTabletCategory\x12\x18\n\x10TabletCategoryID\x18\x01 \x01(\x04\x12\x1c\n\x14MaxDisconnectTimeout\x18\x02 \x01(\x04\x12\x19\n\x11StickTogetherInDC\x18\x03 \x01(\x08\"B\n\x11TDataCentersGroup\x12\x19\n\rDataCenterNum\x18\x01 \x03(\x04\x42\x02\x18\x01\x12\x12\n\nDataCenter\x18\x02 \x03(\t\"S\n\x16TDataCentersPreference\x12\x39\n\x11\x44\x61taCentersGroups\x18\x01 \x03(\x0b\x32\x1e.NKikimrHive.TDataCentersGroup\"\xe4\x07\n\x0fTEvCreateTablet\x12\r\n\x05Owner\x18\x01 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x02 \x01(\x04\x12\x39\n\nTabletType\x18\x03 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x1a\n\x12\x41ssignStateStorage\x18\x04 \x01(\r\x12\x16\n\x0e\x41llowedNodeIDs\x18\x07 \x03(\r\x12#\n\x17\x41llowedDataCenterNumIDs\x18\x0e \x03(\x04\x42\x02\x18\x01\x12\x34\n\x0eTabletCategory\x18\x10 \x01(\x0b\x32\x1c.NKikimrHive.TTabletCategory\x12\x33\n\x0e\x46ollowerGroups\x18\x11 \x03(\x0b\x32\x1b.NKikimrHive.TFollowerGroup\x12\x33\n\x0cObjectDomain\x18\x12 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x34\n\x0eTabletBootMode\x18\x13 \x01(\x0e\x32\x1c.NKikimrHive.ETabletBootMode\x12\x10\n\x08ObjectId\x18\x14 \x01(\x04\x12\x38\n\x0e\x42indedChannels\x18\x15 \x03(\x0b\x32 .NKikimrStoragePool.TChannelBind\x12\x10\n\x08TabletID\x18\x16 \x01(\x06\x12\x35\n\x0e\x41llowedDomains\x18\x17 \x03(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x42\n\x15\x44\x61taCentersPreference\x18\x18 \x01(\x0b\x32#.NKikimrHive.TDataCentersPreference\x12\x1a\n\x12\x41llowedDataCenters\x18\x19 \x03(\t\x12\x34\n\x0e\x42\x61lancerPolicy\x18\x1a \x01(\x0e\x32\x1c.NKikimrHive.EBalancerPolicy\x12\x1b\n\x0f\x43hannelsProfile\x18\x05 \x01(\rB\x02\x18\x01\x12\x11\n\x05\x46lags\x18\x06 \x01(\rB\x02\x18\x01\x12#\n\x17\x42ootTimeoutMilliSeconds\x18\x08 \x01(\rB\x02\x18\x01\x12\x1c\n\x10\x42ootAttemptLimit\x18\t \x01(\rB\x02\x18\x01\x12\x18\n\x06Weight\x18\n \x01(\x04:\x04\x31\x30\x30\x30\x42\x02\x18\x01\x12\x18\n\rFollowerCount\x18\x0b \x01(\r:\x01\x30\x12%\n\x16\x41llowFollowerPromotion\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\'\n\x18\x43rossDataCenterFollowers\x18\r \x01(\x08:\x05\x66\x61lse\x12$\n\x1c\x43rossDataCenterFollowerCount\x18\x0f \x01(\r\"2\n\x0fTEvLookupTablet\x12\r\n\x05Owner\x18\x01 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x02 \x01(\x04\"\xeb\x01\n\x14TEvCreateTabletReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\r\n\x05Owner\x18\x02 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x03 \x01(\x04\x12\x10\n\x08TabletID\x18\x04 \x01(\x06\x12\x0e\n\x06Origin\x18\x05 \x01(\x06\x12.\n\x0b\x45rrorReason\x18\x06 \x01(\x0e\x32\x19.NKikimrHive.EErrorReason\x12\x34\n\x0e\x46orwardRequest\x18\x07 \x01(\x0b\x32\x1c.NKikimrHive.TForwardRequest\"W\n\x17TEvTabletCreationResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\"P\n\rTEvStopTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12-\n\rActorToNotify\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\"S\n\x13TEvStopTabletResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\"U\n\x15TEvResumeTabletResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\"=\n\x0fTChannelRequest\x12\n\n\x02Id\x18\x01 \x01(\r\x12\x0c\n\x04Type\x18\x02 \x01(\r\x12\x10\n\x08Locality\x18\x03 \x01(\r\"\x90\x01\n\x14TEvReconfigureTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x10\n\x08\x41utoboot\x18\x02 \x01(\x08\x12$\n\x1c\x43hannelReconfigureGeneration\x18\x03 \x01(\r\x12.\n\x08\x43hannels\x18\x04 \x03(\x0b\x32\x1c.NKikimrHive.TChannelRequest\"\xa7\x01\n\x0eTEvAdoptTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x11\n\tPrevOwner\x18\x02 \x01(\x06\x12\x14\n\x0cPrevOwnerIdx\x18\x03 \x01(\x04\x12\x39\n\nTabletType\x18\x04 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\r\n\x05Owner\x18\x05 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x06 \x01(\x04\"\x95\x01\n\x13TEvAdoptTabletReply\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x0e\n\x06Origin\x18\x02 \x01(\x06\x12\r\n\x05Owner\x18\x03 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x04 \x01(\x04\x12*\n\x06Status\x18\x05 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0f\n\x07\x45xplain\x18\x06 \x01(\t\"\x98\x01\n\x19TEvReconfigureTabletReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\x12\x10\n\x08\x41utoboot\x18\x03 \x01(\x08\x12+\n\x08\x43hannels\x18\x04 \x03(\x0b\x32\x19.NKikimrHive.TChannelInfo\"i\n\x0fTEvDeleteTablet\x12\x14\n\x0cShardOwnerId\x18\x01 \x01(\x06\x12\x15\n\rShardLocalIdx\x18\x02 \x03(\x04\x12\x17\n\x0fTxId_Deprecated\x18\x03 \x01(\x04\x12\x10\n\x08TabletID\x18\x04 \x03(\x06\"\xce\x01\n\x14TEvDeleteTabletReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Origin\x18\x02 \x01(\x06\x12\x17\n\x0fTxId_Deprecated\x18\x03 \x01(\x04\x12\x14\n\x0cShardOwnerId\x18\x04 \x01(\x04\x12\x15\n\rShardLocalIdx\x18\x05 \x03(\x04\x12\x34\n\x0e\x46orwardRequest\x18\x06 \x01(\x0b\x32\x1c.NKikimrHive.TForwardRequest\"4\n\x15TEvDeleteOwnerTablets\x12\r\n\x05Owner\x18\x01 \x01(\x06\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"u\n\x1aTEvDeleteOwnerTabletsReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\r\n\x05Owner\x18\x02 \x01(\x06\x12\x0c\n\x04TxId\x18\x03 \x01(\x04\x12\x0e\n\x06Origin\x18\x04 \x01(\x06\"Q\n\x14TEvLookupChannelInfo\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x10\n\x08\x43hannels\x18\x02 \x03(\r\x12\x15\n\rForGeneration\x18\x03 \x03(\r\"~\n\x0eTEvChannelInfo\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x10\n\x08TabletID\x18\x02 \x01(\x06\x12.\n\x0b\x43hannelInfo\x18\x03 \x03(\x0b\x32\x19.NKikimrHive.TChannelInfo\"j\n\x0eTTabletMetrics\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x32\n\rResourceUsage\x18\x04 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x12\n\nFollowerID\x18\x03 \x01(\r\"\x97\x01\n\x10TEvTabletMetrics\x12\x32\n\rTabletMetrics\x18\x01 \x03(\x0b\x32\x1b.NKikimrHive.TTabletMetrics\x12\x37\n\x12TotalResourceUsage\x18\x02 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x16\n\x0eTotalNodeUsage\x18\x03 \x01(\x01\"\xef\x01\n\x11TEvReassignTablet\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x10\n\x08\x43hannels\x18\x02 \x03(\r\x12\x16\n\x0e\x46orcedGroupIDs\x18\x03 \x03(\r\x12J\n\x0eReassignReason\x18\x04 \x01(\x0e\x32\x32.NKikimrHive.TEvReassignTablet.EHiveReassignReason\"R\n\x13\x45HiveReassignReason\x12\x1b\n\x17HIVE_REASSIGN_REASON_NO\x10\x00\x12\x1e\n\x1aHIVE_REASSIGN_REASON_SPACE\x10\x01\"\'\n\x0fTForwardRequest\x12\x14\n\x0cHiveTabletId\x18\x01 \x01(\x06\"\xc3\x01\n\x12TEvRequestHiveInfo\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x39\n\nTabletType\x18\x02 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x17\n\x0fReturnFollowers\x18\x03 \x01(\x08\x12\x12\n\nFollowerID\x18\x04 \x01(\r\x12\x15\n\rReturnMetrics\x18\x05 \x01(\x08\x12\x1c\n\x14ReturnChannelHistory\x18\x06 \x01(\x08\"\xad\x01\n\x13TEvResponseHiveInfo\x12)\n\x07Tablets\x18\x01 \x03(\x0b\x32\x18.NKikimrHive.TTabletInfo\x12\x34\n\x0e\x46orwardRequest\x18\x02 \x01(\x0b\x32\x1c.NKikimrHive.TForwardRequest\x12\x1a\n\x12StartTimeTimestamp\x18\x03 \x01(\x04\x12\x19\n\x11ResponseTimestamp\x18\x04 \x01(\x04\"K\n\x19TEvRequestHiveDomainStats\x12\x17\n\x0fReturnFollowers\x18\x03 \x01(\x08\x12\x15\n\rReturnMetrics\x18\x05 \x01(\x08\"e\n\x1aTHiveDomainStatsStateCount\x12\x38\n\rVolatileState\x18\x01 \x01(\x0e\x32!.NKikimrHive.ETabletVolatileState\x12\r\n\x05\x43ount\x18\x02 \x01(\r\"\xc3\x01\n\x10THiveDomainStats\x12\x0f\n\x07ShardId\x18\x01 \x01(\x06\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12;\n\nStateStats\x18\x03 \x03(\x0b\x32\'.NKikimrHive.THiveDomainStatsStateCount\x12,\n\x07Metrics\x18\x04 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x0f\n\x07NodeIds\x18\x05 \x03(\r\x12\x12\n\nAliveNodes\x18\x06 \x01(\r\"P\n\x1aTEvResponseHiveDomainStats\x12\x32\n\x0b\x44omainStats\x18\x01 \x03(\x0b\x32\x1d.NKikimrHive.THiveDomainStats\"0\n\x17TEvRequestHiveNodeStats\x12\x15\n\rReturnMetrics\x18\x05 \x01(\x08\"\xf5\x01\n\x0eTHiveNodeStats\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12;\n\nStateStats\x18\x03 \x03(\x0b\x32\'.NKikimrHive.THiveDomainStatsStateCount\x12,\n\x07Metrics\x18\x04 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x19\n\x11RestartsPerPeriod\x18\x06 \x01(\r\x12\x1a\n\x12LastAliveTimestamp\x18\x07 \x01(\x04\x12\x31\n\nNodeDomain\x18\x08 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\"J\n\x18TEvResponseHiveNodeStats\x12.\n\tNodeStats\x18\x01 \x03(\x0b\x32\x1b.NKikimrHive.THiveNodeStats\"\x1c\n\x1aTEvRequestHiveStorageStats\"\xfb\x01\n\x16THiveStorageGroupStats\x12\x0f\n\x07GroupID\x18\x01 \x01(\r\x12\x15\n\rAcquiredUnits\x18\x02 \x01(\x04\x12\x14\n\x0c\x41\x63quiredIOPS\x18\x03 \x01(\x02\x12\x1a\n\x12\x41\x63quiredThroughput\x18\x04 \x01(\x04\x12\x14\n\x0c\x41\x63quiredSize\x18\x05 \x01(\x04\x12\x13\n\x0bMaximumIOPS\x18\x07 \x01(\x02\x12\x19\n\x11MaximumThroughput\x18\x08 \x01(\x04\x12\x13\n\x0bMaximumSize\x18\t \x01(\x04\x12\x15\n\rAllocatedSize\x18\n \x01(\x04\x12\x15\n\rAvailableSize\x18\x0b \x01(\x04\"Z\n\x15THiveStoragePoolStats\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x33\n\x06Groups\x18\x02 \x03(\x0b\x32#.NKikimrHive.THiveStorageGroupStats\"P\n\x1bTEvResponseHiveStorageStats\x12\x31\n\x05Pools\x18\x01 \x03(\x0b\x32\".NKikimrHive.THiveStoragePoolStats\"/\n\x0cTTabletOwner\x12\r\n\x05Owner\x18\x01 \x01(\x06\x12\x10\n\x08OwnerIdx\x18\x02 \x01(\x04\"e\n\x0cTEvDrainNode\x12\x0e\n\x06NodeID\x18\x01 \x01(\r\x12\x15\n\x07Persist\x18\x03 \x01(\x08:\x04true\x12\x17\n\x08KeepDown\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x15\n\rDrainInFlight\x18\x05 \x01(\r\"S\n\x12TEvDrainNodeResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x11\n\tMovements\x18\x02 \x01(\r\"\x1d\n\x0bTEvFillNode\x12\x0e\n\x06NodeID\x18\x01 \x01(\r\"?\n\x11TEvFillNodeResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\"+\n\x17TEvGetTabletStorageInfo\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\"\xa9\x01\n\x1dTEvGetTabletStorageInfoResult\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x33\n\x04Info\x18\x03 \x01(\x0b\x32%.NKikimrTabletBase.TTabletStorageInfo\x12\x15\n\rStatusMessage\x18\x04 \x01(\t\"5\n!TEvGetTabletStorageInfoRegistered\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\"\x86\x01\n\x16TEvLockTabletExecution\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\nOwnerActor\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x11\n\tReconnect\x18\x03 \x01(\x08\x12\x1b\n\x13MaxReconnectTimeout\x18\x04 \x01(\x04\".\n\x1aTEvLockTabletExecutionLost\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\"s\n\x1cTEvLockTabletExecutionResult\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x15\n\rStatusMessage\x18\x03 \x01(\t\"X\n\x18TEvUnlockTabletExecution\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\nOwnerActor\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\"u\n\x1eTEvUnlockTabletExecutionResult\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x15\n\rStatusMessage\x18\x03 \x01(\t\"4\n\x19TEvInvalidateStoragePools\x12\x17\n\x0fStoragePoolName\x18\x01 \x03(\t\" \n\x1eTEvInvalidateStoragePoolsReply\"-\n\x1aTEvReassignOnDecommitGroup\x12\x0f\n\x07GroupId\x18\x01 \x01(\r\"!\n\x1fTEvReassignOnDecommitGroupReply\"T\n\x1aTEvRequestTabletIdSequence\x12(\n\x05Owner\x18\x01 \x01(\x0b\x32\x19.NKikimrHive.TTabletOwner\x12\x0c\n\x04Size\x18\x02 \x01(\x04\"g\n\x1bTEvResponseTabletIdSequence\x12(\n\x05Owner\x18\x01 \x01(\x0b\x32\x19.NKikimrHive.TTabletOwner\x12\x0f\n\x07\x42\x65ginId\x18\x02 \x01(\x04\x12\r\n\x05\x45ndId\x18\x03 \x01(\x04\"\x9c\x01\n\x0fTEvSeizeTablets\x12\x12\n\nNewOwnerID\x18\x01 \x01(\x06\x12\x33\n\x0c\x46ilterDomain\x18\x02 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x1c\n\x11MaxTabletsToSeize\x18\x03 \x01(\r:\x01\x31\x12\"\n\x14WaitForTabletsToRise\x18\x04 \x01(\x08:\x04true\"^\n\x15TTabletChannelGenInfo\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\r\n\x05Group\x18\x02 \x01(\x04\x12\x0f\n\x07Version\x18\x03 \x01(\x04\x12\x11\n\tTimestamp\x18\x04 \x01(\x04\"\xa7\x01\n\x12TTabletChannelInfo\x12\x13\n\x0bStoragePool\x18\x01 \x01(\t\x12\x31\n\x07\x42inding\x18\x02 \x01(\x0b\x32 .NKikimrStoragePool.TChannelBind\x12\x33\n\x07History\x18\x03 \x03(\x0b\x32\".NKikimrHive.TTabletChannelGenInfo\x12\x14\n\x0cNeedNewGroup\x18\x04 \x01(\x08\"\xa0\x07\n\x0bTTabletInfo\x12\x10\n\x08TabletID\x18\x01 \x01(\x06\x12\x39\n\nTabletType\x18\x02 \x01(\x0e\x32%.NKikimrTabletBase.TTabletTypes.EType\x12\x38\n\rVolatileState\x18\x03 \x01(\x0e\x32!.NKikimrHive.ETabletVolatileState\x12\x0e\n\x06NodeID\x18\x04 \x01(\r\x12\x18\n\x10\x45xecutorCounters\x18\x05 \x03(\x04\x12\x1b\n\x13\x41pplicationCounters\x18\x06 \x03(\x04\x12.\n\x0bTabletOwner\x18\x07 \x01(\x0b\x32\x19.NKikimrHive.TTabletOwner\x12\x12\n\nFollowerID\x18\x08 \x01(\r\x12\r\n\x05State\x18\t \x01(\r\x12,\n\x07Metrics\x18\n \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x12\n\nGeneration\x18\x0b \x01(\r\x12\x34\n\x0eTabletBootMode\x18\x0c \x01(\x0e\x32\x1c.NKikimrHive.ETabletBootMode\x12\x33\n\x0cObjectDomain\x18\r \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x10\n\x08ObjectId\x18\x0e \x01(\x04\x12\x35\n\x0e\x41llowedDomains\x18\x0f \x03(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x33\n\x0e\x46ollowerGroups\x18\x10 \x03(\x0b\x32\x1b.NKikimrHive.TFollowerGroup\x12\x37\n\x0eTabletChannels\x18\x11 \x03(\x0b\x32\x1f.NKikimrHive.TTabletChannelInfo\x12-\n\rLockedToActor\x18\x12 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x1e\n\x16LockedReconnectTimeout\x18\x13 \x01(\x04\x12\x1c\n\x14TabletStorageVersion\x18\x14 \x01(\x04\x12\x32\n\rResourceUsage\x18\x15 \x01(\x0b\x32\x1b.NKikimrTabletBase.TMetrics\x12\x19\n\x11RestartsPerPeriod\x18\x16 \x01(\r\x12\x1a\n\x12LastAliveTimestamp\x18\x17 \x01(\x04\x12\x34\n\x0e\x42\x61lancerPolicy\x18\x18 \x01(\x0e\x32\x1c.NKikimrHive.EBalancerPolicy\"A\n\x14TEvSeizeTabletsReply\x12)\n\x07Tablets\x18\x01 \x03(\x0b\x32\x18.NKikimrHive.TTabletInfo\":\n\x11TEvReleaseTablets\x12\x12\n\nNewOwnerID\x18\x01 \x01(\x06\x12\x11\n\tTabletIDs\x18\x02 \x03(\x06\"+\n\x16TEvReleaseTabletsReply\x12\x11\n\tTabletIDs\x18\x01 \x03(\x06\"A\n\x10TEvConfigureHive\x12-\n\x06\x44omain\x18\x01 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\"I\n\x10TEvInitMigration\x12\x35\n\x0fMigrationFilter\x18\x01 \x01(\x0b\x32\x1c.NKikimrHive.TEvSeizeTablets\"C\n\x15TEvInitMigrationReply\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\"\x13\n\x11TEvQueryMigration\"i\n\x16TEvQueryMigrationReply\x12\x34\n\x0eMigrationState\x18\x01 \x01(\x0e\x32\x1c.NKikimrHive.EMigrationState\x12\x19\n\x11MigrationProgress\x18\x02 \x01(\x05\"I\n\x11TTabletStatistics\x12\x18\n\x10RestartTimestamp\x18\x01 \x03(\x04\x12\x1a\n\x12LastAliveTimestamp\x18\x02 \x01(\x04\"G\n\x0fTNodeStatistics\x12\x18\n\x10RestartTimestamp\x18\x01 \x03(\x04\x12\x1a\n\x12LastAliveTimestamp\x18\x02 \x01(\x04\")\n\x16TEvRequestTabletOwners\x12\x0f\n\x07OwnerID\x18\x01 \x01(\x06\"A\n\x12TTabletOwnerRecord\x12\x0f\n\x07OwnerID\x18\x01 \x01(\x06\x12\r\n\x05\x42\x65gin\x18\x02 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x03 \x01(\x04\"M\n\x14TEvTabletOwnersReply\x12\x35\n\x0cTabletOwners\x18\x01 \x03(\x0b\x32\x1f.NKikimrHive.TTabletOwnerRecord*N\n\x0f\x45TabletBootMode\x12\x1c\n\x18TABLET_BOOT_MODE_DEFAULT\x10\x00\x12\x1d\n\x19TABLET_BOOT_MODE_EXTERNAL\x10\x01*8\n\x0f\x45\x42\x61lancerPolicy\x12\x12\n\x0ePOLICY_BALANCE\x10\x00\x12\x11\n\rPOLICY_IGNORE\x10\x01*u\n\x0c\x45\x45rrorReason\x12\x18\n\x14\x45RROR_REASON_UNKNOWN\x10\x00\x12\'\n#ERROR_REASON_CHANNELS_CANNOT_SHRINK\x10\x01\x12\"\n\x1e\x45RROR_REASON_INVALID_ARGUMENTS\x10\x02*\xea\x01\n\x14\x45TabletVolatileState\x12!\n\x1dTABLET_VOLATILE_STATE_UNKNOWN\x10\x00\x12!\n\x1dTABLET_VOLATILE_STATE_STOPPED\x10\x01\x12!\n\x1dTABLET_VOLATILE_STATE_BOOTING\x10\x02\x12\"\n\x1eTABLET_VOLATILE_STATE_STARTING\x10\x03\x12!\n\x1dTABLET_VOLATILE_STATE_RUNNING\x10\x04\x12\"\n\x1e_TABLET_VOLATILE_STATE_BLOCKED\x10\x05*k\n\x0f\x45MigrationState\x12\x15\n\x11MIGRATION_UNKNOWN\x10\x00\x12\x13\n\x0fMIGRATION_READY\x10\x01\x12\x14\n\x10MIGRATION_ACTIVE\x10\x02\x12\x16\n\x12MIGRATION_COMPLETE\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.hive_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TDATACENTERSGROUP.fields_by_name['DataCenterNum']._options = None
  _TDATACENTERSGROUP.fields_by_name['DataCenterNum']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['AllowedDataCenterNumIDs']._options = None
  _TEVCREATETABLET.fields_by_name['AllowedDataCenterNumIDs']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['ChannelsProfile']._options = None
  _TEVCREATETABLET.fields_by_name['ChannelsProfile']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['Flags']._options = None
  _TEVCREATETABLET.fields_by_name['Flags']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['BootTimeoutMilliSeconds']._options = None
  _TEVCREATETABLET.fields_by_name['BootTimeoutMilliSeconds']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['BootAttemptLimit']._options = None
  _TEVCREATETABLET.fields_by_name['BootAttemptLimit']._serialized_options = b'\030\001'
  _TEVCREATETABLET.fields_by_name['Weight']._options = None
  _TEVCREATETABLET.fields_by_name['Weight']._serialized_options = b'\030\001'
  _ETABLETBOOTMODE._serialized_start=9724
  _ETABLETBOOTMODE._serialized_end=9802
  _EBALANCERPOLICY._serialized_start=9804
  _EBALANCERPOLICY._serialized_end=9860
  _EERRORREASON._serialized_start=9862
  _EERRORREASON._serialized_end=9979
  _ETABLETVOLATILESTATE._serialized_start=9982
  _ETABLETVOLATILESTATE._serialized_end=10216
  _EMIGRATIONSTATE._serialized_start=10218
  _EMIGRATIONSTATE._serialized_end=10325
  _TCHANNELINFO._serialized_start=263
  _TCHANNELINFO._serialized_end=436
  _TCHANNELINFO_THISTORYSLOT._serialized_start=362
  _TCHANNELINFO_THISTORYSLOT._serialized_end=436
  _TEVBOOTTABLET._serialized_start=438
  _TEVBOOTTABLET._serialized_end=471
  _TEVBOOTTABLETREPLY._serialized_start=473
  _TEVBOOTTABLETREPLY._serialized_end=556
  _TTABLETCATEGORY._serialized_start=558
  _TTABLETCATEGORY._serialized_end=658
  _TDATACENTERSGROUP._serialized_start=660
  _TDATACENTERSGROUP._serialized_end=726
  _TDATACENTERSPREFERENCE._serialized_start=728
  _TDATACENTERSPREFERENCE._serialized_end=811
  _TEVCREATETABLET._serialized_start=814
  _TEVCREATETABLET._serialized_end=1810
  _TEVLOOKUPTABLET._serialized_start=1812
  _TEVLOOKUPTABLET._serialized_end=1862
  _TEVCREATETABLETREPLY._serialized_start=1865
  _TEVCREATETABLETREPLY._serialized_end=2100
  _TEVTABLETCREATIONRESULT._serialized_start=2102
  _TEVTABLETCREATIONRESULT._serialized_end=2189
  _TEVSTOPTABLET._serialized_start=2191
  _TEVSTOPTABLET._serialized_end=2271
  _TEVSTOPTABLETRESULT._serialized_start=2273
  _TEVSTOPTABLETRESULT._serialized_end=2356
  _TEVRESUMETABLETRESULT._serialized_start=2358
  _TEVRESUMETABLETRESULT._serialized_end=2443
  _TCHANNELREQUEST._serialized_start=2445
  _TCHANNELREQUEST._serialized_end=2506
  _TEVRECONFIGURETABLET._serialized_start=2509
  _TEVRECONFIGURETABLET._serialized_end=2653
  _TEVADOPTTABLET._serialized_start=2656
  _TEVADOPTTABLET._serialized_end=2823
  _TEVADOPTTABLETREPLY._serialized_start=2826
  _TEVADOPTTABLETREPLY._serialized_end=2975
  _TEVRECONFIGURETABLETREPLY._serialized_start=2978
  _TEVRECONFIGURETABLETREPLY._serialized_end=3130
  _TEVDELETETABLET._serialized_start=3132
  _TEVDELETETABLET._serialized_end=3237
  _TEVDELETETABLETREPLY._serialized_start=3240
  _TEVDELETETABLETREPLY._serialized_end=3446
  _TEVDELETEOWNERTABLETS._serialized_start=3448
  _TEVDELETEOWNERTABLETS._serialized_end=3500
  _TEVDELETEOWNERTABLETSREPLY._serialized_start=3502
  _TEVDELETEOWNERTABLETSREPLY._serialized_end=3619
  _TEVLOOKUPCHANNELINFO._serialized_start=3621
  _TEVLOOKUPCHANNELINFO._serialized_end=3702
  _TEVCHANNELINFO._serialized_start=3704
  _TEVCHANNELINFO._serialized_end=3830
  _TTABLETMETRICS._serialized_start=3832
  _TTABLETMETRICS._serialized_end=3938
  _TEVTABLETMETRICS._serialized_start=3941
  _TEVTABLETMETRICS._serialized_end=4092
  _TEVREASSIGNTABLET._serialized_start=4095
  _TEVREASSIGNTABLET._serialized_end=4334
  _TEVREASSIGNTABLET_EHIVEREASSIGNREASON._serialized_start=4252
  _TEVREASSIGNTABLET_EHIVEREASSIGNREASON._serialized_end=4334
  _TFORWARDREQUEST._serialized_start=4336
  _TFORWARDREQUEST._serialized_end=4375
  _TEVREQUESTHIVEINFO._serialized_start=4378
  _TEVREQUESTHIVEINFO._serialized_end=4573
  _TEVRESPONSEHIVEINFO._serialized_start=4576
  _TEVRESPONSEHIVEINFO._serialized_end=4749
  _TEVREQUESTHIVEDOMAINSTATS._serialized_start=4751
  _TEVREQUESTHIVEDOMAINSTATS._serialized_end=4826
  _THIVEDOMAINSTATSSTATECOUNT._serialized_start=4828
  _THIVEDOMAINSTATSSTATECOUNT._serialized_end=4929
  _THIVEDOMAINSTATS._serialized_start=4932
  _THIVEDOMAINSTATS._serialized_end=5127
  _TEVRESPONSEHIVEDOMAINSTATS._serialized_start=5129
  _TEVRESPONSEHIVEDOMAINSTATS._serialized_end=5209
  _TEVREQUESTHIVENODESTATS._serialized_start=5211
  _TEVREQUESTHIVENODESTATS._serialized_end=5259
  _THIVENODESTATS._serialized_start=5262
  _THIVENODESTATS._serialized_end=5507
  _TEVRESPONSEHIVENODESTATS._serialized_start=5509
  _TEVRESPONSEHIVENODESTATS._serialized_end=5583
  _TEVREQUESTHIVESTORAGESTATS._serialized_start=5585
  _TEVREQUESTHIVESTORAGESTATS._serialized_end=5613
  _THIVESTORAGEGROUPSTATS._serialized_start=5616
  _THIVESTORAGEGROUPSTATS._serialized_end=5867
  _THIVESTORAGEPOOLSTATS._serialized_start=5869
  _THIVESTORAGEPOOLSTATS._serialized_end=5959
  _TEVRESPONSEHIVESTORAGESTATS._serialized_start=5961
  _TEVRESPONSEHIVESTORAGESTATS._serialized_end=6041
  _TTABLETOWNER._serialized_start=6043
  _TTABLETOWNER._serialized_end=6090
  _TEVDRAINNODE._serialized_start=6092
  _TEVDRAINNODE._serialized_end=6193
  _TEVDRAINNODERESULT._serialized_start=6195
  _TEVDRAINNODERESULT._serialized_end=6278
  _TEVFILLNODE._serialized_start=6280
  _TEVFILLNODE._serialized_end=6309
  _TEVFILLNODERESULT._serialized_start=6311
  _TEVFILLNODERESULT._serialized_end=6374
  _TEVGETTABLETSTORAGEINFO._serialized_start=6376
  _TEVGETTABLETSTORAGEINFO._serialized_end=6419
  _TEVGETTABLETSTORAGEINFORESULT._serialized_start=6422
  _TEVGETTABLETSTORAGEINFORESULT._serialized_end=6591
  _TEVGETTABLETSTORAGEINFOREGISTERED._serialized_start=6593
  _TEVGETTABLETSTORAGEINFOREGISTERED._serialized_end=6646
  _TEVLOCKTABLETEXECUTION._serialized_start=6649
  _TEVLOCKTABLETEXECUTION._serialized_end=6783
  _TEVLOCKTABLETEXECUTIONLOST._serialized_start=6785
  _TEVLOCKTABLETEXECUTIONLOST._serialized_end=6831
  _TEVLOCKTABLETEXECUTIONRESULT._serialized_start=6833
  _TEVLOCKTABLETEXECUTIONRESULT._serialized_end=6948
  _TEVUNLOCKTABLETEXECUTION._serialized_start=6950
  _TEVUNLOCKTABLETEXECUTION._serialized_end=7038
  _TEVUNLOCKTABLETEXECUTIONRESULT._serialized_start=7040
  _TEVUNLOCKTABLETEXECUTIONRESULT._serialized_end=7157
  _TEVINVALIDATESTORAGEPOOLS._serialized_start=7159
  _TEVINVALIDATESTORAGEPOOLS._serialized_end=7211
  _TEVINVALIDATESTORAGEPOOLSREPLY._serialized_start=7213
  _TEVINVALIDATESTORAGEPOOLSREPLY._serialized_end=7245
  _TEVREASSIGNONDECOMMITGROUP._serialized_start=7247
  _TEVREASSIGNONDECOMMITGROUP._serialized_end=7292
  _TEVREASSIGNONDECOMMITGROUPREPLY._serialized_start=7294
  _TEVREASSIGNONDECOMMITGROUPREPLY._serialized_end=7327
  _TEVREQUESTTABLETIDSEQUENCE._serialized_start=7329
  _TEVREQUESTTABLETIDSEQUENCE._serialized_end=7413
  _TEVRESPONSETABLETIDSEQUENCE._serialized_start=7415
  _TEVRESPONSETABLETIDSEQUENCE._serialized_end=7518
  _TEVSEIZETABLETS._serialized_start=7521
  _TEVSEIZETABLETS._serialized_end=7677
  _TTABLETCHANNELGENINFO._serialized_start=7679
  _TTABLETCHANNELGENINFO._serialized_end=7773
  _TTABLETCHANNELINFO._serialized_start=7776
  _TTABLETCHANNELINFO._serialized_end=7943
  _TTABLETINFO._serialized_start=7946
  _TTABLETINFO._serialized_end=8874
  _TEVSEIZETABLETSREPLY._serialized_start=8876
  _TEVSEIZETABLETSREPLY._serialized_end=8941
  _TEVRELEASETABLETS._serialized_start=8943
  _TEVRELEASETABLETS._serialized_end=9001
  _TEVRELEASETABLETSREPLY._serialized_start=9003
  _TEVRELEASETABLETSREPLY._serialized_end=9046
  _TEVCONFIGUREHIVE._serialized_start=9048
  _TEVCONFIGUREHIVE._serialized_end=9113
  _TEVINITMIGRATION._serialized_start=9115
  _TEVINITMIGRATION._serialized_end=9188
  _TEVINITMIGRATIONREPLY._serialized_start=9190
  _TEVINITMIGRATIONREPLY._serialized_end=9257
  _TEVQUERYMIGRATION._serialized_start=9259
  _TEVQUERYMIGRATION._serialized_end=9278
  _TEVQUERYMIGRATIONREPLY._serialized_start=9280
  _TEVQUERYMIGRATIONREPLY._serialized_end=9385
  _TTABLETSTATISTICS._serialized_start=9387
  _TTABLETSTATISTICS._serialized_end=9460
  _TNODESTATISTICS._serialized_start=9462
  _TNODESTATISTICS._serialized_end=9533
  _TEVREQUESTTABLETOWNERS._serialized_start=9535
  _TEVREQUESTTABLETOWNERS._serialized_end=9576
  _TTABLETOWNERRECORD._serialized_start=9578
  _TTABLETOWNERRECORD._serialized_end=9643
  _TEVTABLETOWNERSREPLY._serialized_start=9645
  _TEVTABLETOWNERSREPLY._serialized_end=9722
# @@protoc_insertion_point(module_scope)
