# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/proto/dq_state_load_plan.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1ydb/library/yql/dq/proto/dq_state_load_plan.proto\x12\x1eNYql.NDqProto.NDqStateLoadPlan\"\x81\x02\n\tTTaskPlan\x12=\n\tStateType\x18\x01 \x01(\x0e\x32*.NYql.NDqProto.NDqStateLoadPlan.EStateType\x12=\n\x07Program\x18\x02 \x01(\x0b\x32,.NYql.NDqProto.NDqStateLoadPlan.TProgramPlan\x12<\n\x07Sources\x18\x03 \x03(\x0b\x32+.NYql.NDqProto.NDqStateLoadPlan.TSourcePlan\x12\x38\n\x05Sinks\x18\x04 \x03(\x0b\x32).NYql.NDqProto.NDqStateLoadPlan.TSinkPlan\"M\n\x0cTProgramPlan\x12=\n\tStateType\x18\x01 \x01(\x0e\x32*.NYql.NDqProto.NDqStateLoadPlan.EStateType\"\xf7\x01\n\x0bTSourcePlan\x12=\n\tStateType\x18\x01 \x01(\x0e\x32*.NYql.NDqProto.NDqStateLoadPlan.EStateType\x12\x12\n\nInputIndex\x18\x02 \x01(\x04\x12[\n\x13\x46oreignTasksSources\x18\x03 \x03(\x0b\x32>.NYql.NDqProto.NDqStateLoadPlan.TSourcePlan.TForeignTaskSource\x1a\x38\n\x12TForeignTaskSource\x12\x0e\n\x06TaskId\x18\x01 \x01(\x04\x12\x12\n\nInputIndex\x18\x02 \x01(\x04\"_\n\tTSinkPlan\x12=\n\tStateType\x18\x01 \x01(\x0e\x32*.NYql.NDqProto.NDqStateLoadPlan.EStateType\x12\x13\n\x0bOutputIndex\x18\x02 \x01(\x04*j\n\nEStateType\x12\x1a\n\x16STATE_TYPE_UNSPECIFIED\x10\x00\x12\x14\n\x10STATE_TYPE_EMPTY\x10\x01\x12\x12\n\x0eSTATE_TYPE_OWN\x10\x02\x12\x16\n\x12STATE_TYPE_FOREIGN\x10\x03\x42\x03\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.proto.dq_state_load_plan_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _ESTATETYPE._serialized_start=771
  _ESTATETYPE._serialized_end=877
  _TTASKPLAN._serialized_start=86
  _TTASKPLAN._serialized_end=343
  _TPROGRAMPLAN._serialized_start=345
  _TPROGRAMPLAN._serialized_end=422
  _TSOURCEPLAN._serialized_start=425
  _TSOURCEPLAN._serialized_end=672
  _TSOURCEPLAN_TFOREIGNTASKSOURCE._serialized_start=616
  _TSOURCEPLAN_TFOREIGNTASKSOURCE._serialized_end=672
  _TSINKPLAN._serialized_start=674
  _TSINKPLAN._serialized_end=769
# @@protoc_insertion_point(module_scope)
