# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/pqconfig.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos.draft import persqueue_error_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_draft_dot_persqueue__error__codes__pb2
from ydb.public.api.protos.draft import persqueue_common_pb2 as ydb_dot_public_dot_api_dot_protos_dot_draft_dot_persqueue__common__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import msgbus_kv_pb2 as ydb_dot_core_dot_protos_dot_msgbus__kv__pb2
from ydb.core.protos import node_limits_pb2 as ydb_dot_core_dot_protos_dot_node__limits__pb2
from ydb.core.protos import netclassifier_pb2 as ydb_dot_core_dot_protos_dot_netclassifier__pb2
from ydb.core.protos import services_pb2 as ydb_dot_core_dot_protos_dot_services__pb2
from ydb.core.protos import type_info_pb2 as ydb_dot_core_dot_protos_dot_type__info__pb2
from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/pqconfig.proto\x12\tNKikimrPQ\x1a\x37ydb/public/api/protos/draft/persqueue_error_codes.proto\x1a\x32ydb/public/api/protos/draft/persqueue_common.proto\x1a\x1aydb/core/protos/base.proto\x1a\x1fydb/core/protos/msgbus_kv.proto\x1a!ydb/core/protos/node_limits.proto\x1a#ydb/core/protos/netclassifier.proto\x1a\x1eydb/core/protos/services.proto\x1a\x1fydb/core/protos/type_info.proto\x1a&library/cpp/actors/protos/actors.proto\"8\n\x0eTPartitionMeta\x12\x13\n\x0bStartOffset\x18\x01 \x01(\x04\x12\x11\n\tEndOffset\x18\x02 \x01(\x04\"2\n\x10TPartitionTxMeta\x12\x10\n\x08PlanStep\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\"\xd5\x1d\n\tTPQConfig\x12\x1f\n\x12\x41\x43LRetryTimeoutSec\x18\x01 \x01(\r:\x03\x33\x30\x30\x12,\n\x1f\x42\x61lancerMetadataRetryTimeoutSec\x18\x02 \x01(\r:\x03\x32\x34\x30\x12\x1c\n\x10MaxBlobsPerLevel\x18\x03 \x01(\r:\x02\x36\x34\x12\x1c\n\x0bMaxBlobSize\x18\x04 \x01(\r:\x07\x38\x33\x38\x38\x36\x30\x38\x12$\n\x18\x43lustersUpdateTimeoutSec\x18\x05 \x01(\r:\x02\x33\x30\x12\x15\n\x07\x45nabled\x18\x06 \x01(\x08:\x04true\x12#\n\x13MetaCacheTimeoutSec\x18\x07 \x01(\r:\x02\x33\x30\x42\x02\x18\x01\x12\x1e\n\x0eMaxReadCookies\x18\x08 \x01(\r:\x06\x31\x30\x30\x30\x30\x30\x12\x16\n\x08\x43heckACL\x18\t \x01(\x08:\x04true\x12$\n\x18SourceIdCleanupPeriodSec\x18\n \x01(\r:\x02\x36\x30\x12\'\n\x16SourceIdMaxLifetimeSec\x18\x0b \x01(\r:\x07\x31\x33\x38\x32\x34\x30\x30\x12(\n\x18SourceIdTotalShardsCount\x18\x0c \x01(\r:\x06\x31\x33\x31\x30\x37\x32\x12G\n\x06Tactic\x18\r \x01(\x0e\x32\'.NKikimrClient.TKeyValueRequest.ETactic:\x0eMAX_THROUGHPUT\x12-\n\x1fRequireCredentialsInNewProtocol\x18\x0e \x01(\x08:\x04true\x12\x1a\n\x10\x43lusterTablePath\x18\x0f \x01(\t:\x00\x12\x1a\n\x10VersionTablePath\x18\x10 \x01(\t:\x00\x12*\n\x1f\x43lustersUpdateTimeoutOnErrorSec\x18\x11 \x01(\r:\x01\x31\x12\"\n\x15WriteInitLatencyBigMs\x18\x13 \x01(\r:\x03\x39\x30\x30\x12!\n\x14ReadInitLatencyBigMs\x18\x14 \x01(\r:\x03\x39\x30\x30\x12\x1f\n\x12\x43ommitLatencyBigMs\x18\x15 \x01(\r:\x03\x39\x30\x30\x12\x1e\n\x11WriteLatencyBigMs\x18\x16 \x01(\r:\x03\x35\x35\x30\x12\x1d\n\x10ReadLatencyBigMs\x18\x17 \x01(\r:\x03\x35\x35\x30\x12&\n\x18ReadLatencyFromDiskBigMs\x18\x1c \x01(\r:\x04\x31\x30\x30\x30\x12:\n\rQuotingConfig\x18\x12 \x01(\x0b\x32#.NKikimrPQ.TPQConfig.TQuotingConfig\x12)\n\x1cRemoteClusterEnabledDelaySec\x18\x18 \x01(\r:\x03\x33\x30\x30\x12H\n;CloseClientSessionWithEnabledRemotePreferredClusterDelaySec\x18\x19 \x01(\r:\x03\x33\x30\x30\x12(\n\x1aRoundRobinPartitionMapping\x18\x1a \x01(\x08:\x04true\x12\x0e\n\x04Root\x18\x1b \x01(\t:\x00\x12\x18\n\x10TestDatabaseRoot\x18/ \x01(\t\x12\x38\n\x0cMirrorConfig\x18\x1d \x01(\x0b\x32\".NKikimrPQ.TPQConfig.TMirrorConfig\x12\x1c\n\x11MinWriteLatencyMs\x18\x1e \x01(\x04:\x01\x30\x12\x33\n\x0f\x43hannelProfiles\x18\x1f \x03(\x0b\x32\x1a.NKikimrPQ.TChannelProfile\x12(\n\x1aTopicsAreFirstClassCitizen\x18  \x01(\x08:\x04true\x12.\n\x1fUseSrcIdMetaMappingInFirstClass\x18\x34 \x01(\x08:\x05\x66\x61lse\x12\x31\n\x11SourceIdTablePath\x18! \x01(\t:\x16/Root/PQ/SourceIdMeta2\x12%\n\x1dValidWriteSpeedLimitsKbPerSec\x18\" \x03(\r\x12G\n\x14ValidRetentionLimits\x18\x30 \x03(\x0b\x32).NKikimrPQ.TPQConfig.TValidRetentionLimit\x12J\n\x15\x42illingMeteringConfig\x18# \x01(\x0b\x32+.NKikimrPQ.TPQConfig.TBillingMeteringConfig\x12V\n\x13PersQueueNodeConfig\x18$ \x01(\x0b\x32\x39.NKikimrNodeLimits.TNodeLimitsConfig.TPersQueueNodeConfig\x12%\n\x17\x45nableProtoSourceIdInfo\x18% \x01(\x08:\x04true\x12\x10\n\x08\x44\x61tabase\x18& \x01(\t\x12\x32\n#ForceClientServiceTypePasswordCheck\x18\x31 \x01(\x08:\x05\x66\x61lse\x12\x42\n\x11\x43lientServiceType\x18\' \x03(\x0b\x32\'.NKikimrPQ.TPQConfig.TClientServiceType\x12I\n\x18\x44\x65\x66\x61ultClientServiceType\x18( \x01(\x0b\x32\'.NKikimrPQ.TPQConfig.TClientServiceType\x12/\n DisallowDefaultClientServiceType\x18+ \x01(\x08:\x05\x66\x61lse\x12\x37\n$MetaCacheRefreshIntervalMilliSeconds\x18) \x01(\r:\x05\x31\x30\x30\x30\x30\x42\x02\x18\x01\x12,\n\x19MetaCacheSkipVersionCheck\x18* \x01(\x08:\x05\x66\x61lseB\x02\x18\x01\x12\x19\n\x11NonChargeableUser\x18, \x03(\t\x12\x1c\n\x12LbCommunalDatabase\x18- \x01(\t:\x00\x12\x42\n\x11PQDiscoveryConfig\x18. \x01(\x0b\x32\'.NKikimrPQ.TPQConfig.TPQDiscoveryConfig\x12!\n\x12MaxStorageNodePort\x18\x32 \x01(\r:\x05\x31\x39\x30\x30\x31\x12H\n\x14MoveTopicActorConfig\x18\x33 \x01(\x0b\x32*.NKikimrPQ.TPQConfig.TMoveTopicActorConfig\x1a\xa2\x03\n\x0eTQuotingConfig\x12\x1b\n\rEnableQuoting\x18\x01 \x01(\x08:\x04true\x12\x1e\n\x14QuotersDirectoryPath\x18\x02 \x01(\t:\x00\x12k\n\x1cTopicWriteQuotaEntityToLimit\x18\x03 \x01(\x0e\x32\x32.NKikimrPQ.TPQConfig.TQuotingConfig.ELimitedEntity:\x11USER_PAYLOAD_SIZE\x12 \n\x11\x45nableReadQuoting\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x0fReadCreditBytes\x18\x05 \x01(\x04:\x06\x31\x30\x30\x30\x30\x30\x12\x1e\n\x13QuotaWaitDurationMs\x18\x06 \x01(\x04:\x01\x30\x12\x32\n#PartitionReadQuotaIsTwiceWriteQuota\x18\x07 \x01(\x08:\x05\x66\x61lse\"O\n\x0e\x45LimitedEntity\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x15\n\x11WRITTEN_BLOB_SIZE\x10\x01\x12\x15\n\x11USER_PAYLOAD_SIZE\x10\x02\x1a\x64\n\x0eTPQLibSettings\x12\x17\n\x0cThreadsCount\x18\x01 \x01(\r:\x01\x31\x12!\n\x16\x43ompressionPoolThreads\x18\x02 \x01(\r:\x01\x31\x12\x16\n\x0bGRpcThreads\x18\x03 \x01(\r:\x01\x31\x1a\x62\n\rTMirrorConfig\x12\x15\n\x07\x45nabled\x18\x01 \x01(\x08:\x04true\x12:\n\rPQLibSettings\x18\x02 \x01(\x0b\x32#.NKikimrPQ.TPQConfig.TPQLibSettings\x1a\x84\x01\n\x14TValidRetentionLimit\x12\x18\n\x10MinPeriodSeconds\x18\x01 \x01(\r\x12\x18\n\x10MaxPeriodSeconds\x18\x02 \x01(\r\x12\x1b\n\x13MinStorageMegabytes\x18\x03 \x01(\x04\x12\x1b\n\x13MaxStorageMegabytes\x18\x04 \x01(\x04\x1a\xc7\x01\n\x13TReadMeteringConfig\x12\x42\n\x07Pricing\x18\x02 \x03(\x0b\x32\x31.NKikimrPQ.TPQConfig.TReadMeteringConfig.TPricing\x12I\n\x0eUnknownPricing\x18\x03 \x01(\x0b\x32\x31.NKikimrPQ.TPQConfig.TReadMeteringConfig.TPricing\x1a!\n\x08TPricing\x12\x15\n\x04Name\x18\x01 \x01(\t:\x07unknown\x1a\x86\x01\n\x16TBillingMeteringConfig\x12\x16\n\x07\x45nabled\x18\x01 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x10\x46lushIntervalSec\x18\x02 \x01(\x04:\x02\x33\x30\x12\x36\n\x04Read\x18\x03 \x01(\x0b\x32(.NKikimrPQ.TPQConfig.TReadMeteringConfig\x1a\x87\x01\n\x12TClientServiceType\x12\x1a\n\x04Name\x18\x01 \x01(\t:\x0c\x64\x61ta-streams\x12\x17\n\x0fReadPricingName\x18\x02 \x01(\t\x12$\n\x19MaxReadRulesCountPerTopic\x18\x03 \x01(\r:\x01\x30\x12\x16\n\x0ePasswordHashes\x18\x04 \x03(\t\x1a\xc8\x01\n\x12TPQDiscoveryConfig\x12/\n CacheRefreshIntervalMilliSeconds\x18\x01 \x01(\r:\x05\x31\x30\x30\x30\x30\x12$\n\x15\x43\x61\x63heSkipVersionCheck\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x1c\n\x0eLBFrontEnabled\x18\x03 \x01(\x08:\x04true\x12\x1f\n\x11UseLbAccountAlias\x18\x04 \x01(\x08:\x04true\x12\x1c\n\x12LbUserDatabaseRoot\x18\x05 \x01(\t:\x00\x1a\x30\n\x15TMoveTopicActorConfig\x12\x17\n\x0f\x41llowedUserSIDs\x18\x01 \x03(\t\"\x85\x01\n\x0fTChannelProfile\x12\x10\n\x08PoolKind\x18\x01 \x01(\t\x12\x0c\n\x04Size\x18\x02 \x01(\x04\x12\x10\n\x08ReadIops\x18\x03 \x01(\x01\x12\x15\n\rReadBandwidth\x18\x04 \x01(\x01\x12\x11\n\tWriteIops\x18\x05 \x01(\x01\x12\x16\n\x0eWriteBandwidth\x18\x06 \x01(\x01\"\xf0\x03\n\x16TMirrorPartitionConfig\x12\x10\n\x08\x45ndpoint\x18\x01 \x01(\t\x12\x14\n\x0c\x45ndpointPort\x18\x06 \x01(\r\x12\r\n\x05Topic\x18\x02 \x01(\t\x12\x10\n\x08\x43onsumer\x18\x03 \x01(\t\x12\x1c\n\x14ReadFromTimestampsMs\x18\x05 \x01(\x04\x12\x43\n\x0b\x43redentials\x18\x07 \x01(\x0b\x32..NKikimrPQ.TMirrorPartitionConfig.TCredentials\x12\x10\n\x08\x44\x61tabase\x18\x08 \x01(\t\x12\"\n\x13UseSecureConnection\x18\t \x01(\x08:\x05\x66\x61lse\x12\x1c\n\rSyncWriteTime\x18\n \x01(\x08:\x05\x66\x61lse\x1a\xd5\x01\n\x0cTCredentials\x12\x14\n\nOauthToken\x18\x01 \x01(\tH\x00\x12\x13\n\tJwtParams\x18\x02 \x01(\tH\x00\x12L\n\x03Iam\x18\x03 \x01(\x0b\x32=.NKikimrPQ.TMirrorPartitionConfig.TCredentials.IamCredentialsH\x00\x1a=\n\x0eIamCredentials\x12\x10\n\x08\x45ndpoint\x18\x01 \x01(\t\x12\x19\n\x11ServiceAccountKey\x18\x02 \x01(\tB\r\n\x0b\x43redentials\"\xfc\x05\n\x10TPartitionConfig\x12%\n\x13MaxCountInPartition\x18\x01 \x01(\x05:\x08\x31\x30\x30\x30\x30\x30\x30\x30\x12)\n\x12MaxSizeInPartition\x18\x02 \x01(\x03:\r1099511627776\x12\x1f\n\x0fLifetimeSeconds\x18\x03 \x01(\x05:\x06\x36\x30\x34\x38\x30\x30\x12\x19\n\x11StorageLimitBytes\x18\x10 \x01(\x04\x12\x19\n\x11ImportantClientId\x18\x04 \x03(\t\x12\x1d\n\x0cLowWatermark\x18\x05 \x01(\r:\x07\x36\x32\x39\x31\x34\x35\x36\x12(\n\x17SourceIdLifetimeSeconds\x18\x06 \x01(\r:\x07\x31\x33\x38\x32\x34\x30\x30\x12\"\n\x11SourceIdMaxCounts\x18\x1f \x01(\r:\x07\x36\x30\x30\x30\x30\x30\x30\x12,\n\x1aWriteSpeedInBytesPerSecond\x18\x07 \x01(\x04:\x08\x35\x30\x30\x30\x30\x30\x30\x30\x12\x1b\n\tBurstSize\x18\x08 \x01(\x04:\x08\x35\x30\x30\x30\x30\x30\x30\x30\x12\x39\n\tReadQuota\x18\x0b \x03(\x0b\x32&.NKikimrPQ.TPartitionConfig.TReadQuota\x12&\n\x14MaxWriteInflightSize\x18\t \x01(\x04:\x08\x33\x30\x30\x30\x30\x30\x30\x30\x12)\n\x17\x42orderWriteInflightSize\x18\x0c \x01(\x04:\x08\x31\x30\x30\x30\x30\x30\x30\x30\x12\x17\n\x0bNumChannels\x18\n \x01(\r:\x02\x31\x30\x12\x1a\n\x0fTotalPartitions\x18\r \x01(\r:\x01\x31\x12;\n\x17\x45xplicitChannelProfiles\x18\x0e \x03(\x0b\x32\x1a.NKikimrPQ.TChannelProfile\x12\x35\n\nMirrorFrom\x18\x0f \x01(\x0b\x32!.NKikimrPQ.TMirrorPartitionConfig\x1aP\n\nTReadQuota\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x1d\n\x15SpeedInBytesPerSecond\x18\x02 \x01(\x04\x12\x11\n\tBurstSize\x18\x03 \x01(\x04\"8\n\x12TPartitionKeyRange\x12\x11\n\tFromBound\x18\x01 \x01(\x0c\x12\x0f\n\x07ToBound\x18\x02 \x01(\x0c\"L\n\rTMessageGroup\x12\n\n\x02Id\x18\x01 \x01(\x0c\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrPQ.TPartitionKeyRange\"\x8a\n\n\x0fTPQTabletConfig\x12\x1c\n\tCacheSize\x18\x01 \x01(\x04:\t104857600\x12\x34\n\x0fPartitionConfig\x18\x02 \x01(\x0b\x32\x1b.NKikimrPQ.TPartitionConfig\x12\x14\n\x0cPartitionIds\x18\x03 \x03(\r\x12\x11\n\tTopicName\x18\x04 \x01(\t\x12\x0f\n\x07Version\x18\x05 \x01(\r\x12\x16\n\x07LocalDC\x18\x06 \x01(\x08:\x05\x66\x61lse\x12\x1f\n\x10RequireAuthWrite\x18\x07 \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x0fRequireAuthRead\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x10\n\x08Producer\x18\t \x01(\t\x12\r\n\x05Ident\x18\n \x01(\t\x12\r\n\x05Topic\x18\x0b \x01(\t\x12\n\n\x02\x44\x43\x18\x0c \x01(\t\x12\x11\n\tReadRules\x18\r \x03(\t\x12\x1c\n\x14ReadFromTimestampsMs\x18\x0e \x03(\x04\x12\x1e\n\x16\x43onsumerFormatVersions\x18\x0f \x03(\x04\x12:\n\x0e\x43onsumerCodecs\x18\x10 \x03(\x0b\x32\".NKikimrPQ.TPQTabletConfig.TCodecs\x12\x1c\n\x14ReadRuleServiceTypes\x18\x11 \x03(\t\x12\x15\n\rFormatVersion\x18\x14 \x01(\x04\x12\x32\n\x06\x43odecs\x18\x15 \x01(\x0b\x32\".NKikimrPQ.TPQTabletConfig.TCodecs\x12\x18\n\x10ReadRuleVersions\x18\x16 \x03(\x04\x12\x1b\n\x13ReadRuleGenerations\x18  \x03(\x04\x12\x11\n\tTopicPath\x18\x17 \x01(\t\x12\r\n\x05\x41\x62\x63Id\x18\x18 \x01(\x04\x12\x0f\n\x07\x41\x62\x63Slug\x18\x19 \x01(\t\x12\x13\n\tYcCloudId\x18\x1a \x01(\t:\x00\x12\x14\n\nYcFolderId\x18\x1b \x01(\t:\x00\x12\x17\n\rYdbDatabaseId\x18\x1c \x01(\t:\x00\x12\x19\n\x0fYdbDatabasePath\x18\x1d \x01(\t:\x00\x12\x1b\n\x11\x46\x65\x64\x65rationAccount\x18! \x01(\t:\x00\x12J\n\x12PartitionKeySchema\x18\x1e \x03(\x0b\x32..NKikimrPQ.TPQTabletConfig.TKeyComponentSchema\x12\x39\n\nPartitions\x18\x1f \x03(\x0b\x32%.NKikimrPQ.TPQTabletConfig.TPartition\x12>\n\x0cMeteringMode\x18\" \x01(\x0e\x32(.NKikimrPQ.TPQTabletConfig.EMeteringMode\x1a&\n\x07TCodecs\x12\x0b\n\x03Ids\x18\x01 \x03(\x03\x12\x0e\n\x06\x43odecs\x18\x02 \x03(\t\x1a^\n\x13TKeyComponentSchema\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0e\n\x06TypeId\x18\x02 \x01(\r\x12)\n\x08TypeInfo\x18\x03 \x01(\x0b\x32\x17.NKikimrProto.TTypeInfo\x1aR\n\nTPartition\x12\x13\n\x0bPartitionId\x18\x01 \x01(\r\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrPQ.TPartitionKeyRange\"U\n\rEMeteringMode\x12#\n\x1fMETERING_MODE_RESERVED_CAPACITY\x10\x00\x12\x1f\n\x1bMETERING_MODE_REQUEST_UNITS\x10\x01\"\xad\x02\n\x11TMessageGroupInfo\x12\r\n\x05SeqNo\x18\x01 \x01(\x04\x12\x0e\n\x06Offset\x18\x02 \x01(\x04\x12\x16\n\x0eWriteTimestamp\x18\x03 \x01(\x04\x12\x17\n\x0f\x43reateTimestamp\x18\x04 \x01(\x04\x12\x10\n\x08\x45xplicit\x18\x05 \x01(\x08\x12/\n\x08KeyRange\x18\x06 \x01(\x0b\x32\x1d.NKikimrPQ.TPartitionKeyRange\x12\x32\n\x05State\x18\x07 \x01(\x0e\x32#.NKikimrPQ.TMessageGroupInfo.EState\"Q\n\x06\x45State\x12\x11\n\rSTATE_UNKNOWN\x10\x00\x12\x14\n\x10STATE_REGISTERED\x10\x01\x12\x1e\n\x1aSTATE_PENDING_REGISTRATION\x10\x02\"K\n\x10TBootstrapConfig\x12\x37\n\x15\x45xplicitMessageGroups\x18\x01 \x03(\x0b\x32\x18.NKikimrPQ.TMessageGroup\"\x85\x01\n\rTUpdateConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x30\n\x0cTabletConfig\x18\x02 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12\x34\n\x0f\x42ootstrapConfig\x18\x03 \x01(\x0b\x32\x1b.NKikimrPQ.TBootstrapConfig\"\xf5\x03\n\x15TUpdateBalancerConfig\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x11\n\tTopicName\x18\x03 \x01(\t\x12\x0c\n\x04Path\x18\x04 \x01(\t\x12\x0f\n\x07Version\x18\x05 \x01(\r\x12\x17\n\x0fTotalGroupCount\x18\x0b \x01(\r\x12\x17\n\x0fNextPartitionId\x18\x0c \x01(\r\x12\x30\n\x0cTabletConfig\x18\x07 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12\x1a\n\x12PartitionPerTablet\x18\x08 \x01(\r\x12\x15\n\rSchemeShardId\x18\t \x01(\x04\x12?\n\nPartitions\x18\x06 \x03(\x0b\x32+.NKikimrPQ.TUpdateBalancerConfig.TPartition\x12\x39\n\x07Tablets\x18\n \x03(\x0b\x32(.NKikimrPQ.TUpdateBalancerConfig.TTablet\x1a@\n\nTPartition\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\r\n\x05Group\x18\x03 \x01(\r\x1a\x37\n\x07TTablet\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12\r\n\x05Owner\x18\x02 \x01(\x04\x12\x0b\n\x03Idx\x18\x03 \x01(\x04\"\x0b\n\tTDescribe\"\xb8\x02\n\x11TDescribeResponse\x12\x11\n\tTopicName\x18\x01 \x01(\t\x12\x0f\n\x07Version\x18\x02 \x01(\r\x12*\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12\x1a\n\x12PartitionPerTablet\x18\x04 \x01(\r\x12\x15\n\rSchemeShardId\x18\x06 \x01(\x04\x12\x18\n\x10\x42\x61lancerTabletId\x18\x07 \x01(\x04\x12\x16\n\x0eSecurityObject\x18\x08 \x01(\x0c\x12;\n\nPartitions\x18\x05 \x03(\x0b\x32\'.NKikimrPQ.TDescribeResponse.TPartition\x1a\x31\n\nTPartition\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\"\x7f\n\tTCheckACL\x12(\n\tOperation\x18\x02 \x01(\x0e\x32\x15.NKikimrPQ.EOperation\x12+\n\x04\x41uth\x18\x04 \x01(\x0b\x32\x1d.NPersQueueCommon.Credentials\x12\x0c\n\x04User\x18\x05 \x01(\t\x12\r\n\x05Token\x18\x06 \x01(\x0c\"c\n\x11TCheckACLResponse\x12\"\n\x06\x41\x63\x63\x65ss\x18\x01 \x01(\x0e\x32\x12.NKikimrPQ.EAccess\x12\r\n\x05Topic\x18\x02 \x01(\t\x12\x0c\n\x04Path\x18\x03 \x01(\t\x12\r\n\x05\x45rror\x18\x04 \x01(\t\"\x19\n\x17TGetPartitionIdForWrite\"6\n\x1fTGetPartitionIdForWriteResponse\x12\x13\n\x0bPartitionId\x18\x01 \x01(\x04\"\x89\x01\n\x14TRegisterReadSession\x12\x0f\n\x07Session\x18\x01 \x01(\t\x12*\n\nPipeClient\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x10\n\x08\x43lientId\x18\x03 \x01(\t\x12\x12\n\nClientNode\x18\x04 \x01(\t\x12\x0e\n\x06Groups\x18\x05 \x03(\r\"(\n\x14TGetReadSessionsInfo\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\"\x14\n\x12TReadSessionStatus\"\xd4\x02\n\x1aTReadSessionStatusResponse\x12I\n\tPartition\x18\x08 \x03(\x0b\x32\x36.NKikimrPQ.TReadSessionStatusResponse.TPartitionStatus\x12\x0f\n\x07Session\x18\x04 \x01(\t\x12\x11\n\tTimestamp\x18\x05 \x01(\x04\x12\x12\n\nClientNode\x18\x06 \x01(\t\x12\x13\n\x0bProxyNodeId\x18\x07 \x01(\r\x1a\x9d\x01\n\x10TPartitionStatus\x12\x13\n\x0bNextCommits\x18\x01 \x03(\x04\x12\x12\n\nLastReadId\x18\x02 \x01(\x04\x12\x17\n\x0fReadIdCommitted\x18\x03 \x01(\x04\x12\x10\n\x08\x41ssignId\x18\x04 \x01(\x04\x12\r\n\x05Topic\x18\x05 \x01(\t\x12\x11\n\tPartition\x18\x07 \x01(\x04\x12\x13\n\x0bTimestampMs\x18\x08 \x01(\x04\"\xa1\x03\n\x19TReadSessionsInfoResponse\x12J\n\rPartitionInfo\x18\x01 \x03(\x0b\x32\x33.NKikimrPQ.TReadSessionsInfoResponse.TPartitionInfo\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12K\n\x0cReadSessions\x18\x03 \x03(\x0b\x32\x35.NKikimrPQ.TReadSessionsInfoResponse.TReadSessionInfo\x1a\x85\x01\n\x0eTPartitionInfo\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x12\n\nClientNode\x18\x02 \x01(\t\x12\x13\n\x0bProxyNodeId\x18\x03 \x01(\r\x12\x0f\n\x07Session\x18\x04 \x01(\t\x12\x11\n\tTimestamp\x18\x05 \x01(\x04\x12\x13\n\x0bTimestampMs\x18\x06 \x01(\x04\x1aQ\n\x10TReadSessionInfo\x12,\n\x0cSessionActor\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0f\n\x07Session\x18\x02 \x01(\t\"\xc3\x01\n\x0eTLockPartition\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x10\n\x08TabletId\x18\x02 \x01(\x04\x12\r\n\x05Topic\x18\x03 \x01(\t\x12\x12\n\nGeneration\x18\x04 \x01(\r\x12\x0c\n\x04Step\x18\x05 \x01(\r\x12\x0f\n\x07Session\x18\x06 \x01(\t\x12\x10\n\x08\x43lientId\x18\x07 \x01(\t\x12*\n\nPipeClient\x18\x08 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0c\n\x04Path\x18\t \x01(\t\"\xb1\x01\n\x11TReleasePartition\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12\x0f\n\x07Session\x18\x03 \x01(\t\x12\x10\n\x08\x43lientId\x18\x04 \x01(\t\x12\r\n\x05\x43ount\x18\x05 \x01(\r\x12*\n\nPipeClient\x18\x06 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\r\n\x05Group\x18\x07 \x01(\r\x12\x0c\n\x04Path\x18\x08 \x01(\t\"\x85\x01\n\x12TPartitionReleased\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\r\n\x05Topic\x18\x02 \x01(\t\x12\x0f\n\x07Session\x18\x03 \x01(\t\x12*\n\nPipeClient\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x10\n\x08\x43lientId\x18\x05 \x01(\t\"L\n\x0bTDropTablet\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12/\n\x0eRequestedState\x18\x02 \x01(\x0e\x32\x17.NKikimrPQ.ETabletState\"\x8d\x01\n\x11TDropTabletResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x10\n\x08TabletId\x18\x03 \x01(\x04\x12,\n\x0b\x41\x63tualState\x18\x04 \x01(\x0e\x32\x17.NKikimrPQ.ETabletState\"6\n\x0cTTabletState\x12&\n\x05State\x18\x01 \x01(\x0e\x32\x17.NKikimrPQ.ETabletState\"Y\n\x15TUpdateConfigResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0e\n\x06Origin\x18\x02 \x01(\x04\x12\"\n\x06Status\x18\x03 \x01(\x0e\x32\x12.NKikimrPQ.EStatus\"\x1c\n\x08TOffsets\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\"\xbb\x03\n\x10TOffsetsResponse\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12;\n\nPartResult\x18\x02 \x03(\x0b\x32\'.NKikimrPQ.TOffsetsResponse.TPartResult\x1a\xd7\x02\n\x0bTPartResult\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x13\n\x0bStartOffset\x18\x02 \x01(\x03\x12\x11\n\tEndOffset\x18\x03 \x01(\x03\x12\x14\n\x0c\x43lientOffset\x18\x04 \x01(\x03\x12\x18\n\x10WriteTimestampMS\x18\x05 \x01(\x03\x12\x19\n\x11\x43reateTimestampMS\x18\x06 \x01(\x03\x12\x34\n\tErrorCode\x18\x07 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x08 \x01(\t\x12\x18\n\x10\x43lientReadOffset\x18\t \x01(\x03\x12\x1c\n\x14ReadWriteTimestampMS\x18\n \x01(\x03\x12\x1d\n\x15ReadCreateTimestampMS\x18\x0b \x01(\x03\x12 \n\x18WriteTimestampEstimateMS\x18\x0c \x01(\x04\";\n\x07TStatus\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x1e\n\x16GetStatForAllConsumers\x18\x02 \x01(\x08\"`\n\x0fTClientPosition\x12\x0e\n\x06Offset\x18\x01 \x01(\x03\x12\x0c\n\x04Size\x18\x02 \x01(\x04\x12\x16\n\x0eWriteTimestamp\x18\x03 \x01(\x04\x12\x17\n\x0f\x43reateTimestamp\x18\x04 \x01(\x04\"\xdc\x01\n\x0bTClientInfo\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x31\n\rWritePosition\x18\x02 \x01(\x0b\x32\x1a.NKikimrPQ.TClientPosition\x12\x30\n\x0cReadPosition\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TClientPosition\x12\x12\n\nWriteLagMs\x18\x04 \x01(\x04\x12\x11\n\tReadLagMs\x18\x05 \x01(\x04\x12\x1b\n\x13LastReadTimestampMs\x18\x08 \x01(\x04\x12\x12\n\nTotalLagMs\x18\t \x01(\x04\"\x99\x0b\n\x0fTStatusResponse\x12\x10\n\x08TabletId\x18\x01 \x01(\x04\x12:\n\nPartResult\x18\x02 \x03(\x0b\x32&.NKikimrPQ.TStatusResponse.TPartResult\x1a\x65\n\rTErrorMessage\x12\x11\n\tTimestamp\x18\x01 \x01(\x04\x12\x30\n\x07Service\x18\x02 \x01(\x0e\x32\x1f.NKikimrServices.EServiceKikimr\x12\x0f\n\x07Message\x18\x03 \x01(\t\x1a\x93\x07\n\x0bTPartResult\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x32\n\x06Status\x18\x02 \x01(\x0e\x32\".NKikimrPQ.TStatusResponse.EStatus\x12\x1f\n\x17LastInitDurationSeconds\x18\x03 \x01(\x05\x12\x19\n\x11\x43reationTimestamp\x18\x04 \x01(\x05\x12\x10\n\x08GapCount\x18\x05 \x01(\x05\x12\x0f\n\x07GapSize\x18\x06 \x01(\x03\x12\x1b\n\x13\x41vgWriteSpeedPerSec\x18\x07 \x01(\x03\x12\x1b\n\x13\x41vgWriteSpeedPerMin\x18\x08 \x01(\x03\x12\x1c\n\x14\x41vgWriteSpeedPerHour\x18\t \x01(\x03\x12\x1b\n\x13\x41vgWriteSpeedPerDay\x18\n \x01(\x03\x12\x1a\n\x12\x41vgReadSpeedPerSec\x18\x0b \x01(\x03\x12\x1a\n\x12\x41vgReadSpeedPerMin\x18\x0c \x01(\x03\x12\x1b\n\x13\x41vgReadSpeedPerHour\x18\r \x01(\x03\x12\x1a\n\x12\x41vgReadSpeedPerDay\x18\x0e \x01(\x03\x12\x16\n\x0eReadBytesQuota\x18\x0f \x01(\x03\x12\x17\n\x0fWriteBytesQuota\x18\x10 \x01(\x03\x12\x15\n\rPartitionSize\x18\x11 \x01(\x03\x12(\n\x08LagsInfo\x18\x12 \x01(\x0b\x32\x16.NKikimrPQ.TClientInfo\x12\x13\n\x0bStartOffset\x18\x13 \x01(\x03\x12\x11\n\tEndOffset\x18\x14 \x01(\x03\x12\x1c\n\x14LastWriteTimestampMs\x18\x15 \x01(\x03\x12\x12\n\nWriteLagMs\x18\x16 \x01(\x03\x12\x1b\n\x13\x41vgQuotaSpeedPerSec\x18\x17 \x01(\x03\x12\x1b\n\x13\x41vgQuotaSpeedPerMin\x18\x18 \x01(\x03\x12\x1c\n\x14\x41vgQuotaSpeedPerHour\x18\x19 \x01(\x03\x12\x1b\n\x13\x41vgQuotaSpeedPerDay\x18\x1a \x01(\x03\x12\x15\n\rSourceIdCount\x18\x1b \x01(\x03\x12\"\n\x1aSourceIdRetentionPeriodSec\x18\x1c \x01(\x03\x12\x38\n\x06\x45rrors\x18\x1d \x03(\x0b\x32(.NKikimrPQ.TStatusResponse.TErrorMessage\x12\x42\n\x0e\x43onsumerResult\x18\x1e \x03(\x0b\x32*.NKikimrPQ.TStatusResponse.TConsumerResult\x1a\xbc\x01\n\x0fTConsumerResult\x12\x10\n\x08\x43onsumer\x18\x01 \x01(\t\x12\x1a\n\x12\x41vgReadSpeedPerMin\x18\x02 \x01(\x03\x12\x1b\n\x13\x41vgReadSpeedPerHour\x18\x03 \x01(\x03\x12\x1a\n\x12\x41vgReadSpeedPerDay\x18\x04 \x01(\x03\x12\x12\n\nWriteLagMs\x18\x05 \x01(\x04\x12\x11\n\tReadLagMs\x18\x06 \x01(\x04\x12\x1b\n\x13LastReadTimestampMs\x18\x07 \x01(\x04\"|\n\x07\x45Status\x12\r\n\tSTATUS_OK\x10\x00\x12\x12\n\x0eSTATUS_UNKNOWN\x10\x01\x12\x17\n\x13STATUS_INITIALIZING\x10\x02\x12\x1c\n\x18STATUS_PARTITION_IS_FULL\x10\x03\x12\x17\n\x13STATUS_DISK_IS_FULL\x10\x04\"\x8d\x01\n\x0cTHasDataInfo\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x0e\n\x06Offset\x18\x02 \x01(\x04\x12\x10\n\x08\x44\x65\x61\x64line\x18\x03 \x01(\x04\x12&\n\x06Sender\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x06\x43ookie\x18\x05 \x01(\x04\x12\x10\n\x08\x43lientId\x18\x06 \x01(\t\"l\n\x14THasDataInfoResponse\x12\x11\n\tEndOffset\x18\x01 \x01(\x04\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x04\x12\x0f\n\x07SizeLag\x18\x03 \x01(\x04\x12 \n\x18WriteTimestampEstimateMS\x18\x04 \x01(\x04\"\xde\x01\n\x0cTBatchHeader\x12\x0e\n\x06Offset\x18\x01 \x01(\x04\x12\x0e\n\x06PartNo\x18\x02 \x01(\r\x12\r\n\x05\x43ount\x18\x03 \x01(\r\x12\x1a\n\x12InternalPartsCount\x18\x04 \x01(\r\x12\x14\n\x0cUnpackedSize\x18\x05 \x01(\r\x12\x13\n\x0bPayloadSize\x18\x06 \x01(\r\x12\x0e\n\x06\x46ormat\x18\x07 \x01(\r\x12\x12\n\nHasKinesis\x18\x08 \x01(\x08\"4\n\x0e\x45PayloadFormat\x12\x11\n\rEUncompressed\x10\x00\x12\x0f\n\x0b\x45\x43ompressed\x10\x01\"\x83\x01\n\tTUserInfo\x12\x0e\n\x06Offset\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\r\x12\x0c\n\x04Step\x18\x03 \x01(\r\x12\x0f\n\x07Session\x18\x04 \x01(\t\x12\x17\n\x0fOffsetRewindSum\x18\x05 \x01(\x04\x12\x1a\n\x12ReadRuleGeneration\x18\x06 \x01(\x04\"*\n\x14TPartitionClientInfo\x12\x12\n\nPartitions\x18\x01 \x03(\x05\"\x97\x01\n\x13TClientInfoResponse\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x13\n\x0bStartOffset\x18\x02 \x01(\x04\x12\x11\n\tEndOffset\x18\x03 \x01(\x04\x12\x19\n\x11ResponseTimestamp\x18\x04 \x01(\x04\x12*\n\nClientInfo\x18\x05 \x03(\x0b\x32\x16.NKikimrPQ.TClientInfo\"\xb0\x01\n\x19TPQClusterDiscoveryConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12.\n\"TimedCountersUpdateIntervalSeconds\x18\x02 \x01(\r:\x02\x31\x35\x12\x34\n\x0c\x43loudNetData\x18\x03 \x01(\x0b\x32\x1e.NKikimrNetClassifier.TNetData\x12\x1c\n\x14RequestInflightLimit\x18\x04 \x01(\x04\"f\n\rTYdsNextToken\x12\x19\n\x11\x43reationTimestamp\x18\x01 \x02(\x04\x12\x12\n\nMaxResults\x18\x02 \x02(\r\x12\x13\n\x0b\x41lreadyRead\x18\x03 \x02(\r\x12\x11\n\tStreamArn\x18\x04 \x02(\t\"\xfd\x01\n\x11TYdsShardIterator\x12\x12\n\nStreamName\x18\x01 \x02(\t\x12\x11\n\tStreamArn\x18\x02 \x02(\t\x12\x0f\n\x07ShardId\x18\x03 \x02(\r\x12\x17\n\x0fReadTimestampMs\x18\x04 \x02(\x04\x12\x16\n\x0eSequenceNumber\x18\x05 \x02(\x04\x12\x1b\n\x13\x43reationTimestampMs\x18\x06 \x02(\x04\x12\x35\n\x04Kind\x18\x07 \x01(\x0e\x32\'.NKikimrPQ.TYdsShardIterator.ETopicKind\"+\n\nETopicKind\x12\x0f\n\x0bKIND_COMMON\x10\x00\x12\x0c\n\x08KIND_CDC\x10\x01\"f\n\x13TPartitionOperation\x12\x13\n\x0bPartitionId\x18\x01 \x02(\x04\x12\r\n\x05\x42\x65gin\x18\x02 \x01(\x04\x12\x0b\n\x03\x45nd\x18\x03 \x01(\x04\x12\x10\n\x08\x43onsumer\x18\x04 \x01(\t\x12\x0c\n\x04Path\x18\x05 \x02(\t\"\x90\x02\n\x0fTKqpTransaction\x12\x32\n\nOperations\x18\x01 \x03(\x0b\x32\x1e.NKikimrPQ.TPartitionOperation\x12/\n\x02Op\x18\x02 \x02(\x0e\x32#.NKikimrPQ.TKqpTransaction.ELocksOp\x12\x15\n\rSendingShards\x18\x03 \x03(\x04\x12\x17\n\x0fReceivingShards\x18\x04 \x03(\x04\x12\x11\n\tImmediate\x18\x05 \x02(\x08\x12\x10\n\x08LockTxId\x18\x06 \x01(\x06\"C\n\x08\x45LocksOp\x12\x0f\n\x0bUnspecified\x10\x00\x12\x0c\n\x08Validate\x10\x01\x12\n\n\x06\x43ommit\x10\x02\x12\x0c\n\x08Rollback\x10\x03\"y\n\x15TEvProposeTransaction\x12&\n\x06Source\x18\x01 \x02(\x0b\x32\x16.NActorsProto.TActorId\x12*\n\x06TxBody\x18\x02 \x02(\x0b\x32\x1a.NKikimrPQ.TKqpTransaction\x12\x0c\n\x04TxId\x18\x03 \x02(\x04\"\xac\x02\n\x1bTEvProposeTransactionResult\x12\x0e\n\x06Origin\x18\x01 \x02(\x04\x12>\n\x06Status\x18\x02 \x02(\x0e\x32..NKikimrPQ.TEvProposeTransactionResult.EStatus\x12\x0c\n\x04TxId\x18\x03 \x02(\x04\x12\x0f\n\x07MinStep\x18\x04 \x01(\x04\x12\x0f\n\x07MaxStep\x18\x06 \x01(\x04\x12\x0c\n\x04Step\x18\x07 \x01(\x04\"\x7f\n\x07\x45Status\x12\x0c\n\x08PREPARED\x10\x01\x12\x0c\n\x08\x43OMPLETE\x10\x02\x12\x0b\n\x07\x41\x42ORTED\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x10\n\x0cLOCKS_BROKEN\x10\x05\x12\r\n\tCANCELLED\x10\x06\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x07\x12\x0e\n\nOVERLOADED\x10\x08\",\n\x1cTEvCancelTransactionProposal\x12\x0c\n\x04TxId\x18\x01 \x02(\x04*\'\n\nEOperation\x12\x0b\n\x07READ_OP\x10\x01\x12\x0c\n\x08WRITE_OP\x10\x02*/\n\x07\x45\x41\x63\x63\x65ss\x12\x0b\n\x07\x41LLOWED\x10\x01\x12\n\n\x06\x44\x45NIED\x10\x02\x12\x0b\n\x07UNKNOWN\x10\x03*)\n\x0c\x45TabletState\x12\x0b\n\x07\x45Normal\x10\x00\x12\x0c\n\x08\x45\x44ropped\x10\x01*Q\n\x07\x45Status\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\x12\x15\n\x11\x45RROR_BAD_VERSION\x10\x02\x12\x1c\n\x18\x45RROR_UPDATE_IN_PROGRESS\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.pqconfig_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPQCONFIG.fields_by_name['MetaCacheTimeoutSec']._options = None
  _TPQCONFIG.fields_by_name['MetaCacheTimeoutSec']._serialized_options = b'\030\001'
  _TPQCONFIG.fields_by_name['MetaCacheRefreshIntervalMilliSeconds']._options = None
  _TPQCONFIG.fields_by_name['MetaCacheRefreshIntervalMilliSeconds']._serialized_options = b'\030\001'
  _TPQCONFIG.fields_by_name['MetaCacheSkipVersionCheck']._options = None
  _TPQCONFIG.fields_by_name['MetaCacheSkipVersionCheck']._serialized_options = b'\030\001'
  _EOPERATION._serialized_start=15140
  _EOPERATION._serialized_end=15179
  _EACCESS._serialized_start=15181
  _EACCESS._serialized_end=15228
  _ETABLETSTATE._serialized_start=15230
  _ETABLETSTATE._serialized_end=15271
  _ESTATUS._serialized_start=15273
  _ESTATUS._serialized_end=15354
  _TPARTITIONMETA._serialized_start=392
  _TPARTITIONMETA._serialized_end=448
  _TPARTITIONTXMETA._serialized_start=450
  _TPARTITIONTXMETA._serialized_end=500
  _TPQCONFIG._serialized_start=503
  _TPQCONFIG._serialized_end=4300
  _TPQCONFIG_TQUOTINGCONFIG._serialized_start=2815
  _TPQCONFIG_TQUOTINGCONFIG._serialized_end=3233
  _TPQCONFIG_TQUOTINGCONFIG_ELIMITEDENTITY._serialized_start=3154
  _TPQCONFIG_TQUOTINGCONFIG_ELIMITEDENTITY._serialized_end=3233
  _TPQCONFIG_TPQLIBSETTINGS._serialized_start=3235
  _TPQCONFIG_TPQLIBSETTINGS._serialized_end=3335
  _TPQCONFIG_TMIRRORCONFIG._serialized_start=3337
  _TPQCONFIG_TMIRRORCONFIG._serialized_end=3435
  _TPQCONFIG_TVALIDRETENTIONLIMIT._serialized_start=3438
  _TPQCONFIG_TVALIDRETENTIONLIMIT._serialized_end=3570
  _TPQCONFIG_TREADMETERINGCONFIG._serialized_start=3573
  _TPQCONFIG_TREADMETERINGCONFIG._serialized_end=3772
  _TPQCONFIG_TREADMETERINGCONFIG_TPRICING._serialized_start=3739
  _TPQCONFIG_TREADMETERINGCONFIG_TPRICING._serialized_end=3772
  _TPQCONFIG_TBILLINGMETERINGCONFIG._serialized_start=3775
  _TPQCONFIG_TBILLINGMETERINGCONFIG._serialized_end=3909
  _TPQCONFIG_TCLIENTSERVICETYPE._serialized_start=3912
  _TPQCONFIG_TCLIENTSERVICETYPE._serialized_end=4047
  _TPQCONFIG_TPQDISCOVERYCONFIG._serialized_start=4050
  _TPQCONFIG_TPQDISCOVERYCONFIG._serialized_end=4250
  _TPQCONFIG_TMOVETOPICACTORCONFIG._serialized_start=4252
  _TPQCONFIG_TMOVETOPICACTORCONFIG._serialized_end=4300
  _TCHANNELPROFILE._serialized_start=4303
  _TCHANNELPROFILE._serialized_end=4436
  _TMIRRORPARTITIONCONFIG._serialized_start=4439
  _TMIRRORPARTITIONCONFIG._serialized_end=4935
  _TMIRRORPARTITIONCONFIG_TCREDENTIALS._serialized_start=4722
  _TMIRRORPARTITIONCONFIG_TCREDENTIALS._serialized_end=4935
  _TMIRRORPARTITIONCONFIG_TCREDENTIALS_IAMCREDENTIALS._serialized_start=4859
  _TMIRRORPARTITIONCONFIG_TCREDENTIALS_IAMCREDENTIALS._serialized_end=4920
  _TPARTITIONCONFIG._serialized_start=4938
  _TPARTITIONCONFIG._serialized_end=5702
  _TPARTITIONCONFIG_TREADQUOTA._serialized_start=5622
  _TPARTITIONCONFIG_TREADQUOTA._serialized_end=5702
  _TPARTITIONKEYRANGE._serialized_start=5704
  _TPARTITIONKEYRANGE._serialized_end=5760
  _TMESSAGEGROUP._serialized_start=5762
  _TMESSAGEGROUP._serialized_end=5838
  _TPQTABLETCONFIG._serialized_start=5841
  _TPQTABLETCONFIG._serialized_end=7131
  _TPQTABLETCONFIG_TCODECS._serialized_start=6826
  _TPQTABLETCONFIG_TCODECS._serialized_end=6864
  _TPQTABLETCONFIG_TKEYCOMPONENTSCHEMA._serialized_start=6866
  _TPQTABLETCONFIG_TKEYCOMPONENTSCHEMA._serialized_end=6960
  _TPQTABLETCONFIG_TPARTITION._serialized_start=6962
  _TPQTABLETCONFIG_TPARTITION._serialized_end=7044
  _TPQTABLETCONFIG_EMETERINGMODE._serialized_start=7046
  _TPQTABLETCONFIG_EMETERINGMODE._serialized_end=7131
  _TMESSAGEGROUPINFO._serialized_start=7134
  _TMESSAGEGROUPINFO._serialized_end=7435
  _TMESSAGEGROUPINFO_ESTATE._serialized_start=7354
  _TMESSAGEGROUPINFO_ESTATE._serialized_end=7435
  _TBOOTSTRAPCONFIG._serialized_start=7437
  _TBOOTSTRAPCONFIG._serialized_end=7512
  _TUPDATECONFIG._serialized_start=7515
  _TUPDATECONFIG._serialized_end=7648
  _TUPDATEBALANCERCONFIG._serialized_start=7651
  _TUPDATEBALANCERCONFIG._serialized_end=8152
  _TUPDATEBALANCERCONFIG_TPARTITION._serialized_start=8031
  _TUPDATEBALANCERCONFIG_TPARTITION._serialized_end=8095
  _TUPDATEBALANCERCONFIG_TTABLET._serialized_start=8097
  _TUPDATEBALANCERCONFIG_TTABLET._serialized_end=8152
  _TDESCRIBE._serialized_start=8154
  _TDESCRIBE._serialized_end=8165
  _TDESCRIBERESPONSE._serialized_start=8168
  _TDESCRIBERESPONSE._serialized_end=8480
  _TDESCRIBERESPONSE_TPARTITION._serialized_start=8031
  _TDESCRIBERESPONSE_TPARTITION._serialized_end=8080
  _TCHECKACL._serialized_start=8482
  _TCHECKACL._serialized_end=8609
  _TCHECKACLRESPONSE._serialized_start=8611
  _TCHECKACLRESPONSE._serialized_end=8710
  _TGETPARTITIONIDFORWRITE._serialized_start=8712
  _TGETPARTITIONIDFORWRITE._serialized_end=8737
  _TGETPARTITIONIDFORWRITERESPONSE._serialized_start=8739
  _TGETPARTITIONIDFORWRITERESPONSE._serialized_end=8793
  _TREGISTERREADSESSION._serialized_start=8796
  _TREGISTERREADSESSION._serialized_end=8933
  _TGETREADSESSIONSINFO._serialized_start=8935
  _TGETREADSESSIONSINFO._serialized_end=8975
  _TREADSESSIONSTATUS._serialized_start=8977
  _TREADSESSIONSTATUS._serialized_end=8997
  _TREADSESSIONSTATUSRESPONSE._serialized_start=9000
  _TREADSESSIONSTATUSRESPONSE._serialized_end=9340
  _TREADSESSIONSTATUSRESPONSE_TPARTITIONSTATUS._serialized_start=9183
  _TREADSESSIONSTATUSRESPONSE_TPARTITIONSTATUS._serialized_end=9340
  _TREADSESSIONSINFORESPONSE._serialized_start=9343
  _TREADSESSIONSINFORESPONSE._serialized_end=9760
  _TREADSESSIONSINFORESPONSE_TPARTITIONINFO._serialized_start=9544
  _TREADSESSIONSINFORESPONSE_TPARTITIONINFO._serialized_end=9677
  _TREADSESSIONSINFORESPONSE_TREADSESSIONINFO._serialized_start=9679
  _TREADSESSIONSINFORESPONSE_TREADSESSIONINFO._serialized_end=9760
  _TLOCKPARTITION._serialized_start=9763
  _TLOCKPARTITION._serialized_end=9958
  _TRELEASEPARTITION._serialized_start=9961
  _TRELEASEPARTITION._serialized_end=10138
  _TPARTITIONRELEASED._serialized_start=10141
  _TPARTITIONRELEASED._serialized_end=10274
  _TDROPTABLET._serialized_start=10276
  _TDROPTABLET._serialized_end=10352
  _TDROPTABLETRESULT._serialized_start=10355
  _TDROPTABLETRESULT._serialized_end=10496
  _TTABLETSTATE._serialized_start=10498
  _TTABLETSTATE._serialized_end=10552
  _TUPDATECONFIGRESPONSE._serialized_start=10554
  _TUPDATECONFIGRESPONSE._serialized_end=10643
  _TOFFSETS._serialized_start=10645
  _TOFFSETS._serialized_end=10673
  _TOFFSETSRESPONSE._serialized_start=10676
  _TOFFSETSRESPONSE._serialized_end=11119
  _TOFFSETSRESPONSE_TPARTRESULT._serialized_start=10776
  _TOFFSETSRESPONSE_TPARTRESULT._serialized_end=11119
  _TSTATUS._serialized_start=11121
  _TSTATUS._serialized_end=11180
  _TCLIENTPOSITION._serialized_start=11182
  _TCLIENTPOSITION._serialized_end=11278
  _TCLIENTINFO._serialized_start=11281
  _TCLIENTINFO._serialized_end=11501
  _TSTATUSRESPONSE._serialized_start=11504
  _TSTATUSRESPONSE._serialized_end=12937
  _TSTATUSRESPONSE_TERRORMESSAGE._serialized_start=11601
  _TSTATUSRESPONSE_TERRORMESSAGE._serialized_end=11702
  _TSTATUSRESPONSE_TPARTRESULT._serialized_start=11705
  _TSTATUSRESPONSE_TPARTRESULT._serialized_end=12620
  _TSTATUSRESPONSE_TCONSUMERRESULT._serialized_start=12623
  _TSTATUSRESPONSE_TCONSUMERRESULT._serialized_end=12811
  _TSTATUSRESPONSE_ESTATUS._serialized_start=12813
  _TSTATUSRESPONSE_ESTATUS._serialized_end=12937
  _THASDATAINFO._serialized_start=12940
  _THASDATAINFO._serialized_end=13081
  _THASDATAINFORESPONSE._serialized_start=13083
  _THASDATAINFORESPONSE._serialized_end=13191
  _TBATCHHEADER._serialized_start=13194
  _TBATCHHEADER._serialized_end=13416
  _TBATCHHEADER_EPAYLOADFORMAT._serialized_start=13364
  _TBATCHHEADER_EPAYLOADFORMAT._serialized_end=13416
  _TUSERINFO._serialized_start=13419
  _TUSERINFO._serialized_end=13550
  _TPARTITIONCLIENTINFO._serialized_start=13552
  _TPARTITIONCLIENTINFO._serialized_end=13594
  _TCLIENTINFORESPONSE._serialized_start=13597
  _TCLIENTINFORESPONSE._serialized_end=13748
  _TPQCLUSTERDISCOVERYCONFIG._serialized_start=13751
  _TPQCLUSTERDISCOVERYCONFIG._serialized_end=13927
  _TYDSNEXTTOKEN._serialized_start=13929
  _TYDSNEXTTOKEN._serialized_end=14031
  _TYDSSHARDITERATOR._serialized_start=14034
  _TYDSSHARDITERATOR._serialized_end=14287
  _TYDSSHARDITERATOR_ETOPICKIND._serialized_start=14244
  _TYDSSHARDITERATOR_ETOPICKIND._serialized_end=14287
  _TPARTITIONOPERATION._serialized_start=14289
  _TPARTITIONOPERATION._serialized_end=14391
  _TKQPTRANSACTION._serialized_start=14394
  _TKQPTRANSACTION._serialized_end=14666
  _TKQPTRANSACTION_ELOCKSOP._serialized_start=14599
  _TKQPTRANSACTION_ELOCKSOP._serialized_end=14666
  _TEVPROPOSETRANSACTION._serialized_start=14668
  _TEVPROPOSETRANSACTION._serialized_end=14789
  _TEVPROPOSETRANSACTIONRESULT._serialized_start=14792
  _TEVPROPOSETRANSACTIONRESULT._serialized_end=15092
  _TEVPROPOSETRANSACTIONRESULT_ESTATUS._serialized_start=14965
  _TEVPROPOSETRANSACTIONRESULT_ESTATUS._serialized_end=15092
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_start=15094
  _TEVCANCELTRANSACTIONPROPOSAL._serialized_end=15138
# @@protoc_insertion_point(module_scope)
