# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/subdomains.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2
from ydb.public.api.protos import ydb_cms_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__cms__pb2
from ydb.library.login.protos import login_pb2 as ydb_dot_library_dot_login_dot_protos_dot_login__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n ydb/core/protos/subdomains.proto\x12\x11NKikimrSubDomains\x1a/ydb/core/protos/bind_channel_storage_pool.proto\x1a#ydb/public/api/protos/ydb_cms.proto\x1a$ydb/library/login/protos/login.proto\"1\n\nTDomainKey\x12\x13\n\x0bSchemeShard\x18\x01 \x01(\x06\x12\x0e\n\x06PathId\x18\x02 \x01(\x06\"\xd5\x03\n\x12TSubDomainSettings\x12\x16\n\x0ePlanResolution\x18\x01 \x01(\x04\x12\x14\n\x0c\x43oordinators\x18\x02 \x01(\x04\x12\x11\n\tMediators\x18\x03 \x01(\x04\x12\x0c\n\x04Name\x18\x04 \x01(\t\x12\"\n\x1aTimeCastBucketsPerMediator\x18\x05 \x01(\r\x12\x36\n\x0cStoragePools\x18\x06 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\x12\"\n\x13\x45xternalSchemeShard\x18\x07 \x01(\x08:\x05\x66\x61lse\x12\x1b\n\x0c\x45xternalHive\x18\x08 \x01(\x08:\x05\x66\x61lse\x12\x39\n\x12ResourcesDomainKey\x18\t \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\'\n\x18\x45xternalSysViewProcessor\x18\n \x01(\x08:\x05\x66\x61lse\x12>\n\x14\x44\x65\x63laredSchemeQuotas\x18\x0b \x01(\x0b\x32 .NKikimrSubDomains.TSchemeQuotas\x12/\n\x0e\x44\x61tabaseQuotas\x18\x0c \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\"\xc6\x01\n\x11TProcessingParams\x12\x0f\n\x07Version\x18\x01 \x01(\r\x12\x16\n\x0ePlanResolution\x18\x02 \x01(\x04\x12\x14\n\x0c\x43oordinators\x18\x03 \x03(\x06\x12\"\n\x1aTimeCastBucketsPerMediator\x18\x04 \x01(\x04\x12\x11\n\tMediators\x18\x05 \x03(\x06\x12\x13\n\x0bSchemeShard\x18\x06 \x01(\x06\x12\x0c\n\x04Hive\x18\x07 \x01(\x06\x12\x18\n\x10SysViewProcessor\x18\x08 \x01(\x06\"\x90\x01\n\x0fTDiskSpaceUsage\x12:\n\x06Tables\x18\x01 \x01(\x0b\x32*.NKikimrSubDomains.TDiskSpaceUsage.TTables\x1a\x41\n\x07TTables\x12\x11\n\tTotalSize\x18\x01 \x01(\x04\x12\x10\n\x08\x44\x61taSize\x18\x02 \x01(\x04\x12\x11\n\tIndexSize\x18\x03 \x01(\x04\")\n\x0cTDomainState\x12\x19\n\x11\x44iskQuotaExceeded\x18\x01 \x01(\x08\"\xd8\x05\n\x12TDomainDescription\x12 \n\x18SchemeShardId_Depricated\x18\x01 \x01(\x06\x12\x19\n\x11PathId_Depricated\x18\x02 \x01(\x06\x12>\n\x10ProcessingParams\x18\x03 \x01(\x0b\x32$.NKikimrSubDomains.TProcessingParams\x12\x30\n\tDomainKey\x18\x04 \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12\x36\n\x0cStoragePools\x18\x05 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\x12\x13\n\x0bPathsInside\x18\x06 \x01(\x04\x12\x12\n\nPathsLimit\x18\x07 \x01(\x04\x12\x14\n\x0cShardsInside\x18\x08 \x01(\x04\x12\x13\n\x0bShardsLimit\x18\t \x01(\x04\x12\x39\n\x12ResourcesDomainKey\x18\n \x01(\x0b\x32\x1d.NKikimrSubDomains.TDomainKey\x12:\n\x0e\x44iskSpaceUsage\x18\x0b \x01(\x0b\x32\".NKikimrSubDomains.TDiskSpaceUsage\x12>\n\x14\x44\x65\x63laredSchemeQuotas\x18\x0c \x01(\x0b\x32 .NKikimrSubDomains.TSchemeQuotas\x12\x1a\n\x12PQPartitionsInside\x18\r \x01(\x04\x12\x19\n\x11PQPartitionsLimit\x18\x0e \x01(\x04\x12/\n\x0e\x44\x61tabaseQuotas\x18\x0f \x01(\x0b\x32\x17.Ydb.Cms.DatabaseQuotas\x12\x34\n\x0b\x44omainState\x18\x10 \x01(\x0b\x32\x1f.NKikimrSubDomains.TDomainState\x12\x32\n\rSecurityState\x18\x14 \x01(\x0b\x32\x1b.NLoginProto.TSecurityState\"F\n\rTSchemeQuotas\x12\x35\n\x0cSchemeQuotas\x18\x01 \x03(\x0b\x32\x1f.NKikimrSubDomains.TSchemeQuota\"9\n\x0cTSchemeQuota\x12\x12\n\nBucketSize\x18\x01 \x01(\x01\x12\x15\n\rBucketSeconds\x18\x02 \x01(\x04')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.subdomains_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TDOMAINKEY._serialized_start=179
  _TDOMAINKEY._serialized_end=228
  _TSUBDOMAINSETTINGS._serialized_start=231
  _TSUBDOMAINSETTINGS._serialized_end=700
  _TPROCESSINGPARAMS._serialized_start=703
  _TPROCESSINGPARAMS._serialized_end=901
  _TDISKSPACEUSAGE._serialized_start=904
  _TDISKSPACEUSAGE._serialized_end=1048
  _TDISKSPACEUSAGE_TTABLES._serialized_start=983
  _TDISKSPACEUSAGE_TTABLES._serialized_end=1048
  _TDOMAINSTATE._serialized_start=1050
  _TDOMAINSTATE._serialized_end=1091
  _TDOMAINDESCRIPTION._serialized_start=1094
  _TDOMAINDESCRIPTION._serialized_end=1822
  _TSCHEMEQUOTAS._serialized_start=1824
  _TSCHEMEQUOTAS._serialized_end=1894
  _TSCHEMEQUOTA._serialized_start=1896
  _TSCHEMEQUOTA._serialized_end=1953
# @@protoc_insertion_point(module_scope)
