# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_testshard.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(ydb/core/protos/counters_testshard.proto\x12\x12NKikimr.NTestShard\x1a\x1eydb/core/protos/counters.proto*4\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00*\xb3\x01\n\x0f\x45SimpleCounters\x12\'\n\x12\x43OUNTER_MODE_WRITE\x10\x00\x1a\x0f\x82\xd6\x1b\x0b\n\tModeWrite\x12\x36\n\x1a\x43OUNTER_MODE_READ_VALIDATE\x10\x01\x1a\x16\x82\xd6\x1b\x12\n\x10ModeReadValidate\x12?\n!COUNTER_MODE_STATE_SERVER_CONNECT\x10\x02\x1a\x18\x82\xd6\x1b\x14\n\x12StateServerConnect*4\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x42%\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\tTestShard')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_testshard_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\tTestShard'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_WRITE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_WRITE"]._serialized_options = b'\202\326\033\013\n\tModeWrite'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_READ_VALIDATE"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_READ_VALIDATE"]._serialized_options = b'\202\326\033\022\n\020ModeReadValidate'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_STATE_SERVER_CONNECT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_MODE_STATE_SERVER_CONNECT"]._serialized_options = b'\202\326\033\024\n\022StateServerConnect'
  _ECUMULATIVECOUNTERS._serialized_start=96
  _ECUMULATIVECOUNTERS._serialized_end=148
  _ESIMPLECOUNTERS._serialized_start=151
  _ESIMPLECOUNTERS._serialized_end=330
  _EPERCENTILECOUNTERS._serialized_start=332
  _EPERCENTILECOUNTERS._serialized_end=384
# @@protoc_insertion_point(module_scope)
