# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_proxy.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import export_pb2 as ydb_dot_core_dot_protos_dot_export__pb2
from ydb.core.protos import flat_scheme_op_pb2 as ydb_dot_core_dot_protos_dot_flat__scheme__op__pb2
from ydb.core.protos import issue_id_pb2 as ydb_dot_core_dot_protos_dot_issue__id__pb2
from ydb.core.protos import query_stats_pb2 as ydb_dot_core_dot_protos_dot_query__stats__pb2
from ydb.library.mkql_proto.protos import minikql_pb2 as ydb_dot_library_dot_mkql__proto_dot_protos_dot_minikql__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/tx_proxy.proto\x12\x12NKikimrTxUserProxy\x1a\x1cydb/core/protos/export.proto\x1a$ydb/core/protos/flat_scheme_op.proto\x1a\x1eydb/core/protos/issue_id.proto\x1a!ydb/core/protos/query_stats.proto\x1a+ydb/library/mkql_proto/protos/minikql.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\"\xa5\x03\n\x0eTRWTransaction\x12@\n\tPredicate\x18\x01 \x03(\x0b\x32-.NKikimrTxUserProxy.TRWTransaction.TPredicate\x12\x36\n\x04Read\x18\x02 \x03(\x0b\x32(.NKikimrTxUserProxy.TRWTransaction.TRead\x12\x38\n\x05Write\x18\x03 \x03(\x0b\x32).NKikimrTxUserProxy.TRWTransaction.TWrite\x1a\x64\n\nTPredicate\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\r\n\x05Value\x18\x02 \x01(\x0c\x12\x11\n\tValueType\x18\x03 \x01(\r\x12\x14\n\x0cMustNotExist\x18\x04 \x01(\x08\x12\x11\n\tMustExist\x18\x05 \x01(\x08\x1a\x31\n\x05TRead\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\x1b\n\x13\x45xpectedPayloadType\x18\n \x01(\r\x1a\x46\n\x06TWrite\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\r\n\x05Value\x18\x02 \x01(\x0c\x12\x11\n\tValueType\x18\x03 \x01(\r\x12\r\n\x05\x45rase\x18\x04 \x01(\x08\"f\n\x10TReadTransaction\x12\x0e\n\x06StepId\x18\x02 \x01(\x06\x12\x0f\n\x07OrderId\x18\x03 \x01(\x06\x1a\x31\n\x05TRead\x12\x0b\n\x03Key\x18\x01 \x01(\x0c\x12\x1b\n\x13\x45xpectedPayloadType\x18\n \x01(\r\"\x90\x01\n\tTKeyRange\x12%\n\x04\x46rom\x18\x01 \x01(\x0b\x32\x17.NKikimrMiniKQL.TParams\x12#\n\x02To\x18\x02 \x01(\x0b\x32\x17.NKikimrMiniKQL.TParams\x12\x1b\n\rFromInclusive\x18\x03 \x01(\x08:\x04true\x12\x1a\n\x0bToInclusive\x18\x04 \x01(\x08:\x05\x66\x61lse\"\x9d\x02\n\x15TReadTableTransaction\x12\x0c\n\x04Path\x18\x01 \x01(\t\x12\x16\n\x07Ordered\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x1e\n\x0f\x41llowDuplicates\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x07\x43olumns\x18\x04 \x03(\t\x12/\n\x08KeyRange\x18\x05 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\x12\x13\n\x08RowLimit\x18\x06 \x01(\x04:\x01\x30\x12\x12\n\nApiVersion\x18\x07 \x01(\r\x12\x14\n\x0cSnapshotStep\x18\x08 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\t \x01(\x04\"\'\n\x08\x45Version\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\n\n\x06YDB_V1\x10\x01\"\xeb\x01\n\x19TCreateVolatileSnapshotTx\x12\x44\n\x06Tables\x18\x01 \x03(\x0b\x32\x34.NKikimrTxUserProxy.TCreateVolatileSnapshotTx.TTable\x12\x0c\n\x04Name\x18\x02 \x01(\t\x12\x11\n\tTimeoutMs\x18\x03 \x01(\x04\x12\x19\n\x11IgnoreSystemViews\x18\x04 \x01(\x08\x1aL\n\x06TTable\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\"\xf8\x01\n\x1aTRefreshVolatileSnapshotTx\x12\x45\n\x06Tables\x18\x01 \x03(\x0b\x32\x35.NKikimrTxUserProxy.TRefreshVolatileSnapshotTx.TTable\x12\x14\n\x0cSnapshotStep\x18\x02 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x03 \x01(\x04\x12\x19\n\x11IgnoreSystemViews\x18\x04 \x01(\x08\x1aL\n\x06TTable\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\"\xf8\x01\n\x1aTDiscardVolatileSnapshotTx\x12\x45\n\x06Tables\x18\x01 \x03(\x0b\x32\x35.NKikimrTxUserProxy.TDiscardVolatileSnapshotTx.TTable\x12\x14\n\x0cSnapshotStep\x18\x02 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x03 \x01(\x04\x12\x19\n\x11IgnoreSystemViews\x18\x04 \x01(\x08\x1aL\n\x06TTable\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\"\xae\x01\n\x0fTCommitWritesTx\x12:\n\x06Tables\x18\x01 \x03(\x0b\x32*.NKikimrTxUserProxy.TCommitWritesTx.TTable\x12\x11\n\tWriteTxId\x18\x02 \x01(\x04\x1aL\n\x06TTable\x12\x11\n\tTablePath\x18\x01 \x01(\t\x12/\n\x08KeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrTxUserProxy.TKeyRange\"\xe1\x06\n\x13TMiniKQLTransaction\x12M\n\x04Mode\x18\x01 \x01(\x0e\x32-.NKikimrTxUserProxy.TMiniKQLTransaction.EMode:\x10\x43OMPILE_AND_EXEC\x12H\n\x07Program\x18\x02 \x01(\x0b\x32\x37.NKikimrTxUserProxy.TMiniKQLTransaction.TMiniKQLProgram\x12\x46\n\x06Params\x18\x03 \x01(\x0b\x32\x36.NKikimrTxUserProxy.TMiniKQLTransaction.TMiniKQLParams\x12 \n\x12\x45valuateResultType\x18\x32 \x01(\x08:\x04true\x12!\n\x13\x45valuateResultValue\x18\x33 \x01(\x08:\x04true\x12\x16\n\x08\x46latMKQL\x18\x34 \x01(\x08:\x04true\x12\x13\n\x0bLlvmRuntime\x18\x35 \x01(\x08\x12\"\n\x1aPerShardKeysSizeLimitBytes\x18\x36 \x01(\x04\x12\x14\n\x0c\x43ollectStats\x18\x37 \x01(\x08\x12?\n\x06Limits\x18\x38 \x01(\x0b\x32/.NKikimrTxUserProxy.TMiniKQLTransaction.TLimits\x12\x14\n\x0cSnapshotStep\x18\t \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\n \x01(\x04\x1a\x45\n\x0fTMiniKQLProgram\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x0b\n\x03\x42in\x18\x02 \x01(\x0c\x12\x17\n\x0fResultDocScheme\x18\x03 \x01(\x0c\x1aS\n\x0eTMiniKQLParams\x12\x0c\n\x04Text\x18\x01 \x01(\t\x12\x0b\n\x03\x42in\x18\x02 \x01(\x0c\x12&\n\x05Proto\x18\x03 \x01(\x0b\x32\x17.NKikimrMiniKQL.TParams\x1a\x87\x01\n\x07TLimits\x12\x1b\n\x13\x41\x66\x66\x65\x63tedShardsLimit\x18\x01 \x01(\r\x12\x19\n\x11ReadsetCountLimit\x18\x02 \x01(\r\x12#\n\x1b\x43omputeNodeMemoryLimitBytes\x18\x03 \x01(\x04\x12\x1f\n\x17TotalReadSizeLimitBytes\x18\x04 \x01(\x04\"*\n\x05\x45Mode\x12\x14\n\x10\x43OMPILE_AND_EXEC\x10\x01\x12\x0b\n\x07\x43OMPILE\x10\x02\"\xb6\x01\n\x16TMiniKQLCompileResults\x12\x17\n\x0f\x43ompiledProgram\x18\x01 \x01(\x0c\x12\x35\n\x14ProgramCompileErrors\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x16\n\x0e\x43ompiledParams\x18\x14 \x01(\x0c\x12\x34\n\x13ParamsCompileErrors\x18\x15 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"\xe7\x04\n\x0cTTransaction\x12\x43\n\x12MiniKQLTransaction\x18\x04 \x01(\x0b\x32\'.NKikimrTxUserProxy.TMiniKQLTransaction\x12\r\n\x05\x46lags\x18\x06 \x01(\r\x12\x15\n\rUserRequestId\x18\x08 \x01(\t\x12\x34\n\x0cModifyScheme\x18\n \x01(\x0b\x32\x1e.NKikimrSchemeOp.TModifyScheme\x12\x41\n\x19TransactionalModification\x18\x0b \x03(\x0b\x32\x1e.NKikimrSchemeOp.TModifyScheme\x12G\n\x14ReadTableTransaction\x18\x14 \x01(\x0b\x32).NKikimrTxUserProxy.TReadTableTransaction\x12M\n\x16\x43reateVolatileSnapshot\x18\x1e \x01(\x0b\x32-.NKikimrTxUserProxy.TCreateVolatileSnapshotTx\x12O\n\x17RefreshVolatileSnapshot\x18\x1f \x01(\x0b\x32..NKikimrTxUserProxy.TRefreshVolatileSnapshotTx\x12O\n\x17\x44iscardVolatileSnapshot\x18  \x01(\x0b\x32..NKikimrTxUserProxy.TDiscardVolatileSnapshotTx\x12\x39\n\x0c\x43ommitWrites\x18( \x01(\x0b\x32#.NKikimrTxUserProxy.TCommitWritesTx\"\xea\x01\n\x15TEvProposeTransaction\x12\x35\n\x0bTransaction\x18\x01 \x01(\x0b\x32 .NKikimrTxUserProxy.TTransaction\x12\x12\n\nProxyFlags\x18\x02 \x01(\x04\x12\x19\n\x11\x45xecTimeoutPeriod\x18\x03 \x01(\x04\x12\x11\n\tUserToken\x18\x04 \x01(\t\x12\x16\n\x0eStreamResponse\x18\x05 \x01(\x08\x12\x15\n\rCancelAfterMs\x18\x06 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x07 \x01(\t\x12\x13\n\x0bRequestType\x18\x08 \x01(\t\"\x84\x02\n\x0fTTxProxyTimings\x12\x19\n\x11WallClockAccepted\x18\n \x01(\x04\x12\x19\n\x11WallClockResolved\x18\x0b \x01(\x04\x12\x19\n\x11WallClockPrepared\x18\x0c \x01(\x04\x12\x18\n\x10WallClockPlanned\x18\r \x01(\x04\x12\x14\n\x0cWallClockNow\x18\x0e \x01(\x04\x12\x1a\n\x12\x45lapsedPrepareExec\x18\x0f \x01(\x04\x12\x17\n\x0f\x45lapsedExecExec\x18\x10 \x01(\x04\x12\x1e\n\x16\x45lapsedPrepareComplete\x18\x11 \x01(\x04\x12\x1b\n\x13\x45lapsedExecComplete\x18\x12 \x01(\x04\"\x99\x07\n\x1bTEvProposeTransactionStatus\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0c\n\x04TxId\x18\x02 \x01(\x06\x12\x0c\n\x04Step\x18\x03 \x01(\x06\x12\x39\n\nStatusCode\x18\x07 \x01(\x0e\x32%.NKikimrIssues.TStatusIds.EStatusCode\x12\'\n\x06Issues\x18\x08 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x1d\n\x15\x45xecutionEngineStatus\x18\n \x01(\r\x12%\n\x1d\x45xecutionEngineResponseStatus\x18\x0b \x01(\r\x12\x1f\n\x17\x45xecutionEngineResponse\x18\x0c \x01(\x0c\x12\x15\n\rMiniKQLErrors\x18\r \x01(\x0c\x12\x17\n\x0f\x44\x61taShardErrors\x18\x0e \x01(\x0c\x12\x1d\n\x15\x43omplainingDataShards\x18\x0f \x03(\x06\x12\x16\n\x0eUnresolvedKeys\x18\x10 \x03(\x0c\x12I\n\x15MiniKQLCompileResults\x18\x11 \x01(\x0b\x32*.NKikimrTxUserProxy.TMiniKQLCompileResults\x12\x41\n ExecutionEngineEvaluatedResponse\x18\x12 \x01(\x0b\x32\x17.NKikimrMiniKQL.TResult\x12,\n\x07TxStats\x18\x13 \x01(\x0b\x32\x1b.NKikimrQueryStats.TTxStats\x12\x34\n\x07Timings\x18\x14 \x01(\x0b\x32#.NKikimrTxUserProxy.TTxProxyTimings\x12\x18\n\x10HadFollowerReads\x18\x15 \x01(\x08\x12\x19\n\x11SchemeShardStatus\x18\x1e \x01(\r\x12\x1d\n\x15SchemeShardReportedId\x18\x1f \x01(\r\x12\x19\n\x11SchemeShardReason\x18  \x01(\x0c\x12\x1b\n\x13SchemeShardTabletId\x18! \x01(\x06\x12\x0e\n\x06PathId\x18\" \x01(\x04\x12\x16\n\x0ePathCreateTxId\x18# \x01(\x04\x12\x14\n\x0cPathDropTxId\x18$ \x01(\x04\x12\x19\n\x11\x44\x61taShardTabletId\x18( \x01(\x06\x12#\n\x1bSerializedReadTableResponse\x18\x32 \x01(\x0c\x12 \n\x18ReadTableResponseVersion\x18\x33 \x01(\r\"\x84\x01\n\x0bTEvNavigate\x12\x34\n\x0c\x44\x65scribePath\x18\x05 \x01(\x0b\x32\x1e.NKikimrSchemeOp.TDescribePath\x12\x11\n\tUserToken\x18\x06 \x01(\t\x12\x14\n\x0c\x44\x61tabaseName\x18\x07 \x01(\tJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xce\x01\n\x1cTEvNavigateStatus_Deprecated\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x14\n\x0cSchemePrefix\x18\n \x01(\x0c\x12\x12\n\nSchemePart\x18\x0b \x01(\x0c\x12\x19\n\x11SchemeShardStatus\x18\x1e \x01(\r\x12\x1d\n\x15SchemeShardReportedId\x18\x1f \x01(\r\x12:\n\x0fPathDescription\x18( \x01(\x0b\x32!.NKikimrSchemeOp.TPathDescription\"<\n\x12TEvInvalidateTable\x12\x15\n\rSchemeShardId\x18\x01 \x01(\x04\x12\x0f\n\x07TableId\x18\x02 \x01(\x04\"\xef\x02\n\x10TEvExportRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\x12\x11\n\tUserToken\x18\x02 \x01(\t\x12;\n\x0c\x43reateExport\x18\x03 \x01(\x0b\x32#.NKikimrExport.TCreateExportRequestH\x00\x12\x35\n\tGetExport\x18\x04 \x01(\x0b\x32 .NKikimrExport.TGetExportRequestH\x00\x12;\n\x0c\x43\x61ncelExport\x18\x05 \x01(\x0b\x32#.NKikimrExport.TCancelExportRequestH\x00\x12;\n\x0c\x46orgetExport\x18\x06 \x01(\x0b\x32#.NKikimrExport.TForgetExportRequestH\x00\x12\x39\n\x0bListExports\x18\x07 \x01(\x0b\x32\".NKikimrExport.TListExportsRequestH\x00\x42\t\n\x07Request\"\xf7\x02\n\x11TEvExportResponse\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x18\n\x10\x45rrorDescription\x18\x07 \x01(\t\x12<\n\x0c\x43reateExport\x18\x02 \x01(\x0b\x32$.NKikimrExport.TCreateExportResponseH\x00\x12\x36\n\tGetExport\x18\x03 \x01(\x0b\x32!.NKikimrExport.TGetExportResponseH\x00\x12<\n\x0c\x43\x61ncelExport\x18\x04 \x01(\x0b\x32$.NKikimrExport.TCancelExportResponseH\x00\x12<\n\x0c\x46orgetExport\x18\x05 \x01(\x0b\x32$.NKikimrExport.TForgetExportResponseH\x00\x12:\n\x0bListExports\x18\x06 \x01(\x0b\x32#.NKikimrExport.TListExportsResponseH\x00\x42\n\n\x08ResponseB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_proxy_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TRWTRANSACTION._serialized_start=282
  _TRWTRANSACTION._serialized_end=703
  _TRWTRANSACTION_TPREDICATE._serialized_start=480
  _TRWTRANSACTION_TPREDICATE._serialized_end=580
  _TRWTRANSACTION_TREAD._serialized_start=582
  _TRWTRANSACTION_TREAD._serialized_end=631
  _TRWTRANSACTION_TWRITE._serialized_start=633
  _TRWTRANSACTION_TWRITE._serialized_end=703
  _TREADTRANSACTION._serialized_start=705
  _TREADTRANSACTION._serialized_end=807
  _TREADTRANSACTION_TREAD._serialized_start=582
  _TREADTRANSACTION_TREAD._serialized_end=631
  _TKEYRANGE._serialized_start=810
  _TKEYRANGE._serialized_end=954
  _TREADTABLETRANSACTION._serialized_start=957
  _TREADTABLETRANSACTION._serialized_end=1242
  _TREADTABLETRANSACTION_EVERSION._serialized_start=1203
  _TREADTABLETRANSACTION_EVERSION._serialized_end=1242
  _TCREATEVOLATILESNAPSHOTTX._serialized_start=1245
  _TCREATEVOLATILESNAPSHOTTX._serialized_end=1480
  _TCREATEVOLATILESNAPSHOTTX_TTABLE._serialized_start=1404
  _TCREATEVOLATILESNAPSHOTTX_TTABLE._serialized_end=1480
  _TREFRESHVOLATILESNAPSHOTTX._serialized_start=1483
  _TREFRESHVOLATILESNAPSHOTTX._serialized_end=1731
  _TREFRESHVOLATILESNAPSHOTTX_TTABLE._serialized_start=1404
  _TREFRESHVOLATILESNAPSHOTTX_TTABLE._serialized_end=1480
  _TDISCARDVOLATILESNAPSHOTTX._serialized_start=1734
  _TDISCARDVOLATILESNAPSHOTTX._serialized_end=1982
  _TDISCARDVOLATILESNAPSHOTTX_TTABLE._serialized_start=1404
  _TDISCARDVOLATILESNAPSHOTTX_TTABLE._serialized_end=1480
  _TCOMMITWRITESTX._serialized_start=1985
  _TCOMMITWRITESTX._serialized_end=2159
  _TCOMMITWRITESTX_TTABLE._serialized_start=1404
  _TCOMMITWRITESTX_TTABLE._serialized_end=1480
  _TMINIKQLTRANSACTION._serialized_start=2162
  _TMINIKQLTRANSACTION._serialized_end=3027
  _TMINIKQLTRANSACTION_TMINIKQLPROGRAM._serialized_start=2691
  _TMINIKQLTRANSACTION_TMINIKQLPROGRAM._serialized_end=2760
  _TMINIKQLTRANSACTION_TMINIKQLPARAMS._serialized_start=2762
  _TMINIKQLTRANSACTION_TMINIKQLPARAMS._serialized_end=2845
  _TMINIKQLTRANSACTION_TLIMITS._serialized_start=2848
  _TMINIKQLTRANSACTION_TLIMITS._serialized_end=2983
  _TMINIKQLTRANSACTION_EMODE._serialized_start=2985
  _TMINIKQLTRANSACTION_EMODE._serialized_end=3027
  _TMINIKQLCOMPILERESULTS._serialized_start=3030
  _TMINIKQLCOMPILERESULTS._serialized_end=3212
  _TTRANSACTION._serialized_start=3215
  _TTRANSACTION._serialized_end=3830
  _TEVPROPOSETRANSACTION._serialized_start=3833
  _TEVPROPOSETRANSACTION._serialized_end=4067
  _TTXPROXYTIMINGS._serialized_start=4070
  _TTXPROXYTIMINGS._serialized_end=4330
  _TEVPROPOSETRANSACTIONSTATUS._serialized_start=4333
  _TEVPROPOSETRANSACTIONSTATUS._serialized_end=5254
  _TEVNAVIGATE._serialized_start=5257
  _TEVNAVIGATE._serialized_end=5389
  _TEVNAVIGATESTATUS_DEPRECATED._serialized_start=5392
  _TEVNAVIGATESTATUS_DEPRECATED._serialized_end=5598
  _TEVINVALIDATETABLE._serialized_start=5600
  _TEVINVALIDATETABLE._serialized_end=5660
  _TEVEXPORTREQUEST._serialized_start=5663
  _TEVEXPORTREQUEST._serialized_end=6030
  _TEVEXPORTRESPONSE._serialized_start=6033
  _TEVEXPORTRESPONSE._serialized_end=6408
# @@protoc_insertion_point(module_scope)
