# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18ydb/core/protos/tx.proto\x12\tNKikimrTx\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\x1a\x19google/protobuf/any.proto\"\xe7\x01\n\x11TProxyTransaction\x12@\n\x0b\x41\x66\x66\x65\x63tedSet\x18\x01 \x03(\x0b\x32+.NKikimrTx.TProxyTransaction.TAffectedEntry\x12\x11\n\tExecLevel\x18\x03 \x01(\r\x12\x0c\n\x04TxId\x18\x04 \x01(\x06\x12\x0f\n\x07MinStep\x18\x06 \x01(\x04\x12\x0f\n\x07MaxStep\x18\x07 \x01(\x04\x12\x1a\n\x12IgnoreLowDiskSpace\x18\x08 \x01(\x08\x1a\x31\n\x0eTAffectedEntry\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\r\n\x05\x46lags\x18\x02 \x01(\r\"a\n\x15TEvProposeTransaction\x12\x31\n\x0bTransaction\x18\x01 \x01(\x0b\x32\x1c.NKikimrTx.TProxyTransaction\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\"K\n\x1bTEvProposeTransactionStatus\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0e\n\x06StepId\x18\x02 \x01(\x06\x12\x0c\n\x04TxId\x18\t \x01(\x06\"+\n\x12TEvAcquireReadStep\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\"?\n\x18TEvAcquireReadStepResult\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\x0c\n\x04Step\x18\x02 \x01(\x06\"<\n\x14TEvSubscribeReadStep\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\">\n\x16TEvUnsubscribeReadStep\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\"t\n\x1aTEvSubscribeReadStepResult\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\x12\x17\n\x0fLastAcquireStep\x18\x03 \x01(\x06\x12\x17\n\x0fNextAcquireStep\x18\x04 \x01(\x06\"[\n\x1aTEvSubscribeReadStepUpdate\x12\x15\n\rCoordinatorID\x18\x01 \x01(\x06\x12\r\n\x05SeqNo\x18\x02 \x01(\x04\x12\x17\n\x0fNextAcquireStep\x18\x03 \x01(\x06\"]\n\x17TCoordinatorTransaction\x12\x13\n\x0b\x41\x66\x66\x65\x63tedSet\x18\x01 \x03(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x06\x12\x0c\n\x04\x42ody\x18\x03 \x01(\x0c\x12\x11\n\tModerator\x18\x05 \x01(\x04\"\xa4\x01\n\x1cTEvSubDomainConfigurationAck\x12?\n\x06Status\x18\x01 \x01(\x0e\x32/.NKikimrTx.TEvSubDomainConfigurationAck.EStatus\x12\x12\n\nOnTabletId\x18\x02 \x01(\x06\"/\n\x07\x45Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\x0b\n\x07\x41LREADY\x10\x01\x12\n\n\x06REJECT\x10\x02\"O\n\x12TEvCoordinatorSync\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x06\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\"\xc4\x01\n\x18TEvCoordinatorSyncResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06\x43ookie\x18\x02 \x01(\x06\x12\x14\n\x0c\x43ompleteStep\x18\x03 \x01(\x06\x12\x13\n\x0bLatestKnown\x18\x04 \x01(\x06\x12\x16\n\x0eSubjectiveTime\x18\x05 \x01(\x06\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\"\xde\x01\n\x12TEvCoordinatorStep\x12\x38\n\x0cTransactions\x18\x01 \x03(\x0b\x32\".NKikimrTx.TCoordinatorTransaction\x12\x0c\n\x04Step\x18\x02 \x01(\x06\x12\x10\n\x08PrevStep\x18\x03 \x01(\x06\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\x12#\n\x1b\x41\x63tiveCoordinatorGeneration\x18\x0b \x01(\x04\x12\x1e\n\x16TotalTxAffectedEntries\x18\x14 \x01(\x04\"\"\n\rTEvTxAllocate\x12\x11\n\tRangeSize\x18\x01 \x01(\x06\"\x9a\x01\n\x13TEvTxAllocateResult\x12\x36\n\x06Status\x18\x01 \x01(\x0e\x32&.NKikimrTx.TEvTxAllocateResult.EStatus\x12\x12\n\nRangeBegin\x18\x02 \x01(\x06\x12\x10\n\x08RangeEnd\x18\x03 \x01(\x06\"%\n\x07\x45Status\x12\x0b\n\x07SUCCESS\x10\x00\x12\r\n\tIMPOSIBLE\x10\x01\"\xd1\x02\n\x18TEvCoordinatorStepResult\x12;\n\x06Status\x18\x01 \x01(\x0e\x32+.NKikimrTx.TEvCoordinatorStepResult.EStatus\x12\x0c\n\x04Step\x18\x02 \x01(\x06\x12\x14\n\x0c\x43ompleteStep\x18\x03 \x01(\x06\x12\x13\n\x0bLatestKnown\x18\x04 \x01(\x06\x12\x16\n\x0eSubjectiveTime\x18\x05 \x01(\x06\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x15\n\rCoordinatorID\x18\n \x01(\x06\"|\n\x07\x45Status\x12\x17\n\x13UNKNOWN_COORDINATOR\x10\x00\x12\x13\n\x0f\x41\x43\x43\x45PTED_DOMAIN\x10\x01\x12\x14\n\x10\x41\x43\x43\x45PTED_FOREIGN\x10\x02\x12\x15\n\x11\x44ISCARDED_TOOLATE\x10\x03\x12\x16\n\x12\x44ISCARDED_TOOEARLY\x10\x04\">\n\x0eTEvPlanStepAck\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x0c\n\x04Step\x18\x02 \x01(\x06\x12\x0c\n\x04TxId\x18\x03 \x03(\x06\"5\n\x13TEvPlanStepAccepted\x12\x10\n\x08TabletId\x18\x01 \x01(\x06\x12\x0c\n\x04Step\x18\x02 \x01(\x06\"\x81\x01\n\x14TMediatorTransaction\x12\x0c\n\x04TxId\x18\x01 \x01(\x06\x12\x13\n\x0b\x43oordinator\x18\x02 \x01(\x06\x12\x11\n\tModerator\x18\x03 \x01(\x06\x12\x0c\n\x04\x42ody\x18\x04 \x01(\x0c\x12%\n\x05\x41\x63kTo\x18\n \x01(\x0b\x32\x16.NActorsProto.TActorId\"\x80\x01\n\x13TEvMediatorPlanStep\x12\x35\n\x0cTransactions\x18\x01 \x03(\x0b\x32\x1f.NKikimrTx.TMediatorTransaction\x12\x0c\n\x04Step\x18\x02 \x01(\x04\x12\x12\n\nMediatorID\x18\t \x01(\x06\x12\x10\n\x08TabletID\x18\n \x01(\x06\"g\n\x19TEvTransactionBatchResult\x12*\n\x06Status\x18\x01 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0c\n\x04Step\x18\x02 \x01(\x04\x12\x10\n\x08TabletID\x18\n \x01(\x04\"3\n\x0fTEvMediatorDone\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x12\n\nMediatorID\x18\n \x01(\x04\"\x17\n\x15TEvMediatorDoneResult\"-\n\x0bTBalanceHop\x12\r\n\x05Shard\x18\x01 \x01(\x04\x12\x0f\n\x07Sibling\x18\x02 \x03(\x04\"4\n\rTBalanceTrack\x12#\n\x03Hop\x18\x01 \x03(\x0b\x32\x16.NKikimrTx.TBalanceHop\"<\n\x11TBalanceTrackList\x12\'\n\x05Track\x18\x01 \x03(\x0b\x32\x18.NKikimrTx.TBalanceTrack\"\xb3\x01\n\x0cTReadSetData\x12\x33\n\x08\x44\x65\x63ision\x18\x01 \x01(\x0e\x32!.NKikimrTx.TReadSetData.EDecision\x12\"\n\x04\x44\x61ta\x18\x02 \x01(\x0b\x32\x14.google.protobuf.Any\"J\n\tEDecision\x12\x14\n\x10\x44\x45\x43ISION_UNKNOWN\x10\x00\x12\x13\n\x0f\x44\x45\x43ISION_COMMIT\x10\x01\x12\x12\n\x0e\x44\x45\x43ISION_ABORT\x10\x02\"\x97\x02\n\nTEvReadSet\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x14\n\x0cTabletSource\x18\x03 \x01(\x04\x12\x12\n\nTabletDest\x18\x04 \x01(\x04\x12\x16\n\x0eTabletProducer\x18\x05 \x01(\x04\x12\x0f\n\x07ReadSet\x18\x06 \x01(\x0c\x12\x36\n\x10\x42\x61lanceTrackList\x18\x07 \x01(\x0b\x32\x1c.NKikimrTx.TBalanceTrackList\x12\r\n\x05Seqno\x18\x08 \x01(\x04\x12\r\n\x05\x46lags\x18\t \x01(\r\"D\n\x06\x45\x46lags\x12\x0f\n\x0b\x46LAG_NO_ACK\x10\x01\x12\x10\n\x0c\x46LAG_NO_DATA\x10\x02\x12\x17\n\x13\x46LAG_EXPECT_READSET\x10\x04\"\x8b\x01\n\rTEvReadSetAck\x12\x0c\n\x04Step\x18\x01 \x01(\x04\x12\x0c\n\x04TxId\x18\x02 \x01(\x04\x12\x14\n\x0cTabletSource\x18\x03 \x01(\x04\x12\x12\n\nTabletDest\x18\x04 \x01(\x04\x12\x16\n\x0eTabletConsumer\x18\x05 \x01(\x04\x12\r\n\x05\x46lags\x18\x06 \x01(\r\x12\r\n\x05Seqno\x18\x07 \x01(\x04\"Q\n\tTKeyRange\x12\x0c\n\x04\x46rom\x18\x01 \x01(\x0c\x12\n\n\x02To\x18\x02 \x01(\x0c\x12\x15\n\rFromInclusive\x18\x03 \x01(\x08\x12\x13\n\x0bToInclusive\x18\x04 \x01(\x08\"b\n\x19TEvStreamClearanceRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0f\n\x07ShardId\x18\x02 \x01(\x04\x12&\n\x08KeyRange\x18\x03 \x01(\x0b\x32\x14.NKikimrTx.TKeyRange\";\n\x1aTEvStreamClearanceResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0f\n\x07\x43leared\x18\x02 \x01(\x08\")\n\x19TEvStreamClearancePending\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"6\n\x15TEvStreamQuotaRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0f\n\x07ShardId\x18\x02 \x01(\x04\"l\n\x16TEvStreamQuotaResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x18\n\x10MessageSizeLimit\x18\x02 \x01(\x04\x12\x18\n\x10ReservedMessages\x18\x03 \x01(\r\x12\x10\n\x08RowLimit\x18\x04 \x01(\x04\"6\n\x15TEvStreamQuotaRelease\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x0f\n\x07ShardId\x18\x02 \x01(\x04\"\x1f\n\x0fTEvStreamIsDead\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\'\n\x17TEvInterruptTransaction\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\"\x12\n\x10TEvStreamDataAckB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPROXYTRANSACTION._serialized_start=135
  _TPROXYTRANSACTION._serialized_end=366
  _TPROXYTRANSACTION_TAFFECTEDENTRY._serialized_start=317
  _TPROXYTRANSACTION_TAFFECTEDENTRY._serialized_end=366
  _TEVPROPOSETRANSACTION._serialized_start=368
  _TEVPROPOSETRANSACTION._serialized_end=465
  _TEVPROPOSETRANSACTIONSTATUS._serialized_start=467
  _TEVPROPOSETRANSACTIONSTATUS._serialized_end=542
  _TEVACQUIREREADSTEP._serialized_start=544
  _TEVACQUIREREADSTEP._serialized_end=587
  _TEVACQUIREREADSTEPRESULT._serialized_start=589
  _TEVACQUIREREADSTEPRESULT._serialized_end=652
  _TEVSUBSCRIBEREADSTEP._serialized_start=654
  _TEVSUBSCRIBEREADSTEP._serialized_end=714
  _TEVUNSUBSCRIBEREADSTEP._serialized_start=716
  _TEVUNSUBSCRIBEREADSTEP._serialized_end=778
  _TEVSUBSCRIBEREADSTEPRESULT._serialized_start=780
  _TEVSUBSCRIBEREADSTEPRESULT._serialized_end=896
  _TEVSUBSCRIBEREADSTEPUPDATE._serialized_start=898
  _TEVSUBSCRIBEREADSTEPUPDATE._serialized_end=989
  _TCOORDINATORTRANSACTION._serialized_start=991
  _TCOORDINATORTRANSACTION._serialized_end=1084
  _TEVSUBDOMAINCONFIGURATIONACK._serialized_start=1087
  _TEVSUBDOMAINCONFIGURATIONACK._serialized_end=1251
  _TEVSUBDOMAINCONFIGURATIONACK_ESTATUS._serialized_start=1204
  _TEVSUBDOMAINCONFIGURATIONACK_ESTATUS._serialized_end=1251
  _TEVCOORDINATORSYNC._serialized_start=1253
  _TEVCOORDINATORSYNC._serialized_end=1332
  _TEVCOORDINATORSYNCRESULT._serialized_start=1335
  _TEVCOORDINATORSYNCRESULT._serialized_end=1531
  _TEVCOORDINATORSTEP._serialized_start=1534
  _TEVCOORDINATORSTEP._serialized_end=1756
  _TEVTXALLOCATE._serialized_start=1758
  _TEVTXALLOCATE._serialized_end=1792
  _TEVTXALLOCATERESULT._serialized_start=1795
  _TEVTXALLOCATERESULT._serialized_end=1949
  _TEVTXALLOCATERESULT_ESTATUS._serialized_start=1912
  _TEVTXALLOCATERESULT_ESTATUS._serialized_end=1949
  _TEVCOORDINATORSTEPRESULT._serialized_start=1952
  _TEVCOORDINATORSTEPRESULT._serialized_end=2289
  _TEVCOORDINATORSTEPRESULT_ESTATUS._serialized_start=2165
  _TEVCOORDINATORSTEPRESULT_ESTATUS._serialized_end=2289
  _TEVPLANSTEPACK._serialized_start=2291
  _TEVPLANSTEPACK._serialized_end=2353
  _TEVPLANSTEPACCEPTED._serialized_start=2355
  _TEVPLANSTEPACCEPTED._serialized_end=2408
  _TMEDIATORTRANSACTION._serialized_start=2411
  _TMEDIATORTRANSACTION._serialized_end=2540
  _TEVMEDIATORPLANSTEP._serialized_start=2543
  _TEVMEDIATORPLANSTEP._serialized_end=2671
  _TEVTRANSACTIONBATCHRESULT._serialized_start=2673
  _TEVTRANSACTIONBATCHRESULT._serialized_end=2776
  _TEVMEDIATORDONE._serialized_start=2778
  _TEVMEDIATORDONE._serialized_end=2829
  _TEVMEDIATORDONERESULT._serialized_start=2831
  _TEVMEDIATORDONERESULT._serialized_end=2854
  _TBALANCEHOP._serialized_start=2856
  _TBALANCEHOP._serialized_end=2901
  _TBALANCETRACK._serialized_start=2903
  _TBALANCETRACK._serialized_end=2955
  _TBALANCETRACKLIST._serialized_start=2957
  _TBALANCETRACKLIST._serialized_end=3017
  _TREADSETDATA._serialized_start=3020
  _TREADSETDATA._serialized_end=3199
  _TREADSETDATA_EDECISION._serialized_start=3125
  _TREADSETDATA_EDECISION._serialized_end=3199
  _TEVREADSET._serialized_start=3202
  _TEVREADSET._serialized_end=3481
  _TEVREADSET_EFLAGS._serialized_start=3413
  _TEVREADSET_EFLAGS._serialized_end=3481
  _TEVREADSETACK._serialized_start=3484
  _TEVREADSETACK._serialized_end=3623
  _TKEYRANGE._serialized_start=3625
  _TKEYRANGE._serialized_end=3706
  _TEVSTREAMCLEARANCEREQUEST._serialized_start=3708
  _TEVSTREAMCLEARANCEREQUEST._serialized_end=3806
  _TEVSTREAMCLEARANCERESPONSE._serialized_start=3808
  _TEVSTREAMCLEARANCERESPONSE._serialized_end=3867
  _TEVSTREAMCLEARANCEPENDING._serialized_start=3869
  _TEVSTREAMCLEARANCEPENDING._serialized_end=3910
  _TEVSTREAMQUOTAREQUEST._serialized_start=3912
  _TEVSTREAMQUOTAREQUEST._serialized_end=3966
  _TEVSTREAMQUOTARESPONSE._serialized_start=3968
  _TEVSTREAMQUOTARESPONSE._serialized_end=4076
  _TEVSTREAMQUOTARELEASE._serialized_start=4078
  _TEVSTREAMQUOTARELEASE._serialized_end=4132
  _TEVSTREAMISDEAD._serialized_start=4134
  _TEVSTREAMISDEAD._serialized_end=4165
  _TEVINTERRUPTTRANSACTION._serialized_start=4167
  _TEVINTERRUPTTRANSACTION._serialized_end=4206
  _TEVSTREAMDATAACK._serialized_start=4208
  _TEVSTREAMDATAACK._serialized_end=4226
# @@protoc_insertion_point(module_scope)
