# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ydb.core.protos import msgbus_kv_pb2 as ydb_dot_core_dot_protos_dot_msgbus__kv__pb2
from ydb.core.protos import msgbus_pb2 as ydb_dot_core_dot_protos_dot_msgbus__pb2
from ydb.core.protos import msgbus_pq_pb2 as ydb_dot_core_dot_protos_dot_msgbus__pq__pb2


class TGRpcServerStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.Request = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/Request',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.SchemeOperation = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SchemeOperation',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperation.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.SchemeOperationStatus = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SchemeOperationStatus',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperationStatus.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.SchemeDescribe = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SchemeDescribe',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeDescribe.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.WhoAmI = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/WhoAmI',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TWhoAmI.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.LoginRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/LoginRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLoginRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.ChooseProxy = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/ChooseProxy',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TChooseProxyRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.PersQueueRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/PersQueueRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pq__pb2.TPersQueueRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.SchemeInitRoot = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SchemeInitRoot',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeInitRoot.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.BSAdm = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/BSAdm',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBSAdm.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.ResolveNode = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/ResolveNode',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResolveNodeRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.FillNode = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/FillNode',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TFillNodeRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.DrainNode = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DrainNode',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TDrainNodeRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.BlobStorageConfig = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/BlobStorageConfig',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBlobStorageConfigRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.HiveCreateTablet = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/HiveCreateTablet',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.THiveCreateTablet.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.LocalEnumerateTablets = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/LocalEnumerateTablets',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalEnumerateTablets.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.KeyValue = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/KeyValue',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__kv__pb2.TKeyValueRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.TestShardControl = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/TestShardControl',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTestShardControlRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.RegisterNode = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/RegisterNode',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationResponse.FromString,
                )
        self.CmsRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/CmsRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsResponse.FromString,
                )
        self.SqsRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/SqsRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsResponse.FromString,
                )
        self.ConsoleRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/ConsoleRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleResponse.FromString,
                )
        self.LocalMKQL = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/LocalMKQL',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalMKQL.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.LocalSchemeTx = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/LocalSchemeTx',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalSchemeTx.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.TabletKillRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/TabletKillRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletKillRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.InterconnectDebug = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/InterconnectDebug',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TInterconnectDebug.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.TabletStateRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/TabletStateRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletStateRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.BlobStorageLoadRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/BlobStorageLoadRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsTestLoadRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.BlobStorageGetRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/BlobStorageGetRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsGetRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.DataShardLoadRequest = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DataShardLoadRequest',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TDsTestLoadRequest.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
                )
        self.DbSchema = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DbSchema',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                )
        self.DbOperation = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DbOperation',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                )
        self.DbBatch = channel.unary_unary(
                '/NKikimrClient.TGRpcServer/DbBatch',
                request_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
                response_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                )


class TGRpcServerServicer(object):
    """Missing associated documentation comment in .proto file."""

    def Request(self, request, context):
        """TODO
        * Rename Request to MiniKQLRequest ???

        ///////////////////////////////////////////////////////////////////////////////////////////////
        KIKIMR CLIENT INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////

        MiniKQL request (DML)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchemeOperation(self, request, context):
        """DML transactions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchemeOperationStatus(self, request, context):
        """status polling for scheme transactions
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchemeDescribe(self, request, context):
        """describe
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def WhoAmI(self, request, context):
        """whoami
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LoginRequest(self, request, context):
        """login
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ChooseProxy(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        CHOOSE PROXY INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def PersQueueRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        PERSISTENT QUEUE CLIENT INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////

        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SchemeInitRoot(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        ADMIN INTERNAL INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BSAdm(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResolveNode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FillNode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DrainNode(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BlobStorageConfig(self, request, context):
        """Blob storage configuration manipulation/query interface
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def HiveCreateTablet(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        KV-TABLET INTERNAL INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LocalEnumerateTablets(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def KeyValue(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TestShardControl(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def RegisterNode(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        DYNAMIC NODES INTERNAL INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CmsRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        CMS INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SqsRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        SQS INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ConsoleRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        CONSOLE INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LocalMKQL(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        INTROSPECTION
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LocalSchemeTx(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TabletKillRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def InterconnectDebug(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def TabletStateRequest(self, request, context):
        """[DEPRECATED]
        rpc Navigate(TSchemeNavigate) returns (TResponse);

        ///////////////////////////////////////////////////////////////////////////////////////////////
        MONITORING
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BlobStorageLoadRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        BLOBSTORAGE LOAD TEST
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def BlobStorageGetRequest(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DataShardLoadRequest(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        DATASHARD LOAD TEST
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DbSchema(self, request, context):
        """///////////////////////////////////////////////////////////////////////////////////////////////
        HTTP INTERFACE
        ///////////////////////////////////////////////////////////////////////////////////////////////
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DbOperation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DbBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TGRpcServerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'Request': grpc.unary_unary_rpc_method_handler(
                    servicer.Request,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'SchemeOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.SchemeOperation,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperation.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'SchemeOperationStatus': grpc.unary_unary_rpc_method_handler(
                    servicer.SchemeOperationStatus,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperationStatus.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'SchemeDescribe': grpc.unary_unary_rpc_method_handler(
                    servicer.SchemeDescribe,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeDescribe.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'WhoAmI': grpc.unary_unary_rpc_method_handler(
                    servicer.WhoAmI,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TWhoAmI.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'LoginRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.LoginRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLoginRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'ChooseProxy': grpc.unary_unary_rpc_method_handler(
                    servicer.ChooseProxy,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TChooseProxyRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'PersQueueRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.PersQueueRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pq__pb2.TPersQueueRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'SchemeInitRoot': grpc.unary_unary_rpc_method_handler(
                    servicer.SchemeInitRoot,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeInitRoot.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'BSAdm': grpc.unary_unary_rpc_method_handler(
                    servicer.BSAdm,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBSAdm.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'ResolveNode': grpc.unary_unary_rpc_method_handler(
                    servicer.ResolveNode,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResolveNodeRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'FillNode': grpc.unary_unary_rpc_method_handler(
                    servicer.FillNode,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TFillNodeRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'DrainNode': grpc.unary_unary_rpc_method_handler(
                    servicer.DrainNode,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TDrainNodeRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'BlobStorageConfig': grpc.unary_unary_rpc_method_handler(
                    servicer.BlobStorageConfig,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBlobStorageConfigRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'HiveCreateTablet': grpc.unary_unary_rpc_method_handler(
                    servicer.HiveCreateTablet,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.THiveCreateTablet.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'LocalEnumerateTablets': grpc.unary_unary_rpc_method_handler(
                    servicer.LocalEnumerateTablets,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalEnumerateTablets.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'KeyValue': grpc.unary_unary_rpc_method_handler(
                    servicer.KeyValue,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__kv__pb2.TKeyValueRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'TestShardControl': grpc.unary_unary_rpc_method_handler(
                    servicer.TestShardControl,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTestShardControlRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'RegisterNode': grpc.unary_unary_rpc_method_handler(
                    servicer.RegisterNode,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationResponse.SerializeToString,
            ),
            'CmsRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.CmsRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsResponse.SerializeToString,
            ),
            'SqsRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.SqsRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsResponse.SerializeToString,
            ),
            'ConsoleRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.ConsoleRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleResponse.SerializeToString,
            ),
            'LocalMKQL': grpc.unary_unary_rpc_method_handler(
                    servicer.LocalMKQL,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalMKQL.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'LocalSchemeTx': grpc.unary_unary_rpc_method_handler(
                    servicer.LocalSchemeTx,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalSchemeTx.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'TabletKillRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.TabletKillRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletKillRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'InterconnectDebug': grpc.unary_unary_rpc_method_handler(
                    servicer.InterconnectDebug,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TInterconnectDebug.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'TabletStateRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.TabletStateRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletStateRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'BlobStorageLoadRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.BlobStorageLoadRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsTestLoadRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'BlobStorageGetRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.BlobStorageGetRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsGetRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'DataShardLoadRequest': grpc.unary_unary_rpc_method_handler(
                    servicer.DataShardLoadRequest,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TDsTestLoadRequest.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.SerializeToString,
            ),
            'DbSchema': grpc.unary_unary_rpc_method_handler(
                    servicer.DbSchema,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ),
            'DbOperation': grpc.unary_unary_rpc_method_handler(
                    servicer.DbOperation,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ),
            'DbBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.DbBatch,
                    request_deserializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
                    response_serializer=ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'NKikimrClient.TGRpcServer', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TGRpcServer(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def Request(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/Request',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchemeOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SchemeOperation',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperation.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchemeOperationStatus(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SchemeOperationStatus',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeOperationStatus.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchemeDescribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SchemeDescribe',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeDescribe.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def WhoAmI(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/WhoAmI',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TWhoAmI.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LoginRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/LoginRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TLoginRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ChooseProxy(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/ChooseProxy',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TChooseProxyRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def PersQueueRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/PersQueueRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pq__pb2.TPersQueueRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SchemeInitRoot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SchemeInitRoot',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSchemeInitRoot.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BSAdm(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/BSAdm',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TBSAdm.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResolveNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/ResolveNode',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResolveNodeRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def FillNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/FillNode',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TFillNodeRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DrainNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DrainNode',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TDrainNodeRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BlobStorageConfig(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/BlobStorageConfig',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TBlobStorageConfigRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def HiveCreateTablet(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/HiveCreateTablet',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.THiveCreateTablet.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LocalEnumerateTablets(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/LocalEnumerateTablets',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalEnumerateTablets.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def KeyValue(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/KeyValue',
            ydb_dot_core_dot_protos_dot_msgbus__kv__pb2.TKeyValueRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TestShardControl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/TestShardControl',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TTestShardControlRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def RegisterNode(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/RegisterNode',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TNodeRegistrationResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CmsRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/CmsRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TCmsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SqsRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/SqsRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TSqsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ConsoleRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/ConsoleRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TConsoleResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LocalMKQL(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/LocalMKQL',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalMKQL.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def LocalSchemeTx(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/LocalSchemeTx',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TLocalSchemeTx.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TabletKillRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/TabletKillRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletKillRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def InterconnectDebug(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/InterconnectDebug',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TInterconnectDebug.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def TabletStateRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/TabletStateRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TTabletStateRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BlobStorageLoadRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/BlobStorageLoadRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsTestLoadRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def BlobStorageGetRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/BlobStorageGetRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TBsGetRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DataShardLoadRequest(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DataShardLoadRequest',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TDsTestLoadRequest.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DbSchema(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DbSchema',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DbOperation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DbOperation',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DbBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/NKikimrClient.TGRpcServer/DbBatch',
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.SerializeToString,
            ydb_dot_core_dot_protos_dot_msgbus__pb2.TJSON.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)
