# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/counters.proto\x12\x07NKikimr\x1a google/protobuf/descriptor.proto\"%\n\x06TRange\x12\r\n\x05Value\x18\x01 \x01(\x04\x12\x0c\n\x04Name\x18\x02 \x01(\t\"b\n\x0fTCounterOptions\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x1f\n\x06Ranges\x18\x02 \x03(\x0b\x32\x0f.NKikimr.TRange\x12\x10\n\x08Integral\x18\x03 \x01(\x08\x12\x0e\n\x06SVName\x18\x04 \x01(\t\"\x1e\n\x0eTTxTypeOptions\x12\x0c\n\x04Name\x18\x01 \x01(\t\"\xb7\x02\n\x16TLabeledCounterOptions\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12@\n\x08\x41ggrFunc\x18\x02 \x01(\x0e\x32..NKikimr.TLabeledCounterOptions.EAggregateFunc\x12\x45\n\x04Type\x18\x03 \x01(\x0e\x32,.NKikimr.TLabeledCounterOptions.ECounterType:\tCT_SIMPLE\x12\x10\n\x06SVName\x18\x04 \x01(\t:\x00\";\n\x0c\x45\x43ounterType\x12\r\n\tCT_SIMPLE\x10\x01\x12\x0e\n\nCT_TIMELAG\x10\x02\x12\x0c\n\x08\x43T_DERIV\x10\x03\"7\n\x0e\x45\x41ggregateFunc\x12\x0b\n\x07\x45\x41\x46_MAX\x10\x01\x12\x0b\n\x07\x45\x41\x46_MIN\x10\x02\x12\x0b\n\x07\x45\x41\x46_SUM\x10\x03\"1\n TLabeledCounterGroupNamesOptions\x12\r\n\x05Names\x18\x01 \x03(\t*5\n\x15\x45TxTypeSimpleCounters\x12\x1c\n\x18\x43OUNTER_TT_SIMPLE_IGNORE\x10\x00*\x82\x06\n\x19\x45TxTypeCumulativeCounters\x12 \n\x1c\x43OUNTER_TT_CULUMATIVE_IGNORE\x10\x00\x12)\n\x14\x43OUNTER_TT_POSTPONED\x10\x01\x1a\x0f\x82\xd6\x1b\x0b\n\tPostponed\x12.\n\x17\x43OUNTER_TT_RO_COMPLETED\x10\x02\x1a\x11\x82\xd6\x1b\r\n\x0bRoCompleted\x12.\n\x17\x43OUNTER_TT_RW_COMPLETED\x10\x03\x1a\x11\x82\xd6\x1b\r\n\x0bRwCompleted\x12#\n\x11\x43OUNTER_TT_WRITES\x10\x04\x1a\x0c\x82\xd6\x1b\x08\n\x06Writes\x12\x30\n\x18\x43OUNTER_TT_BYTES_WRITTEN\x10\x05\x1a\x12\x82\xd6\x1b\x0e\n\x0cWrittenBytes\x12*\n\x15\x43OUNTER_TT_BYTES_READ\x10\x06\x1a\x0f\x82\xd6\x1b\x0b\n\tReadBytes\x12\x34\n\x1a\x43OUNTER_TT_EXECUTE_CPUTIME\x10\x07\x1a\x14\x82\xd6\x1b\x10\n\x0e\x45xecuteCPUTime\x12<\n\x1e\x43OUNTER_TT_BOOKKEEPING_CPUTIME\x10\x08\x1a\x18\x82\xd6\x1b\x14\n\x12\x42ookkeepingCPUTime\x12\x36\n\x1b\x43OUNTER_TT_COMMITED_CPUTIME\x10\t\x1a\x15\x82\xd6\x1b\x11\n\x0f\x43ommitedCPUTime\x12\x32\n\x19\x43OUNTER_TT_TOUCHED_BLOCKS\x10\n\x1a\x13\x82\xd6\x1b\x0f\n\rTouchedBlocks\x12\x30\n\x18\x43OUNTER_TT_LOADED_BLOCKS\x10\x0b\x1a\x12\x82\xd6\x1b\x0e\n\x0cLoadedBlocks\x12+\n\x15\x43OUNTER_TT_TERMINATED\x10\x0c\x1a\x10\x82\xd6\x1b\x0c\n\nTerminated\x12\x39\n\x1d\x43OUNTER_TT_REDO_WRITTEN_BYTES\x10\r\x1a\x16\x82\xd6\x1b\x12\n\x10RedoWrittenBytes\x12;\n\x1e\x43OUNTER_TT_ANNEX_WRITTEN_BYTES\x10\x0e\x1a\x17\x82\xd6\x1b\x13\n\x11\x41nnexWrittenBytes*\x9b\x03\n\x19\x45TxTypePercentileCounters\x12 \n\x1c\x43OUNTER_TT_PERCENTILE_IGNORE\x10\x00\x1a\xdb\x02\x92\xd6\x1b\xd6\x02\x12\x11\x08\xf4\x03\x12\x0c(1) < 500 us\x12\x11\x08\xe8\x07\x12\x0c(2) 0.5-1 ms\x12\x0f\x08\xd0\x0f\x12\n(3) 1-2 ms\x12\x0f\x08\xa0\x1f\x12\n(4) 2-4 ms\x12\x0f\x08\xc0>\x12\n(5) 4-8 ms\x12\x10\x08\x80}\x12\x0b(6) 8-16 ms\x12\x12\x08\x80\xfa\x01\x12\x0c(7) 16-32 ms\x12\x12\x08\x80\xf4\x03\x12\x0c(8) 32-64 ms\x12\x13\x08\x80\xe8\x07\x12\r(9) 64-128 ms\x12\x15\x08\x80\xd0\x0f\x12\x0f(10) 128-256 ms\x12\x15\x08\x80\xa0\x1f\x12\x0f(11) 256-512 ms\x12\x16\x08\x80\xc0>\x12\x10(12) 512-1024 ms\x12\x17\x08\x80\x89z\x12\x11(13) 1024-2000 ms\x12\x11\x08\x80\x92\xf4\x01\x12\n(14) 2-4 s\x12\x11\x08\x80\xa4\xe8\x03\x12\n(15) 4-8 s\x12\x12\x08\x80\xc8\xd0\x07\x12\x0b(16) 8-16 s\x12\x13\x08\x80\x90\xa1\x0f\x12\x0c(17) 16-32 s:R\n\x0b\x43ounterOpts\x12!.google.protobuf.EnumValueOptions\x18\xe0\xba\x03 \x01(\x0b\x32\x18.NKikimr.TCounterOptions:P\n\nTxTypeOpts\x12!.google.protobuf.EnumValueOptions\x18\xe1\xba\x03 \x01(\x0b\x32\x17.NKikimr.TTxTypeOptions:`\n\x12LabeledCounterOpts\x12!.google.protobuf.EnumValueOptions\x18\xe4\xba\x03 \x01(\x0b\x32\x1f.NKikimr.TLabeledCounterOptions:S\n\x11GlobalCounterOpts\x12\x1c.google.protobuf.EnumOptions\x18\xe2\xba\x03 \x01(\x0b\x32\x18.NKikimr.TCounterOptions:g\n\x14GlobalGroupNamesOpts\x12\x1c.google.protobuf.EnumOptions\x18\xe5\xba\x03 \x01(\x0b\x32).NKikimr.TLabeledCounterGroupNamesOptions:6\n\x0eTabletTypeName\x12\x1c.google.protobuf.FileOptions\x18\xe3\xba\x03 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(CounterOpts)
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(TxTypeOpts)
  google_dot_protobuf_dot_descriptor__pb2.EnumValueOptions.RegisterExtension(LabeledCounterOpts)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(GlobalCounterOpts)
  google_dot_protobuf_dot_descriptor__pb2.EnumOptions.RegisterExtension(GlobalGroupNamesOpts)
  google_dot_protobuf_dot_descriptor__pb2.FileOptions.RegisterExtension(TabletTypeName)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_POSTPONED"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_POSTPONED"]._serialized_options = b'\202\326\033\013\n\tPostponed'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_RO_COMPLETED"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_RO_COMPLETED"]._serialized_options = b'\202\326\033\r\n\013RoCompleted'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_RW_COMPLETED"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_RW_COMPLETED"]._serialized_options = b'\202\326\033\r\n\013RwCompleted'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_WRITES"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_WRITES"]._serialized_options = b'\202\326\033\010\n\006Writes'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BYTES_WRITTEN"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BYTES_WRITTEN"]._serialized_options = b'\202\326\033\016\n\014WrittenBytes'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BYTES_READ"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BYTES_READ"]._serialized_options = b'\202\326\033\013\n\tReadBytes'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_EXECUTE_CPUTIME"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_EXECUTE_CPUTIME"]._serialized_options = b'\202\326\033\020\n\016ExecuteCPUTime'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BOOKKEEPING_CPUTIME"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_BOOKKEEPING_CPUTIME"]._serialized_options = b'\202\326\033\024\n\022BookkeepingCPUTime'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_COMMITED_CPUTIME"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_COMMITED_CPUTIME"]._serialized_options = b'\202\326\033\021\n\017CommitedCPUTime'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_TOUCHED_BLOCKS"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_TOUCHED_BLOCKS"]._serialized_options = b'\202\326\033\017\n\rTouchedBlocks'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_LOADED_BLOCKS"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_LOADED_BLOCKS"]._serialized_options = b'\202\326\033\016\n\014LoadedBlocks'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_TERMINATED"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_TERMINATED"]._serialized_options = b'\202\326\033\014\n\nTerminated'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_REDO_WRITTEN_BYTES"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_REDO_WRITTEN_BYTES"]._serialized_options = b'\202\326\033\022\n\020RedoWrittenBytes'
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_ANNEX_WRITTEN_BYTES"]._options = None
  _ETXTYPECUMULATIVECOUNTERS.values_by_name["COUNTER_TT_ANNEX_WRITTEN_BYTES"]._serialized_options = b'\202\326\033\023\n\021AnnexWrittenBytes'
  _ETXTYPEPERCENTILECOUNTERS._options = None
  _ETXTYPEPERCENTILECOUNTERS._serialized_options = b'\222\326\033\326\002\022\021\010\364\003\022\014(1) < 500 us\022\021\010\350\007\022\014(2) 0.5-1 ms\022\017\010\320\017\022\n(3) 1-2 ms\022\017\010\240\037\022\n(4) 2-4 ms\022\017\010\300>\022\n(5) 4-8 ms\022\020\010\200}\022\013(6) 8-16 ms\022\022\010\200\372\001\022\014(7) 16-32 ms\022\022\010\200\364\003\022\014(8) 32-64 ms\022\023\010\200\350\007\022\r(9) 64-128 ms\022\025\010\200\320\017\022\017(10) 128-256 ms\022\025\010\200\240\037\022\017(11) 256-512 ms\022\026\010\200\300>\022\020(12) 512-1024 ms\022\027\010\200\211z\022\021(13) 1024-2000 ms\022\021\010\200\222\364\001\022\n(14) 2-4 s\022\021\010\200\244\350\003\022\n(15) 4-8 s\022\022\010\200\310\320\007\022\013(16) 8-16 s\022\023\010\200\220\241\017\022\014(17) 16-32 s'
  _ETXTYPESIMPLECOUNTERS._serialized_start=613
  _ETXTYPESIMPLECOUNTERS._serialized_end=666
  _ETXTYPECUMULATIVECOUNTERS._serialized_start=669
  _ETXTYPECUMULATIVECOUNTERS._serialized_end=1439
  _ETXTYPEPERCENTILECOUNTERS._serialized_start=1442
  _ETXTYPEPERCENTILECOUNTERS._serialized_end=1853
  _TRANGE._serialized_start=77
  _TRANGE._serialized_end=114
  _TCOUNTEROPTIONS._serialized_start=116
  _TCOUNTEROPTIONS._serialized_end=214
  _TTXTYPEOPTIONS._serialized_start=216
  _TTXTYPEOPTIONS._serialized_end=246
  _TLABELEDCOUNTEROPTIONS._serialized_start=249
  _TLABELEDCOUNTEROPTIONS._serialized_end=560
  _TLABELEDCOUNTEROPTIONS_ECOUNTERTYPE._serialized_start=444
  _TLABELEDCOUNTEROPTIONS_ECOUNTERTYPE._serialized_end=503
  _TLABELEDCOUNTEROPTIONS_EAGGREGATEFUNC._serialized_start=505
  _TLABELEDCOUNTEROPTIONS_EAGGREGATEFUNC._serialized_end=560
  _TLABELEDCOUNTERGROUPNAMESOPTIONS._serialized_start=562
  _TLABELEDCOUNTERGROUPNAMESOPTIONS._serialized_end=611
# @@protoc_insertion_point(module_scope)
