# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/export.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_export_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__export__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/export.proto\x12\rNKikimrExport\x1a&ydb/public/api/protos/ydb_export.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\"\xdf\x02\n\x07TExport\x12\n\n\x02Id\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x35\n\x08Progress\x18\x04 \x01(\x0e\x32#.Ydb.Export.ExportProgress.Progress\x12\x35\n\rItemsProgress\x18\x07 \x03(\x0b\x32\x1e.Ydb.Export.ExportItemProgress\x12<\n\x12\x45xportToYtSettings\x18\x05 \x01(\x0b\x32\x1e.Ydb.Export.ExportToYtSettingsH\x00\x12<\n\x12\x45xportToS3Settings\x18\x06 \x01(\x0b\x32\x1e.Ydb.Export.ExportToS3SettingsH\x00\x42\n\n\x08Settings\"\xd8\x01\n\x14TCreateExportRequest\x12\x38\n\x0fOperationParams\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12<\n\x12\x45xportToYtSettings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Export.ExportToYtSettingsH\x00\x12<\n\x12\x45xportToS3Settings\x18\x03 \x01(\x0b\x32\x1e.Ydb.Export.ExportToS3SettingsH\x00\x42\n\n\x08Settings\"\x83\x01\n\x16TEvCreateExportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x0f\n\x07UserSID\x18\x04 \x01(\t\x12\x34\n\x07Request\x18\x03 \x01(\x0b\x32#.NKikimrExport.TCreateExportRequest\">\n\x15TCreateExportResponse\x12%\n\x05\x45ntry\x18\x01 \x01(\x0b\x32\x16.NKikimrExport.TExport\"_\n\x17TEvCreateExportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrExport.TCreateExportResponse\"\x1f\n\x11TGetExportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"^\n\x13TEvGetExportRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x31\n\x07Request\x18\x01 \x01(\x0b\x32 .NKikimrExport.TGetExportRequest\";\n\x12TGetExportResponse\x12%\n\x05\x45ntry\x18\x01 \x01(\x0b\x32\x16.NKikimrExport.TExport\"K\n\x14TEvGetExportResponse\x12\x33\n\x08Response\x18\x01 \x01(\x0b\x32!.NKikimrExport.TGetExportResponse\"\"\n\x14TCancelExportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"r\n\x16TEvCancelExportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x02 \x01(\x0b\x32#.NKikimrExport.TCancelExportRequest\"k\n\x15TCancelExportResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"_\n\x17TEvCancelExportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrExport.TCancelExportResponse\"\"\n\x14TForgetExportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"r\n\x16TEvForgetExportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x02 \x01(\x0b\x32#.NKikimrExport.TForgetExportRequest\"k\n\x15TForgetExportResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"_\n\x17TEvForgetExportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrExport.TForgetExportResponse\"H\n\x13TListExportsRequest\x12\x10\n\x08PageSize\x18\x01 \x01(\x04\x12\x11\n\tPageToken\x18\x02 \x01(\t\x12\x0c\n\x04Kind\x18\x03 \x01(\t\"b\n\x15TEvListExportsRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x33\n\x07Request\x18\x01 \x01(\x0b\x32\".NKikimrExport.TListExportsRequest\"\xaa\x01\n\x14TListExportsResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x07\x45ntries\x18\x03 \x03(\x0b\x32\x16.NKikimrExport.TExport\x12\x15\n\rNextPageToken\x18\x04 \x01(\t\"O\n\x16TEvListExportsResponse\x12\x35\n\x08Response\x18\x01 \x01(\x0b\x32#.NKikimrExport.TListExportsResponseB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.export_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEXPORT._serialized_start=224
  _TEXPORT._serialized_end=575
  _TCREATEEXPORTREQUEST._serialized_start=578
  _TCREATEEXPORTREQUEST._serialized_end=794
  _TEVCREATEEXPORTREQUEST._serialized_start=797
  _TEVCREATEEXPORTREQUEST._serialized_end=928
  _TCREATEEXPORTRESPONSE._serialized_start=930
  _TCREATEEXPORTRESPONSE._serialized_end=992
  _TEVCREATEEXPORTRESPONSE._serialized_start=994
  _TEVCREATEEXPORTRESPONSE._serialized_end=1089
  _TGETEXPORTREQUEST._serialized_start=1091
  _TGETEXPORTREQUEST._serialized_end=1122
  _TEVGETEXPORTREQUEST._serialized_start=1124
  _TEVGETEXPORTREQUEST._serialized_end=1218
  _TGETEXPORTRESPONSE._serialized_start=1220
  _TGETEXPORTRESPONSE._serialized_end=1279
  _TEVGETEXPORTRESPONSE._serialized_start=1281
  _TEVGETEXPORTRESPONSE._serialized_end=1356
  _TCANCELEXPORTREQUEST._serialized_start=1358
  _TCANCELEXPORTREQUEST._serialized_end=1392
  _TEVCANCELEXPORTREQUEST._serialized_start=1394
  _TEVCANCELEXPORTREQUEST._serialized_end=1508
  _TCANCELEXPORTRESPONSE._serialized_start=1510
  _TCANCELEXPORTRESPONSE._serialized_end=1617
  _TEVCANCELEXPORTRESPONSE._serialized_start=1619
  _TEVCANCELEXPORTRESPONSE._serialized_end=1714
  _TFORGETEXPORTREQUEST._serialized_start=1716
  _TFORGETEXPORTREQUEST._serialized_end=1750
  _TEVFORGETEXPORTREQUEST._serialized_start=1752
  _TEVFORGETEXPORTREQUEST._serialized_end=1866
  _TFORGETEXPORTRESPONSE._serialized_start=1868
  _TFORGETEXPORTRESPONSE._serialized_end=1975
  _TEVFORGETEXPORTRESPONSE._serialized_start=1977
  _TEVFORGETEXPORTRESPONSE._serialized_end=2072
  _TLISTEXPORTSREQUEST._serialized_start=2074
  _TLISTEXPORTSREQUEST._serialized_end=2146
  _TEVLISTEXPORTSREQUEST._serialized_start=2148
  _TEVLISTEXPORTSREQUEST._serialized_end=2246
  _TLISTEXPORTSRESPONSE._serialized_start=2249
  _TLISTEXPORTSRESPONSE._serialized_end=2419
  _TEVLISTEXPORTSRESPONSE._serialized_start=2421
  _TEVLISTEXPORTSRESPONSE._serialized_end=2500
# @@protoc_insertion_point(module_scope)
