# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/login/protos/login.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/library/login/protos/login.proto\x12\x0bNLoginProto\"O\n\nTPublicKey\x12\r\n\x05KeyId\x18\x01 \x01(\x04\x12\x14\n\nKeyDataPEM\x18\x02 \x01(\tH\x00\x12\x11\n\tExpiresAt\x18\t \x01(\x04\x42\t\n\x07KeyData\"7\n\x08\x45SidType\"+\n\x07SidType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x08\n\x04USER\x10\x01\x12\t\n\x05GROUP\x10\x02\"`\n\x04TSid\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12+\n\x04Type\x18\x02 \x01(\x0e\x32\x1d.NLoginProto.ESidType.SidType\x12\x0c\n\x04Hash\x18\x03 \x01(\t\x12\x0f\n\x07Members\x18\x04 \x03(\t\"p\n\x0eTSecurityState\x12+\n\nPublicKeys\x18\x01 \x03(\x0b\x32\x17.NLoginProto.TPublicKey\x12\x1f\n\x04Sids\x18\x02 \x03(\x0b\x32\x11.NLoginProto.TSid\x12\x10\n\x08\x41udience\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.login.protos.login_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TPUBLICKEY._serialized_start=53
  _TPUBLICKEY._serialized_end=132
  _ESIDTYPE._serialized_start=134
  _ESIDTYPE._serialized_end=189
  _ESIDTYPE_SIDTYPE._serialized_start=146
  _ESIDTYPE_SIDTYPE._serialized_end=189
  _TSID._serialized_start=191
  _TSID._serialized_end=287
  _TSECURITYSTATE._serialized_start=289
  _TSECURITYSTATE._serialized_end=401
# @@protoc_insertion_point(module_scope)
