# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/storage.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/yq/libs/config/protos/storage.proto\x12\x0bNYq.NConfig\"\xaf\x02\n\x11TYdbStorageConfig\x12\x10\n\x08\x45ndpoint\x18\x01 \x01(\t\x12\x10\n\x08\x44\x61tabase\x18\x02 \x01(\t\x12\x11\n\tOAuthFile\x18\x03 \x01(\t\x12\x13\n\x0bTablePrefix\x18\x04 \x01(\t\x12\x17\n\x0f\x43\x65rtificateFile\x18\x06 \x01(\t\x12\x13\n\x0bIamEndpoint\x18\x07 \x01(\t\x12\x11\n\tSaKeyFile\x18\x08 \x01(\t\x12\x1f\n\x17UseLocalMetadataService\x18\t \x01(\x08\x12\x18\n\x10\x43lientTimeoutSec\x18\n \x01(\r\x12\x1b\n\x13OperationTimeoutSec\x18\x0b \x01(\r\x12\x16\n\x0e\x43\x61ncelAfterSec\x18\x0c \x01(\r\x12\x0e\n\x06UseSsl\x18\r \x01(\x08\x12\r\n\x05Token\x18\x05 \x01(\tB\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.storage_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TYDBSTORAGECONFIG._serialized_start=62
  _TYDBSTORAGECONFIG._serialized_end=365
# @@protoc_insertion_point(module_scope)
