# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/folder_service/proto/folder_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5ydb/library/folder_service/proto/folder_service.proto\x12\x1bNKikimrProto.NFolderService\x1a\x1fgoogle/protobuf/timestamp.proto\"\x84\x03\n\x06\x46older\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x63loud_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12?\n\x06labels\x18\x06 \x03(\x0b\x32/.NKikimrProto.NFolderService.Folder.LabelsEntry\x12:\n\x06status\x18\x07 \x01(\x0e\x32*.NKikimrProto.NFolderService.Folder.Status\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"]\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08\x44\x45LETING\x10\x02\x12\x0b\n\x07\x44\x45LETED\x10\x03\x12\x14\n\x10PENDING_DELETION\x10\x04\"%\n\x10GetFolderRequest\x12\x11\n\tfolder_id\x18\x01 \x01(\t\"H\n\x11GetFolderResponse\x12\x33\n\x06\x66older\x18\x01 \x01(\x0b\x32#.NKikimrProto.NFolderService.Folderb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.folder_service.proto.folder_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FOLDER_LABELSENTRY._options = None
  _FOLDER_LABELSENTRY._serialized_options = b'8\001'
  _FOLDER._serialized_start=120
  _FOLDER._serialized_end=508
  _FOLDER_LABELSENTRY._serialized_start=368
  _FOLDER_LABELSENTRY._serialized_end=413
  _FOLDER_STATUS._serialized_start=415
  _FOLDER_STATUS._serialized_end=508
  _GETFOLDERREQUEST._serialized_start=510
  _GETFOLDERREQUEST._serialized_end=547
  _GETFOLDERRESPONSE._serialized_start=549
  _GETFOLDERRESPONSE._serialized_end=621
# @@protoc_insertion_point(module_scope)
