# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/long_tx_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ydb/core/protos/long_tx_service.proto\x12\x14NKikimrLongTxService\x1a,ydb/public/api/protos/ydb_status_codes.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\"Y\n\tTLongTxId\x12\x10\n\x08UniqueId\x18\x01 \x01(\x0c\x12\x0e\n\x06NodeId\x18\x02 \x01(\r\x12\x14\n\x0cSnapshotStep\x18\x03 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x04 \x01(\x04\"\xb5\x01\n\nTEvBeginTx\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\x12\x34\n\x04Mode\x18\x02 \x01(\x0e\x32&.NKikimrLongTxService.TEvBeginTx.EMode\"[\n\x05\x45Mode\x12\x14\n\x10MODE_UNSPECIFIED\x10\x00\x12\x12\n\x0eMODE_READ_ONLY\x10\x01\x12\x13\n\x0fMODE_WRITE_ONLY\x10\x02\x12\x13\n\x0fMODE_READ_WRITE\x10\x03\"\x99\x01\n\x10TEvBeginTxResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x31\n\x08LongTxId\x18\x03 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\"@\n\x0bTEvCommitTx\x12\x31\n\x08LongTxId\x18\x01 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\"g\n\x11TEvCommitTxResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"B\n\rTEvRollbackTx\x12\x31\n\x08LongTxId\x18\x01 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\"i\n\x13TEvRollbackTxResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"\xc8\x01\n\x1aTEvAttachColumnShardWrites\x12\x31\n\x08LongTxId\x18\x01 \x01(\x0b\x32\x1f.NKikimrLongTxService.TLongTxId\x12G\n\x06Writes\x18\x02 \x03(\x0b\x32\x37.NKikimrLongTxService.TEvAttachColumnShardWrites.TWrite\x1a.\n\x06TWrite\x12\x13\n\x0b\x43olumnShard\x18\x01 \x01(\x04\x12\x0f\n\x07WriteId\x18\x02 \x01(\x04\"v\n TEvAttachColumnShardWritesResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\".\n\x16TEvAcquireReadSnapshot\x12\x14\n\x0c\x44\x61tabaseName\x18\x01 \x01(\t\"\xb4\x01\n\x1cTEvAcquireReadSnapshotResult\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x14\n\x0cSnapshotStep\x18\x03 \x01(\x04\x12\x14\n\x0cSnapshotTxId\x18\x04 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x05 \x01(\t\"4\n\x10TEvSubscribeLock\x12\x0e\n\x06LockId\x18\x01 \x01(\x04\x12\x10\n\x08LockNode\x18\x02 \x01(\r\"\xd6\x01\n\rTEvLockStatus\x12\x0e\n\x06LockId\x18\x01 \x01(\x04\x12\x10\n\x08LockNode\x18\x02 \x01(\r\x12;\n\x06Status\x18\x03 \x01(\x0e\x32+.NKikimrLongTxService.TEvLockStatus.EStatus\"f\n\x07\x45Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x15\n\x11STATUS_SUBSCRIBED\x10\x01\x12\x14\n\x10STATUS_NOT_FOUND\x10\x02\x12\x16\n\x12STATUS_UNAVAILABLE\x10\x03\"6\n\x12TEvUnsubscribeLock\x12\x0e\n\x06LockId\x18\x01 \x01(\x04\x12\x10\n\x08LockNode\x18\x02 \x01(\rB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.long_tx_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TLONGTXID._serialized_start=156
  _TLONGTXID._serialized_end=245
  _TEVBEGINTX._serialized_start=248
  _TEVBEGINTX._serialized_end=429
  _TEVBEGINTX_EMODE._serialized_start=338
  _TEVBEGINTX_EMODE._serialized_end=429
  _TEVBEGINTXRESULT._serialized_start=432
  _TEVBEGINTXRESULT._serialized_end=585
  _TEVCOMMITTX._serialized_start=587
  _TEVCOMMITTX._serialized_end=651
  _TEVCOMMITTXRESULT._serialized_start=653
  _TEVCOMMITTXRESULT._serialized_end=756
  _TEVROLLBACKTX._serialized_start=758
  _TEVROLLBACKTX._serialized_end=824
  _TEVROLLBACKTXRESULT._serialized_start=826
  _TEVROLLBACKTXRESULT._serialized_end=931
  _TEVATTACHCOLUMNSHARDWRITES._serialized_start=934
  _TEVATTACHCOLUMNSHARDWRITES._serialized_end=1134
  _TEVATTACHCOLUMNSHARDWRITES_TWRITE._serialized_start=1088
  _TEVATTACHCOLUMNSHARDWRITES_TWRITE._serialized_end=1134
  _TEVATTACHCOLUMNSHARDWRITESRESULT._serialized_start=1136
  _TEVATTACHCOLUMNSHARDWRITESRESULT._serialized_end=1254
  _TEVACQUIREREADSNAPSHOT._serialized_start=1256
  _TEVACQUIREREADSNAPSHOT._serialized_end=1302
  _TEVACQUIREREADSNAPSHOTRESULT._serialized_start=1305
  _TEVACQUIREREADSNAPSHOTRESULT._serialized_end=1485
  _TEVSUBSCRIBELOCK._serialized_start=1487
  _TEVSUBSCRIBELOCK._serialized_end=1539
  _TEVLOCKSTATUS._serialized_start=1542
  _TEVLOCKSTATUS._serialized_end=1756
  _TEVLOCKSTATUS_ESTATUS._serialized_start=1654
  _TEVLOCKSTATUS_ESTATUS._serialized_end=1756
  _TEVUNSUBSCRIBELOCK._serialized_start=1758
  _TEVUNSUBSCRIBELOCK._serialized_end=1812
# @@protoc_insertion_point(module_scope)
