# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/persqueue_error_codes_v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ydb/public/api/protos/persqueue_error_codes_v1.proto\x12\x17Ydb.PersQueue.ErrorCode*\x86\x05\n\tErrorCode\x12\x06\n\x02OK\x10\x00\x12\x12\n\x0cINITIALIZING\x10\xa1\xc2\x1e\x12\x0e\n\x08OVERLOAD\x10\xa2\xc2\x1e\x12\x11\n\x0b\x42\x41\x44_REQUEST\x10\xa3\xc2\x1e\x12\x12\n\x0cWRONG_COOKIE\x10\xa4\xc2\x1e\x12\x16\n\x10SOURCEID_DELETED\x10\xb8\xc2\x1e\x12#\n\x1dWRITE_ERROR_PARTITION_IS_FULL\x10\xa5\xc2\x1e\x12\x1e\n\x18WRITE_ERROR_DISK_IS_FULL\x10\xaf\xc2\x1e\x12\x1c\n\x16WRITE_ERROR_BAD_OFFSET\x10\xb3\xc2\x1e\x12#\n\x1d\x43REATE_SESSION_ALREADY_LOCKED\x10\xa6\xc2\x1e\x12\x1f\n\x19\x44\x45LETE_SESSION_NO_SESSION\x10\xa7\xc2\x1e\x12\x1c\n\x16READ_ERROR_IN_PROGRESS\x10\xa8\xc2\x1e\x12\x1b\n\x15READ_ERROR_NO_SESSION\x10\xa9\xc2\x1e\x12!\n\x1bREAD_ERROR_TOO_SMALL_OFFSET\x10\xab\xc2\x1e\x12\x1f\n\x19READ_ERROR_TOO_BIG_OFFSET\x10\xac\xc2\x1e\x12\'\n!SET_OFFSET_ERROR_COMMIT_TO_FUTURE\x10\xad\xc2\x1e\x12\x17\n\x11TABLET_IS_DROPPED\x10\xae\xc2\x1e\x12\x13\n\rREAD_NOT_DONE\x10\xb0\xc2\x1e\x12\x13\n\rUNKNOWN_TOPIC\x10\xb1\xc2\x1e\x12\x13\n\rACCESS_DENIED\x10\xb2\xc2\x1e\x12\x16\n\x10\x43LUSTER_DISABLED\x10\xb4\xc2\x1e\x12\x1c\n\x16WRONG_PARTITION_NUMBER\x10\xb5\xc2\x1e\x12\"\n\x1cPREFERRED_CLUSTER_MISMATCHED\x10\xb6\xc2\x1e\x12\x0b\n\x05\x45RROR\x10\x84\xc3\x1e\x42$\n\"com.yandex.ydb.persqueue.errorcodeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.persqueue_error_codes_v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\"com.yandex.ydb.persqueue.errorcode'
  _ERRORCODE._serialized_start=82
  _ERRORCODE._serialized_end=728
# @@protoc_insertion_point(module_scope)
