# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_pdisk_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.ydb/core/protos/blobstorage_pdisk_config.proto\x12\x12NKikimrBlobStorage\"\x97\x08\n\x0cTPDiskConfig\x12\"\n\x1aStatisticsUpdateIntervalMs\x18\x64 \x01(\x04\x12\x1c\n\x14\x42ytesSchedulerWeight\x18i \x01(\x04\x12\x11\n\tLogWeight\x18k \x01(\x04\x12\x13\n\x0b\x46reshWeight\x18l \x01(\x04\x12\x12\n\nCompWeight\x18m \x01(\x04\x12\x15\n\rSyncLogWeight\x18n \x01(\x04\x12\x12\n\nHugeWeight\x18o \x01(\x04\x12\x16\n\x0e\x46\x61stReadWeight\x18p \x01(\x04\x12\x17\n\x0fOtherReadWeight\x18q \x01(\x04\x12\x12\n\nLoadWeight\x18r \x01(\x04\x12\x15\n\rLowReadWeight\x18x \x01(\x04\x12\x19\n\x11MinLogChunksTotal\x18\x01 \x01(\x04\x12&\n\x1eMaxLogChunksPerOwnerMultiplier\x18\x02 \x01(\x04\x12#\n\x1bMaxLogChunksPerOwnerDivisor\x18\x03 \x01(\x04\x12\x1e\n\x16SortFreeChunksPerItems\x18\x04 \x01(\x04\x12\x12\n\nSectorSize\x18\x06 \x01(\r\x12\x11\n\tChunkSize\x18\x07 \x01(\r\x12\x45\n\x12GetDriveDataSwitch\x18\xe8\x07 \x01(\x0e\x32(.NKikimrBlobStorage.TPDiskConfig.ESwitch\x12\x43\n\x10WriteCacheSwitch\x18\xe9\x07 \x01(\x0e\x32(.NKikimrBlobStorage.TPDiskConfig.ESwitch\x12\x1d\n\x14\x44riveModelSeekTimeNs\x18\xed\x07 \x01(\x04\x12\x1b\n\x12\x44riveModelSpeedBps\x18\xee\x07 \x01(\x04\x12$\n\x1b\x44riveModelBulkWrieBlockSize\x18\xf0\x07 \x01(\x04\x12\x1f\n\x16\x44riveModelTrimSpeedBps\x18\xf1\x07 \x01(\x04\x12\x15\n\x0cReorderingMs\x18\xf3\x07 \x01(\x04\x12\x14\n\x0b\x43ostLimitNs\x18\xfe\x07 \x01(\x04\x12\x17\n\x0e\x44\x65viceInFlight\x18\xff\x07 \x01(\x04\x12\"\n\x19\x42ufferPoolBufferSizeBytes\x18\x80\x08 \x01(\r\x12\x1e\n\x15\x42ufferPoolBufferCount\x18\x81\x08 \x01(\r\x12#\n\x1aMaxQueuedCompletionActions\x18\x82\x08 \x01(\r\x12\"\n\x19InsaneLogChunksMultiplier\x18\xd0\x0f \x01(\x04\x12\x1a\n\x11\x45xpectedSlotCount\x18\xd1\x0f \x01(\x04\"U\n\x07\x45Switch\x12\x0e\n\nDoNotTouch\x10\x00\x12\n\n\x06\x45nable\x10\x01\x12\x0f\n\x0b\x46orceEnable\x10\x02\x12\x0b\n\x07\x44isable\x10\x03\x12\x10\n\x0c\x46orceDisable\x10\x04\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_pdisk_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPDISKCONFIG._serialized_start=71
  _TPDISKCONFIG._serialized_end=1118
  _TPDISKCONFIG_ESWITCH._serialized_start=1033
  _TPDISKCONFIG_ESWITCH._serialized_end=1118
# @@protoc_insertion_point(module_scope)
