# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/console.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import console_base_pb2 as ydb_dot_core_dot_protos_dot_console__base__pb2
from ydb.core.protos import console_tenant_pb2 as ydb_dot_core_dot_protos_dot_console__tenant__pb2
from ydb.core.protos import console_config_pb2 as ydb_dot_core_dot_protos_dot_console__config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dydb/core/protos/console.proto\x12\x0eNKikimrConsole\x1a\"ydb/core/protos/console_base.proto\x1a$ydb/core/protos/console_tenant.proto\x1a$ydb/core/protos/console_config.proto\"w\n\x07TConfig\x12\x35\n\rTenantsConfig\x18\x01 \x01(\x0b\x32\x1e.NKikimrConsole.TTenantsConfig\x12\x35\n\rConfigsConfig\x18\x02 \x01(\x0b\x32\x1e.NKikimrConsole.TConfigsConfig\"\x13\n\x11TGetConfigRequest\"=\n\x12TGetConfigResponse\x12\'\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TConfig\"\x82\x01\n\x11TSetConfigRequest\x12\'\n\x06\x43onfig\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TConfig\x12\x44\n\x05Merge\x18\x02 \x01(\x0e\x32*.NKikimrConsole.TConfigItem.EMergeStrategy:\tOVERWRITE\"=\n\x12TSetConfigResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"\xa7\x01\n\x0eTLogRecordData\x12\x31\n\x06\x41\x63tion\x18\x01 \x01(\x0b\x32!.NKikimrConsole.TConfigureRequest\x12K\n\x0f\x41\x66\x66\x65\x63tedConfigs\x18\x02 \x03(\x0b\x32\x32.NKikimrConsole.TConfigureResponse.TAffectedConfig\x12\x15\n\rAffectedKinds\x18\x03 \x03(\r\"g\n\nTLogRecord\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x11\n\tTimestamp\x18\x02 \x01(\x04\x12\x0c\n\x04User\x18\x03 \x01(\t\x12,\n\x04\x44\x61ta\x18\x04 \x01(\x0b\x32\x1e.NKikimrConsole.TLogRecordData\"\x94\x01\n\nTLogFilter\x12\x0e\n\x06\x46romId\x18\x01 \x01(\x04\x12\x15\n\rFromTimestamp\x18\x02 \x01(\x04\x12\x12\n\x05Limit\x18\x03 \x01(\r:\x03\x31\x30\x30\x12\x15\n\rAffectedKinds\x18\x04 \x03(\r\x12\r\n\x05Users\x18\x05 \x03(\t\x12\x14\n\x0c\x45xcludeUsers\x18\x06 \x03(\t\x12\x0f\n\x07Reverse\x18\x07 \x01(\x08\"C\n\x12TGetLogTailRequest\x12-\n\tLogFilter\x18\x01 \x01(\x0b\x32\x1a.NKikimrConsole.TLogFilter\"n\n\x13TGetLogTailResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12.\n\nLogRecords\x18\x04 \x03(\x0b\x32\x1a.NKikimrConsole.TLogRecordB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.console_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TCONFIG._serialized_start=161
  _TCONFIG._serialized_end=280
  _TGETCONFIGREQUEST._serialized_start=282
  _TGETCONFIGREQUEST._serialized_end=301
  _TGETCONFIGRESPONSE._serialized_start=303
  _TGETCONFIGRESPONSE._serialized_end=364
  _TSETCONFIGREQUEST._serialized_start=367
  _TSETCONFIGREQUEST._serialized_end=497
  _TSETCONFIGRESPONSE._serialized_start=499
  _TSETCONFIGRESPONSE._serialized_end=560
  _TLOGRECORDDATA._serialized_start=563
  _TLOGRECORDDATA._serialized_end=730
  _TLOGRECORD._serialized_start=732
  _TLOGRECORD._serialized_end=835
  _TLOGFILTER._serialized_start=838
  _TLOGFILTER._serialized_end=986
  _TGETLOGTAILREQUEST._serialized_start=988
  _TGETLOGTAILREQUEST._serialized_end=1055
  _TGETLOGTAILRESPONSE._serialized_start=1057
  _TGETLOGTAILRESPONSE._serialized_end=1167
# @@protoc_insertion_point(module_scope)
