# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/mkql_proto/protos/minikql.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+ydb/library/mkql_proto/protos/minikql.proto\x12\x0eNKikimrMiniKQL\x1a\x1cgoogle/protobuf/struct.proto\"2\n\x0eTDecimalParams\x12\x11\n\tPrecision\x18\x01 \x02(\r\x12\r\n\x05Scale\x18\x02 \x02(\r\"R\n\tTDataType\x12\x0e\n\x06Scheme\x18\x01 \x02(\r\x12\x35\n\rDecimalParams\x18\x02 \x01(\x0b\x32\x1e.NKikimrMiniKQL.TDecimalParams\"4\n\rTOptionalType\x12#\n\x04Item\x18\x01 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"0\n\tTListType\x12#\n\x04Item\x18\x01 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"4\n\nTTupleType\x12&\n\x07\x45lement\x18\x01 \x03(\x0b\x32\x15.NKikimrMiniKQL.TType\"<\n\x07TMember\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12#\n\x04Type\x18\x02 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"6\n\x0bTStructType\x12\'\n\x06Member\x18\x01 \x03(\x0b\x32\x17.NKikimrMiniKQL.TMember\"|\n\x0cTVariantType\x12\x30\n\nTupleItems\x18\x01 \x01(\x0b\x32\x1a.NKikimrMiniKQL.TTupleTypeH\x00\x12\x32\n\x0bStructItems\x18\x02 \x01(\x0b\x32\x1b.NKikimrMiniKQL.TStructTypeH\x00\x42\x06\n\x04type\"W\n\tTDictType\x12\"\n\x03Key\x18\x01 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\x12&\n\x07Payload\x18\x02 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"\x16\n\x07TPgType\x12\x0b\n\x03oid\x18\x01 \x02(\r\"?\n\x0bTTaggedType\x12\x0b\n\x03Tag\x18\x01 \x02(\t\x12#\n\x04Item\x18\x02 \x02(\x0b\x32\x15.NKikimrMiniKQL.TType\"\xd4\x03\n\x05TType\x12\'\n\x04Kind\x18\x01 \x02(\x0e\x32\x19.NKikimrMiniKQL.ETypeKind\x12)\n\x04\x44\x61ta\x18\x02 \x01(\x0b\x32\x19.NKikimrMiniKQL.TDataTypeH\x00\x12\x31\n\x08Optional\x18\x03 \x01(\x0b\x32\x1d.NKikimrMiniKQL.TOptionalTypeH\x00\x12)\n\x04List\x18\x04 \x01(\x0b\x32\x19.NKikimrMiniKQL.TListTypeH\x00\x12+\n\x05Tuple\x18\x05 \x01(\x0b\x32\x1a.NKikimrMiniKQL.TTupleTypeH\x00\x12-\n\x06Struct\x18\x06 \x01(\x0b\x32\x1b.NKikimrMiniKQL.TStructTypeH\x00\x12)\n\x04\x44ict\x18\x07 \x01(\x0b\x32\x19.NKikimrMiniKQL.TDictTypeH\x00\x12/\n\x07Variant\x18\x08 \x01(\x0b\x32\x1c.NKikimrMiniKQL.TVariantTypeH\x00\x12%\n\x02Pg\x18\t \x01(\x0b\x32\x17.NKikimrMiniKQL.TPgTypeH\x00\x12-\n\x06Tagged\x18\n \x01(\x0b\x32\x1b.NKikimrMiniKQL.TTaggedTypeH\x00\x42\x0b\n\ttype_type\"Z\n\nTValuePair\x12#\n\x03Key\x18\x01 \x02(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12\'\n\x07Payload\x18\x02 \x02(\x0b\x32\x16.NKikimrMiniKQL.TValue\"\xe8\x03\n\x06TValue\x12\x0e\n\x04\x42ool\x18\x01 \x01(\x08H\x00\x12\x0f\n\x05Int32\x18\x02 \x01(\x05H\x00\x12\x10\n\x06Uint32\x18\x03 \x01(\rH\x00\x12\x0f\n\x05Int64\x18\x04 \x01(\x03H\x00\x12\x10\n\x06Uint64\x18\x05 \x01(\x04H\x00\x12\x0f\n\x05\x46loat\x18\x06 \x01(\x02H\x00\x12\x10\n\x06\x44ouble\x18\x07 \x01(\x01H\x00\x12\x0f\n\x05\x42ytes\x18\x08 \x01(\x0cH\x00\x12\x0e\n\x04Text\x18\t \x01(\tH\x00\x12*\n\x08Optional\x18\n \x01(\x0b\x32\x16.NKikimrMiniKQL.TValueH\x00\x12\x10\n\x06Low128\x18\x0f \x01(\x06H\x00\x12\x33\n\rNullFlagValue\x18\x12 \x01(\x0e\x32\x1a.google.protobuf.NullValueH\x00\x12$\n\x04List\x18\x0b \x03(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12%\n\x05Tuple\x18\x0c \x03(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12&\n\x06Struct\x18\r \x03(\x0b\x32\x16.NKikimrMiniKQL.TValue\x12(\n\x04\x44ict\x18\x0e \x03(\x0b\x32\x1a.NKikimrMiniKQL.TValuePair\x12\r\n\x05Hi128\x18\x10 \x01(\x06\x12\x14\n\x0cVariantIndex\x18\x11 \x01(\rB\r\n\x0bvalue_value\"U\n\x07TResult\x12#\n\x04Type\x18\x01 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\x12%\n\x05Value\x18\x02 \x01(\x0b\x32\x16.NKikimrMiniKQL.TValue\"U\n\x07TParams\x12#\n\x04Type\x18\x01 \x01(\x0b\x32\x15.NKikimrMiniKQL.TType\x12%\n\x05Value\x18\x02 \x01(\x0b\x32\x16.NKikimrMiniKQL.TValue*\xc3\x01\n\tETypeKind\x12\x0b\n\x07Unknown\x10\x00\x12\x08\n\x04Void\x10\x01\x12\x08\n\x04\x44\x61ta\x10\x02\x12\x0c\n\x08Optional\x10\x03\x12\x08\n\x04List\x10\x04\x12\t\n\x05Tuple\x10\x05\x12\n\n\x06Struct\x10\x06\x12\x08\n\x04\x44ict\x10\x07\x12\x0b\n\x07Variant\x10\x08\x12\x08\n\x04Null\x10\t\x12\x06\n\x02Pg\x10\n\x12\n\n\x06Tagged\x10\x0b\x12\x0f\n\x0bReserved_12\x10\x0c\x12\x0f\n\x0bReserved_13\x10\r\x12\x0f\n\x0bReserved_14\x10\x0e\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.mkql_proto.protos.minikql_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _ETYPEKIND._serialized_start=2038
  _ETYPEKIND._serialized_end=2233
  _TDECIMALPARAMS._serialized_start=93
  _TDECIMALPARAMS._serialized_end=143
  _TDATATYPE._serialized_start=145
  _TDATATYPE._serialized_end=227
  _TOPTIONALTYPE._serialized_start=229
  _TOPTIONALTYPE._serialized_end=281
  _TLISTTYPE._serialized_start=283
  _TLISTTYPE._serialized_end=331
  _TTUPLETYPE._serialized_start=333
  _TTUPLETYPE._serialized_end=385
  _TMEMBER._serialized_start=387
  _TMEMBER._serialized_end=447
  _TSTRUCTTYPE._serialized_start=449
  _TSTRUCTTYPE._serialized_end=503
  _TVARIANTTYPE._serialized_start=505
  _TVARIANTTYPE._serialized_end=629
  _TDICTTYPE._serialized_start=631
  _TDICTTYPE._serialized_end=718
  _TPGTYPE._serialized_start=720
  _TPGTYPE._serialized_end=742
  _TTAGGEDTYPE._serialized_start=744
  _TTAGGEDTYPE._serialized_end=807
  _TTYPE._serialized_start=810
  _TTYPE._serialized_end=1278
  _TVALUEPAIR._serialized_start=1280
  _TVALUEPAIR._serialized_end=1370
  _TVALUE._serialized_start=1373
  _TVALUE._serialized_end=1861
  _TRESULT._serialized_start=1863
  _TRESULT._serialized_end=1948
  _TPARAMS._serialized_start=1950
  _TPARAMS._serialized_end=2035
# @@protoc_insertion_point(module_scope)
