# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/dq/actors/protos/dq_status_codes.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6ydb/library/yql/dq/actors/protos/dq_status_codes.proto\x12\rNYql.NDqProto\"\xa3\x02\n\tStatusIds\"\x95\x02\n\nStatusCode\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07SUCCESS\x10\x01\x12\x12\n\x0eINTERNAL_ERROR\x10\x02\x12\x0b\n\x07TIMEOUT\x10\x03\x12\x0b\n\x07\x41\x42ORTED\x10\x04\x12\x0f\n\x0bUNAVAILABLE\x10\x05\x12\x0f\n\x0b\x42\x41\x44_REQUEST\x10\x06\x12\x17\n\x13PRECONDITION_FAILED\x10\x07\x12\r\n\tCANCELLED\x10\x08\x12\x0e\n\nOVERLOADED\x10\t\x12\x12\n\x0eLIMIT_EXCEEDED\x10\n\x12\x0f\n\x0bUNSUPPORTED\x10\x0b\x12\x12\n\x0e\x45XTERNAL_ERROR\x10\x0c\x12\x16\n\x12\x43LUSTER_OVERLOADED\x10\r\x12\x10\n\x0cSCHEME_ERROR\x10\x0e\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.dq.actors.protos.dq_status_codes_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STATUSIDS._serialized_start=74
  _STATUSIDS._serialized_end=365
  _STATUSIDS_STATUSCODE._serialized_start=88
  _STATUSIDS_STATUSCODE._serialized_end=365
# @@protoc_insertion_point(module_scope)
