# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/shared_cache.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"ydb/core/protos/shared_cache.proto\x12\x12NKikimrSharedCache\"\x85\x01\n\x12TSharedCacheConfig\x12\x1e\n\x0bMemoryLimit\x18\x01 \x01(\x04:\t536870912\x12&\n\x13ScanQueueInFlyLimit\x18\x02 \x01(\x04:\t536870912\x12\'\n\x14\x41syncQueueInFlyLimit\x18\x03 \x01(\x04:\t536870912B\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.shared_cache_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSHAREDCACHECONFIG._serialized_start=59
  _TSHAREDCACHECONFIG._serialized_end=192
# @@protoc_insertion_point(module_scope)
