# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/import.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos import ydb_import_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__import__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cydb/core/protos/import.proto\x12\rNKikimrImport\x1a&ydb/public/api/protos/ydb_import.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\"\xa5\x02\n\x07TImport\x12\n\n\x02Id\x18\x01 \x01(\x04\x12)\n\x06Status\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x03 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x35\n\x08Progress\x18\x04 \x01(\x0e\x32#.Ydb.Import.ImportProgress.Progress\x12\x35\n\rItemsProgress\x18\x05 \x03(\x0b\x32\x1e.Ydb.Import.ImportItemProgress\x12@\n\x14ImportFromS3Settings\x18\x06 \x01(\x0b\x32 .Ydb.Import.ImportFromS3SettingsH\x00\x42\n\n\x08Settings\"\x9e\x01\n\x14TCreateImportRequest\x12\x38\n\x0fOperationParams\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12@\n\x14ImportFromS3Settings\x18\x02 \x01(\x0b\x32 .Ydb.Import.ImportFromS3SettingsH\x00\x42\n\n\x08Settings\"\x83\x01\n\x16TEvCreateImportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x0f\n\x07UserSID\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x04 \x01(\x0b\x32#.NKikimrImport.TCreateImportRequest\">\n\x15TCreateImportResponse\x12%\n\x05\x45ntry\x18\x01 \x01(\x0b\x32\x16.NKikimrImport.TImport\"_\n\x17TEvCreateImportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrImport.TCreateImportResponse\"\x1f\n\x11TGetImportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"^\n\x13TEvGetImportRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x31\n\x07Request\x18\x01 \x01(\x0b\x32 .NKikimrImport.TGetImportRequest\";\n\x12TGetImportResponse\x12%\n\x05\x45ntry\x18\x01 \x01(\x0b\x32\x16.NKikimrImport.TImport\"K\n\x14TEvGetImportResponse\x12\x33\n\x08Response\x18\x01 \x01(\x0b\x32!.NKikimrImport.TGetImportResponse\"\"\n\x14TCancelImportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"r\n\x16TEvCancelImportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x02 \x01(\x0b\x32#.NKikimrImport.TCancelImportRequest\"k\n\x15TCancelImportResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"_\n\x17TEvCancelImportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrImport.TCancelImportResponse\"\"\n\x14TForgetImportRequest\x12\n\n\x02Id\x18\x01 \x01(\x04\"r\n\x16TEvForgetImportRequest\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x14\n\x0c\x44\x61tabaseName\x18\x03 \x01(\t\x12\x34\n\x07Request\x18\x02 \x01(\x0b\x32#.NKikimrImport.TForgetImportRequest\"k\n\x15TForgetImportResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"_\n\x17TEvForgetImportResponse\x12\x0c\n\x04TxId\x18\x01 \x01(\x04\x12\x36\n\x08Response\x18\x02 \x01(\x0b\x32$.NKikimrImport.TForgetImportResponse\"H\n\x13TListImportsRequest\x12\x10\n\x08PageSize\x18\x01 \x01(\x04\x12\x11\n\tPageToken\x18\x02 \x01(\t\x12\x0c\n\x04Kind\x18\x03 \x01(\t\"b\n\x15TEvListImportsRequest\x12\x14\n\x0c\x44\x61tabaseName\x18\x02 \x01(\t\x12\x33\n\x07Request\x18\x01 \x01(\x0b\x32\".NKikimrImport.TListImportsRequest\"\xaa\x01\n\x14TListImportsResponse\x12)\n\x06Status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06Issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\'\n\x07\x45ntries\x18\x03 \x03(\x0b\x32\x16.NKikimrImport.TImport\x12\x15\n\rNextPageToken\x18\x04 \x01(\t\"O\n\x16TEvListImportsResponse\x12\x35\n\x08Response\x18\x01 \x01(\x0b\x32#.NKikimrImport.TListImportsResponseB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.import_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TIMPORT._serialized_start=224
  _TIMPORT._serialized_end=517
  _TCREATEIMPORTREQUEST._serialized_start=520
  _TCREATEIMPORTREQUEST._serialized_end=678
  _TEVCREATEIMPORTREQUEST._serialized_start=681
  _TEVCREATEIMPORTREQUEST._serialized_end=812
  _TCREATEIMPORTRESPONSE._serialized_start=814
  _TCREATEIMPORTRESPONSE._serialized_end=876
  _TEVCREATEIMPORTRESPONSE._serialized_start=878
  _TEVCREATEIMPORTRESPONSE._serialized_end=973
  _TGETIMPORTREQUEST._serialized_start=975
  _TGETIMPORTREQUEST._serialized_end=1006
  _TEVGETIMPORTREQUEST._serialized_start=1008
  _TEVGETIMPORTREQUEST._serialized_end=1102
  _TGETIMPORTRESPONSE._serialized_start=1104
  _TGETIMPORTRESPONSE._serialized_end=1163
  _TEVGETIMPORTRESPONSE._serialized_start=1165
  _TEVGETIMPORTRESPONSE._serialized_end=1240
  _TCANCELIMPORTREQUEST._serialized_start=1242
  _TCANCELIMPORTREQUEST._serialized_end=1276
  _TEVCANCELIMPORTREQUEST._serialized_start=1278
  _TEVCANCELIMPORTREQUEST._serialized_end=1392
  _TCANCELIMPORTRESPONSE._serialized_start=1394
  _TCANCELIMPORTRESPONSE._serialized_end=1501
  _TEVCANCELIMPORTRESPONSE._serialized_start=1503
  _TEVCANCELIMPORTRESPONSE._serialized_end=1598
  _TFORGETIMPORTREQUEST._serialized_start=1600
  _TFORGETIMPORTREQUEST._serialized_end=1634
  _TEVFORGETIMPORTREQUEST._serialized_start=1636
  _TEVFORGETIMPORTREQUEST._serialized_end=1750
  _TFORGETIMPORTRESPONSE._serialized_start=1752
  _TFORGETIMPORTRESPONSE._serialized_end=1859
  _TEVFORGETIMPORTRESPONSE._serialized_start=1861
  _TEVFORGETIMPORTRESPONSE._serialized_end=1956
  _TLISTIMPORTSREQUEST._serialized_start=1958
  _TLISTIMPORTSREQUEST._serialized_end=2030
  _TEVLISTIMPORTSREQUEST._serialized_start=2032
  _TEVLISTIMPORTSREQUEST._serialized_end=2130
  _TLISTIMPORTSRESPONSE._serialized_start=2133
  _TLISTIMPORTSRESPONSE._serialized_end=2303
  _TEVLISTIMPORTSRESPONSE._serialized_start=2305
  _TEVLISTIMPORTSRESPONSE._serialized_end=2384
# @@protoc_insertion_point(module_scope)
