# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/query_stats.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/query_stats.proto\x12\x11NKikimrQueryStats\":\n\x0cTReadOpStats\x12\r\n\x05\x43ount\x18\x01 \x01(\x04\x12\x0c\n\x04Rows\x18\x02 \x01(\x04\x12\r\n\x05\x42ytes\x18\x03 \x01(\x04\";\n\rTWriteOpStats\x12\r\n\x05\x43ount\x18\x01 \x01(\x04\x12\x0c\n\x04Rows\x18\x02 \x01(\x04\x12\r\n\x05\x42ytes\x18\x03 \x01(\x04\"A\n\nTTableInfo\x12\x15\n\rSchemeshardId\x18\x01 \x01(\x04\x12\x0e\n\x06PathId\x18\x02 \x01(\x04\x12\x0c\n\x04Name\x18\x03 \x01(\t\"\xac\x02\n\x11TTableAccessStats\x12\x30\n\tTableInfo\x18\x01 \x01(\x0b\x32\x1d.NKikimrQueryStats.TTableInfo\x12\x32\n\tSelectRow\x18\x02 \x01(\x0b\x32\x1f.NKikimrQueryStats.TReadOpStats\x12\x34\n\x0bSelectRange\x18\x03 \x01(\x0b\x32\x1f.NKikimrQueryStats.TReadOpStats\x12\x33\n\tUpdateRow\x18\x04 \x01(\x0b\x32 .NKikimrQueryStats.TWriteOpStats\x12\x32\n\x08\x45raseRow\x18\x05 \x01(\x0b\x32 .NKikimrQueryStats.TWriteOpStats\x12\x12\n\nShardCount\x18\x06 \x01(\x04\"}\n\x0eTPerShardStats\x12\x0f\n\x07ShardId\x18\x01 \x01(\x04\x12\x13\n\x0b\x43puTimeUsec\x18\x02 \x01(\x04\x12\x1d\n\x15OutgoingReadSetsCount\x18\x03 \x01(\x04\x12\x13\n\x0bProgramSize\x18\x04 \x01(\x04\x12\x11\n\tReplySize\x18\x05 \x01(\x04\"\xb4\x01\n\x08TTxStats\x12>\n\x10TableAccessStats\x18\x01 \x03(\x0b\x32$.NKikimrQueryStats.TTableAccessStats\x12\x12\n\nDurationUs\x18\x02 \x01(\x04\x12\x1a\n\x12\x43omputeCpuTimeUsec\x18\x03 \x01(\x04\x12\x38\n\rPerShardStats\x18\x04 \x03(\x0b\x32!.NKikimrQueryStats.TPerShardStatsB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.query_stats_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TREADOPSTATS._serialized_start=56
  _TREADOPSTATS._serialized_end=114
  _TWRITEOPSTATS._serialized_start=116
  _TWRITEOPSTATS._serialized_end=175
  _TTABLEINFO._serialized_start=177
  _TTABLEINFO._serialized_end=242
  _TTABLEACCESSSTATS._serialized_start=245
  _TTABLEACCESSSTATS._serialized_end=545
  _TPERSHARDSTATS._serialized_start=547
  _TPERSHARDSTATS._serialized_end=672
  _TTXSTATS._serialized_start=675
  _TTXSTATS._serialized_end=855
# @@protoc_insertion_point(module_scope)
