# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/node_limits.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!ydb/core/protos/node_limits.proto\x12\x11NKikimrNodeLimits\"\xc2\x01\n\x11TNodeLimitsConfig\x12V\n\x13PersQueueNodeConfig\x18\x01 \x01(\x0b\x32\x39.NKikimrNodeLimits.TNodeLimitsConfig.TPersQueueNodeConfig\x1aU\n\x14TPersQueueNodeConfig\x12\x1f\n\x11SharedCacheSizeMb\x18\x01 \x01(\x04:\x04\x38\x31\x39\x32\x12\x1c\n\x10\x43\x61\x63heKeepTimeSec\x18\x02 \x01(\r:\x02\x31\x30\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.node_limits_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TNODELIMITSCONFIG._serialized_start=57
  _TNODELIMITSCONFIG._serialized_end=251
  _TNODELIMITSCONFIG_TPERSQUEUENODECONFIG._serialized_start=166
  _TNODELIMITSCONFIG_TPERSQUEUENODECONFIG._serialized_end=251
# @@protoc_insertion_point(module_scope)
