# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/providers/common/proto/gateways_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.library.yql.protos import clickhouse_pb2 as ydb_dot_library_dot_yql_dot_protos_dot_clickhouse__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<ydb/library/yql/providers/common/proto/gateways_config.proto\x12\x04NYql\x1a\'ydb/library/yql/protos/clickhouse.proto\"5\n\x11TActivationByHour\x12\x0c\n\x04Hour\x18\x01 \x02(\r\x12\x12\n\nPercentage\x18\x02 \x02(\r\"\xa0\x01\n\x15TActivationPercentage\x12\x15\n\nPercentage\x18\x01 \x01(\r:\x01\x30\x12\'\n\x06\x42yHour\x18\x02 \x03(\x0b\x32\x17.NYql.TActivationByHour\x12\x14\n\x0cIncludeUsers\x18\x03 \x03(\t\x12\x14\n\x0c\x45xcludeUsers\x18\x04 \x03(\t\x12\x1b\n\rExcludeRobots\x18\x05 \x01(\x08:\x04true\"U\n\x05TAttr\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\r\n\x05Value\x18\x02 \x02(\t\x12/\n\nActivation\x18\x03 \x01(\x0b\x32\x1b.NYql.TActivationPercentage\"D\n\x12TRemoteFilePattern\x12\x0f\n\x07Pattern\x18\x01 \x02(\t\x12\x0f\n\x07\x43luster\x18\x02 \x02(\t\x12\x0c\n\x04Path\x18\x03 \x02(\t\"\xab\x02\n\x12THttpGatewayConfig\x12\x18\n\x10MaxInFlightCount\x18\x01 \x01(\r\x12$\n\x1cMaxSimulatenousDownloadsSize\x18\x02 \x01(\x04\x12\x1c\n\x14\x42uffersSizePerStream\x18\x03 \x01(\r\x12 \n\x18\x43onnectionTimeoutSeconds\x18\x04 \x01(\x04\x12\x1b\n\x13\x42ytesPerSecondLimit\x18\x05 \x01(\x04\x12 \n\x18\x44ownloadBufferBytesLimit\x18\x06 \x01(\x04\x12\x1d\n\x15RequestTimeoutSeconds\x18\x07 \x01(\x04\x12\x1b\n\x13LowSpeedTimeSeconds\x18\x08 \x01(\x04\x12\x1a\n\x12LowSpeedBytesLimit\x18\t \x01(\x04\"\xab\x01\n\x10TYtClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x07YTToken\x18\x04 \x01(\t\x12\x0e\n\x06YTName\x18\x05 \x01(\t\x12 \n\x12\x45nabledYtQlQueries\x18\x06 \x01(\x08:\x04true\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\x91\x04\n\x10TYtGatewayConfig\x12\x19\n\x0eGatewayThreads\x18\x01 \x01(\r:\x01\x30\x12/\n\nYtLogLevel\x18\x02 \x01(\x0e\x32\x11.NYql.EYtLogLevel:\x08YL_ERROR\x12\x15\n\rPerfToolsPath\x18\x04 \x01(\t\x12\x1c\n\x14PerfToolsFromPackage\x18\x05 \x01(\x08\x12\x10\n\x08MrJobBin\x18\x06 \x01(\t\x12\x13\n\x0bMrJobBinMd5\x18\r \x01(\t\x12\x14\n\x0cMrJobUdfsDir\x18\x07 \x01(\t\x12#\n\x1b\x45xecuteUdfLocallyIfPossible\x18\x08 \x01(\x08\x12\x1d\n\x0eLocalChainTest\x18\t \x01(\x08:\x05\x66\x61lse\x12\x16\n\x0eYtDebugLogFile\x18\n \x01(\t\x12\x19\n\x0eYtDebugLogSize\x18\x0b \x01(\x04:\x01\x30\x12$\n\x15YtDebugLogAlwaysWrite\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\x16\n\x0eLocalChainFile\x18\x0e \x01(\t\x12\x34\n\x12RemoteFilePatterns\x18\x64 \x03(\x0b\x32\x18.NYql.TRemoteFilePattern\x12.\n\x0e\x43lusterMapping\x18\x65 \x03(\x0b\x32\x16.NYql.TYtClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x66 \x03(\x0b\x32\x0b.NYql.TAttr\"K\n\x13TYtOrmClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x15\n\x07\x45nabled\x18\x03 \x01(\x08:\x04true\"H\n\x13TYtOrmGatewayConfig\x12\x31\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x19.NYql.TYtOrmClusterConfig\"?\n\tTHostPort\x12\x0c\n\x04Host\x18\x01 \x02(\t\x12\x0c\n\x04Port\x18\x02 \x02(\r\x12\x16\n\x0eTotalTimeoutMs\x18\x03 \x01(\x04\"\x9f\x01\n\x0fTKikimrGrpcData\x12\x10\n\x08Locators\x18\x01 \x03(\t\x12\x11\n\tTimeoutMs\x18\x02 \x01(\x04\x12\x1b\n\x13MaxMessageSizeBytes\x18\x03 \x01(\x04\x12\x13\n\x0bMaxInFlight\x18\x04 \x01(\r\x12\x1f\n\x17\x45nableEndpointDiscovery\x18\x05 \x01(\x08\x12\x14\n\x0cUseLegacyApi\x18\x06 \x01(\x08\"\xb4\x02\n\x14TKikimrClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x02 \x01(\x08:\x05\x66\x61lse\x12#\n\nMessageBus\x18\x03 \x03(\x0b\x32\x0f.NYql.THostPort\x12#\n\x04Grpc\x18\x04 \x01(\x0b\x32\x15.NYql.TKikimrGrpcData\x12\x10\n\x08\x44\x61tabase\x18\x05 \x01(\t\x12\x10\n\x05TvmId\x18\x06 \x01(\r:\x01\x30\x12\r\n\x05Token\x18\x07 \x01(\t\x12\x10\n\x08ProxyUrl\x18\x08 \x01(\t\x12\x10\n\x08Location\x18\t \x01(\t\x12\x11\n\tIsFromMvp\x18\n \x01(\x08\x12#\n\tTokenType\x18\x0b \x01(\x0e\x32\x10.NYql.ETokenType\x12\x1d\n\x08Settings\x18\x65 \x03(\x0b\x32\x0b.NYql.TAttr\"p\n\x14TKikimrGatewayConfig\x12\x32\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x1a.NYql.TKikimrClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x02 \x03(\x0b\x32\x0b.NYql.TAttr\"W\n\x15TKikimrMvpProxyConfig\x12\x0c\n\x04Host\x18\x01 \x01(\t\x12\x0c\n\x04Port\x18\x02 \x01(\r\x12\x10\n\x08\x42\x61sePath\x18\x03 \x01(\t\x12\x10\n\x05TvmId\x18\x04 \x01(\r:\x01\x30\"L\n\x17TKikimrMvpGatewayConfig\x12\x31\n\x0cProxyMapping\x18\x01 \x03(\x0b\x32\x1b.NYql.TKikimrMvpProxyConfig\"\x9d\x02\n\x11TYdbClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x10\n\x08\x45ndpoint\x18\x02 \x01(\t\x12\r\n\x05Token\x18\x03 \x01(\t\x12#\n\x04Grpc\x18\x04 \x01(\x0b\x32\x15.NYql.TKikimrGrpcData\x12\x10\n\x05TvmId\x18\x05 \x01(\r:\x01\x30\x12\x10\n\x08\x44\x61tabase\x18\x06 \x01(\t\x12\n\n\x02Id\x18\x07 \x01(\t\x12\x0e\n\x06Secure\x18\x08 \x01(\x08\x12\x18\n\x10ServiceAccountId\x18\t \x01(\t\x12!\n\x19ServiceAccountIdSignature\x18\n \x01(\t\x12\x18\n\x10\x41\x64\x64\x42\x65\x61rerToToken\x18\x0b \x01(\x08\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\x99\x01\n\x11TYdbGatewayConfig\x12/\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x17.NYql.TYdbClusterConfig\x12\x17\n\x0f\x44\x65\x66\x61ultEndpoint\x18\x02 \x01(\t\x12\x14\n\x0c\x44\x65\x66\x61ultToken\x18\x03 \x01(\t\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x04 \x03(\x0b\x32\x0b.NYql.TAttr\"\x9d\x03\n\x18TClickHouseClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x07\x43luster\x18\x03 \x01(\t\x12\x0f\n\x07\x43HToken\x18\x04 \x01(\t\x12\x1d\n\x08Settings\x18\x65 \x03(\x0b\x32\x0b.NYql.TAttr\x12%\n\nHostScheme\x18\x05 \x01(\x0e\x32\x11.NYql.EHostScheme\x12\x10\n\x08HostPort\x18\x06 \x01(\r\x12\x1a\n\x12\x43HTokenYavSecretId\x18\x07 \x01(\t\x12\x1b\n\x13\x43HTokenYavVersionId\x18\x08 \x01(\t\x12\x15\n\rCHTokenYavKey\x18\t \x01(\t\x12\x34\n\x06Runner\x18\n \x01(\x0b\x32$.NYql.NProto.TClickHouseRunnerConfig\x12\x1c\n\x0eNativeHostPort\x18\x0b \x01(\r:\x04\x39\x30\x30\x30\x12\x1b\n\x0cNativeSecure\x18\x0c \x01(\x08:\x05\x66\x61lse\x12\n\n\x02Id\x18\r \x01(\t\x12\x14\n\x0cGroupAllowed\x18\x0e \x03(\t\"x\n\x18TClickHouseGatewayConfig\x12\x36\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x1e.NYql.TClickHouseClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x02 \x03(\x0b\x32\x0b.NYql.TAttr\"[\n\x0fTYfArtifactLink\x12#\n\x04Type\x18\x01 \x01(\x0e\x32\x15.NYql.EYfArtifactType\x12\x0b\n\x03Url\x18\x02 \x01(\t\x12\x16\n\x0eTargetFilePath\x18\x03 \x01(\t\"k\n\x1bTRtmrOperationArtifactsInfo\x12&\n\x04Type\x18\x01 \x01(\x0e\x32\x18.NYql.ERtmrOperationType\x12$\n\x05Links\x18\x02 \x03(\x0b\x32\x15.NYql.TYfArtifactLink\"8\n\x13TRtmrPqConsumerInfo\x12\x0f\n\x07\x43luster\x18\x01 \x01(\t\x12\x10\n\x08\x43onsumer\x18\x02 \x01(\t\"\xf2\x03\n\x12TRtmrClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x02 \x01(\x08:\x05\x66\x61lse\x12\x0f\n\x07\x43luster\x18\x03 \x01(\t\x12\x12\n\nRemoteName\x18\x04 \x01(\t\x12\x11\n\tYfCluster\x18\x05 \x01(\t\x12\x13\n\x0bS3TokenPath\x18\x06 \x01(\t\x12\x17\n\x0fS3FileCachePath\x18\x07 \x01(\t\x12\x10\n\x05TvmId\x18\x08 \x01(\r:\x01\x30\x12\x15\n\rTvmSecretPath\x18\t \x01(\t\x12\r\n\x05Users\x18\n \x03(\t\x12 \n\x11UploadViaYfClient\x18\x0b \x01(\x08:\x05\x66\x61lse\x12\x15\n\rMdsTorrentUrl\x18\x0c \x01(\t\x12<\n\x11\x41rtifactOverrides\x18\r \x03(\x0b\x32!.NYql.TRtmrOperationArtifactsInfo\x12\x12\n\nPqConsumer\x18\x0e \x01(\t\x12\x34\n\x11PqConsumerMapping\x18\x0f \x03(\x0b\x32\x19.NYql.TRtmrPqConsumerInfo\x12\x17\n\x0fMaxPqPartitions\x18\x10 \x01(\r\x12\x1f\n\x17PreviewCollectTimeoutMs\x18\x11 \x01(\r\x12\x1d\n\x08Settings\x18\x65 \x03(\x0b\x32\x0b.NYql.TAttr\"\xd8\x02\n\x12TRtmrGatewayConfig\x12\x30\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x18.NYql.TRtmrClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x02 \x03(\x0b\x32\x0b.NYql.TAttr\x12\x15\n\rYqlRtmrDynLib\x18\x03 \x01(\t\x12\x1e\n\x0fUseFakeYfUpload\x18\x04 \x01(\x08:\x05\x66\x61lse\x12\x11\n\tArtifacts\x18\x05 \x03(\t\x12:\n\x0f\x43ommonArtifacts\x18\x06 \x03(\x0b\x32!.NYql.TRtmrOperationArtifactsInfo\x12\x1b\n\x0fMaxPqPartitions\x18\x07 \x01(\r:\x02\x31\x30\x12%\n\x17PreviewCollectTimeoutMs\x18\x08 \x01(\r:\x04\x32\x30\x30\x30\x12 \n\x11KeepActiveProcess\x18\t \x01(\x08:\x05\x66\x61lse\"\xba\x03\n\x10TPqClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12G\n\x0b\x43lusterType\x18\x02 \x01(\x0e\x32#.NYql.TPqClusterConfig.EClusterType:\rCT_PERS_QUEUE\x12\x10\n\x08\x45ndpoint\x18\x03 \x01(\t\x12\x1d\n\x15\x43onfigManagerEndpoint\x18\x04 \x01(\t\x12\r\n\x05Token\x18\x05 \x01(\t\x12\x17\n\x08\x44\x61tabase\x18\x06 \x01(\t:\x05/Root\x12\x10\n\x05TvmId\x18\x07 \x01(\r:\x01\x30\x12\x0e\n\x06UseSsl\x18\x08 \x01(\x08\x12\x18\n\x10ServiceAccountId\x18\t \x01(\t\x12!\n\x19ServiceAccountIdSignature\x18\n \x01(\t\x12\x18\n\x10\x41\x64\x64\x42\x65\x61rerToToken\x18\x0b \x01(\x08\x12\x12\n\nDatabaseId\x18\x0c \x01(\t\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"J\n\x0c\x45\x43lusterType\x12\x12\n\x0e\x43T_UNSPECIFIED\x10\x00\x12\x11\n\rCT_PERS_QUEUE\x10\x01\x12\x13\n\x0f\x43T_DATA_STREAMS\x10\x02\"~\n\x10TPqGatewayConfig\x12.\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x16.NYql.TPqClusterConfig\x12\x14\n\x0c\x44\x65\x66\x61ultToken\x18\x02 \x01(\t\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\x8f\x01\n\x12TStatClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x16\n\x07\x44\x65\x66\x61ult\x18\x03 \x01(\x08:\x05\x66\x61lse\x12\x11\n\tStatToken\x18\x04 \x01(\t\x12\x10\n\x08StatName\x18\x05 \x01(\t\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\x87\x01\n\x12TStatGatewayConfig\x12\x19\n\x0eGatewayThreads\x18\x01 \x01(\r:\x01\x30\x12\x30\n\x0e\x43lusterMapping\x18\x65 \x03(\x0b\x32\x18.NYql.TStatClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x66 \x03(\x0b\x32\x0b.NYql.TAttr\"5\n\x12TChytClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x11\n\tYtCluster\x18\x02 \x01(\t\"F\n\x12TChytGatewayConfig\x12\x30\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x18.NYql.TChytClusterConfig\"\x98\x01\n\x10TS3ClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0b\n\x03Url\x18\x02 \x01(\t\x12\r\n\x05Token\x18\x03 \x01(\t\x12\x18\n\x10ServiceAccountId\x18\x04 \x01(\t\x12!\n\x19ServiceAccountIdSignature\x18\x05 \x01(\t\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"9\n\x12TS3FormatSizeLimit\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x15\n\rFileSizeLimit\x18\x02 \x01(\x04\"\xae\x02\n\x10TS3GatewayConfig\x12.\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x16.NYql.TS3ClusterConfig\x12\x15\n\rFileSizeLimit\x18\x02 \x01(\x04\x12\x31\n\x0f\x46ormatSizeLimit\x18\x06 \x03(\x0b\x32\x18.NYql.TS3FormatSizeLimit\x12\x18\n\x10MaxFilesPerQuery\x18\x03 \x01(\x04\x12\x1b\n\x13MaxReadSizePerQuery\x18\x04 \x01(\x04\x12!\n\x19MaxDiscoveryFilesPerQuery\x18\x05 \x01(\x04\x12 \n\x18MaxInflightListsPerQuery\x18\x07 \x01(\x04\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\"\xbb\x03\n\x15TSolomonClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x0e\n\x06UseSsl\x18\x03 \x01(\x08\x12Q\n\x0b\x43lusterType\x18\x04 \x01(\x0e\x32/.NYql.TSolomonClusterConfig.ESolomonClusterType:\x0bSCT_SOLOMON\x12\r\n\x05Token\x18\x05 \x01(\t\x12\x18\n\x10ServiceAccountId\x18\x06 \x01(\t\x12!\n\x19ServiceAccountIdSignature\x18\x07 \x01(\t\x12\x34\n\x04Path\x18\x08 \x01(\x0b\x32&.NYql.TSolomonClusterConfig.TShardPath\x12\x1d\n\x08Settings\x18\x64 \x03(\x0b\x32\x0b.NYql.TAttr\x1a.\n\nTShardPath\x12\x0f\n\x07Project\x18\x01 \x02(\t\x12\x0f\n\x07\x43luster\x18\x02 \x02(\t\"O\n\x13\x45SolomonClusterType\x12\x13\n\x0fSCT_UNSPECIFIED\x10\x00\x12\x0f\n\x0bSCT_SOLOMON\x10\x01\x12\x12\n\x0eSCT_MONITORING\x10\x02\"r\n\x15TSolomonGatewayConfig\x12\x33\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x1b.NYql.TSolomonClusterConfig\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x02 \x03(\x0b\x32\x0b.NYql.TAttr\"\xe3\x02\n\x1cTFileStorageAdditionalConfig\x12\x43\n\x0b\x41llowedUrls\x18\x02 \x03(\x0b\x32..NYql.TFileStorageAdditionalConfig.TUrlPattern\x12K\n\x13\x45xternalAllowedUrls\x18\x03 \x03(\x0b\x32..NYql.TFileStorageAdditionalConfig.TUrlPattern\x12J\n\rCustomSchemes\x18\x04 \x03(\x0b\x32\x33.NYql.TFileStorageAdditionalConfig.TSchemeTranslate\x1a-\n\x0bTUrlPattern\x12\x0f\n\x07Pattern\x18\x01 \x02(\t\x12\r\n\x05\x41lias\x18\x02 \x01(\t\x1a\x36\n\x10TSchemeTranslate\x12\x0f\n\x07Pattern\x18\x01 \x02(\t\x12\x11\n\tTargetUrl\x18\x02 \x02(\t\"d\n\x18TPostgresqlClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x0f\n\x07PGtoken\x18\x03 \x01(\t\x12\x18\n\x10TargetServerType\x18\x04 \x01(\t\"R\n\x18TPostgresqlGatewayConfig\x12\x36\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x1e.NYql.TPostgresqlClusterConfig\"H\n\x13TMysqlClusterConfig\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x43luster\x18\x02 \x01(\t\x12\x12\n\nMysqlToken\x18\x03 \x01(\t\"H\n\x13TMysqlGatewayConfig\x12\x31\n\x0e\x43lusterMapping\x18\x01 \x03(\x0b\x32\x19.NYql.TMysqlClusterConfig\"\xda\x03\n\x10TDqGatewayConfig\x12 \n\x15\x44\x65\x66\x61ultAutoPercentage\x18\x01 \x01(\r:\x01\x30\x12N\n\x11\x44\x65\x66\x61ultAutoByHour\x18\x02 \x03(\x0b\x32\x33.NYql.TDqGatewayConfig.TDefaultAutoByHourPercentage\x12\x1d\n\x15NoDefaultAutoForUsers\x18\x03 \x03(\t\x12#\n\x1b\x44\x65\x66\x61ultAnalyzeQueryForUsers\x18\x04 \x03(\t\x12$\n\x0f\x44\x65\x66\x61ultSettings\x18\x66 \x03(\x0b\x32\x0b.NYql.TAttr\x12\x1f\n\x14WithHiddenPercentage\x18\x05 \x01(\r:\x01\x30\x12M\n\x10WithHiddenByHour\x18\x06 \x03(\x0b\x32\x33.NYql.TDqGatewayConfig.TDefaultAutoByHourPercentage\x12\x1c\n\x14NoWithHiddenForUsers\x18\x07 \x03(\t\x12\x1a\n\x12WithHiddenForUsers\x18\x08 \x03(\t\x1a@\n\x1cTDefaultAutoByHourPercentage\x12\x0c\n\x04Hour\x18\x01 \x02(\r\x12\x12\n\nPercentage\x18\x02 \x02(\r\"X\n\tTCoreAttr\x12\x0c\n\x04Name\x18\x01 \x02(\t\x12\x0c\n\x04\x41rgs\x18\x02 \x03(\t\x12/\n\nActivation\x18\x03 \x01(\x0b\x32\x1b.NYql.TActivationPercentage\"0\n\x0eTYqlCoreConfig\x12\x1e\n\x05\x46lags\x18\x01 \x03(\x0b\x32\x0f.NYql.TCoreAttr\"@\n\x1cTWarnAsErrorByHourPercentage\x12\x0c\n\x04Hour\x18\x01 \x02(\r\x12\x12\n\nPercentage\x18\x02 \x02(\r\"\xbc\x01\n\x0eTSqlCoreConfig\x12(\n\x1dV0SyntaxWarnAsErrorPercentage\x18\x01 \x01(\r:\x01\x30\x12\x45\n\x19V0SyntaxWarnAsErrorByHour\x18\x02 \x03(\x0b\x32\".NYql.TWarnAsErrorByHourPercentage\x12\x1f\n\x17NoV0SyntaxErrorForUsers\x18\x03 \x03(\t\x12\x18\n\x10TranslationFlags\x18\x04 \x03(\t\"\xb4\x06\n\x0fTGatewaysConfig\x12\"\n\x02Yt\x18\x01 \x01(\x0b\x32\x16.NYql.TYtGatewayConfig\x12*\n\x06Kikimr\x18\x02 \x01(\x0b\x32\x1a.NYql.TKikimrGatewayConfig\x12\x32\n\nClickHouse\x18\x03 \x01(\x0b\x32\x1e.NYql.TClickHouseGatewayConfig\x12&\n\x04Rtmr\x18\x04 \x01(\x0b\x32\x18.NYql.TRtmrGatewayConfig\x12\x30\n\tKikimrMvp\x18\x05 \x01(\x0b\x32\x1d.NYql.TKikimrMvpGatewayConfig\x12&\n\x04Stat\x18\x06 \x01(\x0b\x32\x18.NYql.TStatGatewayConfig\x12&\n\x04\x43hyt\x18\x07 \x01(\x0b\x32\x18.NYql.TChytGatewayConfig\x12,\n\x07Solomon\x18\x08 \x01(\x0b\x32\x1b.NYql.TSolomonGatewayConfig\x12.\n\x02\x46s\x18\t \x01(\x0b\x32\".NYql.TFileStorageAdditionalConfig\x12%\n\x07YqlCore\x18\n \x01(\x0b\x32\x14.NYql.TYqlCoreConfig\x12\x32\n\nPostgresql\x18\x0b \x01(\x0b\x32\x1e.NYql.TPostgresqlGatewayConfig\x12%\n\x07SqlCore\x18\x0c \x01(\x0b\x32\x14.NYql.TSqlCoreConfig\x12\"\n\x02\x44q\x18\r \x01(\x0b\x32\x16.NYql.TDqGatewayConfig\x12(\n\x05Mysql\x18\x0e \x01(\x0b\x32\x19.NYql.TMysqlGatewayConfig\x12$\n\x03Ydb\x18\x0f \x01(\x0b\x32\x17.NYql.TYdbGatewayConfig\x12\"\n\x02Pq\x18\x10 \x01(\x0b\x32\x16.NYql.TPqGatewayConfig\x12\"\n\x02S3\x18\x11 \x01(\x0b\x32\x16.NYql.TS3GatewayConfig\x12-\n\x0bHttpGateway\x18\x12 \x01(\x0b\x32\x18.NYql.THttpGatewayConfig\x12(\n\x05YtOrm\x18\x13 \x01(\x0b\x32\x19.NYql.TYtOrmGatewayConfig*Z\n\x0b\x45YtLogLevel\x12\x14\n\x07YL_NONE\x10\xff\xff\xff\xff\xff\xff\xff\xff\xff\x01\x12\x0c\n\x08YL_FATAL\x10\x00\x12\x0c\n\x08YL_ERROR\x10\x01\x12\x0b\n\x07YL_INFO\x10\x02\x12\x0c\n\x08YL_DEBUG\x10\x03*(\n\x0b\x45HostScheme\x12\x0b\n\x07HS_HTTP\x10\x00\x12\x0c\n\x08HS_HTTPS\x10\x01*?\n\nETokenType\x12\x07\n\x03IAM\x10\x00\x12\t\n\x05OAUTH\x10\x01\x12\x0c\n\x08\x42LACKBOX\x10\x02\x12\x0f\n\x0b\x43REDENTIALS\x10\x03*9\n\x0f\x45YfArtifactType\x12\x0b\n\x07\x41T_NONE\x10\x00\x12\x0b\n\x07\x41T_FILE\x10\x01\x12\x0c\n\x08\x41T_LAYER\x10\x02*e\n\x12\x45RtmrOperationType\x12\x0b\n\x07OT_NONE\x10\x00\x12\x0f\n\x0bOT_LF_PARSE\x10\x01\x12\x0e\n\nOT_YDB_OUT\x10\x02\x12\x12\n\x0eOT_SOLOMON_OUT\x10\x03\x12\r\n\tOT_PQ_OUT\x10\x04\x42\x15\n\x13ru.yandex.yql.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.providers.common.proto.gateways_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\023ru.yandex.yql.proto'
  _EYTLOGLEVEL._serialized_start=9008
  _EYTLOGLEVEL._serialized_end=9098
  _EHOSTSCHEME._serialized_start=9100
  _EHOSTSCHEME._serialized_end=9140
  _ETOKENTYPE._serialized_start=9142
  _ETOKENTYPE._serialized_end=9205
  _EYFARTIFACTTYPE._serialized_start=9207
  _EYFARTIFACTTYPE._serialized_end=9264
  _ERTMROPERATIONTYPE._serialized_start=9266
  _ERTMROPERATIONTYPE._serialized_end=9367
  _TACTIVATIONBYHOUR._serialized_start=111
  _TACTIVATIONBYHOUR._serialized_end=164
  _TACTIVATIONPERCENTAGE._serialized_start=167
  _TACTIVATIONPERCENTAGE._serialized_end=327
  _TATTR._serialized_start=329
  _TATTR._serialized_end=414
  _TREMOTEFILEPATTERN._serialized_start=416
  _TREMOTEFILEPATTERN._serialized_end=484
  _THTTPGATEWAYCONFIG._serialized_start=487
  _THTTPGATEWAYCONFIG._serialized_end=786
  _TYTCLUSTERCONFIG._serialized_start=789
  _TYTCLUSTERCONFIG._serialized_end=960
  _TYTGATEWAYCONFIG._serialized_start=963
  _TYTGATEWAYCONFIG._serialized_end=1492
  _TYTORMCLUSTERCONFIG._serialized_start=1494
  _TYTORMCLUSTERCONFIG._serialized_end=1569
  _TYTORMGATEWAYCONFIG._serialized_start=1571
  _TYTORMGATEWAYCONFIG._serialized_end=1643
  _THOSTPORT._serialized_start=1645
  _THOSTPORT._serialized_end=1708
  _TKIKIMRGRPCDATA._serialized_start=1711
  _TKIKIMRGRPCDATA._serialized_end=1870
  _TKIKIMRCLUSTERCONFIG._serialized_start=1873
  _TKIKIMRCLUSTERCONFIG._serialized_end=2181
  _TKIKIMRGATEWAYCONFIG._serialized_start=2183
  _TKIKIMRGATEWAYCONFIG._serialized_end=2295
  _TKIKIMRMVPPROXYCONFIG._serialized_start=2297
  _TKIKIMRMVPPROXYCONFIG._serialized_end=2384
  _TKIKIMRMVPGATEWAYCONFIG._serialized_start=2386
  _TKIKIMRMVPGATEWAYCONFIG._serialized_end=2462
  _TYDBCLUSTERCONFIG._serialized_start=2465
  _TYDBCLUSTERCONFIG._serialized_end=2750
  _TYDBGATEWAYCONFIG._serialized_start=2753
  _TYDBGATEWAYCONFIG._serialized_end=2906
  _TCLICKHOUSECLUSTERCONFIG._serialized_start=2909
  _TCLICKHOUSECLUSTERCONFIG._serialized_end=3322
  _TCLICKHOUSEGATEWAYCONFIG._serialized_start=3324
  _TCLICKHOUSEGATEWAYCONFIG._serialized_end=3444
  _TYFARTIFACTLINK._serialized_start=3446
  _TYFARTIFACTLINK._serialized_end=3537
  _TRTMROPERATIONARTIFACTSINFO._serialized_start=3539
  _TRTMROPERATIONARTIFACTSINFO._serialized_end=3646
  _TRTMRPQCONSUMERINFO._serialized_start=3648
  _TRTMRPQCONSUMERINFO._serialized_end=3704
  _TRTMRCLUSTERCONFIG._serialized_start=3707
  _TRTMRCLUSTERCONFIG._serialized_end=4205
  _TRTMRGATEWAYCONFIG._serialized_start=4208
  _TRTMRGATEWAYCONFIG._serialized_end=4552
  _TPQCLUSTERCONFIG._serialized_start=4555
  _TPQCLUSTERCONFIG._serialized_end=4997
  _TPQCLUSTERCONFIG_ECLUSTERTYPE._serialized_start=4923
  _TPQCLUSTERCONFIG_ECLUSTERTYPE._serialized_end=4997
  _TPQGATEWAYCONFIG._serialized_start=4999
  _TPQGATEWAYCONFIG._serialized_end=5125
  _TSTATCLUSTERCONFIG._serialized_start=5128
  _TSTATCLUSTERCONFIG._serialized_end=5271
  _TSTATGATEWAYCONFIG._serialized_start=5274
  _TSTATGATEWAYCONFIG._serialized_end=5409
  _TCHYTCLUSTERCONFIG._serialized_start=5411
  _TCHYTCLUSTERCONFIG._serialized_end=5464
  _TCHYTGATEWAYCONFIG._serialized_start=5466
  _TCHYTGATEWAYCONFIG._serialized_end=5536
  _TS3CLUSTERCONFIG._serialized_start=5539
  _TS3CLUSTERCONFIG._serialized_end=5691
  _TS3FORMATSIZELIMIT._serialized_start=5693
  _TS3FORMATSIZELIMIT._serialized_end=5750
  _TS3GATEWAYCONFIG._serialized_start=5753
  _TS3GATEWAYCONFIG._serialized_end=6055
  _TSOLOMONCLUSTERCONFIG._serialized_start=6058
  _TSOLOMONCLUSTERCONFIG._serialized_end=6501
  _TSOLOMONCLUSTERCONFIG_TSHARDPATH._serialized_start=6374
  _TSOLOMONCLUSTERCONFIG_TSHARDPATH._serialized_end=6420
  _TSOLOMONCLUSTERCONFIG_ESOLOMONCLUSTERTYPE._serialized_start=6422
  _TSOLOMONCLUSTERCONFIG_ESOLOMONCLUSTERTYPE._serialized_end=6501
  _TSOLOMONGATEWAYCONFIG._serialized_start=6503
  _TSOLOMONGATEWAYCONFIG._serialized_end=6617
  _TFILESTORAGEADDITIONALCONFIG._serialized_start=6620
  _TFILESTORAGEADDITIONALCONFIG._serialized_end=6975
  _TFILESTORAGEADDITIONALCONFIG_TURLPATTERN._serialized_start=6874
  _TFILESTORAGEADDITIONALCONFIG_TURLPATTERN._serialized_end=6919
  _TFILESTORAGEADDITIONALCONFIG_TSCHEMETRANSLATE._serialized_start=6921
  _TFILESTORAGEADDITIONALCONFIG_TSCHEMETRANSLATE._serialized_end=6975
  _TPOSTGRESQLCLUSTERCONFIG._serialized_start=6977
  _TPOSTGRESQLCLUSTERCONFIG._serialized_end=7077
  _TPOSTGRESQLGATEWAYCONFIG._serialized_start=7079
  _TPOSTGRESQLGATEWAYCONFIG._serialized_end=7161
  _TMYSQLCLUSTERCONFIG._serialized_start=7163
  _TMYSQLCLUSTERCONFIG._serialized_end=7235
  _TMYSQLGATEWAYCONFIG._serialized_start=7237
  _TMYSQLGATEWAYCONFIG._serialized_end=7309
  _TDQGATEWAYCONFIG._serialized_start=7312
  _TDQGATEWAYCONFIG._serialized_end=7786
  _TDQGATEWAYCONFIG_TDEFAULTAUTOBYHOURPERCENTAGE._serialized_start=7722
  _TDQGATEWAYCONFIG_TDEFAULTAUTOBYHOURPERCENTAGE._serialized_end=7786
  _TCOREATTR._serialized_start=7788
  _TCOREATTR._serialized_end=7876
  _TYQLCORECONFIG._serialized_start=7878
  _TYQLCORECONFIG._serialized_end=7926
  _TWARNASERRORBYHOURPERCENTAGE._serialized_start=7928
  _TWARNASERRORBYHOURPERCENTAGE._serialized_end=7992
  _TSQLCORECONFIG._serialized_start=7995
  _TSQLCORECONFIG._serialized_end=8183
  _TGATEWAYSCONFIG._serialized_start=8186
  _TGATEWAYSCONFIG._serialized_end=9006
# @@protoc_insertion_point(module_scope)
