# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/tx_scheme.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import base_pb2 as ydb_dot_core_dot_protos_dot_base__pb2
from ydb.core.protos import bind_channel_storage_pool_pb2 as ydb_dot_core_dot_protos_dot_bind__channel__storage__pool__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fydb/core/protos/tx_scheme.proto\x12\x0fNKikimrTxScheme\x1a&library/cpp/actors/protos/actors.proto\x1a\x1aydb/core/protos/base.proto\x1a/ydb/core/protos/bind_channel_storage_pool.proto\"1\n\rTSchemeConfig\x12 \n\x18PipeClientCachePoolLimit\x18\x01 \x01(\x04\"|\n\x07TConfig\x12/\n\x07\x43urrent\x18\x01 \x01(\x0b\x32\x1e.NKikimrTxScheme.TSchemeConfig\x12@\n\x18\x44\x65\x66\x61ultSchemeShardConfig\x18\x03 \x01(\x0b\x32\x1e.NKikimrTxScheme.TSchemeConfig\"\x8f\x01\n\x11TEvNavigateScheme\x12\x0c\n\x04Path\x18\x01 \x01(\x0c\x12\x10\n\x08TextPath\x18\x02 \x01(\x0c\x12\x1e\n\x16ReadMaterializedFamily\x18\x03 \x01(\r\x12\x1a\n\x0cShowFamilies\x18\x04 \x01(\x08:\x04true\x12\x1e\n\x10ShowChildrenTags\x18\x05 \x01(\x08:\x04true\"\xbb\x01\n\x15TEvNavigateSchemePart\x12\x0c\n\x04Path\x18\x01 \x01(\x0c\x12\x10\n\x08TextPath\x18\x02 \x01(\x0c\x12\x1e\n\x16ReadMaterializedFamily\x18\x03 \x01(\r\x12&\n\x06Source\x18\x04 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x1a\n\x0cShowFamilies\x18\x05 \x01(\x08:\x04true\x12\x1e\n\x10ShowChildrenTags\x18\x06 \x01(\x08:\x04true\"h\n\x1bTEvNavigateSchemePartResult\x12\x0e\n\x06Status\x18\x01 \x01(\r\x12\x0f\n\x07ShardId\x18\x02 \x01(\x04\x12\x14\n\x0cSchemePrefix\x18\x03 \x01(\x0c\x12\x12\n\nSchemePart\x18\x04 \x01(\x0c\"\xd1\x01\n\x10TEvInitRootShard\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0f\n\x07RootTag\x18\x02 \x01(\r\x12\x13\n\x0bRootTagName\x18\x03 \x01(\x0c\x12(\n\x06\x43onfig\x18\x04 \x01(\x0b\x32\x18.NKikimrTxScheme.TConfig\x12\r\n\x05Owner\x18\x05 \x01(\t\x12\x36\n\x0cStoragePools\x18\x06 \x03(\x0b\x32 .NKikimrStoragePool.TStoragePool\"8\n\x16TEvInitRootShardResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12\x0e\n\x06Status\x18\x02 \x01(\r\"c\n\x0fTEvUpdateConfig\x12&\n\x06Source\x18\x01 \x01(\x0b\x32\x16.NActorsProto.TActorId\x12(\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x18.NKikimrTxScheme.TConfig\"c\n\x15TEvUpdateConfigResult\x12\x0e\n\x06Origin\x18\x01 \x01(\x04\x12*\n\x06Status\x18\x02 \x01(\x0e\x32\x1a.NKikimrProto.EReplyStatus\x12\x0e\n\x06Reason\x18\x03 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.tx_scheme_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSCHEMECONFIG._serialized_start=169
  _TSCHEMECONFIG._serialized_end=218
  _TCONFIG._serialized_start=220
  _TCONFIG._serialized_end=344
  _TEVNAVIGATESCHEME._serialized_start=347
  _TEVNAVIGATESCHEME._serialized_end=490
  _TEVNAVIGATESCHEMEPART._serialized_start=493
  _TEVNAVIGATESCHEMEPART._serialized_end=680
  _TEVNAVIGATESCHEMEPARTRESULT._serialized_start=682
  _TEVNAVIGATESCHEMEPARTRESULT._serialized_end=786
  _TEVINITROOTSHARD._serialized_start=789
  _TEVINITROOTSHARD._serialized_end=998
  _TEVINITROOTSHARDRESULT._serialized_start=1000
  _TEVINITROOTSHARDRESULT._serialized_end=1056
  _TEVUPDATECONFIG._serialized_start=1058
  _TEVUPDATECONFIG._serialized_end=1157
  _TEVUPDATECONFIGRESULT._serialized_start=1159
  _TEVUPDATECONFIGRESULT._serialized_end=1258
# @@protoc_insertion_point(module_scope)
