# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/yq/libs/config/protos/checkpoint_coordinator.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.yq.libs.config.protos import storage_pb2 as ydb_dot_core_dot_yq_dot_libs_dot_config_dot_protos_dot_storage__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;ydb/core/yq/libs/config/protos/checkpoint_coordinator.proto\x12\x0bNYq.NConfig\x1a,ydb/core/yq/libs/config/protos/storage.proto\"`\n\x19TStateStorageLimitsConfig\x12$\n\x1cMaxGraphCheckpointsSizeBytes\x18\x01 \x01(\x04\x12\x1d\n\x15MaxTaskStateSizeBytes\x18\x02 \x01(\x04\"&\n\x13TCheckpointGcConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\"\x9f\x02\n\x1cTCheckpointCoordinatorConfig\x12\x0f\n\x07\x45nabled\x18\x01 \x01(\x08\x12/\n\x07Storage\x18\x02 \x01(\x0b\x32\x1e.NYq.NConfig.TYdbStorageConfig\x12\x41\n\x17\x43heckpointGarbageConfig\x18\x03 \x01(\x0b\x32 .NYq.NConfig.TCheckpointGcConfig\x12\x42\n\x12StateStorageLimits\x18\x04 \x01(\x0b\x32&.NYq.NConfig.TStateStorageLimitsConfig\x12!\n\x19\x43heckpointingPeriodMillis\x18\x05 \x01(\x04\x12\x13\n\x0bMaxInflight\x18\x06 \x01(\x04\x42\x1b\n\x16ru.yandex.kikimr.proto\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.yq.libs.config.protos.checkpoint_coordinator_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\370\001\001'
  _TSTATESTORAGELIMITSCONFIG._serialized_start=122
  _TSTATESTORAGELIMITSCONFIG._serialized_end=218
  _TCHECKPOINTGCCONFIG._serialized_start=220
  _TCHECKPOINTGCCONFIG._serialized_end=258
  _TCHECKPOINTCOORDINATORCONFIG._serialized_start=261
  _TCHECKPOINTCOORDINATORCONFIG._serialized_end=548
# @@protoc_insertion_point(module_scope)
