# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/library/yql/public/issue/protos/issue_severity.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8ydb/library/yql/public/issue/protos/issue_severity.proto\x12\x04NYql\"R\n\x0cTSeverityIds\"B\n\x0b\x45SeverityId\x12\x0b\n\x07S_FATAL\x10\x00\x12\x0b\n\x07S_ERROR\x10\x01\x12\r\n\tS_WARNING\x10\x02\x12\n\n\x06S_INFO\x10\x03\x42\x16\n\x14\x63om.yandex.yql.protob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.library.yql.public.issue.protos.issue_severity_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024com.yandex.yql.proto'
  _TSEVERITYIDS._serialized_start=66
  _TSEVERITYIDS._serialized_end=148
  _TSEVERITYIDS_ESEVERITYID._serialized_start=82
  _TSEVERITYIDS_ESEVERITYID._serialized_end=148
# @@protoc_insertion_point(module_scope)
