# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/public/api/protos/yq.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.public.api.protos.annotations import sensitive_pb2 as ydb_dot_public_dot_api_dot_protos_dot_annotations_dot_sensitive__pb2
from ydb.public.api.protos.annotations import validation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_annotations_dot_validation__pb2
from ydb.public.api.protos import ydb_operation_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__operation__pb2
from ydb.public.api.protos import ydb_value_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__value__pb2
from ydb.public.api.protos import ydb_issue_message_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__issue__message__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/public/api/protos/yq.proto\x12\x0bYandexQuery\x1a\x31ydb/public/api/protos/annotations/sensitive.proto\x1a\x32ydb/public/api/protos/annotations/validation.proto\x1a)ydb/public/api/protos/ydb_operation.proto\x1a%ydb/public/api/protos/ydb_value.proto\x1a-ydb/public/api/protos/ydb_issue_message.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\"x\n\x03\x41\x63l\x12/\n\nvisibility\x18\x01 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\"@\n\nVisibility\x12\x1a\n\x16VISIBILITY_UNSPECIFIED\x10\x00\x12\x0b\n\x07PRIVATE\x10\x01\x12\t\n\x05SCOPE\x10\x02\"\x83\x03\n\x06Limits\x12!\n\x0fvcpu_rate_limit\x18\x01 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0f\x66low_rate_limit\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fvcpu_time_limit\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fmax_result_size\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12!\n\x0fmax_result_rows\x18\x05 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1e\n\x0cmemory_limit\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12-\n\nresult_ttl\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x36\n\x11\x65xecution_timeout\x18\x08 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00\x12\x38\n\x12\x65xecution_deadline\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x42\t\n\x07timeout\"\xe6\x03\n\x14StreamingDisposition\x12(\n\x06oldest\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12\'\n\x05\x66resh\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00\x12?\n\tfrom_time\x18\x03 \x01(\x0b\x32*.YandexQuery.StreamingDisposition.FromTimeH\x00\x12=\n\x08time_ago\x18\x04 \x01(\x0b\x32).YandexQuery.StreamingDisposition.TimeAgoH\x00\x12T\n\x14\x66rom_last_checkpoint\x18\x05 \x01(\x0b\x32\x34.YandexQuery.StreamingDisposition.FromLastCheckpointH\x00\x1a\x39\n\x08\x46romTime\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x36\n\x07TimeAgo\x12+\n\x08\x64uration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x1a#\n\x12\x46romLastCheckpoint\x12\r\n\x05\x66orce\x18\x01 \x01(\x08\x42\r\n\x0b\x64isposition\"\xc1\x04\n\x0cQueryContent\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.YandexQuery.QueryContent.QueryType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1d\n\x03\x61\x63l\x18\x03 \x01(\x0b\x32\x10.YandexQuery.Acl\x12#\n\x06limits\x18\x04 \x01(\x0b\x32\x13.YandexQuery.Limits\x12\x16\n\x04text\x18\x05 \x01(\tB\x08\xa2\xe6*\x04\x18\x80\xa0\x06\x12\x11\n\tautomatic\x18\x06 \x01(\x08\x12\x1c\n\x0b\x64\x65scription\x18\x07 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\x12\x61\n\x12\x65xecution_settings\x18\n \x03(\x0b\x32\x30.YandexQuery.QueryContent.ExecutionSettingsEntryB\x13\xaa\xe6*\x08\n\x06\n\x04\x08\x01\x10\x64\xa2\xe6*\x03\x18\x80 \x12\x35\n\x06syntax\x18\x0b \x01(\x0e\x32%.YandexQuery.QueryContent.QuerySyntax\x1a\x38\n\x16\x45xecutionSettingsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"E\n\tQueryType\x12\x1a\n\x16QUERY_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tANALYTICS\x10\x01\x12\r\n\tSTREAMING\x10\x02\"?\n\x0bQuerySyntax\x12\x1c\n\x18QUERY_SYNTAX_UNSPECIFIED\x10\x00\x12\n\n\x06YQL_V1\x10\x01\x12\x06\n\x02PG\x10\x02\"\xe5\x01\n\nCommonMeta\x12\x17\n\x02id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x1f\n\ncreated_by\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12 \n\x0bmodified_by\x18\x03 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0bmodified_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1a\n\x08revision\x18\x06 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\xb6\x06\n\tQueryMeta\x12\'\n\x06\x63ommon\x18\x01 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\x12\x30\n\x0csubmitted_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\x0c\x65xecute_mode\x18\x04 \x01(\x0e\x32\x18.YandexQuery.ExecuteMode\x12\x34\n\x06status\x18\x05 \x01(\x0e\x32$.YandexQuery.QueryMeta.ComputeStatus\x12\x1f\n\x17last_job_query_revision\x18\x06 \x01(\x03\x12\x13\n\x0blast_job_id\x18\x07 \x01(\t\x12-\n\texpire_at\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x34\n\x10result_expire_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nstarted_by\x18\n \x01(\t\x12\x14\n\naborted_by\x18\x0b \x01(\tH\x00\x12\x13\n\tpaused_by\x18\x0c \x01(\tH\x00\x12\x1d\n\x15has_saved_checkpoints\x18\r \x01(\x08\"\x83\x02\n\rComputeStatus\x12\x1e\n\x1a\x43OMPUTE_STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08STARTING\x10\x01\x12\x13\n\x0f\x41\x42ORTED_BY_USER\x10\x02\x12\x15\n\x11\x41\x42ORTED_BY_SYSTEM\x10\x03\x12\x14\n\x10\x41\x42ORTING_BY_USER\x10\x04\x12\x16\n\x12\x41\x42ORTING_BY_SYSTEM\x10\x05\x12\x0c\n\x08RESUMING\x10\x06\x12\x0b\n\x07RUNNING\x10\x07\x12\r\n\tCOMPLETED\x10\x08\x12\x0e\n\nCOMPLETING\x10\x0c\x12\n\n\x06\x46\x41ILED\x10\t\x12\x0b\n\x07\x46\x41ILING\x10\r\x12\n\n\x06PAUSED\x10\x0b\x12\x0b\n\x07PAUSING\x10\nB\x08\n\x06\x61\x63tion\"\xc0\x01\n\nBriefQuery\x12\x31\n\x04type\x18\x01 \x01(\x0e\x32#.YandexQuery.QueryContent.QueryType\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12$\n\x04meta\x18\x03 \x01(\x0b\x32\x16.YandexQuery.QueryMeta\x12/\n\nvisibility\x18\x04 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\x12\x11\n\tautomatic\x18\x05 \x01(\x08\"\x19\n\tQueryPlan\x12\x0c\n\x04json\x18\x01 \x01(\t\"\x18\n\x08QueryAst\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"]\n\rResultSetMeta\x12\x1b\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x0b.Ydb.Column\x12\x1c\n\nrows_count\x18\x02 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x11\n\ttruncated\x18\x03 \x01(\x08\"\xe4\x02\n\x05Query\x12$\n\x04meta\x18\x01 \x01(\x0b\x32\x16.YandexQuery.QueryMeta\x12*\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x19.YandexQuery.QueryContent\x12$\n\x04plan\x18\x03 \x01(\x0b\x32\x16.YandexQuery.QueryPlan\x12&\n\x05issue\x18\x04 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\x0ftransient_issue\x18\x05 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\nstatistics\x18\x06 \x01(\x0b\x32\x1c.YandexQuery.QueryStatistics\x12\x33\n\x0fresult_set_meta\x18\x07 \x03(\x0b\x32\x1a.YandexQuery.ResultSetMeta\x12\"\n\x03\x61st\x18\x08 \x01(\x0b\x32\x15.YandexQuery.QueryAst\"\x1f\n\x0fQueryStatistics\x12\x0c\n\x04json\x18\x01 \x01(\t\"\x85\x02\n\x12\x43reateQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12*\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x19.YandexQuery.QueryContent\x12.\n\x0c\x65xecute_mode\x18\x03 \x01(\x0e\x32\x18.YandexQuery.ExecuteMode\x12\x36\n\x0b\x64isposition\x18\x04 \x01(\x0b\x32!.YandexQuery.StreamingDisposition\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13\x43reateQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\".\n\x11\x43reateQueryResult\x12\x19\n\x08query_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\x81\x04\n\x12ListQueriesRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x36\n\x06\x66ilter\x18\x04 \x01(\x0b\x32&.YandexQuery.ListQueriesRequest.Filter\x1a\xbd\x02\n\x06\x46ilter\x12\x37\n\nquery_type\x18\x01 \x01(\x0e\x32#.YandexQuery.QueryContent.QueryType\x12<\n\x06status\x18\x02 \x03(\x0e\x32$.YandexQuery.QueryMeta.ComputeStatusB\x06\x9a\xe6*\x02\x18\x14\x12.\n\x04mode\x18\x03 \x03(\x0e\x32\x18.YandexQuery.ExecuteModeB\x06\x9a\xe6*\x02\x18\x14\x12\x15\n\x04name\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x05 \x01(\x08\x12/\n\nvisibility\x18\x06 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\x12-\n\tautomatic\x18\x07 \x01(\x0e\x32\x1a.YandexQuery.AutomaticType\"C\n\x13ListQueriesResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"]\n\x11ListQueriesResult\x12&\n\x05query\x18\x01 \x03(\x0b\x32\x17.YandexQuery.BriefQuery\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"p\n\x14\x44\x65scribeQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"E\n\x15\x44\x65scribeQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"8\n\x13\x44\x65scribeQueryResult\x12!\n\x05query\x18\x01 \x01(\x0b\x32\x12.YandexQuery.Query\"q\n\x15GetQueryStatusRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"F\n\x16GetQueryStatusResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"c\n\x14GetQueryStatusResult\x12\x34\n\x06status\x18\x01 \x01(\x0e\x32$.YandexQuery.QueryMeta.ComputeStatus\x12\x15\n\rmeta_revision\x18\x02 \x01(\x03\"\xb5\x01\n\x12\x44\x65leteQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13\x44\x65leteQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11\x44\x65leteQueryResult\"\xfe\x02\n\x12ModifyQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12*\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x19.YandexQuery.QueryContent\x12.\n\x0c\x65xecute_mode\x18\x04 \x01(\x0e\x32\x18.YandexQuery.ExecuteMode\x12\x36\n\x0b\x64isposition\x18\x05 \x01(\x0b\x32!.YandexQuery.StreamingDisposition\x12\x33\n\x0fstate_load_mode\x18\x06 \x01(\x0e\x32\x1a.YandexQuery.StateLoadMode\x12#\n\x11previous_revision\x18\x07 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x08 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"C\n\x13ModifyQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x13\n\x11ModifyQueryResult\"\xe0\x01\n\x13\x43ontrolQueryRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12(\n\x06\x61\x63tion\x18\x03 \x01(\x0e\x32\x18.YandexQuery.QueryAction\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"D\n\x14\x43ontrolQueryResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x14\n\x12\x43ontrolQueryResult\"\xe4\x01\n\x08\x42riefJob\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\x12*\n\nquery_meta\x18\x03 \x01(\x0b\x32\x16.YandexQuery.QueryMeta\x12\x12\n\nquery_name\x18\t \x01(\t\x12/\n\nvisibility\x18\n \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\x12\x11\n\tautomatic\x18\x0b \x01(\x08\x12-\n\texpire_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xeb\x03\n\x03Job\x12%\n\x04meta\x18\x01 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\x12\x0c\n\x04text\x18\x02 \x01(\t\x12*\n\nquery_meta\x18\x03 \x01(\x0b\x32\x16.YandexQuery.QueryMeta\x12$\n\x04plan\x18\x04 \x01(\x0b\x32\x16.YandexQuery.QueryPlan\x12&\n\x05issue\x18\x05 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x30\n\nstatistics\x18\x06 \x01(\x0b\x32\x1c.YandexQuery.QueryStatistics\x12\x33\n\x0fresult_set_meta\x18\x07 \x03(\x0b\x32\x1a.YandexQuery.ResultSetMeta\x12\"\n\x03\x61st\x18\x08 \x01(\x0b\x32\x15.YandexQuery.QueryAst\x12\x12\n\nquery_name\x18\t \x01(\t\x12\x1d\n\x03\x61\x63l\x18\n \x01(\x0b\x32\x10.YandexQuery.Acl\x12\x11\n\tautomatic\x18\x0b \x01(\x08\x12-\n\texpire_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x35\n\x06syntax\x18\r \x01(\x0e\x32%.YandexQuery.QueryContent.QuerySyntax\"\x89\x02\n\x0fListJobsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x10\n\x08query_id\x18\x05 \x01(\t\x12\x33\n\x06\x66ilter\x18\x04 \x01(\x0b\x32#.YandexQuery.ListJobsRequest.Filter\x1a:\n\x06\x46ilter\x12\x19\n\x08query_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x02 \x01(\x08\"@\n\x10ListJobsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"V\n\x0eListJobsResult\x12\"\n\x03job\x18\x01 \x03(\x0b\x32\x15.YandexQuery.BriefJob\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"l\n\x12\x44\x65scribeJobRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\x06job_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"C\n\x13\x44\x65scribeJobResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"2\n\x11\x44\x65scribeJobResult\x12\x1d\n\x03job\x18\x01 \x01(\x0b\x32\x10.YandexQuery.Job\"\x15\n\x13\x43urrentIAMTokenAuth\"\n\n\x08NoneAuth\")\n\x12ServiceAccountAuth\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\xb1\x01\n\x07IamAuth\x12\x37\n\x0b\x63urrent_iam\x18\x01 \x01(\x0b\x32 .YandexQuery.CurrentIAMTokenAuthH\x00\x12:\n\x0fservice_account\x18\x02 \x01(\x0b\x32\x1f.YandexQuery.ServiceAccountAuthH\x00\x12%\n\x04none\x18\x03 \x01(\x0b\x32\x15.YandexQuery.NoneAuthH\x00\x42\n\n\x08identity\"\x95\x01\n\x0b\x44\x61taStreams\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.YandexQuery.IamAuth\x12\x19\n\x08\x65ndpoint\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x08\x64\x61tabase\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x0e\n\x06secure\x18\x05 \x01(\x08\"d\n\nMonitoring\x12\x18\n\x07project\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\xc8\x01\x12\x18\n\x07\x63luster\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\xc8\x01\x12\"\n\x04\x61uth\x18\x03 \x01(\x0b\x32\x14.YandexQuery.IamAuth\"\x95\x01\n\x0bYdbDatabase\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.YandexQuery.IamAuth\x12\x19\n\x08\x65ndpoint\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x08\x64\x61tabase\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x0e\n\x06secure\x18\x05 \x01(\x08\"\xd5\x01\n\x11\x43lickHouseCluster\x12\x1c\n\x0b\x64\x61tabase_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1a\n\x05login\x18\x02 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\x1d\n\x08password\x18\x03 \x01(\tB\x0b\xa2\xe6*\x03\x18\x80\x08\xb8\xe6*\x01\x12\"\n\x04\x61uth\x18\x04 \x01(\x0b\x32\x14.YandexQuery.IamAuth\x12\x15\n\x04host\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x04port\x18\x06 \x01(\x05\x42\x0e\xb2\xe6*\n[0; 65536]\x12\x0e\n\x06secure\x18\x07 \x01(\x08\"V\n\x17ObjectStorageConnection\x12\x17\n\x06\x62ucket\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\"\n\x04\x61uth\x18\x02 \x01(\x0b\x32\x14.YandexQuery.IamAuth\"\xc6\x03\n\x11\x43onnectionSetting\x12\x30\n\x0cydb_database\x18\x01 \x01(\x0b\x32\x18.YandexQuery.YdbDatabaseH\x00\x12<\n\x12\x63lickhouse_cluster\x18\x02 \x01(\x0b\x32\x1e.YandexQuery.ClickHouseClusterH\x00\x12\x30\n\x0c\x64\x61ta_streams\x18\x03 \x01(\x0b\x32\x18.YandexQuery.DataStreamsH\x00\x12>\n\x0eobject_storage\x18\x04 \x01(\x0b\x32$.YandexQuery.ObjectStorageConnectionH\x00\x12-\n\nmonitoring\x18\x05 \x01(\x0b\x32\x17.YandexQuery.MonitoringH\x00\"\x91\x01\n\x0e\x43onnectionType\x12\x1f\n\x1b\x43ONNECTION_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0cYDB_DATABASE\x10\x01\x12\x16\n\x12\x43LICKHOUSE_CLUSTER\x10\x02\x12\x10\n\x0c\x44\x41TA_STREAMS\x10\x03\x12\x12\n\x0eOBJECT_STORAGE\x10\x04\x12\x0e\n\nMONITORING\x10\x05\x42\x0c\n\nconnection\"\x9c\x01\n\x11\x43onnectionContent\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12/\n\x07setting\x18\x02 \x01(\x0b\x32\x1e.YandexQuery.ConnectionSetting\x12\x1d\n\x03\x61\x63l\x18\x03 \x01(\x0b\x32\x10.YandexQuery.Acl\x12\x1c\n\x0b\x64\x65scription\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\"d\n\nConnection\x12/\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1e.YandexQuery.ConnectionContent\x12%\n\x04meta\x18\x02 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\"\xa7\x01\n\x17\x43reateConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12/\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1e.YandexQuery.ConnectionContent\x12 \n\x0fidempotency_key\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18\x43reateConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"<\n\x16\x43reateConnectionResult\x12\"\n\rconnection_id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"\xfb\x02\n\x16ListConnectionsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12:\n\x06\x66ilter\x18\x04 \x01(\x0b\x32*.YandexQuery.ListConnectionsRequest.Filter\x1a\xaf\x01\n\x06\x46ilter\x12\x15\n\x04name\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x02 \x01(\x08\x12\x46\n\x0f\x63onnection_type\x18\x03 \x01(\x0e\x32-.YandexQuery.ConnectionSetting.ConnectionType\x12/\n\nvisibility\x18\x04 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\"G\n\x17ListConnectionsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"f\n\x15ListConnectionsResult\x12+\n\nconnection\x18\x01 \x03(\x0b\x32\x17.YandexQuery.Connection\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"z\n\x19\x44\x65scribeConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"J\n\x1a\x44\x65scribeConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"G\n\x18\x44\x65scribeConnectionResult\x12+\n\nconnection\x18\x01 \x01(\x0b\x32\x17.YandexQuery.Connection\"\xf0\x01\n\x17ModifyConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12/\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1e.YandexQuery.ConnectionContent\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18ModifyConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x18\n\x16ModifyConnectionResult\"\xbf\x01\n\x17\x44\x65leteConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"H\n\x18\x44\x65leteConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x18\n\x16\x44\x65leteConnectionResult\"\x83\x01\n\x15TestConnectionRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12/\n\x07setting\x18\x02 \x01(\x0b\x32\x1e.YandexQuery.ConnectionSetting\"F\n\x16TestConnectionResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x16\n\x14TestConnectionResult\"\xcc\x01\n\x14GetResultDataRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1d\n\x08query_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\x10result_set_index\x18\x03 \x01(\x05\x42\x08\xb2\xe6*\x04>= 0\x12\x18\n\x06offset\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\x1c\n\x05limit\x18\x05 \x01(\x03\x42\r\xb2\xe6*\t[1; 1000]\"E\n\x15GetResultDataResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"9\n\x13GetResultDataResult\x12\"\n\nresult_set\x18\x01 \x01(\x0b\x32\x0e.Ydb.ResultSet\"-\n\x06Schema\x12#\n\x06\x63olumn\x18\x01 \x03(\x0b\x32\x0b.Ydb.ColumnB\x06\x9a\xe6*\x02\x18\x64\"\x9c\x02\n\x12\x44\x61taStreamsBinding\x12 \n\x0bstream_name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x17\n\x06\x66ormat\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\x0b\x63ompression\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12#\n\x06schema\x18\x04 \x01(\x0b\x32\x13.YandexQuery.Schema\x12R\n\x0e\x66ormat_setting\x18\x05 \x03(\x0b\x32\x32.YandexQuery.DataStreamsBinding.FormatSettingEntryB\x06\x9a\xe6*\x02\x18\x64\x1a\x34\n\x12\x46ormatSettingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x04\n\x14ObjectStorageBinding\x12\x38\n\x06subset\x18\x01 \x03(\x0b\x32(.YandexQuery.ObjectStorageBinding.Subset\x1a\xb3\x03\n\x06Subset\x12!\n\x0cpath_pattern\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\x17\n\x06\x66ormat\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12[\n\x0e\x66ormat_setting\x18\x03 \x03(\x0b\x32;.YandexQuery.ObjectStorageBinding.Subset.FormatSettingEntryB\x06\x9a\xe6*\x02\x18\x64\x12\x1c\n\x0b\x63ompression\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12#\n\x06schema\x18\x05 \x01(\x0b\x32\x13.YandexQuery.Schema\x12L\n\nprojection\x18\x06 \x03(\x0b\x32\x38.YandexQuery.ObjectStorageBinding.Subset.ProjectionEntry\x12\x16\n\x0epartitioned_by\x18\x07 \x03(\t\x1a\x34\n\x12\x46ormatSettingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x31\n\x0fProjectionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe4\x01\n\x0e\x42indingSetting\x12\x37\n\x0c\x64\x61ta_streams\x18\x01 \x01(\x0b\x32\x1f.YandexQuery.DataStreamsBindingH\x00\x12;\n\x0eobject_storage\x18\x02 \x01(\x0b\x32!.YandexQuery.ObjectStorageBindingH\x00\"Q\n\x0b\x42indingType\x12\x1c\n\x18\x42INDING_TYPE_UNSPECIFIED\x10\x00\x12\x10\n\x0c\x44\x41TA_STREAMS\x10\x01\x12\x12\n\x0eOBJECT_STORAGE\x10\x02\x42\t\n\x07\x62inding\"\xdc\x01\n\x0c\x42riefBinding\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12%\n\x04meta\x18\x03 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\x12\x35\n\x04type\x18\x04 \x01(\x0e\x32\'.YandexQuery.BindingSetting.BindingType\x12/\n\nvisibility\x18\x05 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\"\xba\x01\n\x0e\x42indingContent\x12\x19\n\x04name\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12\"\n\rconnection_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12,\n\x07setting\x18\x03 \x01(\x0b\x32\x1b.YandexQuery.BindingSetting\x12\x1d\n\x03\x61\x63l\x18\x04 \x01(\x0b\x32\x10.YandexQuery.Acl\x12\x1c\n\x0b\x64\x65scription\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80P\"^\n\x07\x42inding\x12,\n\x07\x63ontent\x18\x01 \x01(\x0b\x32\x1b.YandexQuery.BindingContent\x12%\n\x04meta\x18\x02 \x01(\x0b\x32\x17.YandexQuery.CommonMeta\"\xa1\x01\n\x14\x43reateBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12,\n\x07\x63ontent\x18\x02 \x01(\x0b\x32\x1b.YandexQuery.BindingContent\x12 \n\x0fidempotency_key\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15\x43reateBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"6\n\x13\x43reateBindingResult\x12\x1f\n\nbinding_id\x18\x01 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"\xcd\x02\n\x13ListBindingsRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1b\n\npage_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1b\n\x05limit\x18\x03 \x01(\x05\x42\x0c\xb2\xe6*\x08[1; 100]\x12\x37\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\'.YandexQuery.ListBindingsRequest.Filter\x1a\x87\x01\n\x06\x46ilter\x12\x1e\n\rconnection_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\x04name\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x15\n\rcreated_by_me\x18\x03 \x01(\x08\x12/\n\nvisibility\x18\x04 \x01(\x0e\x32\x1b.YandexQuery.Acl.Visibility\"D\n\x14ListBindingsResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"b\n\x12ListBindingsResult\x12*\n\x07\x62inding\x18\x01 \x03(\x0b\x32\x19.YandexQuery.BriefBinding\x12 \n\x0fnext_page_token\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"t\n\x16\x44\x65scribeBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\"G\n\x17\x44\x65scribeBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\">\n\x15\x44\x65scribeBindingResult\x12%\n\x07\x62inding\x18\x01 \x01(\x0b\x32\x14.YandexQuery.Binding\"\xe7\x01\n\x14ModifyBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12,\n\x07\x63ontent\x18\x03 \x01(\x0b\x32\x1b.YandexQuery.BindingContent\x12#\n\x11previous_revision\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15ModifyBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13ModifyBindingResult\"\xb9\x01\n\x14\x44\x65leteBindingRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12\x1f\n\nbinding_id\x18\x02 \x01(\tB\x0b\xa2\xe6*\x07\n\x05\x08\x01\x10\x80\x08\x12#\n\x11previous_revision\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12 \n\x0fidempotency_key\x18\x04 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"E\n\x15\x44\x65leteBindingResponse\x12,\n\toperation\x18\x01 \x01(\x0b\x32\x19.Ydb.Operations.Operation\"\x15\n\x13\x44\x65leteBindingResult*q\n\x0b\x45xecuteMode\x12\x1c\n\x18\x45XECUTE_MODE_UNSPECIFIED\x10\x00\x12\x08\n\x04SAVE\x10\x01\x12\t\n\x05PARSE\x10\x02\x12\x0b\n\x07\x43OMPILE\x10\x03\x12\x0c\n\x08VALIDATE\x10\x04\x12\x0b\n\x07\x45XPLAIN\x10\x05\x12\x07\n\x03RUN\x10\x06*y\n\x0bQueryAction\x12\x1c\n\x18QUERY_ACTION_UNSPECIFIED\x10\x00\x12\t\n\x05PAUSE\x10\x01\x12\x14\n\x10PAUSE_GRACEFULLY\x10\x02\x12\t\n\x05\x41\x42ORT\x10\x03\x12\x14\n\x10\x41\x42ORT_GRACEFULLY\x10\x04\x12\n\n\x06RESUME\x10\x05*U\n\rStateLoadMode\x12\x1f\n\x1bSTATE_LOAD_MODE_UNSPECIFIED\x10\x00\x12\t\n\x05\x45MPTY\x10\x01\x12\x18\n\x14\x46ROM_LAST_CHECKPOINT\x10\x02*Q\n\rAutomaticType\x12\x1e\n\x1a\x41UTOMATIC_TYPE_UNSPECIFIED\x10\x00\x12\r\n\tAUTOMATIC\x10\x01\x12\x11\n\rNOT_AUTOMATIC\x10\x02\x42(\n\x10\x63om.yandex.queryB\x11YandexQueryProtos\xf8\x01\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.public.api.protos.yq_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\020com.yandex.queryB\021YandexQueryProtos\370\001\001'
  _LIMITS.fields_by_name['vcpu_rate_limit']._options = None
  _LIMITS.fields_by_name['vcpu_rate_limit']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['flow_rate_limit']._options = None
  _LIMITS.fields_by_name['flow_rate_limit']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['vcpu_time_limit']._options = None
  _LIMITS.fields_by_name['vcpu_time_limit']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['max_result_size']._options = None
  _LIMITS.fields_by_name['max_result_size']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['max_result_rows']._options = None
  _LIMITS.fields_by_name['max_result_rows']._serialized_options = b'\262\346*\004>= 0'
  _LIMITS.fields_by_name['memory_limit']._options = None
  _LIMITS.fields_by_name['memory_limit']._serialized_options = b'\262\346*\004>= 0'
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._options = None
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._serialized_options = b'8\001'
  _QUERYCONTENT.fields_by_name['name']._options = None
  _QUERYCONTENT.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _QUERYCONTENT.fields_by_name['text']._options = None
  _QUERYCONTENT.fields_by_name['text']._serialized_options = b'\242\346*\004\030\200\240\006'
  _QUERYCONTENT.fields_by_name['description']._options = None
  _QUERYCONTENT.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200P'
  _QUERYCONTENT.fields_by_name['execution_settings']._options = None
  _QUERYCONTENT.fields_by_name['execution_settings']._serialized_options = b'\252\346*\010\n\006\n\004\010\001\020d\242\346*\003\030\200 '
  _COMMONMETA.fields_by_name['id']._options = None
  _COMMONMETA.fields_by_name['id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _COMMONMETA.fields_by_name['created_by']._options = None
  _COMMONMETA.fields_by_name['created_by']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _COMMONMETA.fields_by_name['modified_by']._options = None
  _COMMONMETA.fields_by_name['modified_by']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _COMMONMETA.fields_by_name['revision']._options = None
  _COMMONMETA.fields_by_name['revision']._serialized_options = b'\262\346*\004>= 0'
  _BRIEFQUERY.fields_by_name['name']._options = None
  _BRIEFQUERY.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _RESULTSETMETA.fields_by_name['rows_count']._options = None
  _RESULTSETMETA.fields_by_name['rows_count']._serialized_options = b'\262\346*\004>= 0'
  _CREATEQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _CREATEQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATEQUERYRESULT.fields_by_name['query_id']._options = None
  _CREATEQUERYRESULT.fields_by_name['query_id']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTQUERIESREQUEST_FILTER.fields_by_name['status']._options = None
  _LISTQUERIESREQUEST_FILTER.fields_by_name['status']._serialized_options = b'\232\346*\002\030\024'
  _LISTQUERIESREQUEST_FILTER.fields_by_name['mode']._options = None
  _LISTQUERIESREQUEST_FILTER.fields_by_name['mode']._serialized_options = b'\232\346*\002\030\024'
  _LISTQUERIESREQUEST_FILTER.fields_by_name['name']._options = None
  _LISTQUERIESREQUEST_FILTER.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTQUERIESREQUEST.fields_by_name['page_token']._options = None
  _LISTQUERIESREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTQUERIESREQUEST.fields_by_name['limit']._options = None
  _LISTQUERIESREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTQUERIESRESULT.fields_by_name['next_page_token']._options = None
  _LISTQUERIESRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBEQUERYREQUEST.fields_by_name['query_id']._options = None
  _DESCRIBEQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _GETQUERYSTATUSREQUEST.fields_by_name['query_id']._options = None
  _GETQUERYSTATUSREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETEQUERYREQUEST.fields_by_name['query_id']._options = None
  _DELETEQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETEQUERYREQUEST.fields_by_name['previous_revision']._options = None
  _DELETEQUERYREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _DELETEQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _DELETEQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _MODIFYQUERYREQUEST.fields_by_name['query_id']._options = None
  _MODIFYQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYQUERYREQUEST.fields_by_name['previous_revision']._options = None
  _MODIFYQUERYREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _MODIFYQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _MODIFYQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CONTROLQUERYREQUEST.fields_by_name['query_id']._options = None
  _CONTROLQUERYREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _CONTROLQUERYREQUEST.fields_by_name['previous_revision']._options = None
  _CONTROLQUERYREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _CONTROLQUERYREQUEST.fields_by_name['idempotency_key']._options = None
  _CONTROLQUERYREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTJOBSREQUEST_FILTER.fields_by_name['query_id']._options = None
  _LISTJOBSREQUEST_FILTER.fields_by_name['query_id']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTJOBSREQUEST.fields_by_name['page_token']._options = None
  _LISTJOBSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTJOBSREQUEST.fields_by_name['limit']._options = None
  _LISTJOBSREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTJOBSRESULT.fields_by_name['next_page_token']._options = None
  _LISTJOBSRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBEJOBREQUEST.fields_by_name['job_id']._options = None
  _DESCRIBEJOBREQUEST.fields_by_name['job_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _SERVICEACCOUNTAUTH.fields_by_name['id']._options = None
  _SERVICEACCOUNTAUTH.fields_by_name['id']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMS.fields_by_name['database_id']._options = None
  _DATASTREAMS.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMS.fields_by_name['endpoint']._options = None
  _DATASTREAMS.fields_by_name['endpoint']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMS.fields_by_name['database']._options = None
  _DATASTREAMS.fields_by_name['database']._serialized_options = b'\242\346*\003\030\200\010'
  _MONITORING.fields_by_name['project']._options = None
  _MONITORING.fields_by_name['project']._serialized_options = b'\242\346*\003\030\310\001'
  _MONITORING.fields_by_name['cluster']._options = None
  _MONITORING.fields_by_name['cluster']._serialized_options = b'\242\346*\003\030\310\001'
  _YDBDATABASE.fields_by_name['database_id']._options = None
  _YDBDATABASE.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _YDBDATABASE.fields_by_name['endpoint']._options = None
  _YDBDATABASE.fields_by_name['endpoint']._serialized_options = b'\242\346*\003\030\200\010'
  _YDBDATABASE.fields_by_name['database']._options = None
  _YDBDATABASE.fields_by_name['database']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['database_id']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['database_id']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['login']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['login']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _CLICKHOUSECLUSTER.fields_by_name['password']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['password']._serialized_options = b'\242\346*\003\030\200\010\270\346*\001'
  _CLICKHOUSECLUSTER.fields_by_name['host']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['host']._serialized_options = b'\242\346*\003\030\200\010'
  _CLICKHOUSECLUSTER.fields_by_name['port']._options = None
  _CLICKHOUSECLUSTER.fields_by_name['port']._serialized_options = b'\262\346*\n[0; 65536]'
  _OBJECTSTORAGECONNECTION.fields_by_name['bucket']._options = None
  _OBJECTSTORAGECONNECTION.fields_by_name['bucket']._serialized_options = b'\242\346*\003\030\200\010'
  _CONNECTIONCONTENT.fields_by_name['name']._options = None
  _CONNECTIONCONTENT.fields_by_name['name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _CONNECTIONCONTENT.fields_by_name['description']._options = None
  _CONNECTIONCONTENT.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200P'
  _CREATECONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
  _CREATECONNECTIONREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATECONNECTIONRESULT.fields_by_name['connection_id']._options = None
  _CREATECONNECTIONRESULT.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _LISTCONNECTIONSREQUEST_FILTER.fields_by_name['name']._options = None
  _LISTCONNECTIONSREQUEST_FILTER.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTCONNECTIONSREQUEST.fields_by_name['page_token']._options = None
  _LISTCONNECTIONSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTCONNECTIONSREQUEST.fields_by_name['limit']._options = None
  _LISTCONNECTIONSREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTCONNECTIONSRESULT.fields_by_name['next_page_token']._options = None
  _LISTCONNECTIONSRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _DESCRIBECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYCONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _MODIFYCONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYCONNECTIONREQUEST.fields_by_name['previous_revision']._options = None
  _MODIFYCONNECTIONREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _MODIFYCONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
  _MODIFYCONNECTIONREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _DELETECONNECTIONREQUEST.fields_by_name['connection_id']._options = None
  _DELETECONNECTIONREQUEST.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETECONNECTIONREQUEST.fields_by_name['previous_revision']._options = None
  _DELETECONNECTIONREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _DELETECONNECTIONREQUEST.fields_by_name['idempotency_key']._options = None
  _DELETECONNECTIONREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _GETRESULTDATAREQUEST.fields_by_name['query_id']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['query_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _GETRESULTDATAREQUEST.fields_by_name['result_set_index']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['result_set_index']._serialized_options = b'\262\346*\004>= 0'
  _GETRESULTDATAREQUEST.fields_by_name['offset']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['offset']._serialized_options = b'\262\346*\004>= 0'
  _GETRESULTDATAREQUEST.fields_by_name['limit']._options = None
  _GETRESULTDATAREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\t[1; 1000]'
  _SCHEMA.fields_by_name['column']._options = None
  _SCHEMA.fields_by_name['column']._serialized_options = b'\232\346*\002\030d'
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._options = None
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._serialized_options = b'8\001'
  _DATASTREAMSBINDING.fields_by_name['stream_name']._options = None
  _DATASTREAMSBINDING.fields_by_name['stream_name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DATASTREAMSBINDING.fields_by_name['format']._options = None
  _DATASTREAMSBINDING.fields_by_name['format']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMSBINDING.fields_by_name['compression']._options = None
  _DATASTREAMSBINDING.fields_by_name['compression']._serialized_options = b'\242\346*\003\030\200\010'
  _DATASTREAMSBINDING.fields_by_name['format_setting']._options = None
  _DATASTREAMSBINDING.fields_by_name['format_setting']._serialized_options = b'\232\346*\002\030d'
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._options = None
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._serialized_options = b'8\001'
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._options = None
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._serialized_options = b'8\001'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['path_pattern']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['path_pattern']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format']._serialized_options = b'\242\346*\003\030\200\010'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format_setting']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['format_setting']._serialized_options = b'\232\346*\002\030d'
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['compression']._options = None
  _OBJECTSTORAGEBINDING_SUBSET.fields_by_name['compression']._serialized_options = b'\242\346*\003\030\200\010'
  _BRIEFBINDING.fields_by_name['name']._options = None
  _BRIEFBINDING.fields_by_name['name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BRIEFBINDING.fields_by_name['connection_id']._options = None
  _BRIEFBINDING.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BINDINGCONTENT.fields_by_name['name']._options = None
  _BINDINGCONTENT.fields_by_name['name']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BINDINGCONTENT.fields_by_name['connection_id']._options = None
  _BINDINGCONTENT.fields_by_name['connection_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _BINDINGCONTENT.fields_by_name['description']._options = None
  _BINDINGCONTENT.fields_by_name['description']._serialized_options = b'\242\346*\003\030\200P'
  _CREATEBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
  _CREATEBINDINGREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _CREATEBINDINGRESULT.fields_by_name['binding_id']._options = None
  _CREATEBINDINGRESULT.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['connection_id']._options = None
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['connection_id']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['name']._options = None
  _LISTBINDINGSREQUEST_FILTER.fields_by_name['name']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTBINDINGSREQUEST.fields_by_name['page_token']._options = None
  _LISTBINDINGSREQUEST.fields_by_name['page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _LISTBINDINGSREQUEST.fields_by_name['limit']._options = None
  _LISTBINDINGSREQUEST.fields_by_name['limit']._serialized_options = b'\262\346*\010[1; 100]'
  _LISTBINDINGSRESULT.fields_by_name['next_page_token']._options = None
  _LISTBINDINGSRESULT.fields_by_name['next_page_token']._serialized_options = b'\242\346*\003\030\200\010'
  _DESCRIBEBINDINGREQUEST.fields_by_name['binding_id']._options = None
  _DESCRIBEBINDINGREQUEST.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYBINDINGREQUEST.fields_by_name['binding_id']._options = None
  _MODIFYBINDINGREQUEST.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _MODIFYBINDINGREQUEST.fields_by_name['previous_revision']._options = None
  _MODIFYBINDINGREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _MODIFYBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
  _MODIFYBINDINGREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _DELETEBINDINGREQUEST.fields_by_name['binding_id']._options = None
  _DELETEBINDINGREQUEST.fields_by_name['binding_id']._serialized_options = b'\242\346*\007\n\005\010\001\020\200\010'
  _DELETEBINDINGREQUEST.fields_by_name['previous_revision']._options = None
  _DELETEBINDINGREQUEST.fields_by_name['previous_revision']._serialized_options = b'\262\346*\004>= 0'
  _DELETEBINDINGREQUEST.fields_by_name['idempotency_key']._options = None
  _DELETEBINDINGREQUEST.fields_by_name['idempotency_key']._serialized_options = b'\242\346*\003\030\200\010'
  _EXECUTEMODE._serialized_start=15068
  _EXECUTEMODE._serialized_end=15181
  _QUERYACTION._serialized_start=15183
  _QUERYACTION._serialized_end=15304
  _STATELOADMODE._serialized_start=15306
  _STATELOADMODE._serialized_end=15391
  _AUTOMATICTYPE._serialized_start=15393
  _AUTOMATICTYPE._serialized_end=15474
  _ACL._serialized_start=373
  _ACL._serialized_end=493
  _ACL_VISIBILITY._serialized_start=429
  _ACL_VISIBILITY._serialized_end=493
  _LIMITS._serialized_start=496
  _LIMITS._serialized_end=883
  _STREAMINGDISPOSITION._serialized_start=886
  _STREAMINGDISPOSITION._serialized_end=1372
  _STREAMINGDISPOSITION_FROMTIME._serialized_start=1207
  _STREAMINGDISPOSITION_FROMTIME._serialized_end=1264
  _STREAMINGDISPOSITION_TIMEAGO._serialized_start=1266
  _STREAMINGDISPOSITION_TIMEAGO._serialized_end=1320
  _STREAMINGDISPOSITION_FROMLASTCHECKPOINT._serialized_start=1322
  _STREAMINGDISPOSITION_FROMLASTCHECKPOINT._serialized_end=1357
  _QUERYCONTENT._serialized_start=1375
  _QUERYCONTENT._serialized_end=1952
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._serialized_start=1760
  _QUERYCONTENT_EXECUTIONSETTINGSENTRY._serialized_end=1816
  _QUERYCONTENT_QUERYTYPE._serialized_start=1818
  _QUERYCONTENT_QUERYTYPE._serialized_end=1887
  _QUERYCONTENT_QUERYSYNTAX._serialized_start=1889
  _QUERYCONTENT_QUERYSYNTAX._serialized_end=1952
  _COMMONMETA._serialized_start=1955
  _COMMONMETA._serialized_end=2184
  _QUERYMETA._serialized_start=2187
  _QUERYMETA._serialized_end=3009
  _QUERYMETA_COMPUTESTATUS._serialized_start=2740
  _QUERYMETA_COMPUTESTATUS._serialized_end=2999
  _BRIEFQUERY._serialized_start=3012
  _BRIEFQUERY._serialized_end=3204
  _QUERYPLAN._serialized_start=3206
  _QUERYPLAN._serialized_end=3231
  _QUERYAST._serialized_start=3233
  _QUERYAST._serialized_end=3257
  _RESULTSETMETA._serialized_start=3259
  _RESULTSETMETA._serialized_end=3352
  _QUERY._serialized_start=3355
  _QUERY._serialized_end=3711
  _QUERYSTATISTICS._serialized_start=3713
  _QUERYSTATISTICS._serialized_end=3744
  _CREATEQUERYREQUEST._serialized_start=3747
  _CREATEQUERYREQUEST._serialized_end=4008
  _CREATEQUERYRESPONSE._serialized_start=4010
  _CREATEQUERYRESPONSE._serialized_end=4077
  _CREATEQUERYRESULT._serialized_start=4079
  _CREATEQUERYRESULT._serialized_end=4125
  _LISTQUERIESREQUEST._serialized_start=4128
  _LISTQUERIESREQUEST._serialized_end=4641
  _LISTQUERIESREQUEST_FILTER._serialized_start=4324
  _LISTQUERIESREQUEST_FILTER._serialized_end=4641
  _LISTQUERIESRESPONSE._serialized_start=4643
  _LISTQUERIESRESPONSE._serialized_end=4710
  _LISTQUERIESRESULT._serialized_start=4712
  _LISTQUERIESRESULT._serialized_end=4805
  _DESCRIBEQUERYREQUEST._serialized_start=4807
  _DESCRIBEQUERYREQUEST._serialized_end=4919
  _DESCRIBEQUERYRESPONSE._serialized_start=4921
  _DESCRIBEQUERYRESPONSE._serialized_end=4990
  _DESCRIBEQUERYRESULT._serialized_start=4992
  _DESCRIBEQUERYRESULT._serialized_end=5048
  _GETQUERYSTATUSREQUEST._serialized_start=5050
  _GETQUERYSTATUSREQUEST._serialized_end=5163
  _GETQUERYSTATUSRESPONSE._serialized_start=5165
  _GETQUERYSTATUSRESPONSE._serialized_end=5235
  _GETQUERYSTATUSRESULT._serialized_start=5237
  _GETQUERYSTATUSRESULT._serialized_end=5336
  _DELETEQUERYREQUEST._serialized_start=5339
  _DELETEQUERYREQUEST._serialized_end=5520
  _DELETEQUERYRESPONSE._serialized_start=5522
  _DELETEQUERYRESPONSE._serialized_end=5589
  _DELETEQUERYRESULT._serialized_start=5591
  _DELETEQUERYRESULT._serialized_end=5610
  _MODIFYQUERYREQUEST._serialized_start=5613
  _MODIFYQUERYREQUEST._serialized_end=5995
  _MODIFYQUERYRESPONSE._serialized_start=5997
  _MODIFYQUERYRESPONSE._serialized_end=6064
  _MODIFYQUERYRESULT._serialized_start=6066
  _MODIFYQUERYRESULT._serialized_end=6085
  _CONTROLQUERYREQUEST._serialized_start=6088
  _CONTROLQUERYREQUEST._serialized_end=6312
  _CONTROLQUERYRESPONSE._serialized_start=6314
  _CONTROLQUERYRESPONSE._serialized_end=6382
  _CONTROLQUERYRESULT._serialized_start=6384
  _CONTROLQUERYRESULT._serialized_end=6404
  _BRIEFJOB._serialized_start=6407
  _BRIEFJOB._serialized_end=6635
  _JOB._serialized_start=6638
  _JOB._serialized_end=7129
  _LISTJOBSREQUEST._serialized_start=7132
  _LISTJOBSREQUEST._serialized_end=7397
  _LISTJOBSREQUEST_FILTER._serialized_start=7339
  _LISTJOBSREQUEST_FILTER._serialized_end=7397
  _LISTJOBSRESPONSE._serialized_start=7399
  _LISTJOBSRESPONSE._serialized_end=7463
  _LISTJOBSRESULT._serialized_start=7465
  _LISTJOBSRESULT._serialized_end=7551
  _DESCRIBEJOBREQUEST._serialized_start=7553
  _DESCRIBEJOBREQUEST._serialized_end=7661
  _DESCRIBEJOBRESPONSE._serialized_start=7663
  _DESCRIBEJOBRESPONSE._serialized_end=7730
  _DESCRIBEJOBRESULT._serialized_start=7732
  _DESCRIBEJOBRESULT._serialized_end=7782
  _CURRENTIAMTOKENAUTH._serialized_start=7784
  _CURRENTIAMTOKENAUTH._serialized_end=7805
  _NONEAUTH._serialized_start=7807
  _NONEAUTH._serialized_end=7817
  _SERVICEACCOUNTAUTH._serialized_start=7819
  _SERVICEACCOUNTAUTH._serialized_end=7860
  _IAMAUTH._serialized_start=7863
  _IAMAUTH._serialized_end=8040
  _DATASTREAMS._serialized_start=8043
  _DATASTREAMS._serialized_end=8192
  _MONITORING._serialized_start=8194
  _MONITORING._serialized_end=8294
  _YDBDATABASE._serialized_start=8297
  _YDBDATABASE._serialized_end=8446
  _CLICKHOUSECLUSTER._serialized_start=8449
  _CLICKHOUSECLUSTER._serialized_end=8662
  _OBJECTSTORAGECONNECTION._serialized_start=8664
  _OBJECTSTORAGECONNECTION._serialized_end=8750
  _CONNECTIONSETTING._serialized_start=8753
  _CONNECTIONSETTING._serialized_end=9207
  _CONNECTIONSETTING_CONNECTIONTYPE._serialized_start=9048
  _CONNECTIONSETTING_CONNECTIONTYPE._serialized_end=9193
  _CONNECTIONCONTENT._serialized_start=9210
  _CONNECTIONCONTENT._serialized_end=9366
  _CONNECTION._serialized_start=9368
  _CONNECTION._serialized_end=9468
  _CREATECONNECTIONREQUEST._serialized_start=9471
  _CREATECONNECTIONREQUEST._serialized_end=9638
  _CREATECONNECTIONRESPONSE._serialized_start=9640
  _CREATECONNECTIONRESPONSE._serialized_end=9712
  _CREATECONNECTIONRESULT._serialized_start=9714
  _CREATECONNECTIONRESULT._serialized_end=9774
  _LISTCONNECTIONSREQUEST._serialized_start=9777
  _LISTCONNECTIONSREQUEST._serialized_end=10156
  _LISTCONNECTIONSREQUEST_FILTER._serialized_start=9981
  _LISTCONNECTIONSREQUEST_FILTER._serialized_end=10156
  _LISTCONNECTIONSRESPONSE._serialized_start=10158
  _LISTCONNECTIONSRESPONSE._serialized_end=10229
  _LISTCONNECTIONSRESULT._serialized_start=10231
  _LISTCONNECTIONSRESULT._serialized_end=10333
  _DESCRIBECONNECTIONREQUEST._serialized_start=10335
  _DESCRIBECONNECTIONREQUEST._serialized_end=10457
  _DESCRIBECONNECTIONRESPONSE._serialized_start=10459
  _DESCRIBECONNECTIONRESPONSE._serialized_end=10533
  _DESCRIBECONNECTIONRESULT._serialized_start=10535
  _DESCRIBECONNECTIONRESULT._serialized_end=10606
  _MODIFYCONNECTIONREQUEST._serialized_start=10609
  _MODIFYCONNECTIONREQUEST._serialized_end=10849
  _MODIFYCONNECTIONRESPONSE._serialized_start=10851
  _MODIFYCONNECTIONRESPONSE._serialized_end=10923
  _MODIFYCONNECTIONRESULT._serialized_start=10925
  _MODIFYCONNECTIONRESULT._serialized_end=10949
  _DELETECONNECTIONREQUEST._serialized_start=10952
  _DELETECONNECTIONREQUEST._serialized_end=11143
  _DELETECONNECTIONRESPONSE._serialized_start=11145
  _DELETECONNECTIONRESPONSE._serialized_end=11217
  _DELETECONNECTIONRESULT._serialized_start=11219
  _DELETECONNECTIONRESULT._serialized_end=11243
  _TESTCONNECTIONREQUEST._serialized_start=11246
  _TESTCONNECTIONREQUEST._serialized_end=11377
  _TESTCONNECTIONRESPONSE._serialized_start=11379
  _TESTCONNECTIONRESPONSE._serialized_end=11449
  _TESTCONNECTIONRESULT._serialized_start=11451
  _TESTCONNECTIONRESULT._serialized_end=11473
  _GETRESULTDATAREQUEST._serialized_start=11476
  _GETRESULTDATAREQUEST._serialized_end=11680
  _GETRESULTDATARESPONSE._serialized_start=11682
  _GETRESULTDATARESPONSE._serialized_end=11751
  _GETRESULTDATARESULT._serialized_start=11753
  _GETRESULTDATARESULT._serialized_end=11810
  _SCHEMA._serialized_start=11812
  _SCHEMA._serialized_end=11857
  _DATASTREAMSBINDING._serialized_start=11860
  _DATASTREAMSBINDING._serialized_end=12144
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._serialized_start=12092
  _DATASTREAMSBINDING_FORMATSETTINGENTRY._serialized_end=12144
  _OBJECTSTORAGEBINDING._serialized_start=12147
  _OBJECTSTORAGEBINDING._serialized_end=12665
  _OBJECTSTORAGEBINDING_SUBSET._serialized_start=12230
  _OBJECTSTORAGEBINDING_SUBSET._serialized_end=12665
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._serialized_start=12092
  _OBJECTSTORAGEBINDING_SUBSET_FORMATSETTINGENTRY._serialized_end=12144
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._serialized_start=12616
  _OBJECTSTORAGEBINDING_SUBSET_PROJECTIONENTRY._serialized_end=12665
  _BINDINGSETTING._serialized_start=12668
  _BINDINGSETTING._serialized_end=12896
  _BINDINGSETTING_BINDINGTYPE._serialized_start=12804
  _BINDINGSETTING_BINDINGTYPE._serialized_end=12885
  _BRIEFBINDING._serialized_start=12899
  _BRIEFBINDING._serialized_end=13119
  _BINDINGCONTENT._serialized_start=13122
  _BINDINGCONTENT._serialized_end=13308
  _BINDING._serialized_start=13310
  _BINDING._serialized_end=13404
  _CREATEBINDINGREQUEST._serialized_start=13407
  _CREATEBINDINGREQUEST._serialized_end=13568
  _CREATEBINDINGRESPONSE._serialized_start=13570
  _CREATEBINDINGRESPONSE._serialized_end=13639
  _CREATEBINDINGRESULT._serialized_start=13641
  _CREATEBINDINGRESULT._serialized_end=13695
  _LISTBINDINGSREQUEST._serialized_start=13698
  _LISTBINDINGSREQUEST._serialized_end=14031
  _LISTBINDINGSREQUEST_FILTER._serialized_start=13896
  _LISTBINDINGSREQUEST_FILTER._serialized_end=14031
  _LISTBINDINGSRESPONSE._serialized_start=14033
  _LISTBINDINGSRESPONSE._serialized_end=14101
  _LISTBINDINGSRESULT._serialized_start=14103
  _LISTBINDINGSRESULT._serialized_end=14201
  _DESCRIBEBINDINGREQUEST._serialized_start=14203
  _DESCRIBEBINDINGREQUEST._serialized_end=14319
  _DESCRIBEBINDINGRESPONSE._serialized_start=14321
  _DESCRIBEBINDINGRESPONSE._serialized_end=14392
  _DESCRIBEBINDINGRESULT._serialized_start=14394
  _DESCRIBEBINDINGRESULT._serialized_end=14456
  _MODIFYBINDINGREQUEST._serialized_start=14459
  _MODIFYBINDINGREQUEST._serialized_end=14690
  _MODIFYBINDINGRESPONSE._serialized_start=14692
  _MODIFYBINDINGRESPONSE._serialized_end=14761
  _MODIFYBINDINGRESULT._serialized_start=14763
  _MODIFYBINDINGRESULT._serialized_end=14784
  _DELETEBINDINGREQUEST._serialized_start=14787
  _DELETEBINDINGREQUEST._serialized_end=14972
  _DELETEBINDINGRESPONSE._serialized_start=14974
  _DELETEBINDINGRESPONSE._serialized_end=15043
  _DELETEBINDINGRESULT._serialized_start=15045
  _DELETEBINDINGRESULT._serialized_end=15066
# @@protoc_insertion_point(module_scope)
