# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/msgbus_pq.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import pqconfig_pb2 as ydb_dot_core_dot_protos_dot_pqconfig__pb2
from ydb.public.api.protos.draft import persqueue_error_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_draft_dot_persqueue__error__codes__pb2
from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fydb/core/protos/msgbus_pq.proto\x12\rNKikimrClient\x1a\x1eydb/core/protos/pqconfig.proto\x1a\x37ydb/public/api/protos/draft/persqueue_error_codes.proto\x1a&library/cpp/actors/protos/actors.proto\"\x8b\x17\n\x1aTPersQueuePartitionRequest\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x01(\x05\x12\x13\n\x0bOwnerCookie\x18\x03 \x01(\t\x12\x11\n\tMessageNo\x18\x0c \x01(\x03\x12\x16\n\x0e\x43mdWriteOffset\x18\r \x01(\x03\x12\x45\n\x08\x43mdWrite\x18\x04 \x03(\x0b\x32\x33.NKikimrClient.TPersQueuePartitionRequest.TCmdWrite\x12Q\n\x0e\x43mdGetMaxSeqNo\x18\x05 \x01(\x0b\x32\x39.NKikimrClient.TPersQueuePartitionRequest.TCmdGetMaxSeqNo\x12U\n\x10\x43mdDeleteSession\x18\x06 \x01(\x0b\x32;.NKikimrClient.TPersQueuePartitionRequest.TCmdDeleteSession\x12U\n\x10\x43mdCreateSession\x18\x07 \x01(\x0b\x32;.NKikimrClient.TPersQueuePartitionRequest.TCmdCreateSession\x12\x43\n\x07\x43mdRead\x18\x08 \x01(\x0b\x32\x32.NKikimrClient.TPersQueuePartitionRequest.TCmdRead\x12Y\n\x12\x43mdSetClientOffset\x18\t \x01(\x0b\x32=.NKikimrClient.TPersQueuePartitionRequest.TCmdSetClientOffset\x12Y\n\x12\x43mdGetClientOffset\x18\n \x01(\x0b\x32=.NKikimrClient.TPersQueuePartitionRequest.TCmdGetClientOffset\x12S\n\x0f\x43mdGetOwnership\x18\x0b \x01(\x0b\x32:.NKikimrClient.TPersQueuePartitionRequest.TCmdGetOwnership\x12S\n\x0f\x43mdReserveBytes\x18\x0e \x01(\x0b\x32:.NKikimrClient.TPersQueuePartitionRequest.TCmdReserveBytes\x12\x63\n\x17\x43mdRegisterMessageGroup\x18\x14 \x01(\x0b\x32\x42.NKikimrClient.TPersQueuePartitionRequest.TCmdRegisterMessageGroup\x12g\n\x19\x43mdDeregisterMessageGroup\x18\x15 \x01(\x0b\x32\x44.NKikimrClient.TPersQueuePartitionRequest.TCmdDeregisterMessageGroup\x12]\n\x14\x43mdSplitMessageGroup\x18\x16 \x01(\x0b\x32?.NKikimrClient.TPersQueuePartitionRequest.TCmdSplitMessageGroup\x12*\n\nPipeClient\x18\x0f \x01(\x0b\x32\x16.NActorsProto.TActorId\x12\x0e\n\x06\x43ookie\x18\x10 \x01(\x04\x12\x63\n\x17\x43mdUpdateWriteTimestamp\x18\x11 \x01(\x0b\x32\x42.NKikimrClient.TPersQueuePartitionRequest.TCmdUpdateWriteTimestamp\x12\x1c\n\rIsDirectWrite\x18\x12 \x01(\x08:\x05\x66\x61lse\x12\x14\n\x0cPutUnitsSize\x18\x13 \x01(\x04\x1a\xb2\x02\n\x08TCmdRead\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x11\n\tSessionId\x18\x02 \x01(\t\x12\x0e\n\x06Offset\x18\x03 \x01(\x03\x12\x11\n\x06PartNo\x18\x07 \x01(\x05:\x01\x30\x12\r\n\x05\x43ount\x18\x04 \x01(\x05\x12\r\n\x05\x42ytes\x18\x05 \x01(\x05\x12\x11\n\tTimeoutMs\x18\x06 \x01(\x05\x12\x14\n\x0cMaxTimeLagMs\x18\x08 \x01(\x05\x12\x17\n\x0fReadTimestampMs\x18\t \x01(\x04\x12\x1e\n\x0fMirrorerRequest\x18\n \x01(\x08:\x05\x66\x61lse\x12\x10\n\x08\x43lientDC\x18\x0b \x01(\t\x12\x14\n\x0cPartitionKey\x18\x0c \x01(\t\x12\x14\n\x0c\x45xplicitHash\x18\r \x01(\t\x12 \n\x11\x45xternalOperation\x18\x0e \x01(\x08:\x05\x66\x61lse\x1aZ\n\x11TCmdCreateSession\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x11\n\tSessionId\x18\x02 \x01(\t\x12\x12\n\nGeneration\x18\x03 \x01(\x04\x12\x0c\n\x04Step\x18\x04 \x01(\x04\x1a\x38\n\x11TCmdDeleteSession\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x11\n\tSessionId\x18\x02 \x01(\t\x1aj\n\x13TCmdSetClientOffset\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\x0e\n\x06Offset\x18\x02 \x01(\x03\x12\x11\n\tSessionId\x18\x04 \x01(\t\x12\x1e\n\x0fMirrorerRequest\x18\n \x01(\x08:\x05\x66\x61lse\x1a\'\n\x13TCmdGetClientOffset\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x1a\xdf\x02\n\tTCmdWrite\x12\x10\n\x08SourceId\x18\x01 \x01(\x0c\x12\r\n\x05SeqNo\x18\x02 \x01(\x03\x12\x0c\n\x04\x44\x61ta\x18\x04 \x01(\x0c\x12\x0e\n\x06PartNo\x18\x05 \x01(\x05\x12\x12\n\nTotalParts\x18\x06 \x01(\x05\x12\x11\n\tTotalSize\x18\x07 \x01(\x05\x12\x14\n\x0c\x43reateTimeMS\x18\x08 \x01(\x03\x12#\n\x14\x44isableDeduplication\x18\t \x01(\x08:\x05\x66\x61lse\x12\x13\n\x0bWriteTimeMS\x18\n \x01(\x03\x12\x18\n\x10UncompressedSize\x18\x0c \x01(\x05\x12\x10\n\x08\x43lientDC\x18\x0b \x01(\t\x12\x14\n\x0cPartitionKey\x18\r \x01(\t\x12\x14\n\x0c\x45xplicitHash\x18\x0e \x01(\x0c\x12 \n\x11\x45xternalOperation\x18\x0f \x01(\x08:\x05\x66\x61lse\x12\"\n\x13IgnoreQuotaDeadline\x18\x10 \x01(\x08:\x05\x66\x61lse\x1a/\n\x18TCmdUpdateWriteTimestamp\x12\x13\n\x0bWriteTimeMS\x18\x01 \x01(\x03\x1a#\n\x0fTCmdGetMaxSeqNo\x12\x10\n\x08SourceId\x18\x02 \x03(\x0c\x1a?\n\x10TCmdGetOwnership\x12\x16\n\x05Owner\x18\x01 \x01(\t:\x07\x64\x65\x66\x61ult\x12\x13\n\x05\x46orce\x18\x02 \x01(\x08:\x04true\x1a\x35\n\x10TCmdReserveBytes\x12\x0c\n\x04Size\x18\x01 \x01(\r\x12\x13\n\x0bLastRequest\x18\x02 \x01(\x08\x1a\x8b\x01\n\x18TCmdRegisterMessageGroup\x12\n\n\x02Id\x18\x01 \x01(\x0c\x12\x38\n\x11PartitionKeyRange\x18\x02 \x01(\x0b\x32\x1d.NKikimrPQ.TPartitionKeyRange\x12\x15\n\rStartingSeqNo\x18\x03 \x01(\x03\x12\x12\n\nAfterSplit\x18\x04 \x01(\x08\x1a(\n\x1aTCmdDeregisterMessageGroup\x12\n\n\x02Id\x18\x01 \x01(\x0c\x1a\xd3\x01\n\x15TCmdSplitMessageGroup\x12^\n\x10\x44\x65registerGroups\x18\x01 \x03(\x0b\x32\x44.NKikimrClient.TPersQueuePartitionRequest.TCmdDeregisterMessageGroup\x12Z\n\x0eRegisterGroups\x18\x02 \x03(\x0b\x32\x42.NKikimrClient.TPersQueuePartitionRequest.TCmdRegisterMessageGroup\"\xdb\x0b\n\x15TPersQueueMetaRequest\x12L\n\x0e\x43mdCreateTopic\x18\x01 \x01(\x0b\x32\x34.NKikimrClient.TPersQueueMetaRequest.TCmdCreateTopic\x12L\n\x0e\x43mdChangeTopic\x18\x02 \x01(\x0b\x32\x34.NKikimrClient.TPersQueueMetaRequest.TCmdChangeTopic\x12L\n\x0e\x43mdDeleteTopic\x18\x03 \x01(\x0b\x32\x34.NKikimrClient.TPersQueueMetaRequest.TCmdDeleteTopic\x12V\n\x13\x43mdGetTopicMetadata\x18\x04 \x01(\x0b\x32\x39.NKikimrClient.TPersQueueMetaRequest.TCmdGetTopicMetadata\x12`\n\x18\x43mdGetPartitionLocations\x18\x05 \x01(\x0b\x32>.NKikimrClient.TPersQueueMetaRequest.TCmdGetPartitionLocations\x12\\\n\x16\x43mdGetPartitionOffsets\x18\x06 \x01(\x0b\x32<.NKikimrClient.TPersQueueMetaRequest.TCmdGetPartitionOffsets\x12Z\n\x15\x43mdGetPartitionStatus\x18\x07 \x01(\x0b\x32;.NKikimrClient.TPersQueueMetaRequest.TCmdGetPartitionStatus\x12\\\n\x16\x43mdGetReadSessionsInfo\x18\x08 \x01(\x0b\x32<.NKikimrClient.TPersQueueMetaRequest.TCmdGetReadSessionsInfo\x1a\x86\x01\n\x0fTCmdCreateTopic\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x15\n\rNumPartitions\x18\x02 \x01(\x05\x12*\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12!\n\x16NumPartitionsPerTablet\x18\x04 \x01(\x05:\x01\x35\x1a\x63\n\x0fTCmdChangeTopic\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x15\n\rNumPartitions\x18\x02 \x01(\x05\x12*\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x1a \n\x0fTCmdDeleteTopic\x12\r\n\x05Topic\x18\x01 \x01(\t\x1a%\n\x14TCmdGetTopicMetadata\x12\r\n\x05Topic\x18\x01 \x03(\t\x1a\x31\n\rTTopicRequest\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x03(\x05\x1as\n\x19TCmdGetPartitionLocations\x12H\n\x0cTopicRequest\x18\x01 \x03(\x0b\x32\x32.NKikimrClient.TPersQueueMetaRequest.TTopicRequest\x12\x0c\n\x04Host\x18\x03 \x01(\t\x1au\n\x17TCmdGetPartitionOffsets\x12H\n\x0cTopicRequest\x18\x01 \x03(\x0b\x32\x32.NKikimrClient.TPersQueueMetaRequest.TTopicRequest\x12\x10\n\x08\x43lientId\x18\x02 \x01(\t\x1at\n\x16TCmdGetPartitionStatus\x12H\n\x0cTopicRequest\x18\x01 \x03(\x0b\x32\x32.NKikimrClient.TPersQueueMetaRequest.TTopicRequest\x12\x10\n\x08\x43lientId\x18\x02 \x01(\t\x1a:\n\x17TCmdGetReadSessionsInfo\x12\x10\n\x08\x43lientId\x18\x01 \x01(\t\x12\r\n\x05Topic\x18\x02 \x03(\t\"\xac\x02\n\x16TPersQueueFetchRequest\x12G\n\tPartition\x18\x01 \x03(\x0b\x32\x34.NKikimrClient.TPersQueueFetchRequest.TPartitionInfo\x12\x15\n\rTotalMaxBytes\x18\x02 \x01(\x05\x12\x11\n\x06WaitMs\x18\x03 \x01(\x05:\x01\x30\x12\x10\n\x08\x43lientId\x18\x04 \x01(\t\x12\x1e\n\x0fMirrorerRequest\x18\x05 \x01(\x08:\x05\x66\x61lse\x1am\n\x0eTPartitionInfo\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x01(\x05\x12\x0e\n\x06Offset\x18\x03 \x01(\x03\x12\x10\n\x08MaxBytes\x18\x04 \x01(\x05\x12\x17\n\x0fReadTimestampMs\x18\x05 \x01(\x04\"\x8a\x02\n\x11TPersQueueRequest\x12\x43\n\x10PartitionRequest\x18\x01 \x01(\x0b\x32).NKikimrClient.TPersQueuePartitionRequest\x12\x39\n\x0bMetaRequest\x18\x02 \x01(\x0b\x32$.NKikimrClient.TPersQueueMetaRequest\x12;\n\x0c\x46\x65tchRequest\x18\x03 \x01(\x0b\x32%.NKikimrClient.TPersQueueFetchRequest\x12\x15\n\rSecurityToken\x18\x05 \x01(\t\x12\x0e\n\x06Ticket\x18\x06 \x01(\t\x12\x11\n\tRequestId\x18\x64 \x01(\t\"\xdc\x19\n\x16TPersQueueMetaResponse\x12i\n\x1c\x43mdGetPartitionOffsetsResult\x18\x01 \x01(\x0b\x32\x43.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionOffsetsResult\x12\x63\n\x19\x43mdGetTopicMetadataResult\x18\x02 \x01(\x0b\x32@.NKikimrClient.TPersQueueMetaResponse.TCmdGetTopicMetadataResult\x12m\n\x1e\x43mdGetPartitionLocationsResult\x18\x03 \x01(\x0b\x32\x45.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionLocationsResult\x12g\n\x1b\x43mdGetPartitionStatusResult\x18\x04 \x01(\x0b\x32\x42.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionStatusResult\x12i\n\x1c\x43mdGetReadSessionsInfoResult\x18\x05 \x01(\x0b\x32\x43.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult\x1a\xb3\x02\n\x1dTCmdGetPartitionOffsetsResult\x12\x65\n\x0bTopicResult\x18\x01 \x03(\x0b\x32P.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionOffsetsResult.TTopicResult\x1a\xaa\x01\n\x0cTTopicResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12@\n\x0fPartitionResult\x18\x02 \x03(\x0b\x32\'.NKikimrPQ.TOffsetsResponse.TPartResult\x12\x34\n\tErrorCode\x18\x03 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x04 \x01(\t\x1a\xa8\x02\n\x1aTCmdGetTopicMetadataResult\x12^\n\tTopicInfo\x18\x02 \x03(\x0b\x32K.NKikimrClient.TPersQueueMetaResponse.TCmdGetTopicMetadataResult.TTopicInfo\x1a\xa9\x01\n\nTTopicInfo\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x15\n\rNumPartitions\x18\x02 \x01(\x05\x12*\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x1a.NKikimrPQ.TPQTabletConfig\x12\x34\n\tErrorCode\x18\x04 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x05 \x01(\t\x1a\x8b\x04\n\x1fTCmdGetPartitionLocationsResult\x12g\n\x0bTopicResult\x18\x02 \x03(\x0b\x32R.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionLocationsResult.TTopicResult\x1a\xfe\x02\n\x0cTTopicResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x80\x01\n\x11PartitionLocation\x18\x04 \x03(\x0b\x32\x65.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionLocationsResult.TTopicResult.TPartitionLocation\x12\x34\n\tErrorCode\x18\x05 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x06 \x01(\t\x1a\x90\x01\n\x12TPartitionLocation\x12\x11\n\tPartition\x18\x01 \x01(\x05\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0e\n\x06HostId\x18\x03 \x01(\x05\x12\x34\n\tErrorCode\x18\x06 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x07 \x01(\t\x1a\xb0\x02\n\x1cTCmdGetPartitionStatusResult\x12\x64\n\x0bTopicResult\x18\x02 \x03(\x0b\x32O.NKikimrClient.TPersQueueMetaResponse.TCmdGetPartitionStatusResult.TTopicResult\x1a\xa9\x01\n\x0cTTopicResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12?\n\x0fPartitionResult\x18\x02 \x03(\x0b\x32&.NKikimrPQ.TStatusResponse.TPartResult\x12\x34\n\tErrorCode\x18\x03 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x04 \x01(\t\x1a\x8c\n\n\x1dTCmdGetReadSessionsInfoResult\x12\x65\n\x0bTopicResult\x18\x02 \x03(\x0b\x32P.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult.TTopicResult\x12i\n\rSessionResult\x18\x03 \x03(\x0b\x32R.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult.TSessionResult\x1a\xf9\x02\n\x10TPartitionResult\x12\x35\n\tErrorCode\x18\xbc\x05 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x14\n\x0b\x45rrorReason\x18\xbd\x05 \x01(\t\x12\x11\n\tPartition\x18\x01 \x01(\r\x12\x14\n\x0c\x43lientOffset\x18\x02 \x01(\x04\x12\x13\n\x0bStartOffset\x18\x03 \x01(\x04\x12\x11\n\tEndOffset\x18\x04 \x01(\x04\x12\x12\n\nMessageLag\x18\x05 \x01(\x04\x12\x0f\n\x07TimeLag\x18\x07 \x01(\x04\x12\x0f\n\x07Session\x18\x08 \x01(\t\x12\x12\n\nClientNode\x18\t \x01(\t\x12\x11\n\tProxyNode\x18\n \x01(\t\x12\x12\n\nTabletNode\x18\x0b \x01(\t\x12\x11\n\tTimestamp\x18\x0c \x01(\t\x12\x18\n\x10\x43lientReadOffset\x18\r \x01(\x04\x12\x13\n\x0bReadTimeLag\x18\x0e \x01(\x04\x12\x14\n\x0cTabletNodeId\x18\x0f \x01(\r\x1a\xd7\x01\n\x0cTTopicResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12m\n\x0fPartitionResult\x18\x02 \x03(\x0b\x32T.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult.TPartitionResult\x12\x34\n\tErrorCode\x18\x03 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x04 \x01(\t\x1a\xc2\x03\n\x0eTSessionResult\x12\x0f\n\x07Session\x18\x01 \x01(\t\x12\x11\n\tTimestamp\x18\x05 \x01(\x04\x12\x12\n\nClientNode\x18\x06 \x01(\t\x12\x11\n\tProxyNode\x18\x07 \x01(\t\x12\x34\n\tErrorCode\x18\x08 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\t \x01(\t\x12|\n\x0fPartitionResult\x18\n \x03(\x0b\x32\x63.NKikimrClient.TPersQueueMetaResponse.TCmdGetReadSessionsInfoResult.TSessionResult.TPartitionResult\x1a\x9b\x01\n\x10TPartitionResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x01(\x04\x12\x13\n\x0bNextCommits\x18\x10 \x03(\x04\x12\x12\n\nLastReadId\x18\x11 \x01(\x04\x12\x17\n\x0fReadIdCommitted\x18\x12 \x01(\x04\x12\x10\n\x08\x41ssignId\x18\x13 \x01(\x04\x12\x11\n\tTimestamp\x18\x14 \x01(\x04\"\xc9\x04\n\x0eTCmdReadResult\x12\x11\n\tMaxOffset\x18\x02 \x01(\x04\x12\x35\n\x06Result\x18\x03 \x03(\x0b\x32%.NKikimrClient.TCmdReadResult.TResult\x12\x15\n\rBlobsFromDisk\x18\x04 \x01(\r\x12\x16\n\x0e\x42lobsFromCache\x18\x05 \x01(\r\x12\x34\n\tErrorCode\x18\x06 \x01(\x0e\x32!.NPersQueue.NErrorCode.EErrorCode\x12\x13\n\x0b\x45rrorReason\x18\x07 \x01(\t\x12\x17\n\x0f\x42lobsCachedSize\x18\x08 \x01(\x04\x12\x0f\n\x07SizeLag\x18\t \x01(\x04\x12\x16\n\x0eRealReadOffset\x18\n \x01(\x04\x12\x17\n\x0fWaitQuotaTimeMs\x18\x0b \x01(\x04\x12\x1b\n\x13ReadFromTimestampMs\x18\x0c \x01(\x04\x1a\xfa\x01\n\x07TResult\x12\x0e\n\x06Offset\x18\x01 \x01(\x04\x12\x0c\n\x04\x44\x61ta\x18\x02 \x01(\x0c\x12\x10\n\x08SourceId\x18\x03 \x01(\x0c\x12\r\n\x05SeqNo\x18\x04 \x01(\x04\x12\x0e\n\x06PartNo\x18\x05 \x01(\r\x12\x12\n\nTotalParts\x18\x06 \x01(\r\x12\x11\n\tTotalSize\x18\x07 \x01(\r\x12\x18\n\x10WriteTimestampMS\x18\x08 \x01(\x04\x12\x19\n\x11\x43reateTimestampMS\x18\t \x01(\x04\x12\x18\n\x10UncompressedSize\x18\n \x01(\r\x12\x14\n\x0cPartitionKey\x18\x0b \x01(\t\x12\x14\n\x0c\x45xplicitHash\x18\x0c \x01(\x0c\"\xc5\x01\n\x17TPersQueueFetchResponse\x12\x46\n\nPartResult\x18\x01 \x03(\x0b\x32\x32.NKikimrClient.TPersQueueFetchResponse.TPartResult\x1a\x62\n\x0bTPartResult\x12\r\n\x05Topic\x18\x01 \x01(\t\x12\x11\n\tPartition\x18\x02 \x01(\x05\x12\x31\n\nReadResult\x18\x03 \x01(\x0b\x32\x1d.NKikimrClient.TCmdReadResult\"\xe9\t\n\x1bTPersQueuePartitionResponse\x12R\n\x0e\x43mdWriteResult\x18\x01 \x03(\x0b\x32:.NKikimrClient.TPersQueuePartitionResponse.TCmdWriteResult\x12^\n\x14\x43mdGetMaxSeqNoResult\x18\x02 \x01(\x0b\x32@.NKikimrClient.TPersQueuePartitionResponse.TCmdGetMaxSeqNoResult\x12\x34\n\rCmdReadResult\x18\x03 \x01(\x0b\x32\x1d.NKikimrClient.TCmdReadResult\x12\x66\n\x18\x43mdGetClientOffsetResult\x18\x04 \x01(\x0b\x32\x44.NKikimrClient.TPersQueuePartitionResponse.TCmdGetClientOffsetResult\x12`\n\x15\x43mdGetOwnershipResult\x18\x05 \x01(\x0b\x32\x41.NKikimrClient.TPersQueuePartitionResponse.TCmdGetOwnershipResult\x12\x0e\n\x06\x43ookie\x18\x06 \x01(\x04\x1a\x8a\x02\n\x0fTCmdWriteResult\x12\x16\n\x0e\x41lreadyWritten\x18\x01 \x01(\x08\x12\x10\n\x08SourceId\x18\x02 \x01(\x0c\x12\r\n\x05SeqNo\x18\x03 \x01(\x03\x12\x0e\n\x06Offset\x18\x04 \x01(\x03\x12\x0e\n\x06PartNo\x18\x05 \x01(\x05\x12\x18\n\x10WriteTimestampMS\x18\x06 \x01(\x03\x12\x10\n\x08MaxSeqNo\x18\x07 \x01(\x03\x12\x1d\n\x15PartitionQuotedTimeMs\x18\x08 \x01(\r\x12\x19\n\x11TopicQuotedTimeMs\x18\x0b \x01(\r\x12#\n\x1bTotalTimeInPartitionQueueMs\x18\t \x01(\r\x12\x13\n\x0bWriteTimeMs\x18\n \x01(\r\x1a\xa0\x02\n\x15TCmdGetMaxSeqNoResult\x12\x64\n\x0cSourceIdInfo\x18\x02 \x03(\x0b\x32N.NKikimrClient.TPersQueuePartitionResponse.TCmdGetMaxSeqNoResult.TSourceIdInfo\x1a\xa0\x01\n\rTSourceIdInfo\x12\x10\n\x08SourceId\x18\x01 \x01(\x0c\x12\r\n\x05SeqNo\x18\x02 \x01(\x03\x12\x0e\n\x06Offset\x18\x03 \x01(\x03\x12\x18\n\x10WriteTimestampMS\x18\x04 \x01(\x03\x12\x10\n\x08\x45xplicit\x18\x05 \x01(\x08\x12\x32\n\x05State\x18\x06 \x01(\x0e\x32#.NKikimrPQ.TMessageGroupInfo.EState\x1a\xa6\x01\n\x19TCmdGetClientOffsetResult\x12\x0e\n\x06Offset\x18\x02 \x01(\x04\x12\x11\n\tEndOffset\x18\x03 \x01(\x04\x12\x18\n\x10WriteTimestampMS\x18\x05 \x01(\x04\x12\x19\n\x11\x43reateTimestampMS\x18\x06 \x01(\x04\x12\x0f\n\x07SizeLag\x18\x07 \x01(\x04\x12 \n\x18WriteTimestampEstimateMS\x18\x08 \x01(\x04\x1a-\n\x16TCmdGetOwnershipResult\x12\x13\n\x0bOwnerCookie\x18\x01 \x01(\tB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.msgbus_pq_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TPERSQUEUEPARTITIONREQUEST._serialized_start=180
  _TPERSQUEUEPARTITIONREQUEST._serialized_end=3135
  _TPERSQUEUEPARTITIONREQUEST_TCMDREAD._serialized_start=1572
  _TPERSQUEUEPARTITIONREQUEST_TCMDREAD._serialized_end=1878
  _TPERSQUEUEPARTITIONREQUEST_TCMDCREATESESSION._serialized_start=1880
  _TPERSQUEUEPARTITIONREQUEST_TCMDCREATESESSION._serialized_end=1970
  _TPERSQUEUEPARTITIONREQUEST_TCMDDELETESESSION._serialized_start=1972
  _TPERSQUEUEPARTITIONREQUEST_TCMDDELETESESSION._serialized_end=2028
  _TPERSQUEUEPARTITIONREQUEST_TCMDSETCLIENTOFFSET._serialized_start=2030
  _TPERSQUEUEPARTITIONREQUEST_TCMDSETCLIENTOFFSET._serialized_end=2136
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETCLIENTOFFSET._serialized_start=2138
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETCLIENTOFFSET._serialized_end=2177
  _TPERSQUEUEPARTITIONREQUEST_TCMDWRITE._serialized_start=2180
  _TPERSQUEUEPARTITIONREQUEST_TCMDWRITE._serialized_end=2531
  _TPERSQUEUEPARTITIONREQUEST_TCMDUPDATEWRITETIMESTAMP._serialized_start=2533
  _TPERSQUEUEPARTITIONREQUEST_TCMDUPDATEWRITETIMESTAMP._serialized_end=2580
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETMAXSEQNO._serialized_start=2582
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETMAXSEQNO._serialized_end=2617
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETOWNERSHIP._serialized_start=2619
  _TPERSQUEUEPARTITIONREQUEST_TCMDGETOWNERSHIP._serialized_end=2682
  _TPERSQUEUEPARTITIONREQUEST_TCMDRESERVEBYTES._serialized_start=2684
  _TPERSQUEUEPARTITIONREQUEST_TCMDRESERVEBYTES._serialized_end=2737
  _TPERSQUEUEPARTITIONREQUEST_TCMDREGISTERMESSAGEGROUP._serialized_start=2740
  _TPERSQUEUEPARTITIONREQUEST_TCMDREGISTERMESSAGEGROUP._serialized_end=2879
  _TPERSQUEUEPARTITIONREQUEST_TCMDDEREGISTERMESSAGEGROUP._serialized_start=2881
  _TPERSQUEUEPARTITIONREQUEST_TCMDDEREGISTERMESSAGEGROUP._serialized_end=2921
  _TPERSQUEUEPARTITIONREQUEST_TCMDSPLITMESSAGEGROUP._serialized_start=2924
  _TPERSQUEUEPARTITIONREQUEST_TCMDSPLITMESSAGEGROUP._serialized_end=3135
  _TPERSQUEUEMETAREQUEST._serialized_start=3138
  _TPERSQUEUEMETAREQUEST._serialized_end=4637
  _TPERSQUEUEMETAREQUEST_TCMDCREATETOPIC._serialized_start=3864
  _TPERSQUEUEMETAREQUEST_TCMDCREATETOPIC._serialized_end=3998
  _TPERSQUEUEMETAREQUEST_TCMDCHANGETOPIC._serialized_start=4000
  _TPERSQUEUEMETAREQUEST_TCMDCHANGETOPIC._serialized_end=4099
  _TPERSQUEUEMETAREQUEST_TCMDDELETETOPIC._serialized_start=4101
  _TPERSQUEUEMETAREQUEST_TCMDDELETETOPIC._serialized_end=4133
  _TPERSQUEUEMETAREQUEST_TCMDGETTOPICMETADATA._serialized_start=4135
  _TPERSQUEUEMETAREQUEST_TCMDGETTOPICMETADATA._serialized_end=4172
  _TPERSQUEUEMETAREQUEST_TTOPICREQUEST._serialized_start=4174
  _TPERSQUEUEMETAREQUEST_TTOPICREQUEST._serialized_end=4223
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONLOCATIONS._serialized_start=4225
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONLOCATIONS._serialized_end=4340
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONOFFSETS._serialized_start=4342
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONOFFSETS._serialized_end=4459
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONSTATUS._serialized_start=4461
  _TPERSQUEUEMETAREQUEST_TCMDGETPARTITIONSTATUS._serialized_end=4577
  _TPERSQUEUEMETAREQUEST_TCMDGETREADSESSIONSINFO._serialized_start=4579
  _TPERSQUEUEMETAREQUEST_TCMDGETREADSESSIONSINFO._serialized_end=4637
  _TPERSQUEUEFETCHREQUEST._serialized_start=4640
  _TPERSQUEUEFETCHREQUEST._serialized_end=4940
  _TPERSQUEUEFETCHREQUEST_TPARTITIONINFO._serialized_start=4831
  _TPERSQUEUEFETCHREQUEST_TPARTITIONINFO._serialized_end=4940
  _TPERSQUEUEREQUEST._serialized_start=4943
  _TPERSQUEUEREQUEST._serialized_end=5209
  _TPERSQUEUEMETARESPONSE._serialized_start=5212
  _TPERSQUEUEMETARESPONSE._serialized_end=8504
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONOFFSETSRESULT._serialized_start=5770
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONOFFSETSRESULT._serialized_end=6077
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONOFFSETSRESULT_TTOPICRESULT._serialized_start=5907
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONOFFSETSRESULT_TTOPICRESULT._serialized_end=6077
  _TPERSQUEUEMETARESPONSE_TCMDGETTOPICMETADATARESULT._serialized_start=6080
  _TPERSQUEUEMETARESPONSE_TCMDGETTOPICMETADATARESULT._serialized_end=6376
  _TPERSQUEUEMETARESPONSE_TCMDGETTOPICMETADATARESULT_TTOPICINFO._serialized_start=6207
  _TPERSQUEUEMETARESPONSE_TCMDGETTOPICMETADATARESULT_TTOPICINFO._serialized_end=6376
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT._serialized_start=6379
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT._serialized_end=6902
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT_TTOPICRESULT._serialized_start=6520
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT_TTOPICRESULT._serialized_end=6902
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT_TTOPICRESULT_TPARTITIONLOCATION._serialized_start=6758
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONLOCATIONSRESULT_TTOPICRESULT_TPARTITIONLOCATION._serialized_end=6902
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONSTATUSRESULT._serialized_start=6905
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONSTATUSRESULT._serialized_end=7209
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONSTATUSRESULT_TTOPICRESULT._serialized_start=7040
  _TPERSQUEUEMETARESPONSE_TCMDGETPARTITIONSTATUSRESULT_TTOPICRESULT._serialized_end=7209
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT._serialized_start=7212
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT._serialized_end=8504
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TPARTITIONRESULT._serialized_start=7456
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TPARTITIONRESULT._serialized_end=7833
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TTOPICRESULT._serialized_start=7836
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TTOPICRESULT._serialized_end=8051
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TSESSIONRESULT._serialized_start=8054
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TSESSIONRESULT._serialized_end=8504
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TSESSIONRESULT_TPARTITIONRESULT._serialized_start=8349
  _TPERSQUEUEMETARESPONSE_TCMDGETREADSESSIONSINFORESULT_TSESSIONRESULT_TPARTITIONRESULT._serialized_end=8504
  _TCMDREADRESULT._serialized_start=8507
  _TCMDREADRESULT._serialized_end=9092
  _TCMDREADRESULT_TRESULT._serialized_start=8842
  _TCMDREADRESULT_TRESULT._serialized_end=9092
  _TPERSQUEUEFETCHRESPONSE._serialized_start=9095
  _TPERSQUEUEFETCHRESPONSE._serialized_end=9292
  _TPERSQUEUEFETCHRESPONSE_TPARTRESULT._serialized_start=9194
  _TPERSQUEUEFETCHRESPONSE_TPARTRESULT._serialized_end=9292
  _TPERSQUEUEPARTITIONRESPONSE._serialized_start=9295
  _TPERSQUEUEPARTITIONRESPONSE._serialized_end=10552
  _TPERSQUEUEPARTITIONRESPONSE_TCMDWRITERESULT._serialized_start=9779
  _TPERSQUEUEPARTITIONRESPONSE_TCMDWRITERESULT._serialized_end=10045
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETMAXSEQNORESULT._serialized_start=10048
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETMAXSEQNORESULT._serialized_end=10336
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETMAXSEQNORESULT_TSOURCEIDINFO._serialized_start=10176
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETMAXSEQNORESULT_TSOURCEIDINFO._serialized_end=10336
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETCLIENTOFFSETRESULT._serialized_start=10339
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETCLIENTOFFSETRESULT._serialized_end=10505
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETOWNERSHIPRESULT._serialized_start=10507
  _TPERSQUEUEPARTITIONRESPONSE_TCMDGETOWNERSHIPRESULT._serialized_end=10552
# @@protoc_insertion_point(module_scope)
