# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/counters_kesus.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import counters_pb2 as ydb_dot_core_dot_protos_dot_counters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/counters_kesus.proto\x12\x0eNKikimr.NKesus\x1a\x1eydb/core/protos/counters.proto*\x96\x03\n\x0f\x45SimpleCounters\x12\x19\n\x15\x43OUNTER_SIMPLE_IGNORE\x10\x00\x12&\n\x13\x43OUNTER_PROXY_COUNT\x10\x01\x1a\r\x82\xd6\x1b\t\n\x07Proxies\x12)\n\x15\x43OUNTER_SESSION_COUNT\x10\x02\x1a\x0e\x82\xd6\x1b\n\n\x08Sessions\x12\x36\n\x1c\x43OUNTER_SESSION_ACTIVE_COUNT\x10\x03\x1a\x14\x82\xd6\x1b\x10\n\x0e\x41\x63tiveSessions\x12-\n\x17\x43OUNTER_SEMAPHORE_COUNT\x10\x04\x1a\x10\x82\xd6\x1b\x0c\n\nSemaphores\x12\x38\n\x1d\x43OUNTER_SEMAPHORE_OWNER_COUNT\x10\x05\x1a\x15\x82\xd6\x1b\x11\n\x0fSemaphoreOwners\x12:\n\x1e\x43OUNTER_SEMAPHORE_WAITER_COUNT\x10\x06\x1a\x16\x82\xd6\x1b\x12\n\x10SemaphoreWaiters\x12\x38\n\x1d\x43OUNTER_QUOTER_RESOURCE_COUNT\x10\x07\x1a\x15\x82\xd6\x1b\x11\n\x0fQuoterResources*\xb5\n\n\x13\x45\x43umulativeCounters\x12\x1d\n\x19\x43OUNTER_CUMULATIVE_IGNORE\x10\x00\x12K\n!COUNTER_SCHEDULED_SESSION_TIMEOUT\x10\x01\x1a$\x82\xd6\x1b \n\x1e\x45vents/ScheduledSessionTimeout\x12K\n!COUNTER_SCHEDULED_ACQUIRE_TIMEOUT\x10\x02\x1a$\x82\xd6\x1b \n\x1e\x45vents/ScheduledAcquireTimeout\x12\x38\n\x17\x43OUNTER_SESSION_TIMEOUT\x10\x03\x1a\x1b\x82\xd6\x1b\x17\n\x15\x45vents/SessionTimeout\x12\x38\n\x17\x43OUNTER_ACQUIRE_TIMEOUT\x10\x04\x1a\x1b\x82\xd6\x1b\x17\n\x15\x45vents/AcquireTimeout\x12\x32\n\x14\x43OUNTER_PROXY_KICKED\x10\x05\x1a\x18\x82\xd6\x1b\x14\n\x12\x45vents/ProxyKicked\x12\x36\n\x16\x43OUNTER_SESSION_STOLEN\x10\x06\x1a\x1a\x82\xd6\x1b\x16\n\x14\x45vents/SessionStolen\x12=\n\x1b\x43OUNTER_REQS_PROXY_REGISTER\x10\x07\x1a\x1c\x82\xd6\x1b\x18\n\x16Requests/ProxyRegister\x12\x41\n\x1d\x43OUNTER_REQS_PROXY_UNREGISTER\x10\x08\x1a\x1e\x82\xd6\x1b\x1a\n\x18Requests/ProxyUnregister\x12=\n\x1b\x43OUNTER_REQS_SESSION_ATTACH\x10\t\x1a\x1c\x82\xd6\x1b\x18\n\x16Requests/SessionAttach\x12?\n\x1c\x43OUNTER_REQS_SESSION_DESTROY\x10\n\x1a\x1d\x82\xd6\x1b\x19\n\x17Requests/SessionDestroy\x12=\n\x1b\x43OUNTER_REQS_SESSION_DETACH\x10\x0b\x1a\x1c\x82\xd6\x1b\x18\n\x16Requests/SessionDetach\x12\x43\n\x1e\x43OUNTER_REQS_SEMAPHORE_ACQUIRE\x10\x0c\x1a\x1f\x82\xd6\x1b\x1b\n\x19Requests/SemaphoreAcquire\x12\x41\n\x1d\x43OUNTER_REQS_SEMAPHORE_CREATE\x10\r\x1a\x1e\x82\xd6\x1b\x1a\n\x18Requests/SemaphoreCreate\x12\x41\n\x1d\x43OUNTER_REQS_SEMAPHORE_DELETE\x10\x0e\x1a\x1e\x82\xd6\x1b\x1a\n\x18Requests/SemaphoreDelete\x12\x43\n\x1e\x43OUNTER_REQS_SEMAPHORE_RELEASE\x10\x0f\x1a\x1f\x82\xd6\x1b\x1b\n\x19Requests/SemaphoreRelease\x12P\n%COUNTER_REQS_QUOTER_RESOURCE_DESCRIBE\x10\x10\x1a%\x82\xd6\x1b!\n\x1fRequests/QuoterResourceDescribe\x12\x46\n COUNTER_REQS_QUOTER_RESOURCE_ADD\x10\x11\x1a \x82\xd6\x1b\x1c\n\x1aRequests/QuoterResourceAdd\x12L\n#COUNTER_REQS_QUOTER_RESOURCE_UPDATE\x10\x12\x1a#\x82\xd6\x1b\x1f\n\x1dRequests/QuoterResourceUpdate\x12L\n#COUNTER_REQS_QUOTER_RESOURCE_DELETE\x10\x13\x1a#\x82\xd6\x1b\x1f\n\x1dRequests/QuoterResourceDelete*N\n\x13\x45PercentileCounters\x12\x1d\n\x19\x43OUNTER_PERCENTILE_IGNORE\x10\x00\x1a\x18\x92\xd6\x1b\x14\x12\x08\x08\x00\x12\x04\x30 ms\x12\x08\x08\x01\x12\x04\x31 ms*\xfe\x08\n\x08\x45TxTypes\x12*\n\x12TXTYPE_INIT_SCHEMA\x10\x00\x1a\x12\x8a\xd6\x1b\x0e\n\x0cTxInitSchema\x12\x1d\n\x0bTXTYPE_INIT\x10\x01\x1a\x0c\x8a\xd6\x1b\x08\n\x06TxInit\x12\x1f\n\x0cTXTYPE_DUMMY\x10\x02\x1a\r\x8a\xd6\x1b\t\n\x07TxDummy\x12(\n\x11TXTYPE_CONFIG_GET\x10\x03\x1a\x11\x8a\xd6\x1b\r\n\x0bTxConfigGet\x12(\n\x11TXTYPE_CONFIG_SET\x10\x04\x1a\x11\x8a\xd6\x1b\r\n\x0bTxConfigSet\x12\x30\n\x15TXTYPE_SESSION_ATTACH\x10\x05\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxSessionAttach\x12\x32\n\x16TXTYPE_SESSION_DESTROY\x10\x06\x1a\x16\x8a\xd6\x1b\x12\n\x10TxSessionDestroy\x12\x30\n\x15TXTYPE_SESSION_DETACH\x10\x07\x1a\x15\x8a\xd6\x1b\x11\n\x0fTxSessionDetach\x12\x32\n\x16TXTYPE_SESSION_TIMEOUT\x10\x08\x1a\x16\x8a\xd6\x1b\x12\n\x10TxSessionTimeout\x12\x36\n\x18TXTYPE_SESSIONS_DESCRIBE\x10\t\x1a\x18\x8a\xd6\x1b\x14\n\x12TxSessionsDescribe\x12\x36\n\x18TXTYPE_SEMAPHORE_ACQUIRE\x10\n\x1a\x18\x8a\xd6\x1b\x14\n\x12TxSemaphoreAcquire\x12\x34\n\x17TXTYPE_SEMAPHORE_CREATE\x10\x0b\x1a\x17\x8a\xd6\x1b\x13\n\x11TxSemaphoreCreate\x12\x38\n\x19TXTYPE_SEMAPHORE_DESCRIBE\x10\x0c\x1a\x19\x8a\xd6\x1b\x15\n\x13TxSemaphoreDescribe\x12\x34\n\x17TXTYPE_SEMAPHORE_DELETE\x10\r\x1a\x17\x8a\xd6\x1b\x13\n\x11TxSemaphoreDelete\x12\x36\n\x18TXTYPE_SEMAPHORE_RELEASE\x10\x0e\x1a\x18\x8a\xd6\x1b\x14\n\x12TxSemaphoreRelease\x12\x36\n\x18TXTYPE_SEMAPHORE_TIMEOUT\x10\x0f\x1a\x18\x8a\xd6\x1b\x14\n\x12TxSemaphoreTimeout\x12\x34\n\x17TXTYPE_SEMAPHORE_UPDATE\x10\x10\x1a\x17\x8a\xd6\x1b\x13\n\x11TxSemaphoreUpdate\x12(\n\x11TXTYPE_SELF_CHECK\x10\x11\x1a\x11\x8a\xd6\x1b\r\n\x0bTxSelfCheck\x12\x43\n\x1fTXTYPE_QUOTER_RESOURCE_DESCRIBE\x10\x12\x1a\x1e\x8a\xd6\x1b\x1a\n\x18TxQouterResourceDescribe\x12\x39\n\x1aTXTYPE_QUOTER_RESOURCE_ADD\x10\x13\x1a\x19\x8a\xd6\x1b\x15\n\x13TxQouterResourceAdd\x12?\n\x1dTXTYPE_QUOTER_RESOURCE_UPDATE\x10\x14\x1a\x1c\x8a\xd6\x1b\x18\n\x16TxQouterResourceUpdate\x12?\n\x1dTXTYPE_QUOTER_RESOURCE_DELETE\x10\x15\x1a\x1c\x8a\xd6\x1b\x18\n\x16TxQouterResourceDeleteB!\n\x16ru.yandex.kikimr.proto\x9a\xd6\x1b\x05Kesus')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.counters_kesus_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto\232\326\033\005Kesus'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PROXY_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_PROXY_COUNT"]._serialized_options = b'\202\326\033\t\n\007Proxies'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SESSION_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SESSION_COUNT"]._serialized_options = b'\202\326\033\n\n\010Sessions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SESSION_ACTIVE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SESSION_ACTIVE_COUNT"]._serialized_options = b'\202\326\033\020\n\016ActiveSessions'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_COUNT"]._serialized_options = b'\202\326\033\014\n\nSemaphores'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_OWNER_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_OWNER_COUNT"]._serialized_options = b'\202\326\033\021\n\017SemaphoreOwners'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_WAITER_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_SEMAPHORE_WAITER_COUNT"]._serialized_options = b'\202\326\033\022\n\020SemaphoreWaiters'
  _ESIMPLECOUNTERS.values_by_name["COUNTER_QUOTER_RESOURCE_COUNT"]._options = None
  _ESIMPLECOUNTERS.values_by_name["COUNTER_QUOTER_RESOURCE_COUNT"]._serialized_options = b'\202\326\033\021\n\017QuoterResources'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCHEDULED_SESSION_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCHEDULED_SESSION_TIMEOUT"]._serialized_options = b'\202\326\033 \n\036Events/ScheduledSessionTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCHEDULED_ACQUIRE_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SCHEDULED_ACQUIRE_TIMEOUT"]._serialized_options = b'\202\326\033 \n\036Events/ScheduledAcquireTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SESSION_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SESSION_TIMEOUT"]._serialized_options = b'\202\326\033\027\n\025Events/SessionTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ACQUIRE_TIMEOUT"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_ACQUIRE_TIMEOUT"]._serialized_options = b'\202\326\033\027\n\025Events/AcquireTimeout'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PROXY_KICKED"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_PROXY_KICKED"]._serialized_options = b'\202\326\033\024\n\022Events/ProxyKicked'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SESSION_STOLEN"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_SESSION_STOLEN"]._serialized_options = b'\202\326\033\026\n\024Events/SessionStolen'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_PROXY_REGISTER"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_PROXY_REGISTER"]._serialized_options = b'\202\326\033\030\n\026Requests/ProxyRegister'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_PROXY_UNREGISTER"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_PROXY_UNREGISTER"]._serialized_options = b'\202\326\033\032\n\030Requests/ProxyUnregister'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_ATTACH"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_ATTACH"]._serialized_options = b'\202\326\033\030\n\026Requests/SessionAttach'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_DESTROY"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_DESTROY"]._serialized_options = b'\202\326\033\031\n\027Requests/SessionDestroy'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_DETACH"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SESSION_DETACH"]._serialized_options = b'\202\326\033\030\n\026Requests/SessionDetach'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_ACQUIRE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_ACQUIRE"]._serialized_options = b'\202\326\033\033\n\031Requests/SemaphoreAcquire'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_CREATE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_CREATE"]._serialized_options = b'\202\326\033\032\n\030Requests/SemaphoreCreate'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_DELETE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_DELETE"]._serialized_options = b'\202\326\033\032\n\030Requests/SemaphoreDelete'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_RELEASE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_SEMAPHORE_RELEASE"]._serialized_options = b'\202\326\033\033\n\031Requests/SemaphoreRelease'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_DESCRIBE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_DESCRIBE"]._serialized_options = b'\202\326\033!\n\037Requests/QuoterResourceDescribe'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_ADD"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_ADD"]._serialized_options = b'\202\326\033\034\n\032Requests/QuoterResourceAdd'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_UPDATE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_UPDATE"]._serialized_options = b'\202\326\033\037\n\035Requests/QuoterResourceUpdate'
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_DELETE"]._options = None
  _ECUMULATIVECOUNTERS.values_by_name["COUNTER_REQS_QUOTER_RESOURCE_DELETE"]._serialized_options = b'\202\326\033\037\n\035Requests/QuoterResourceDelete'
  _EPERCENTILECOUNTERS._options = None
  _EPERCENTILECOUNTERS._serialized_options = b'\222\326\033\024\022\010\010\000\022\0040 ms\022\010\010\001\022\0041 ms'
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT_SCHEMA"]._serialized_options = b'\212\326\033\016\n\014TxInitSchema'
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_INIT"]._serialized_options = b'\212\326\033\010\n\006TxInit'
  _ETXTYPES.values_by_name["TXTYPE_DUMMY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_DUMMY"]._serialized_options = b'\212\326\033\t\n\007TxDummy'
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_GET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_GET"]._serialized_options = b'\212\326\033\r\n\013TxConfigGet'
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_SET"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_CONFIG_SET"]._serialized_options = b'\212\326\033\r\n\013TxConfigSet'
  _ETXTYPES.values_by_name["TXTYPE_SESSION_ATTACH"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSION_ATTACH"]._serialized_options = b'\212\326\033\021\n\017TxSessionAttach'
  _ETXTYPES.values_by_name["TXTYPE_SESSION_DESTROY"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSION_DESTROY"]._serialized_options = b'\212\326\033\022\n\020TxSessionDestroy'
  _ETXTYPES.values_by_name["TXTYPE_SESSION_DETACH"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSION_DETACH"]._serialized_options = b'\212\326\033\021\n\017TxSessionDetach'
  _ETXTYPES.values_by_name["TXTYPE_SESSION_TIMEOUT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSION_TIMEOUT"]._serialized_options = b'\212\326\033\022\n\020TxSessionTimeout'
  _ETXTYPES.values_by_name["TXTYPE_SESSIONS_DESCRIBE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SESSIONS_DESCRIBE"]._serialized_options = b'\212\326\033\024\n\022TxSessionsDescribe'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_ACQUIRE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_ACQUIRE"]._serialized_options = b'\212\326\033\024\n\022TxSemaphoreAcquire'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_CREATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_CREATE"]._serialized_options = b'\212\326\033\023\n\021TxSemaphoreCreate'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_DESCRIBE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_DESCRIBE"]._serialized_options = b'\212\326\033\025\n\023TxSemaphoreDescribe'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_DELETE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_DELETE"]._serialized_options = b'\212\326\033\023\n\021TxSemaphoreDelete'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_RELEASE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_RELEASE"]._serialized_options = b'\212\326\033\024\n\022TxSemaphoreRelease'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_TIMEOUT"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_TIMEOUT"]._serialized_options = b'\212\326\033\024\n\022TxSemaphoreTimeout'
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_UPDATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SEMAPHORE_UPDATE"]._serialized_options = b'\212\326\033\023\n\021TxSemaphoreUpdate'
  _ETXTYPES.values_by_name["TXTYPE_SELF_CHECK"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_SELF_CHECK"]._serialized_options = b'\212\326\033\r\n\013TxSelfCheck'
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_DESCRIBE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_DESCRIBE"]._serialized_options = b'\212\326\033\032\n\030TxQouterResourceDescribe'
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_ADD"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_ADD"]._serialized_options = b'\212\326\033\025\n\023TxQouterResourceAdd'
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_UPDATE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_UPDATE"]._serialized_options = b'\212\326\033\030\n\026TxQouterResourceUpdate'
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_DELETE"]._options = None
  _ETXTYPES.values_by_name["TXTYPE_QUOTER_RESOURCE_DELETE"]._serialized_options = b'\212\326\033\030\n\026TxQouterResourceDelete'
  _ESIMPLECOUNTERS._serialized_start=89
  _ESIMPLECOUNTERS._serialized_end=495
  _ECUMULATIVECOUNTERS._serialized_start=498
  _ECUMULATIVECOUNTERS._serialized_end=1831
  _EPERCENTILECOUNTERS._serialized_start=1833
  _EPERCENTILECOUNTERS._serialized_end=1911
  _ETXTYPES._serialized_start=1914
  _ETXTYPES._serialized_end=3064
# @@protoc_insertion_point(module_scope)
