# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/console_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from library.cpp.actors.protos import actors_pb2 as library_dot_cpp_dot_actors_dot_protos_dot_actors__pb2
from ydb.core.protos import config_pb2 as ydb_dot_core_dot_protos_dot_config__pb2
from ydb.core.protos import console_base_pb2 as ydb_dot_core_dot_protos_dot_console__base__pb2
from ydb.public.api.protos import ydb_status_codes_pb2 as ydb_dot_public_dot_api_dot_protos_dot_ydb__status__codes__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$ydb/core/protos/console_config.proto\x12\x0eNKikimrConsole\x1a&library/cpp/actors/protos/actors.proto\x1a\x1cydb/core/protos/config.proto\x1a\"ydb/core/protos/console_base.proto\x1a,ydb/public/api/protos/ydb_status_codes.proto\"/\n\rTConfigItemId\x12\n\n\x02Id\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\"\x17\n\x08TItemIds\x12\x0b\n\x03Ids\x18\x01 \x03(\x04\"\x19\n\x08TNodeIds\x12\r\n\x05Nodes\x18\x01 \x03(\r\"\x17\n\x06THosts\x12\r\n\x05Hosts\x18\x01 \x03(\t\"\x1b\n\x08TTenants\x12\x0f\n\x07Tenants\x18\x01 \x03(\t\"\x1f\n\nTNodeTypes\x12\x11\n\tNodeTypes\x18\x01 \x03(\t\"6\n\x12TTenantAndNodeType\x12\x0e\n\x06Tenant\x18\x01 \x01(\t\x12\x10\n\x08NodeType\x18\x02 \x01(\t\"U\n\x13TTenantAndNodeTypes\x12>\n\x12TenantAndNodeTypes\x18\x01 \x03(\x0b\x32\".NKikimrConsole.TTenantAndNodeType\"\x1b\n\x08TCookies\x12\x0f\n\x07\x43ookies\x18\x01 \x03(\t\"\xbc\x01\n\x0bTUsageScope\x12.\n\nNodeFilter\x18\x01 \x01(\x0b\x32\x18.NKikimrConsole.TNodeIdsH\x00\x12,\n\nHostFilter\x18\x02 \x01(\x0b\x32\x16.NKikimrConsole.THostsH\x00\x12\x45\n\x17TenantAndNodeTypeFilter\x18\x03 \x01(\x0b\x32\".NKikimrConsole.TTenantAndNodeTypeH\x00\x42\x08\n\x06\x46ilter\"Q\n\x0fTNodeAttributes\x12\x0e\n\x06NodeId\x18\x01 \x01(\r\x12\x0c\n\x04Host\x18\x02 \x01(\t\x12\x0e\n\x06Tenant\x18\x03 \x01(\t\x12\x10\n\x08NodeType\x18\x04 \x01(\t\"\xfe\x0c\n\x0bTConfigItem\x12)\n\x02Id\x18\x01 \x01(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\x12\x0c\n\x04Kind\x18\x02 \x01(\r\x12)\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\x12/\n\nUsageScope\x18\x04 \x01(\x0b\x32\x1b.NKikimrConsole.TUsageScope\x12\r\n\x05Order\x18\x05 \x01(\r\x12\x18\n\rMergeStrategy\x18\x06 \x01(\r:\x01\x32\x12\x0e\n\x06\x43ookie\x18\x07 \x01(\t\"\xd6\n\n\x05\x45Kind\x12\x08\n\x04\x41uto\x10\x00\x12\x19\n\x15\x41\x63torSystemConfigItem\x10\x01\x12\x11\n\rLogConfigItem\x10\x02\x12\x19\n\x15NameserviceConfigItem\x10\x03\x12\x1a\n\x16InterconnectConfigItem\x10\x04\x12\x15\n\x11\x44omainsConfigItem\x10\x05\x12\x19\n\x15\x42lobStorageConfigItem\x10\x06\x12\x1c\n\x18\x43hannelProfileConfigItem\x10\x07\x12\x17\n\x13\x42ootstrapConfigItem\x10\x08\x12\x18\n\x14MonitoringConfigItem\x10\n\x12\x1b\n\x17RestartsCountConfigItem\x10\x0b\x12\x18\n\x14MessageBusConfigItem\x10\x0c\x12\x15\n\x11TabletsConfigItem\x10\r\x12\x13\n\x0fVDiskConfigItem\x10\x0e\x12\x18\n\x14\x44riveModelConfigItem\x10\x1f\x12\x16\n\x12IncrHugeConfigItem\x10\x12\x12\x0f\n\x0bUDFsDirItem\x10\x0f\x12\x11\n\rUDFsPathsItem\x10\x10\x12\x11\n\rKQPConfigItem\x10\x11\x12\x17\n\x13MemoryLogConfigItem\x10\x13\x12\x12\n\x0eGRpcConfigItem\x10\x14\x12 \n\x1c\x44ynamicNameserviceConfigItem\x10\x16\x12\x19\n\x15\x44ynamicNodeConfigItem\x10\x18\x12\x11\n\rCmsConfigItem\x10\x19\x12\x14\n\x10\x46\x65\x61tureFlagsItem\x10\x1a\x12\x11\n\rSqsConfigItem\x10\x1b\x12\x10\n\x0cPQConfigItem\x10\x1c\x12\x18\n\x14TenantPoolConfigItem\x10\x1d\x12\x12\n\x0e\x41uthConfigItem\x10\x1e\x12\x1e\n\x1aTenantSlotBrokerConfigItem\x10 \x12\x1f\n\x1b\x43onfigsDispatcherConfigItem\x10!\x12\x1b\n\x17TableProfilesConfigItem\x10\"\x12\x11\n\rKeyConfigItem\x10#\x12\x18\n\x14NodeBrokerConfigItem\x10$\x12\x1a\n\x16TableServiceConfigItem\x10%\x12\x19\n\x15SharedCacheConfigItem\x10&\x12\x1f\n\x1bImmediateControlsConfigItem\x10\'\x12\x17\n\x13\x41llocatorConfigItem\x10(\x12 \n\x1cPQClusterDiscoveryConfigItem\x10)\x12\x1b\n\x17NetClassifierConfigItem\x10*\x12(\n$NetClassifierDistributableConfigItem\x10+\x12\x1c\n\x18ResourceBrokerConfigItem\x10,\x12\x16\n\x12MeteringConfigItem\x10-\x12\x12\n\x0eHiveConfigItem\x10.\x12\x17\n\x13\x44\x61taShardConfigItem\x10\x31\x12\x1c\n\x18\x46\x65\x64\x65ratedQueryConfigItem\x10\x32\x12\x16\n\x12PDiskKeyConfigItem\x10\x33\x12\x18\n\x14\x43ompactionConfigItem\x10\x34\x12\x17\n\x13HttpProxyConfigItem\x10\x35\x12\x19\n\x15SchemeShardConfigItem\x10\x36\x12,\n(ClientCertificateAuthorizationConfigItem\x10\x37\x12\x14\n\x10NamedConfigsItem\x10\x64\x12\x19\n\x15\x43lusterYamlConfigItem\x10\x65\"H\n\x0e\x45MergeStrategy\x12\r\n\tOVERWRITE\x10\x01\x12\t\n\x05MERGE\x10\x02\x12\x1c\n\x18MERGE_OVERWRITE_REPEATED\x10\x03\"Z\n\x0eTAddConfigItem\x12/\n\nConfigItem\x18\x01 \x01(\x0b\x32\x1b.NKikimrConsole.TConfigItem\x12\x17\n\x0f\x45nableAutoSplit\x18\x02 \x01(\x08\"H\n\x11TRemoveConfigItem\x12\x33\n\x0c\x43onfigItemId\x18\x01 \x01(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\"P\n\x12TRemoveConfigItems\x12\x30\n\x0c\x43ookieFilter\x18\x01 \x01(\x0b\x32\x18.NKikimrConsole.TCookiesH\x00\x42\x08\n\x06\x46ilter\"D\n\x11TModifyConfigItem\x12/\n\nConfigItem\x18\x01 \x01(\x0b\x32\x1b.NKikimrConsole.TConfigItem\"\x94\x02\n\x10TConfigureAction\x12\x37\n\rAddConfigItem\x18\x01 \x01(\x0b\x32\x1e.NKikimrConsole.TAddConfigItemH\x00\x12=\n\x10RemoveConfigItem\x18\x02 \x01(\x0b\x32!.NKikimrConsole.TRemoveConfigItemH\x00\x12=\n\x10ModifyConfigItem\x18\x03 \x01(\x0b\x32!.NKikimrConsole.TModifyConfigItemH\x00\x12?\n\x11RemoveConfigItems\x18\x04 \x01(\x0b\x32\".NKikimrConsole.TRemoveConfigItemsH\x00\x42\x08\n\x06\x41\x63tion\"\x86\x01\n\x11TConfigureRequest\x12\x31\n\x07\x41\x63tions\x18\x01 \x03(\x0b\x32 .NKikimrConsole.TConfigureAction\x12\x0e\n\x06\x44ryRun\x18\x02 \x01(\x08\x12\x1b\n\x13\x46illAffectedConfigs\x18\x03 \x01(\x08\x12\x11\n\tUserToken\x18\x04 \x01(\x0c\"\xb2\x02\n\x12TConfigureResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x14\n\x0c\x41\x64\x64\x65\x64ItemIds\x18\x02 \x03(\x04\x12K\n\x0f\x41\x66\x66\x65\x63tedConfigs\x18\x03 \x03(\x0b\x32\x32.NKikimrConsole.TConfigureResponse.TAffectedConfig\x1a\x8f\x01\n\x0fTAffectedConfig\x12\x0e\n\x06Tenant\x18\x01 \x01(\t\x12\x10\n\x08NodeType\x18\x02 \x01(\t\x12,\n\tOldConfig\x18\x03 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\x12,\n\tNewConfig\x18\x04 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\"\xa2\x03\n\x16TGetConfigItemsRequest\x12\x0f\n\x07ItemIds\x18\x01 \x03(\x04\x12,\n\nNodeFilter\x18\x02 \x01(\x0b\x32\x18.NKikimrConsole.TNodeIds\x12*\n\nHostFilter\x18\x03 \x01(\x0b\x32\x16.NKikimrConsole.THosts\x12.\n\x0cTenantFilter\x18\x04 \x01(\x0b\x32\x18.NKikimrConsole.TTenants\x12\x32\n\x0eNodeTypeFilter\x18\x05 \x01(\x0b\x32\x1a.NKikimrConsole.TNodeTypes\x12\x44\n\x17TenantAndNodeTypeFilter\x18\x06 \x01(\x0b\x32#.NKikimrConsole.TTenantAndNodeTypes\x12\x30\n\x0bUsageScopes\x18\x07 \x03(\x0b\x32\x1b.NKikimrConsole.TUsageScope\x12.\n\x0c\x43ookieFilter\x18\x08 \x01(\x0b\x32\x18.NKikimrConsole.TCookies\x12\x11\n\tItemKinds\x18\n \x03(\r\"t\n\x17TGetConfigItemsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x30\n\x0b\x43onfigItems\x18\x02 \x03(\x0b\x32\x1b.NKikimrConsole.TConfigItem\"^\n\x1aTGetNodeConfigItemsRequest\x12-\n\x04Node\x18\x01 \x01(\x0b\x32\x1f.NKikimrConsole.TNodeAttributes\x12\x11\n\tItemKinds\x18\x02 \x03(\r\"x\n\x1bTGetNodeConfigItemsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x30\n\x0b\x43onfigItems\x18\x02 \x03(\x0b\x32\x1b.NKikimrConsole.TConfigItem\"Y\n\x15TGetNodeConfigRequest\x12-\n\x04Node\x18\x01 \x01(\x0b\x32\x1f.NKikimrConsole.TNodeAttributes\x12\x11\n\tItemKinds\x18\x02 \x03(\r\"l\n\x16TGetNodeConfigResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12)\n\x06\x43onfig\x18\x02 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\"\\\n\x0bTSubscriber\x12\x12\n\x08TabletId\x18\x01 \x01(\x04H\x00\x12+\n\tServiceId\x18\x02 \x01(\x0b\x32\x16.NActorsProto.TActorIdH\x00\x42\x0c\n\nSubscriber\";\n\tTConfigId\x12.\n\x07ItemIds\x18\x01 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\"\xb0\x01\n\x1aTConfigSubscriptionRequest\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\x30\n\x07Options\x18\x02 \x01(\x0b\x32\x1f.NKikimrConsole.TNodeAttributes\x12\x17\n\x0f\x43onfigItemKinds\x18\x03 \x03(\r\x12\x33\n\x0cKnownVersion\x18\x04 \x01(\x0b\x32\x1d.NKikimrConfig.TConfigVersion\"Z\n\x1bTConfigSubscriptionResponse\x12\x12\n\nGeneration\x18\x01 \x01(\x04\x12\'\n\x06Status\x18\x02 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"S\n\x18TConfigSubscriptionError\x12\'\n\x04\x43ode\x18\x02 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\x0e\n\x06Reason\x18\x03 \x01(\t\"1\n\x1bTConfigSubscriptionCanceled\x12\x12\n\nGeneration\x18\x01 \x01(\x04\"\x86\x01\n\x1fTConfigSubscriptionNotification\x12\r\n\x05Order\x18\x01 \x01(\x04\x12\x12\n\nGeneration\x18\x02 \x01(\x04\x12)\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\x12\x15\n\rAffectedKinds\x18\x04 \x03(\r\"\x97\x01\n\rTSubscription\x12\n\n\x02Id\x18\x01 \x01(\x04\x12/\n\nSubscriber\x18\x02 \x01(\x0b\x32\x1b.NKikimrConsole.TSubscriber\x12\x30\n\x07Options\x18\x03 \x01(\x0b\x32\x1f.NKikimrConsole.TNodeAttributes\x12\x17\n\x0f\x43onfigItemKinds\x18\x04 \x03(\r\"T\n\x1dTAddConfigSubscriptionRequest\x12\x33\n\x0cSubscription\x18\x01 \x01(\x0b\x32\x1d.NKikimrConsole.TSubscription\"a\n\x1eTAddConfigSubscriptionResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x16\n\x0eSubscriptionId\x18\x02 \x01(\x04\"7\n\x1dTGetConfigSubscriptionRequest\x12\x16\n\x0eSubscriptionId\x18\x01 \x01(\x04\"~\n\x1eTGetConfigSubscriptionResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x33\n\x0cSubscription\x18\x02 \x01(\x0b\x32\x1d.NKikimrConsole.TSubscription\"R\n\x1fTListConfigSubscriptionsRequest\x12/\n\nSubscriber\x18\x01 \x01(\x0b\x32\x1b.NKikimrConsole.TSubscriber\"\x81\x01\n TListConfigSubscriptionsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x34\n\rSubscriptions\x18\x02 \x03(\x0b\x32\x1d.NKikimrConsole.TSubscription\":\n TRemoveConfigSubscriptionRequest\x12\x16\n\x0eSubscriptionId\x18\x01 \x01(\x04\"L\n!TRemoveConfigSubscriptionResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"T\n!TRemoveConfigSubscriptionsRequest\x12/\n\nSubscriber\x18\x01 \x01(\x0b\x32\x1b.NKikimrConsole.TSubscriber\"M\n\"TRemoveConfigSubscriptionsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"Y\n\"TReplaceConfigSubscriptionsRequest\x12\x33\n\x0cSubscription\x18\x01 \x01(\x0b\x32\x1d.NKikimrConsole.TSubscription\"f\n#TReplaceConfigSubscriptionsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x16\n\x0eSubscriptionId\x18\x02 \x01(\x04\"\x8c\x01\n\x1aTConfigNotificationRequest\x12\x16\n\x0eSubscriptionId\x18\x01 \x01(\x04\x12+\n\x08\x43onfigId\x18\x02 \x01(\x0b\x32\x19.NKikimrConsole.TConfigId\x12)\n\x06\x43onfig\x18\x03 \x01(\x0b\x32\x19.NKikimrConfig.TAppConfig\"b\n\x1bTConfigNotificationResponse\x12\x16\n\x0eSubscriptionId\x18\x01 \x01(\x04\x12+\n\x08\x43onfigId\x18\x02 \x01(\x0b\x32\x19.NKikimrConsole.TConfigId\"P\n\x1aTCheckConfigUpdatesRequest\x12\x32\n\x0b\x42\x61seItemIds\x18\x01 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\"\xe3\x01\n\x1bTCheckConfigUpdatesResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x31\n\nAddedItems\x18\x02 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\x12\x33\n\x0cRemovedItems\x18\x03 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\x12\x33\n\x0cUpdatedItems\x18\x04 \x03(\x0b\x32\x1d.NKikimrConsole.TConfigItemId\"\x1e\n\x1cTListConfigValidatorsRequest\"d\n\x14TConfigValidatorInfo\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x13\n\x0b\x44\x65scription\x18\x02 \x01(\t\x12\x18\n\x10\x43heckedItemKinds\x18\x03 \x03(\r\x12\x0f\n\x07\x45nabled\x18\x04 \x01(\x08\"\x82\x01\n\x1dTListConfigValidatorsResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\x12\x38\n\nValidators\x18\x02 \x03(\x0b\x32$.NKikimrConsole.TConfigValidatorInfo\">\n\x1dTToggleConfigValidatorRequest\x12\x0c\n\x04Name\x18\x01 \x01(\t\x12\x0f\n\x07\x44isable\x18\x02 \x01(\x08\"I\n\x1eTToggleConfigValidatorResponse\x12\'\n\x06Status\x18\x01 \x01(\x0b\x32\x17.NKikimrConsole.TStatus\"\xba\x05\n\x0eTConfigsConfig\x12V\n\x16UsageScopeRestrictions\x18\x01 \x01(\x0b\x32\x36.NKikimrConsole.TConfigsConfig.TUsageScopeRestrictions\x12L\n\x11ValidationOptions\x18\x02 \x01(\x0b\x32\x31.NKikimrConsole.TConfigsConfig.TValidationOptions\x1a\xda\x01\n\x17TUsageScopeRestrictions\x12$\n\x1c\x41llowedNodeIdUsageScopeKinds\x18\x01 \x03(\r\x12\"\n\x1a\x41llowedHostUsageScopeKinds\x18\x02 \x03(\r\x12$\n\x1c\x41llowedTenantUsageScopeKinds\x18\x03 \x03(\r\x12&\n\x1e\x41llowedNodeTypeUsageScopeKinds\x18\x04 \x03(\r\x12\'\n\x1f\x44isallowedDomainUsageScopeKinds\x18\x05 \x03(\r\x1a\xa4\x02\n\x12TValidationOptions\x12Z\n\x0fValidationLevel\x18\x01 \x01(\x0e\x32 .NKikimrConsole.EValidationLevel:\x1fVALIDATE_TENANTS_AND_NODE_TYPES\x12-\n\x1eMaxConfigChecksPerModification\x18\x02 \x01(\r:\x05\x31\x30\x30\x30\x30\x12-\n\x1f\x46\x61ilOnExceededConfigChecksLimit\x18\x03 \x01(\x08:\x04true\x12\x31\n#EnableValidationOnNodeConfigRequest\x18\x04 \x01(\x08:\x04true\x12!\n\x13TreatWarningAsError\x18\x05 \x01(\x08:\x04true*u\n\x10\x45ValidationLevel\x12\x11\n\rVALIDATE_NONE\x10\x00\x12\x13\n\x0fVALIDATE_DOMAIN\x10\x01\x12\x14\n\x10VALIDATE_TENANTS\x10\x02\x12#\n\x1fVALIDATE_TENANTS_AND_NODE_TYPES\x10\x03\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.console_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _EVALIDATIONLEVEL._serialized_start=8107
  _EVALIDATIONLEVEL._serialized_end=8224
  _TCONFIGITEMID._serialized_start=208
  _TCONFIGITEMID._serialized_end=255
  _TITEMIDS._serialized_start=257
  _TITEMIDS._serialized_end=280
  _TNODEIDS._serialized_start=282
  _TNODEIDS._serialized_end=307
  _THOSTS._serialized_start=309
  _THOSTS._serialized_end=332
  _TTENANTS._serialized_start=334
  _TTENANTS._serialized_end=361
  _TNODETYPES._serialized_start=363
  _TNODETYPES._serialized_end=394
  _TTENANTANDNODETYPE._serialized_start=396
  _TTENANTANDNODETYPE._serialized_end=450
  _TTENANTANDNODETYPES._serialized_start=452
  _TTENANTANDNODETYPES._serialized_end=537
  _TCOOKIES._serialized_start=539
  _TCOOKIES._serialized_end=566
  _TUSAGESCOPE._serialized_start=569
  _TUSAGESCOPE._serialized_end=757
  _TNODEATTRIBUTES._serialized_start=759
  _TNODEATTRIBUTES._serialized_end=840
  _TCONFIGITEM._serialized_start=843
  _TCONFIGITEM._serialized_end=2505
  _TCONFIGITEM_EKIND._serialized_start=1065
  _TCONFIGITEM_EKIND._serialized_end=2431
  _TCONFIGITEM_EMERGESTRATEGY._serialized_start=2433
  _TCONFIGITEM_EMERGESTRATEGY._serialized_end=2505
  _TADDCONFIGITEM._serialized_start=2507
  _TADDCONFIGITEM._serialized_end=2597
  _TREMOVECONFIGITEM._serialized_start=2599
  _TREMOVECONFIGITEM._serialized_end=2671
  _TREMOVECONFIGITEMS._serialized_start=2673
  _TREMOVECONFIGITEMS._serialized_end=2753
  _TMODIFYCONFIGITEM._serialized_start=2755
  _TMODIFYCONFIGITEM._serialized_end=2823
  _TCONFIGUREACTION._serialized_start=2826
  _TCONFIGUREACTION._serialized_end=3102
  _TCONFIGUREREQUEST._serialized_start=3105
  _TCONFIGUREREQUEST._serialized_end=3239
  _TCONFIGURERESPONSE._serialized_start=3242
  _TCONFIGURERESPONSE._serialized_end=3548
  _TCONFIGURERESPONSE_TAFFECTEDCONFIG._serialized_start=3405
  _TCONFIGURERESPONSE_TAFFECTEDCONFIG._serialized_end=3548
  _TGETCONFIGITEMSREQUEST._serialized_start=3551
  _TGETCONFIGITEMSREQUEST._serialized_end=3969
  _TGETCONFIGITEMSRESPONSE._serialized_start=3971
  _TGETCONFIGITEMSRESPONSE._serialized_end=4087
  _TGETNODECONFIGITEMSREQUEST._serialized_start=4089
  _TGETNODECONFIGITEMSREQUEST._serialized_end=4183
  _TGETNODECONFIGITEMSRESPONSE._serialized_start=4185
  _TGETNODECONFIGITEMSRESPONSE._serialized_end=4305
  _TGETNODECONFIGREQUEST._serialized_start=4307
  _TGETNODECONFIGREQUEST._serialized_end=4396
  _TGETNODECONFIGRESPONSE._serialized_start=4398
  _TGETNODECONFIGRESPONSE._serialized_end=4506
  _TSUBSCRIBER._serialized_start=4508
  _TSUBSCRIBER._serialized_end=4600
  _TCONFIGID._serialized_start=4602
  _TCONFIGID._serialized_end=4661
  _TCONFIGSUBSCRIPTIONREQUEST._serialized_start=4664
  _TCONFIGSUBSCRIPTIONREQUEST._serialized_end=4840
  _TCONFIGSUBSCRIPTIONRESPONSE._serialized_start=4842
  _TCONFIGSUBSCRIPTIONRESPONSE._serialized_end=4932
  _TCONFIGSUBSCRIPTIONERROR._serialized_start=4934
  _TCONFIGSUBSCRIPTIONERROR._serialized_end=5017
  _TCONFIGSUBSCRIPTIONCANCELED._serialized_start=5019
  _TCONFIGSUBSCRIPTIONCANCELED._serialized_end=5068
  _TCONFIGSUBSCRIPTIONNOTIFICATION._serialized_start=5071
  _TCONFIGSUBSCRIPTIONNOTIFICATION._serialized_end=5205
  _TSUBSCRIPTION._serialized_start=5208
  _TSUBSCRIPTION._serialized_end=5359
  _TADDCONFIGSUBSCRIPTIONREQUEST._serialized_start=5361
  _TADDCONFIGSUBSCRIPTIONREQUEST._serialized_end=5445
  _TADDCONFIGSUBSCRIPTIONRESPONSE._serialized_start=5447
  _TADDCONFIGSUBSCRIPTIONRESPONSE._serialized_end=5544
  _TGETCONFIGSUBSCRIPTIONREQUEST._serialized_start=5546
  _TGETCONFIGSUBSCRIPTIONREQUEST._serialized_end=5601
  _TGETCONFIGSUBSCRIPTIONRESPONSE._serialized_start=5603
  _TGETCONFIGSUBSCRIPTIONRESPONSE._serialized_end=5729
  _TLISTCONFIGSUBSCRIPTIONSREQUEST._serialized_start=5731
  _TLISTCONFIGSUBSCRIPTIONSREQUEST._serialized_end=5813
  _TLISTCONFIGSUBSCRIPTIONSRESPONSE._serialized_start=5816
  _TLISTCONFIGSUBSCRIPTIONSRESPONSE._serialized_end=5945
  _TREMOVECONFIGSUBSCRIPTIONREQUEST._serialized_start=5947
  _TREMOVECONFIGSUBSCRIPTIONREQUEST._serialized_end=6005
  _TREMOVECONFIGSUBSCRIPTIONRESPONSE._serialized_start=6007
  _TREMOVECONFIGSUBSCRIPTIONRESPONSE._serialized_end=6083
  _TREMOVECONFIGSUBSCRIPTIONSREQUEST._serialized_start=6085
  _TREMOVECONFIGSUBSCRIPTIONSREQUEST._serialized_end=6169
  _TREMOVECONFIGSUBSCRIPTIONSRESPONSE._serialized_start=6171
  _TREMOVECONFIGSUBSCRIPTIONSRESPONSE._serialized_end=6248
  _TREPLACECONFIGSUBSCRIPTIONSREQUEST._serialized_start=6250
  _TREPLACECONFIGSUBSCRIPTIONSREQUEST._serialized_end=6339
  _TREPLACECONFIGSUBSCRIPTIONSRESPONSE._serialized_start=6341
  _TREPLACECONFIGSUBSCRIPTIONSRESPONSE._serialized_end=6443
  _TCONFIGNOTIFICATIONREQUEST._serialized_start=6446
  _TCONFIGNOTIFICATIONREQUEST._serialized_end=6586
  _TCONFIGNOTIFICATIONRESPONSE._serialized_start=6588
  _TCONFIGNOTIFICATIONRESPONSE._serialized_end=6686
  _TCHECKCONFIGUPDATESREQUEST._serialized_start=6688
  _TCHECKCONFIGUPDATESREQUEST._serialized_end=6768
  _TCHECKCONFIGUPDATESRESPONSE._serialized_start=6771
  _TCHECKCONFIGUPDATESRESPONSE._serialized_end=6998
  _TLISTCONFIGVALIDATORSREQUEST._serialized_start=7000
  _TLISTCONFIGVALIDATORSREQUEST._serialized_end=7030
  _TCONFIGVALIDATORINFO._serialized_start=7032
  _TCONFIGVALIDATORINFO._serialized_end=7132
  _TLISTCONFIGVALIDATORSRESPONSE._serialized_start=7135
  _TLISTCONFIGVALIDATORSRESPONSE._serialized_end=7265
  _TTOGGLECONFIGVALIDATORREQUEST._serialized_start=7267
  _TTOGGLECONFIGVALIDATORREQUEST._serialized_end=7329
  _TTOGGLECONFIGVALIDATORRESPONSE._serialized_start=7331
  _TTOGGLECONFIGVALIDATORRESPONSE._serialized_end=7404
  _TCONFIGSCONFIG._serialized_start=7407
  _TCONFIGSCONFIG._serialized_end=8105
  _TCONFIGSCONFIG_TUSAGESCOPERESTRICTIONS._serialized_start=7592
  _TCONFIGSCONFIG_TUSAGESCOPERESTRICTIONS._serialized_end=7810
  _TCONFIGSCONFIG_TVALIDATIONOPTIONS._serialized_start=7813
  _TCONFIGSCONFIG_TVALIDATIONOPTIONS._serialized_end=8105
# @@protoc_insertion_point(module_scope)
