# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: library/cpp/actors/protos/unittests.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)library/cpp/actors/protos/unittests.proto\"6\n\x07TSimple\x12\x0c\n\x04Str1\x18\x01 \x02(\t\x12\x0c\n\x04Str2\x18\x02 \x01(\t\x12\x0f\n\x07Number1\x18\x03 \x01(\x04\"_\n\x0bTBigMessage\x12\x19\n\x07Simples\x18\x01 \x03(\x0b\x32\x08.TSimple\x12\x0f\n\x07ManyStr\x18\x02 \x03(\t\x12\x12\n\nOneMoreStr\x18\x03 \x01(\t\x12\x10\n\x08YANumber\x18\x04 \x01(\x04\"H\n\x13TMessageWithPayload\x12\x0c\n\x04Meta\x18\x01 \x01(\t\x12\x11\n\tPayloadId\x18\x02 \x03(\r\x12\x10\n\x08SomeData\x18\x03 \x03(\x0c\x42\x03\xf8\x01\x01')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'library.cpp.actors.protos.unittests_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\370\001\001'
  _TSIMPLE._serialized_start=45
  _TSIMPLE._serialized_end=99
  _TBIGMESSAGE._serialized_start=101
  _TBIGMESSAGE._serialized_end=196
  _TMESSAGEWITHPAYLOAD._serialized_start=198
  _TMESSAGEWITHPAYLOAD._serialized_end=270
# @@protoc_insertion_point(module_scope)
