# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/blobstorage_controller.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ydb/core/protos/blobstorage_controller.proto\x12\x12NKikimrBlobStorage\"\xb2\x03\n\x0cTTransaction\x12\x42\n\x0cTxInitScheme\x18\x01 \x01(\x0b\x32,.NKikimrBlobStorage.TTransaction.TInitScheme\x12\x44\n\rTxCreatePDisk\x18\x02 \x01(\x0b\x32-.NKikimrBlobStorage.TTransaction.TCreatePDisk\x12N\n\x12TxCreateVDiskSlots\x18\x03 \x01(\x0b\x32\x32.NKikimrBlobStorage.TTransaction.TCreateVDiskSlots\x12\x44\n\rTxCreateGroup\x18\x04 \x01(\x0b\x32-.NKikimrBlobStorage.TTransaction.TCreateGroup\x1a\x1d\n\x0bTInitScheme\x12\x0e\n\x06Script\x18\x01 \x01(\x0c\x1a\x1e\n\x0cTCreatePDisk\x12\x0e\n\x06Script\x18\x01 \x01(\x0c\x1a#\n\x11TCreateVDiskSlots\x12\x0e\n\x06Script\x18\x01 \x01(\x0c\x1a\x1e\n\x0cTCreateGroup\x12\x0e\n\x06Script\x18\x01 \x01(\x0c\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.blobstorage_controller_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TTRANSACTION._serialized_start=69
  _TTRANSACTION._serialized_end=503
  _TTRANSACTION_TINITSCHEME._serialized_start=373
  _TTRANSACTION_TINITSCHEME._serialized_end=402
  _TTRANSACTION_TCREATEPDISK._serialized_start=404
  _TTRANSACTION_TCREATEPDISK._serialized_end=434
  _TTRANSACTION_TCREATEVDISKSLOTS._serialized_start=436
  _TTRANSACTION_TCREATEVDISKSLOTS._serialized_end=471
  _TTRANSACTION_TCREATEGROUP._serialized_start=473
  _TTRANSACTION_TCREATEGROUP._serialized_end=503
# @@protoc_insertion_point(module_scope)
