# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/serverless_proxy_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ydb.core.protos import config_pb2 as ydb_dot_core_dot_protos_dot_config__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-ydb/core/protos/serverless_proxy_config.proto\x12\rNKikimrConfig\x1a\x1cydb/core/protos/config.proto\"\x9c\x02\n\x16TServerlessProxyConfig\x12\x33\n\nHttpConfig\x18\x01 \x01(\x0b\x32\x1f.NKikimrConfig.THttpProxyConfig\x12.\n\nGRpcConfig\x18\x02 \x01(\x0b\x32\x1a.NKikimrConfig.TGRpcConfig\x12\x0e\n\x06\x43\x61\x43\x65rt\x18\x03 \x01(\t\x12\x1f\n\x17\x44\x61tabaseServiceEndpoint\x18\x04 \x01(\t\x12,\n DatabaseListRefreshPeriodSeconds\x18\x05 \x01(\r:\x02\x31\x30\x12\x10\n\x08TestMode\x18\x06 \x01(\x08\x12,\n\tLogConfig\x18\x07 \x01(\x0b\x32\x19.NKikimrConfig.TLogConfigB\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.serverless_proxy_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TSERVERLESSPROXYCONFIG._serialized_start=95
  _TSERVERLESSPROXYCONFIG._serialized_end=379
# @@protoc_insertion_point(module_scope)
