# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ydb/core/protos/profiler.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1eydb/core/protos/profiler.proto\x12\x0fNActorsProfiler\"\x1a\n\x08TEvStart\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\".\n\x0eTEvStartResult\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\x12\x0c\n\x04IsOk\x18\x02 \x01(\x08\"\x19\n\x07TEvStop\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\">\n\rTEvStopResult\x12\x0e\n\x06\x43ookie\x18\x01 \x01(\x04\x12\x0f\n\x07Profile\x18\x02 \x01(\t\x12\x0c\n\x04IsOk\x18\x03 \x01(\x08\x42\x18\n\x16ru.yandex.kikimr.proto')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ydb.core.protos.profiler_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026ru.yandex.kikimr.proto'
  _TEVSTART._serialized_start=51
  _TEVSTART._serialized_end=77
  _TEVSTARTRESULT._serialized_start=79
  _TEVSTARTRESULT._serialized_end=125
  _TEVSTOP._serialized_start=127
  _TEVSTOP._serialized_end=152
  _TEVSTOPRESULT._serialized_start=154
  _TEVSTOPRESULT._serialized_end=216
# @@protoc_insertion_point(module_scope)
